(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    566686,      10124]
NotebookOptionsPosition[    566060,      10100]
NotebookOutlinePosition[    566401,      10115]
CellTagsIndexPosition[    566358,      10112]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Exact calculation of the partition function of the two-dimensional \
Ising model on an ",
  FontSize->24],
 StyleBox["n ",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox["\[Times] ",
  FontSize->24],
 StyleBox["m",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox[" square lattice.",
  FontSize->24]
}], "Title",
 CellChangeTimes->{{3.499815298083272*^9, 3.4998153192317953`*^9}, {
  3.499816464925851*^9, 3.499816526755418*^9}, {3.499816581485422*^9, 
  3.499816596858984*^9}, {3.507747534378311*^9, 3.507747534946612*^9}}],

Cell[TextData[{
 "This Mathematica code calculates the exact partition function of the \
two-dimensional Ising model on an ",
 StyleBox["n",
  FontSlant->"Italic"],
 " \[Times] ",
 StyleBox["m",
  FontSlant->"Italic"],
 " square lattice with periodic boundary conditions. Copyright: Paul D. \
Beale,  2010. \n\nThe code is based on:\n \tPaul D. Beale, Phys. Rev. Lett. \
",
 StyleBox["76,",
  FontWeight->"Bold"],
 " 78 (1996),\n  \t\tand Section 13.4.A of \n \tR.K. Pathria and Paul D. \
Beale, ",
 StyleBox["Statistical Mechanics, ",
  FontSlant->"Italic"],
 "Third Edition (Academic, Boston, 2011).\n\nThe user's input parameters are \
two positive integers ",
 StyleBox["n",
  FontSlant->"Italic"],
 " and ",
 StyleBox["m",
  FontSlant->"Italic"],
 " specifying the numbers of rows and columns of the square lattice. The code \
has been tested on lattice sizes up to 128 \[Times] 128.\n \n The code \
calculates:\n     \n    \t z = Sum[g[[q + 1]] x^(2 q), {q, 0, n m}] = \
partition function defined in \n    \t \tPathria and Beale, equations \
13.4.56, and 13.4.57 or 13.4.58\n     \n \tg[[q + 1]] = partition function \
coefficient which gives the number of microconfigurations with \n \t\tenergy \
4qJ above the ground state.\n \t\t\n \tx = Exp[-2K] is the Boltzmann factor \
for a single spin flip where K=J/kT\n    \n \ts[[q + 1]]=Log[g[[q+1]]] = \
microcanonical entropy for energy 4qJ above the ground state. \n \t\tThe \
value of s=-\[Infinity] for some values of q since there are no states with \
that energy.\n     \n \nThis code may be used for noncommercial purposes by \
referencing:\n \tPaul D. Beale, Phys. Rev. Lett. ",
 StyleBox["76,",
  FontWeight->"Bold"],
 " 78 (1996),\n  \t\tand\n \tR.K. Pathria and Paul D. Beale, ",
 StyleBox["Statistical Mechanics, ",
  FontSlant->"Italic"],
 "Third Edition (Academic, Boston, 2011).\n\nThe software is provided AS IS \
without warranty of any kind. \n\nInput ",
 StyleBox["n",
  FontSlant->"Italic"],
 " and ",
 StyleBox["m",
  FontSlant->"Italic"],
 " and evaluate the cell: \n\t",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the number of rows and ",
 StyleBox["m",
  FontSlant->"Italic"],
 " is the number of columns. \n\tThe case ",
 StyleBox["n",
  FontSlant->"Italic"],
 "=1 (or ",
 StyleBox["m",
  FontSlant->"Italic"],
 "=1) gives the one-dimensional Ising model."
}], "Text",
 CellChangeTimes->{{3.4998153375545883`*^9, 3.499815343351676*^9}, {
   3.499815384985073*^9, 3.499815600589108*^9}, {3.499816058215013*^9, 
   3.49981627060695*^9}, {3.4998166233598757`*^9, 3.499816854885539*^9}, {
   3.499816941425351*^9, 3.499817064285905*^9}, {3.499817328308955*^9, 
   3.4998173718189163`*^9}, {3.499817526146172*^9, 3.4998176091524878`*^9}, {
   3.499817720697645*^9, 3.499817744971827*^9}, {3.5010025715531178`*^9, 
   3.5010025796405563`*^9}, 3.507747511205781*^9, 3.507921359531795*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n", " ", "=", " ", "64"}], ";", " ", 
   RowBox[{"m", " ", "=", " ", "64"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ClearAll", "[", 
    RowBox[{
    "acc", ",", "one", ",", "two", ",", "c0", ",", "cn", ",", "s0", ",", "sn",
      ",", "b", ",", "a", ",", "sum", ",", "bm", ",", "csqr", ",", "ssqr", 
     ",", "z1", ",", "z2", ",", "z3", ",", "z4", ",", "z", ",", "g", ",", 
     "kq", ",", "s", ",", "arg", ",", " ", "p", ",", "ntemp", ",", " ", 
     "maxtemp", ",", "u", ",", "c", ",", "plotu", ",", "plotc"}], "]"}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Clear", " ", "variables", " ", "in", " ", "case", " ", "they", " ", "are",
     " ", "being", " ", "used", " ", "by", " ", "the", " ", 
    RowBox[{"user", "."}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"acc", " ", "=", " ", 
   RowBox[{"Floor", "[", 
    RowBox[{
     RowBox[{"n", " ", "m", " ", 
      RowBox[{
       RowBox[{"Log", "[", "2", "]"}], "/", 
       RowBox[{"Log", "[", "10", "]"}]}]}], " ", "+", " ", "50"}], "]"}]}], 
  ";", "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Set", " ", "numerical", " ", "accuracy", " ", "more", " ", "than", " ", 
    "sufficient", " ", "to", " ", "handle", " ", "floating", " ", "point", 
    " ", "numbers", " ", "as", " ", "large", " ", "as", " ", "the", " ", 
    "largest", " ", "coefficients", " ", "which", " ", "are", " ", "on", " ", 
    "the", " ", "order", " ", 
    RowBox[{"2", "^", 
     RowBox[{"(", 
      RowBox[{"n", " ", "m"}], ")"}]}]}], " ", "*)"}], "\n", 
  RowBox[{"one", " ", "=", " ", 
   RowBox[{"SetPrecision", "[", 
    RowBox[{"1", ",", " ", "acc"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"two", " ", "=", " ", 
    RowBox[{"SetPrecision", "[", 
     RowBox[{"2", ",", " ", "acc"}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"See", " ", "equation", " ", 
    RowBox[{"13.4", ".", "XX"}], " ", "for", " ", "factors", " ", "in", " ", 
    "partition", " ", "function"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c0", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"one", " ", "-", " ", 
          RowBox[{"one", " ", "x"}]}], ")"}], "^", "m"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"one", " ", "+", " ", 
            RowBox[{"one", " ", "x"}]}], ")"}]}], ")"}], "^", "m"}]}], ",", 
      " ", "acc"}], "]"}], "]"}]}], ";", " ", 
  RowBox[{"s0", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"one", " ", "-", " ", 
          RowBox[{"one", " ", "x"}]}], ")"}], "^", "m"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"one", " ", "+", " ", 
            RowBox[{"one", " ", "x"}]}], ")"}]}], ")"}], "^", "m"}]}], ",", 
      " ", "acc"}], "]"}], "]"}]}], ";", " ", 
  RowBox[{"cn", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"one", " ", "+", " ", 
          RowBox[{"one", " ", "x"}]}], ")"}], "^", "m"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"one", " ", "-", " ", 
            RowBox[{"one", " ", "x"}]}], ")"}]}], ")"}], "^", "m"}]}], ",", 
      " ", "acc"}], "]"}], "]"}]}], ";", " ", 
  RowBox[{"sn", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"one", " ", "+", " ", 
          RowBox[{"one", " ", "x"}]}], ")"}], "^", "m"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"one", " ", "-", " ", 
            RowBox[{"one", " ", "x"}]}], ")"}]}], ")"}], "^", "m"}]}], ",", 
      " ", "acc"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"two", "  ", "x", " ", 
       RowBox[{"(", 
        RowBox[{"one", " ", "-", " ", 
         RowBox[{"one", " ", 
          RowBox[{"x", "^", "2"}]}]}], ")"}]}], ",", " ", "acc"}], "]"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"one", " ", "+", " ", 
            RowBox[{"one", " ", 
             RowBox[{"x", "^", "2"}]}]}], ")"}], "^", "2"}], " ", "-", " ", 
         RowBox[{"b", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"Pi", " ", 
            RowBox[{"q", "/", "n"}]}], "]"}]}]}], ",", " ", "acc"}], "]"}], 
      "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"q", ",", " ", "1", ",", " ", 
       RowBox[{"n", " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sum", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "\n", "    ", 
      RowBox[{"Sum", "[", "\n", "     ", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"m", "!"}], "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", " ", "j"}], ")"}], "!"}]}], "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"m", " ", "-", " ", 
               RowBox[{"2", " ", "j"}]}], ")"}], "!"}]}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", 
                RowBox[{"[", "q", "]"}], "]"}], "^", "2"}], " ", "-", " ", 
              RowBox[{"b", "^", "2"}]}], ")"}], "^", "j"}], " ", 
           RowBox[{
            RowBox[{"a", "[", 
             RowBox[{"[", "q", "]"}], "]"}], "^", 
            RowBox[{"(", 
             RowBox[{"m", " ", "-", " ", 
              RowBox[{"2", " ", "j"}]}], ")"}]}]}], ",", " ", "acc"}], "]"}], 
        "\n", "     ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"j", ",", " ", "0", ",", " ", 
          RowBox[{"Floor", "[", 
           RowBox[{"m", "/", "2"}], "]"}]}], "}"}]}], "]"}], "]"}], "\n", 
     "   ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"q", ",", " ", "1", ",", " ", 
       RowBox[{"n", " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"bm", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"b", "^", "m"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"csqr", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"sum", " ", "+", " ", "bm"}], ")"}], "/", 
    RowBox[{"two", "^", 
     RowBox[{"(", 
      RowBox[{"m", " ", "-", " ", "1"}], ")"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ssqr", " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"sum", " ", "-", " ", "bm"}], ")"}], "/", 
     RowBox[{"two", "^", 
      RowBox[{"(", 
       RowBox[{"m", " ", "-", " ", "1"}], ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Different", " ", "formulae", " ", "for", " ", "partition", " ", 
    "function", " ", "depending", " ", "on", " ", "if", " ", "the", " ", 
    "number", " ", "of", " ", "rows", " ", "is", " ", "even", " ", "or", " ", 
    
    RowBox[{"odd", "."}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"n", ",", " ", "2"}], "]"}], " ", "==", " ", "0"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"even", " ", "number", " ", "of", " ", "rows"}], " ", "*)"}], 
    "\n", " ", 
    RowBox[{
     RowBox[{"z1", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{"csqr", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"2", " ", "q"}], " ", "+", " ", "1"}], "]"}], "]"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{"q", ",", " ", "0", ",", " ", 
            RowBox[{
             RowBox[{"n", "/", "2"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}], 
        "/", "two"}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z2", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{"ssqr", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"2", " ", "q"}], " ", "+", " ", "1"}], "]"}], "]"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{"q", ",", " ", "0", ",", " ", 
            RowBox[{
             RowBox[{"n", "/", "2"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}], 
        "/", "two"}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z3", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"c0", " ", "cn", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"csqr", "[", 
            RowBox[{"[", 
             RowBox[{"2", " ", "q"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "1", ",", " ", 
             RowBox[{
              RowBox[{"n", "/", "2"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}],
          "/", "two"}]}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z4", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"s0", " ", "sn", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"ssqr", "[", 
            RowBox[{"[", 
             RowBox[{"2", " ", "q"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "1", ",", " ", 
             RowBox[{
              RowBox[{"n", "/", "2"}], " ", "-", " ", "1"}]}], "}"}]}], "]"}],
          "/", "two"}]}], "]"}]}], ";"}], "\n", " ", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"odd", " ", "number", " ", "of", " ", "rows"}], " ", "*)"}], 
    "\n", " ", 
    RowBox[{
     RowBox[{"z1", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"cn", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"csqr", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"2", " ", "q"}], " ", "+", " ", "1"}], "]"}], "]"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "0", ",", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", " ", "-", " ", "3"}], ")"}], "/", "2"}]}], 
            "}"}]}], "]"}], "/", "two"}]}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z2", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"sn", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"ssqr", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"2", " ", "q"}], " ", "+", " ", "1"}], "]"}], "]"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "0", ",", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", " ", "-", " ", "3"}], ")"}], "/", "2"}]}], 
            "}"}]}], "]"}], "/", "two"}]}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z3", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"c0", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"csqr", "[", 
            RowBox[{"[", 
             RowBox[{"2", " ", "q"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "1", ",", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", " ", "-", " ", "1"}], ")"}], "/", "2"}]}], 
            "}"}]}], "]"}], "/", "two"}]}], "]"}]}], ";", "\n", " ", 
     RowBox[{"z4", " ", "=", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{"s0", " ", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"ssqr", "[", 
            RowBox[{"[", 
             RowBox[{"2", " ", "q"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"q", ",", " ", "1", ",", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", " ", "-", " ", "1"}], ")"}], "/", "2"}]}], 
            "}"}]}], "]"}], "/", "two"}]}], "]"}]}], ";"}]}], "\n", " ", 
   "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Calculate", " ", "partition", " ", "function"}], ","}], " ", 
   "*)"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "remove", " ", "zero", " ", "coeffiecients", " ", "and", " ", "make", " ", 
    "the", " ", "rest", " ", "integers"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"z", " ", "=", " ", 
    RowBox[{"Rationalize", "[", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{
       "z1", " ", "+", " ", "z2", " ", "+", " ", "z3", " ", "+", " ", "z4"}], 
       ",", " ", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "20"}], ")"}]}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "solution"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"z", " ", "/.", " ", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"1", " ", "\[NotEqual]", " ", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"n", " ", "m"}], " ", ")"}]}]}]}]}], ",", 
     RowBox[{
     "Print", "[", 
      "\"\<Error in Calculation: sum of g[[q]] not equal to 2^( n m) \>\"", 
      "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"put", " ", "coefficients", " ", "onto", "  ", "Table"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"2", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", " ", "m"}], " ", "+", " ", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"[", 
        RowBox[{"q", " ", "+", " ", "1"}], "]"}], "]"}], " ", "=", " ", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"z", ",", " ", 
        RowBox[{"x", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "q"}], ")"}]}]}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"q", ",", " ", "1", ",", " ", 
       RowBox[{"n", " ", "m"}]}], "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Determine", " ", "the", " ", "microcanoical", " ", "entropy"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"s", " ", "=", " ", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"Log", "[", "g", "]"}], ",", " ", "20"}], "]"}]}], ";"}], "\n", 
  
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "the", " ", "microcanonical", " ", "entropy"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kq", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"q", ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "0", ",", " ", 
       RowBox[{"n", " ", "m"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"splot", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kq", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", 
       RowBox[{"s", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{
        RowBox[{"n", " ", "m"}], " ", "+", " ", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"splot", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<S(q)/Nk\>\""}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "and", " ", "plot", " ", "the", " ", "internal", " ", 
    "energy", " ", "per", " ", "spin", " ", "and", " ", "the", " ", 
    "specific", " ", "heat", " ", "as", " ", "functions", " ", "of", " ", 
    RowBox[{"temperature", "."}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxtemp", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ntemp", "=", 
   RowBox[{
    RowBox[{"(", "100", ")"}], 
    RowBox[{"(", "maxtemp", ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"0.01", " ", "j"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0.0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0.0", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "the", " ", "most", " ", "probable", " ", "energy", " ", 
    "for", " ", "each", " ", "temperature", " ", "to", " ", "maintain", " ", 
    "precision"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"arg", "=", 
      RowBox[{"s", "-", 
       RowBox[{"4", " ", 
        RowBox[{"kq", "/", 
         RowBox[{"temp", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], ";", 
     RowBox[{"maxarg", "=", 
      RowBox[{"Max", "[", "arg", "]"}]}], ";", 
     RowBox[{"p", "=", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"arg", "-", "maxarg"}], "]"}], "/", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"Exp", "[", 
          RowBox[{"arg", "-", "maxarg"}], "]"}]}], "]"}]}]}], ";", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"4", 
        RowBox[{
         RowBox[{"Apply", "[", 
          RowBox[{"Plus", ",", " ", 
           RowBox[{"kq", " ", "p"}]}], "]"}], "/", 
         RowBox[{"(", " ", 
          RowBox[{"n", " ", "m"}], ")"}]}]}], " ", "-", " ", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"16", "/", 
        RowBox[{
         RowBox[{"temp", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "^", "2"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", " ", 
            RowBox[{
             RowBox[{"kq", "^", "2"}], " ", "p"}]}], "]"}], "-", 
          RowBox[{
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", " ", 
             RowBox[{"kq", " ", "p"}]}], "]"}], "^", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"n", " ", "m"}], ")"}]}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotu", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"temp", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", 
       RowBox[{"u", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"plotu", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "maxtemp"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"kT", "/", "J"}], ",", 
      RowBox[{"U", "/", "NJ"}]}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotc", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"temp", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", 
       RowBox[{"c", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "ntemp"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"plotc", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "maxtemp"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kT", "/", "J"}], ",", 
       RowBox[{"C", "/", "Nk"}]}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Print", " ", "the", " ", "microcanonical", " ", 
    RowBox[{"entropy", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Some", " ", "terms", " ", "are"}], " ", "-", 
     RowBox[{"Infinity", " ", "since", " ", 
      RowBox[{"g", "[", 
       RowBox[{"[", "q", "]"}], "]"}]}]}], "=", " ", 
    RowBox[{
    "0", " ", "for", " ", "some", " ", "values", " ", "of", " ", "q"}]}], " ",
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<s=\>\"", ",", "s"}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Suppress", " ", "printing", " ", "the", " ", "partition", " ", "function",
     " ", "and", " ", "coefficients", " ", "for", " ", "large", " ", 
    RowBox[{"(", 
     RowBox[{"n", " ", "m"}], ")"}], " ", "due", " ", "to", " ", "the", " ", 
    "size", " ", "of", " ", "the", " ", 
    RowBox[{"output", "."}]}], " ", "*)"}]}], "\n", 
 RowBox[{"If", " ", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "m"}], " ", "\[LessEqual]", " ", "256"}], ",", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<z=\>\"", ",", "z"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", " ", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "m"}], " ", "\[LessEqual]", " ", "256"}], ",", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g=\>\"", ",", "g"}], "]"}]}], "]"}], "\n"}], "Input",
 CellChangeTimes->{{3.499815634938672*^9, 3.49981565088573*^9}, {
   3.499815688126273*^9, 3.4998158088113422`*^9}, {3.49981584529169*^9, 
   3.499815847906057*^9}, {3.4998158987148314`*^9, 3.499815955273926*^9}, {
   3.49981600960148*^9, 3.499816047092263*^9}, {3.4998163547925653`*^9, 
   3.4998164496606207`*^9}, {3.499817079439653*^9, 3.499817081559256*^9}, {
   3.49981714123678*^9, 3.499817316985929*^9}, {3.49981824119701*^9, 
   3.499818245104959*^9}, {3.499819138435478*^9, 3.499819199788876*^9}, {
   3.499819328792638*^9, 3.4998193402867937`*^9}, 3.499822262460988*^9}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw02HlYjOsfx/FBkZAQopBsWSIUZf2UVLRIRVGYNqLStO817XvN1izZsodK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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"q\"", TraditionalForm], 
    FormBox["\"S(q)/Nk\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0., 4096.}, {0., 2835.0929033605325`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.499820456245132*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdXHuwm8V1/8y9fvAKGBubV8AOIUAABQgvY8CWXxjbQSGEEEDYGMeKnQJR
jEMi8oCoSYgypKA8mmsIFTTVNHCnbW46jTIwlwzKNFXT0dAqzSjpiNa0c5up
2qqtMq2mVTune3bP7l2t9qw+cvVH2jtzdXV39/ud355z9uzZb79v37X38IH9
9+89fHDf3jU3HtqbPXBw34Nrtn34kCiaWBRFiw5EUdReE02K7yC+2h/4cxA/
Br/fJf9MQL/fl8X9Xj86hsrEf9Bpd8QnxC5LUlm304GeRJxvN6rsWo0nuHS7
PYMu+XU70On1B64dVbbR4HWh3ekNtBtVtsJWzwpoVgqoRihM16CLZZ06ZJNZ
KJcLkMpOqy7EK4vWScyV0K4VJWaUiNTfDNZ3oJRJQaFcgkwqB00FEqdMw0Kv
DikBl84XoJAvQr2tLFsvZSFTLEMxk4aywohTdp2EXS5Qi5Aq1EF1qgSpTBHK
xQxky824Za5SQaiykEhBTQruQyUTQabSlpdWcwnIVl6PWTZHvrMCGoJ9vnJU
1rWqFXjlWxmh2Ir8v1vNQ5StwNxMrDIy1KmSW0/5lOhTBZKpMvTmZkRPstBW
F0AiysFc3DKBeo3G7nWg1WxCs9mCWjkLiUwJWp2fQVZYcKatDJ2PElCZey1m
WT86xVVzB4rJFFSl47ZFsyTMdlRv6sUERPlKzLIaqXmlMldu3mmquSTkqsok
3Qb6dQH+KGaZELFewgre7YrQUAH+Wlggkasq2cKfk6JnL30vXlmtC1q5veaU
HFn5Qh6y6aT4noTi9DdFswIQByiK0Zd/6dvxymqdoHIlgyQyUK4iepH89HPx
yoRy1xvMOcgnM6JeiS3UTUNIJr4Ij8UqK6JiTbCBfhtmpnJCu5HQWAVeLSYh
QcMZnQLH4bOFeGWirxq2WszBLEptFiEpmnXrGCeLQESglk/CJ597NFaZ0O6Q
cruW53aE8HmPbIgORPmXYpbVzGDudWm6obpUWQw80cncrLJ0j7zyxZhlHTNx
rRDzRwsKySRgbOrWCkLRswOu+fJsvDLhGPOGg6OQz0xBsz4FqXwNgUWbvPHL
KfTLl1+MV2Y0fKdBF1P3XB0yUYrcsQflFIbXOXkdhtps5bWYZXOa9NGZAkzV
OxK+khUeV6xDq5w2EVZH25hlJhB3GzBdaamq6TTaFfqtsgywkkcbg20OXo9Z
Nmfb7uiM0FcEKUEV+k1Im8A6p4Ls6z+OVzYfgOeV3IPmbEnAp8yYFyNFJQbT
KjHoxi+b94w5mEonVO4QpaEqJ3rKC6bLMi9o2LlCuGwetg+1qSwkk0kJXWoo
yg2dF6RTIuzHLtP5A5o1UaipvjcoLyjM5woxyqKTJNaEmDPbIlHrQLvdiRYp
Xd9DVajrTkcysfLTcNl1GlbEW5rlB/LTN1q2nsowF6VoY9r1sKz/xspMHtvr
Qqc7mO+OKtMq67drYpAL956qaZWtpiq9OsD/5OcO+XUSFwOyT42icJRad9Rl
N8mvi0Veq2bdRCojE9Fi3VhpFV376qtzson4q6691qr4+EMVWXGCLFsiTVVK
ilgzo9K6SiYh6HQcyN3p5yWk+DsIuefu52HD9UfwrwXZkTNrSee8ood5A3ky
9SqKduHHUuqXTDVpWsF8B7OBARKTkNzwlCSB8nbeVDrBoypf2Ym/4u1+lbgs
hLNaTE5KL0MT0a+CXCz8rCVWPVkoloqQTiRwBnMN/OQTPzAGFr//n5X1f5Gz
NvCuHSXbwCYI6kWc+G8gmk3aRoXpFxo3ecB3LKBMEptAdPH1Ew9/z1Qs52ls
2vjUuGkcQ2JED239rORJ4C/+XEV1ghR75eKhK0VPlfAr7f7jINKMTrEAJNdj
jMgrSOR9H/q2DXqqLXJCTyMS+hgSgN3TAuTnZbZ4EZhN7YphMPyxwbDHA2CX
UmcdJco5y0MOf0SPownTscupYzhbWACr/Neq/xSXe3a/MMglQVyciCYFDuBN
2niIM0/nUmrgDJrV/OXg92X5eYldi6bTtbZqZO/UoNAeZRk+QSIdw59mE1rs
EkJzRD4Pk58X2ay2b3vG1AaULgfLpGF1McnFHrtmP20EirgMKdmXId1haskN
R8yVq3nQCe4a+XlBQOTpI0CZDsoWFxqFnMGjTNrUtm7+xiC1tzHU0F9tUIk5
SY0dP5hX3fmG0Jk8ocVBXb2V2riDGSPXKFCPrgy180gZKNBqcBYPuSTI8y0B
nqNAQyo818/zzTzkUpvnxhscnmsYAyNPG3TCzqxZdmuNgc/mCS0LEjo7QGgU
qMfA6KiyxTmG2jkKZQmh4CrSXc2N2jWZ9DA41ggY2Q9ioJzyJJjJ4KZCBgr5
HBRm1FI67ubEBMckpIs3G6prBpn0hS707bZKJgWl1i9i39H3MTluUCdnETHX
f5AYMVF2PAEahRTkqn8V90Y3K9yjBpPkyHjhc0Syj3L3E6HdmJb3Ycs/+WHs
e8MTqueCj6ODM4gVpgbuGFo7aI1ec1re4sJOpafwVkzcW6o1rzWOJ9GuSwpz
qEan2wqx5wLHTfAmVyaVhwYOBzl04t6F9LuJWhoMBTVZeRqRvv228tAsp4Is
jeQ3QaOUAdo/VXfB4t2f4xkNh29hNdVoFTVwEzlBM1Ix2oSkge0odRvLaMG+
reULKidSzbYt3xjSzCp/nZohvUFSL5xd0rekfls1Wsl4CHY7gPsmxkZmXpBp
uxwD51koEuQk2+eGZoOTCdkdw+iyNpRD6CS6zBdoZIvlhtDbeJSTTaMBLu7I
RdBRKEwXZAtWA4EOLifbY3PXL0LWOH8U5LDLo0fLFtyYwAYX8Lin0GWuC5s0
9XjqizP6L3Q9RQO53rs5+bQC4gI+eu+FPMEVAbvKFvMz+9t5lJWDzrKMAcXJ
ZxRKyFnYbC7QwVMDzqITThEChpzlolGQw75gIoleC7iRBJ3lYh53FUPH2GLC
qPkS1z9WD1pAL+TcGICqvIRnoJerPieSLRYZMQke5bSAyj1DE7s3Es2v7f8J
1L2Dhzw9wOS//eQv5dHOMDrpM1pH9Y0CYIz1Xwb8MtfkZ/qZ/megc5fxJM4M
qLLH1IksKVL3h2j9az+ZtZAHs3zZgM6ffaPjP6jO9TgMs5qgjC7jfDbKlzrN
Ly7+nSi5MRB94Z0DlMb4ZBFLiXHKX1B7a1ZRt7aucBiO7aEcH0O9WvRZr0t1
WzY9PRSiAyQX9nBLiKQ7BnAC/jeqc8Mmxvsrh2w9podE5hdZmpo74nG6/Vfj
kFdZRMb6HIVPW2uM2H8JkLMpjfWpA5YSY6R/Dhj3akVS3zH5ZfbsfeFsLYn0
OfY/UZ1vQBAdXwhfS2VDo/kfCc8XAq7h8fRtPDeE4bzUNgZexwOcaxr9A0H5
grcNIK8/lxq76RNORT8P1F3LM3krIx+98O8Ny/U8wHmm0RxBuQ6NWhkF4LEB
ut/fMe63aeNT9LyHF1Lfn/a50N8GXGgkpMeFXg+40PU83vmMC+Flf8PJusF1
iAuM8qm5hm8xGkC3uoFnxe054HB/jercMIEOtoGHvDDgFS1DfyMP8Haujz8l
ZJ/rjsJj+vizQF2Sh7wowOSnHP2Azi421zQZN0HtbXK9gdvbQgv9hMRYI0n5
1GaexiUBJ/pLqnOHEQ6xkZAe1/4x4fmiwBYeLxG47C+4Lm/l8d4R6NafM3Wo
jpGQHhqvBrhvc22rt6t98aLOKfVGntVlnFv+KGD0UXiekYOR+s+YjqJfbleQ
/CppXBsxlxMJXxz6kVHGTUTHvyZawJaML/F6pxH7p0TOF0AGKQ2uiWAhezMs
JY8Zd+0oRX9Cdb7wsmPAjNaKQ5liLDs3VwSU9EOjyp0cEwW50H2bK4ygP2bo
oENpEr61DSxkB8enlysZu6DNfsDU4YS2yyLprntgIbs5PpJXERHn8RRpvKrR
qROLbK8aWAapQT/WvZ2rDYlXAoZ9l2I0jk2cqxnT4HD6PtX58pCbFQVfEL4m
oOSXOSXv4vHWmWtmAzpJWQDy+nXU2BfvX2J6hvPEu3km1wZ69iLXs4Cm1nPX
fDfQ0VtG4Hm6jAarBLr8Hh7yugCT73L0Ayq8nrvmOwFBt47A8/gvdusPA3Xv
dd3lBkY+pjbf4UgHFLfBvsZ+iPD3SZDrRNjR20bgRRO2/VR69QeM0THwvo/H
20iXuZkI5n2/R+2HksXbebyk3V/7mbkX7Ar7Eb9AZ/Wbv0MEpgOs38/jbaLL
3LwVY8HznGLvcF1kM6E4z63K4f8tztwBlW2msqGM+XdJkM8X7+TxtjCesH3b
M1GZqcOxcBcPuZUuc50VmXyTo+8Mkjt4+G2c1p5lVI2DJD0Cz2fL5xi/QQe4
m8e7MXBZiZO12/Wb7YTiPKMr/ea3bA3YwybQy+0xFf9UwHh7FPz8bdPx7ALp
93ZcN0tuOBI9TXXuIEQXvEfREVlgrZiSiAlKqDLTrXHvAu1g9IJB5Ai1H4o8
jm53G8KYV5czGagc7cnv1Znvw/R494h22k5ih9Df5Cr2WPTw5yjk8c1+mSOO
fYNoZ0ydfTWg93sVYeVn6uXtVGoKOuPfKdoVcMOvUZ3PffcZldq5Nr4KWz76
8/HsFGlqroIw3HwlppL3GpqVfB5q8r3Zo5ATCig22uPeR7rZ9j/7Af0n7Qrb
Me819KBdlS+8ypWTMLUUNt49pZsDOrNnm98I6H0/EZ6gxvI4Ee/yaiHbTSkq
sxxPMX2CqLneih6ZUdR8U8S76TI3g8Ck8EvUfmjicjzpAzz8LQTvzmg4szzO
mX7/KDz/jGZPil8gufjWhRtBDljwEv09BGql/95+fp6xPqZNB3nOt9Jlbm6A
lnmM2ltWU6I/xOO9l+kbmuxzga7YjnyAh7/NNov97s9nArq3zRdQxW1U5htn
NsSj1EX33jWa7z4e/n0xe//pgAbv5+FvpzLLkAr+EcbCgn70gIUn4d4f8KJP
kYSh0e14YkAHdxC8O+IwRH2C2vsGtD16Ajq4I+AEtrN8LGa7B3hRdwbY2lPI
Q4yzYI8/wsPrQ6h8uraVcZjg8VFy116HePg05yyOKQ8x7oC3Yh7k4e+mMitu
K/gHuYrDFpjE2k2S3VGAkj8SYG+PpIAC9hC8gBvS24cDurfjQEAB9zBWR/j7
qb0vDtiec3gUvN9/7Vf5DgZE2X7+UV7UXirzBUX0Ct3ug9TONx7Q2rrdQ7yo
e2NC7I9J6WOWKClpX0wB+2IK+Djflw8ENG+L0ur1UbItmeNFaXX43NUWtScg
yn4T5WElatwvb2Vi0tSxY5RG1HTBrbXHvLv4wZjk74pJ/pOG/PC6uwrt8e5D
HgiQt91Zz54+n7XJf4rI611Bsyof4/6kjlw+zjaX22O2U0nVvLPqhblx4IXu
ZYYI26NLJ5lDObVD+BHjIcPr9N64dz1/LWB5nCF1u1upnW/itT3pUUN+ePXe
Hfdu6H1UZo85/frG8HbOhJ3LeMfwZ4j8Uv/aHjVZyogrRWl0/BvZKY187HU2
YM81vnf29U0AK9Ez7NEcul2e2A8u9PXL2QvZY32Ayuykw3cKw86Y7X5dMfVN
aVkqs7Izr6n0YSA+09uZ2md5UTqXtPJM7zkXN1I72/W1KDvn/JwlSko6FLjQ
NvCWABF7DD7G90Vn1/YwnvCozbcv5TsJ4gu8qI9SmbWz4VXbhkDvbWco8KIe
8ijGd5qGPrPMpuRT9Bd5UXpdaAdx38u666idHcR97R7nReUCbO1eXRWz3Zd4
UQ9Tmb3o8m0DX07t7AA54bHpE5YoKUmv3G1/0gJsf9JP79nq1e3sGPYk3xd9
D8LXF9vFL6J2dmSY9PTly7yoR6jMDkI+Ued7RC32BKGv8KIeDUDY/nSuR4GL
PZS+xovKeyCWeEbJ2dTOHnWLPTb9Oi/qswFRtg1O99h0iUfUEV7U56nM9sBl
njCznNrZc9MyjwKftkRJSQWPOo7zuO5SD5HjPep9hu/L41Rmj/izPCP+WR7i
CSqzo+6pnrnkd3iIr1KZHeJ0R2yXfJ6HkJ+p8dTL757D2hfy/RSSaZ+dKevp
qRr1lje+O92F2XIFKI+2Do58BarlMrRwrdZrwfQMvYtPDw4dq/GHDr08AWbz
aToOFtxDJUUuX4N0qghtPFxYrKxaJJdUoVxsNcxVcoCHnBbLJcilEpCbVlkI
HvGcyKrjcz0HT8ryuUpW0G9Cs5SFKXmaqejiVFbizTQ6RHMZzBZyUBU5YaWQ
FsvpPNQbdCRsYcaoI2nTWgXVfAZmjlKK2ULxGcB/m6W0EIkUvWdXyu/yrGQ8
6PboNKTpZFTo1SBXrCtGS2FuNi8g5YHA8sDhdLEqWOI6clYpf7NN5xzotrWS
56CcxaNh1QHAdbFGVadDe8+9VNd0ZsWKMK8Mkc6r/L9ThVxBna+NB+SidpPC
SKjYbkNpO6KTpm0+6inHs6HT0Cu3JMy01HJSqqakblJ4jtQ0qknQGcD1YgbK
6HXIBQ/nFS6CB+0mBK92swI1PGy5XoRkdgqmcgXxf39YNWuh35pW9HPTMNef
98MeijJHiA8dAKk0U83J062lGlolyCAN4bf54oxQs1JBW9KeIToF0b4hD4tP
RCkozjTknaJhDzoWujVh4kSJ3KsJ+WyZboe09VnSZofdOr8Q3VqsMa2nbkGs
OdOCR79BKk+DsWx1Sp7Uji6UzCtP22rTwLMvm5AT4rKFAmRT8hjk+fsH3QYU
ciV5XPL8+qkP1ak8TDf1muo4MRj2wCP5/dJj9anB/U5d4AprZb8OU8Ij9RHA
W21HmZRwHTpCt9/v6wDZsw5stI0qv1Ngixb9L+srIZ4=\
\>"]],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxd1XdYk2cXBvAkkDASggMVlQpixYGts7iw5ygORKs46mhBaT+pCwUVFziq
omhdKLaCWtsqUieiVUEUcACO4kCkIlWBTEhCJjOLj3He9Lp8/+G6SfI8z7l/
D6H395GzwzksFiuBzWK1/ox1S5tSGRMHrPbnXns+ZsuZvXYrZ2We/uj1FFs+
kdz6XPjo/Wm2rJrV+ptrH33+hi07vzkbNc4546P1btvygJDDD+r63/1o/Rxb
Tmn59Juz9z7a774tD297Hn60f54tP6zr37JD/kfneWTLs9s2fPzR+Z7YcmVM
64JPobn9yW0/byEYKa9pPV7UM5BQbj//c9hLuX2ZlzDK2p7b53kJsqb2HNi2
QRHUqNpz+3xFIHjSnlt3Czn8Cl5GtOf2eYuh5FDbgrlt47wphqXHzW25ff7X
EBHa2JY9W4/TqwSu3NK05fY+SsCc/6EtL/2h9fkHgpU5bbm9nzfAG767Lbeu
5pb2Bh718GrL7X2VQp8t0a0HyK1vXa6uFE4sXWhpze39vQX5raOm1vxl24Jl
AD2fth4ot73PMlgYsae2Nbcdb/e/MLfZS/1fv+8gvCiztdLcZ4WtzztwWtjn
zX99v4dlb8setuYubQf8AIN7Kc7/1/8HqDtSsqs1ty0XUg6mKztm/edRAXYv
ugr/m6cCtPGiG1abTwXMOu6HVtt8FbAkfdIFi82rErbMtsrNtnkr4bBerDfZ
/CpBdV+WY7TNL4Kfvx8DTTZPEaS89w1vsPUhgtqhDZ51Nl8xVBadCtHb+hHD
b+EZXI3NWwy9+s62U9r6ksBd93tjZDZ/Ceh+ij5UYetPAimad+/f2u6DFPy2
+3Nf2fqUwu67+94/tt0PKYi6zPDPsfUrg6gn8YZrtvsig36fHyo6a+tbBl1i
G39PtN0fOSR4xvffYetfDl0zXX0jbPdJDj3PrVw61+ZRBZ0ClieNtnlUwbzs
3OieNo8qOBzFvdpkZTyqIL3wfF2xlfGohj1nlPoLVsajGqLyK6bHWhmPargp
W3luipXxUMAvBwNOCFtyQpuHAhoFdXkvLIyHAnrMU2T9ZGE8lLBxzxoXsDAe
ShgoLJiqMjMeSrg9rWfTETPjoQLl5vO/DzYzHirYVXjzfp6J8VABO/ni22AT
41ED3ZZ7fF9sZDxq4NuSDy+nGRmPGtjm4JZ0u4nxUMOmvHE+Hk2Mhxp8K2bI
1jYyHmoYb7kL2Q2Mhwb8th79xVjPeGjAsPvHaQPrGQ8NnLDT3ZlWx3ho4dAh
9wmLapl5tGDn6fjFdwbGRwslm3Kq5uiZ+bRwauzotC90jJcWRsftLuZqmXm1
ECp8efahmvHTQnp+9NLVNcz8OgjNcFnCVTGeOij/ese7eAXThw7eszt0rKti
fHWg+zsMpsuZfnSg+t/BMwekjLcOBvp+tu6mmOlLD7ywxfL8SsZfDzELXw/L
Lmf608OXT0v2nHjP/H3qYbPdjE6h/zJ96mHv4Ods+7fM/dDD6a2J2w/9w/Rr
gLiR+/8yFTP3xQCKrK8fBhUxfbfkmYGvYp4z98cAB/5Zxd7/N9O/AXpO2hMZ
85i5Twb4TGc/OjCf8aiFvr+6bDLcZzxqoSAgamJsDuNRC8tOnv3rQxbjUQui
qTmlHhmMRy30frA6b8RfjEctlD3UxfW9ynjUwuL1Dj7qi4xHHXRwlacfTGU8
6mCO69BBdmcYjzqYVFN+8qtfGY86SICR7IgkxqMOOk6/9k1oIuNRByaD4qzX
IcajHnw0B0tu7GU86qFX4Gip+y7Gox5mOS3Ln7aV8aiH1c7zwqdvZDzqYd/f
ovTuaxiPeugdtDbh+grGowGmZ/1d1WUJ49EAFwX1JyaEMh4NsKNfp7iR8xiP
BojIGLbVMIPxaHl989Bv109hPFrW+7BDfQcYj0YYKmLZFYxkPBohtfb+4qOD
GY9GWJpXWuDZj/FohB4PPesiejEejVD+uemPTV0Yj0Z4u9J9+3gB49EIlrUD
RhVwGI8m6N/11Fpuk5U8muBu8fRnFrWVPJoguWZExRWJlTyaYGpUZ3+3Mit5
NMHmFx1WDH5hJY8mCL4RorQ8tJKHEU4n5I/almklDyMc2D71QdplK3kY4aT2
N/XB3630fWmE+gN3evQ4ZiUPI6zIDEieFW8lDyPsara/PizGSh4mMF6b/8ed
CCt5mGDH69jjikVW8jDBkm3VGdnBVvIwQfavx9yHT7CShwnmsPrcDxxuJQ8T
3FzU+aK5j5U8zDCJ8/rOdDcreZhhwvpHz/zsreRhBv8tX5zLNFjIwwwR3/vU
vhBZyMMMY5b4LIgpspCHGdLuqhfczLWQhxmS9up+2HbFQh4WyJ2b//bVCQt5
WGBeboT6aryFPCyws9uG/E7RFvKwQP1sdVjjYgt5WKCW530mdJqFPCyQMdVn
CvhZyMMKHTZ4VyV7WcjDCoE3Z9cud7aQhxViFLfTLhnM5GEFh86bBn77zkwe
VvANyZwcnWcmDyuYTP0u6i+ZyaMZovwk2UVHzeTRDOZ7T/8UbDaTRzMUFXae
eHqRmTyawXGYe68dAWbyaIbMKV7LrvYzk0czeBzvoPfmm8mDhdLF93qV1Jho
HhZyJmW9yXlhIh8Wbr7pvr003UTzsXBBpkd59yMm8mLh60But5goU27buD+w
8JPog3GaGSbyY6Gv71cXIgeZ6PuBhZ38WXyNo4k8WRgcvMLlO4mR+mDhxfl9
8zJyjOTLwrWizlni40bqh4X/dgy9VBxpJG8WTrn8+2fRk43UFxvHLfLHqz2N
5M9Gr/gzd1Zqmqg/Nk7YPO7ogftNdB/Y6OLm/lxzpIn6ZOPrcXzfVWFNdD/Y
2Ogz2OP1oCbql43K1Gn1VfWNdF/Y+FiSqgrLaaS+2RhzaO+tdzsb6f6wMe/p
pnhRQCP1z8b/PU+NLGM10n1i48nVxhVdbjeQBwf57yvk6pUN5MHBCIdw757d
G8iDg4WL9z/3vF9PHhy0vjE43wmvJw8Ofl4cuuKpUz3dPw7CrwHx29PryIOD
cXtGhM4NqSMPDgbtPfjHRmEdeXBwYmrvoaqCWvLgYOgTay13dy15cDBYuUj/
YUoteXDQrzKqwylhLXlw8IvAn5/ElxrIww6jBFu/63LOQB52uNPwrKBsnYE8
7HDQ+MgteycayMMOta/PrBZ1NZCHHf74nTwiS6EnDzuM7yb1VeXqycMO09mW
Td/8oicPO1RdCA6qWaUnDzs8ppQvTZisJw873MebunWYl5487DBNUbomz6gj
Dzv8y8dfN+ofHXnYY+Sk9W5x13XkYY9xyQd7nzysIw97FMkM30Sv0pGHPT4P
a3jLm64jD3v8JhbWBPnqyMMel3Ty+HkkX0ce9phmHhL4SKklD3t88SqKbyjU
koc9ZvX/8+WNNC15tOwn4Wl4R7TkYY9jcr7uLlmnJQ977BOz9Osp87XkYY+N
WVdqfcdqyYOLHovTDh701JIHF7t4+dcvtdeSBxe9s85vWV2sIQ8uRmvc5mtO
a8iDi6JHZcunrdSQBxfnpqVZY0dpyIOLUQEjbsTwNOTBxYnnmzaOL1GTBxe3
uXB2PE1RkwcXvUzPgzqsV5MHFze5lSW4TFaTBxfreeuCsrupyYOHR7X1qT0U
NeTBwzHy+c69s2vIg4ePo1VOhQk15MHDU2+2L+8WXkMePDz91yn35tE15NGS
kwVDtrvWkAcPUyLjNYlSFXnw0D340J3Rd1XkwUOzflXPVYkq8uCh6pPwjIEr
VeTBQ0mDcl5kgIo8eDg7snv5SA8VefBQO/DTWTvqlOThgBXZ5seBL5Tk4YCT
OzbH7r+gJA8HXNDvdsbkOCV5OOCwn/IrNi5WkocDvirPWOMxVkkeDvgUexiH
dlOShwOmucZ8csugIA8HXOS762jqSwV5OODcqP7e7DQFeTjghmOlqQ/3K8jD
AWdszeGrlivIwwEVAYLpmwIV5OGI6gHBa3/opyAPRywtfnX8Bk9BHo6Y098q
DpNVk4cjWicV7l9eUE0ejhjF+rKoMLWaPBwxa30pZ198NXk44jD/AbGnllXT
/09H/LEg+HduUDV5OGJh0lHxA99q8nBEWa3i3iuXavJwxNXnL+QM11aRhyN2
uNpxleRVFXm0vH+xJVx8s4o8nHCRaM/0wclV5OGE2y7dKCzYUkUeTsh5MuDk
+bAq8nDCFQ/fRhdPrCIPJxwjye01eUAVeTjhgvTk8GaXKvJwQq8VKZ9Y9XLy
cMKkNaHe40vl5OGECd9OmvcoW04eLZ8/ee7M4bNy8mjZ79SChqR9cvJwQhx0
LEgUKScPZ/ToeitpxTw5eThjp9edJEPGycnDGf3HFowY8amcPJxxm9OepHV8
OXk4Y8q4Dd5qvYw8nDGuT7PiTJmMPJzRpznF9cgDGXk44+yAyusZF2Xk4YyP
0WLqkigjD2dM91d3vRQrIw9nPPp+2IgNS2Tk4YxYfm3vhq9k5OGMO63JX13y
k5EHH4e4Btzr7CUjDz5e/ryD91UnGXnw8SJvTuYWg5Q8+Pi525DC2PdS8uDj
Hvmui5ceScmDj6NmPznLvy4lDz4e2MwSnDwlJQ8+Sh78MmZhvJQ8+Pj0yMyf
Jq2Vkgcf/Z5/tnBxqJQ8+C1/T4scUwOl5MHHPB9vs/sIKXkIsGvmnZMZnlLy
EKDPpYWzdvCl5CHAlFP2P61vkJCHABckHriZKJaQhwDdhmyc/O8LCXkI8Pwq
9bVpdyXkIcBvVFcjJecl5CHAwAfmppSfJeQhwNLCfc8O7JSQhwC3bY1afjJS
Qh4CjPjEa+bLEAl5CJAXN5PjGyQhDwHOGKtxvDRSQh4uKBJ6KGf2lZCHC3Zi
dxrevbOEPFww6YznKh5bQh4umPkkuV83jZg8XDAh5YU+6L2YPFww8NPmsD/+
FpOHC87NnsrrkSUmj5b1Yy5sunFeTB4uKAmRzYw6LiYPF+zqeqDvV3vE5OGC
J96WHwtaLyaPliz9Z8yyJWLyEKL+vuDWuTli8hDiZd+sVE6AmDyE+Ljr5bRt
w8TkIcTMujFrunuLyUOInHETEl91FJOHEL/v7X7nAltMHkLEQ7sTTutE5CFE
9zk5d9MrReQhxLDdCxXlRSLyEKKqS1C+7wMReQgx7fgbY+J1EXkI8YTf8dHu
Z0XkIUTFuyVDMxNF5OGKCbtDEtfFicjDFQVZxR2D1ovIwxWfjpkTNvYHEXm4
YvDLhOFT5ovIwxX9Ji4fvypQRB6uePnHMrwyWkQerhhSYqnm+YrIwxXXhnHq
N3uIyMMVzSf6efKEIvJwxV4OmV6XmivJwxWzmu0ylukqycMV1X+G/PaluJI8
OqC2SZg0qKQy9/97KP7f
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     FractionBox["kT", "J"], TraditionalForm], 
    FormBox[
     FractionBox["U", "NJ"], TraditionalForm]},
  PlotRange->{{0, 4}, {-2, 0}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.499820515721115*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw113lczN0XB/Bpapq2KT8kSRIePHikZImac+zJGiraLMlSooUs2aV4smav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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     FractionBox["kT", "J"], TraditionalForm], 
    FormBox[
     FractionBox["C", "Nk"], TraditionalForm]},
  PlotRange->{{0, 4}, {0, 3}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.499820515792137*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"s=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.6931471805599453094172321214581765680747545421319511512698`20.", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", 
     "9.01091334727928902242401757895629538498`20.", ",", 
     "9.70406052783923433184124970041447195306`20.", ",", 
     "16.63772718860587230922249302056606775384`20.", ",", 
     "18.023290466471560252303674828128326441`20.", ",", 
     "23.86417587765481876896346676120164231107`20.", ",", 
     "25.65156724481855300618993681670909524422`20.", ",", 
     "30.81085525106772533672560132434387462692`20.", ",", 
     "32.87753724949052630659269662118730131152`20.", ",", 
     "37.54490675573525890194924261583290920796`20.", ",", 
     "39.81992822973490434214829128387814889337`20.", ",", 
     "44.10939793077697670403350818623262317125`20.", ",", 
     "46.54419057453375856620456678161567865093`20.", ",", 
     "50.53424031449418162021265516944723300253`20.", ",", 
     "53.09200972912564907672296030903008322075`20.", ",", 
     "56.84117774459522201669589154941110021565`20.", ",", 
     "59.49235481866828529841804469739326708057`20.", ",", 
     "63.04642318348171881828544632350204864657`20.", ",", 
     "65.76656157706440482223039025356865262752`20.", ",", 
     "69.16224113115691242712663215947960087315`20.", ",", 
     "71.930998149113428787889283790150398007`20.", ",", 
     "75.19801044019067104904056927858320998581`20.", ",", 
     "77.99859857700147786848219213943922302444`20.", ",", 
     "81.1609981097789586351847651112700453536`20.", ",", 
     "83.97980932920735262155754850572007502976`20.", ",", 
     "87.05694327944009360555970098281918285205`20.", ",", 
     "89.88320805984141096998830194535322447649`20.", ",", 
     "92.8904964982917440580201855284772312736`20.", ",", 
     "95.7159284879343532506728223864047965033`20.", ",", 
     "98.66554100251522495102705805527657297781`20.", ",", 
     "101.483964965925251794856546168673610236`20.", ",", 
     "104.38541863323189583395266055705996691883`20.", ",", 
     "107.19239903835284370177075246681655660431`20.", ",", 
     "110.0530822381286510073311443218033172838`20.", ",", 
     "112.84557315711044748557371527298738057378`20.", ",", 
     "115.67119469103361348755334617109647707464`20.", ",", 
     "118.44722696919707397055778435006281215177`20.", ",", 
     "121.24219145481355600723421239329219187347`20.", ",", 
     "124.00060592489511872545499472635904882276`20.", ",", 
     "126.76831968468851292253967639986856066385`20.", ",", 
     "129.50854862875705689401932933498652411158`20.", ",", 
     "132.25166308652965293336001446889964903888`20.", ",", 
     "134.97355739377622465915586383386365805622`20.", ",", 
     "137.69415861480481300460190739227780585111`20.", ",", 
     "140.3978552846181808583204639293528508277`20.", ",", 
     "143.09760876670984967019546806442162287969`20.", ",", 
     "145.78343220476210622816892885687790510912`20.", ",", 
     "148.46369163392333991161450397625873653129`20.", ",", 
     "151.13208209296910168366068771009469357945`20.", ",", 
     "153.79396985462516526593719249726118473941`20.", ",", 
     "156.44543293377904511044203403661550684507`20.", ",", 
     "159.08989900051232893052549502240004924368`20.", ",", 
     "161.72497099635582466609467911778906352276`20.", ",", 
     "164.35283559778969260652721903771780544424`20.", ",", 
     "166.97206046894998421464843676939092947903`20.", ",", 
     "169.58404481441575298837803528319321370732`20.", ",", 
     "172.18795944185023198752735543763212863539`20.", ",", 
     "174.78470777751222699328297072659440137817`20.", ",", 
     "177.37383300645954795317740367206740684777`20.", ",", 
     "179.95592846919329752447977880907439220689`20.", ",", 
     "182.53076408078475441466985847791898997674`20.", ",", 
     "185.09874015836406295534721499943795406564`20.", ",", 
     "187.65976244084424545959200057764509497365`20.", ",", 
     "190.21411134440470207317998191188383256649`20.", ",", 
     "192.76177233118156319767062425953906886815`20.", ",", 
     "195.30295120776148696505025695558727127165`20.", ",", 
     "197.83767894300531187764654968850194398136`20.", ",", 
     "200.36611457850691162474538254385563318875`20.", ",", 
     "202.88831398224609730418990617013935879959`20.", ",", 
     "205.40440644567160023345315894488452221639`20.", ",", 
     "207.9144604987711191426314458275868118663`20.", ",", 
     "210.41858603767986385212825906915272835219`20.", ",", 
     "212.916857109089060862818054659110201151`20.", ",", 
     "215.40937050821539625835138685506398031784`20.", ",", 
     "217.89620171545073794751154617951853675659`20.", ",", 
     "220.37743826315178228434410992840289801236`20.", ",", 
     "222.8531548020822550497886073480276496345`20.", ",", 
     "225.32343196361136918455467777092888404315`20.", ",", 
     "227.78834237259028661187157414358225280749`20.", ",", 
     "230.24796123844028350991135924459406945171`20.", ",", 
     "232.70235857995954798308400350138776484967`20.", ",", 
     "235.15160513692534986409306761302926294858`20.", ",", 
     "237.59576809095915496206102232319463194844`20.", ",", 
     "240.03491434980290287425438648070144519316`20.", ",", 
     "242.46910821939457844368051979122224640046`20.", ",", 
     "244.89841322377131767027607060302768873248`20.", ",", 
     "247.32289085690177120750233698415881105049`20.", ",", 
     "249.74260159197658070004442944892795282047`20.", ",", 
     "252.15760422545477526473330228745006860923`20.", ",", 
     "254.56795644038378857182121980512743314105`20.", ",", 
     "256.97371447214011787041219644192237209914`20.", ",", 
     "259.37493342762096019719147407365520550412`20.", ",", 
     "261.77166712381843764798145635499351450464`20.", ",", 
     "264.16396827379849659516751201970676627251`20.", ",", 
     "266.55188841688531380593456202113607478173`20.", ",", 
     "268.93547803196296941145937363435692778523`20.", ",", 
     "271.31478651534219385722642680395254222823`20.", ",", 
     "273.68986225422218779978192127567918925844`20.", ",", 
     "276.06075262870862214837784184231359588752`20.", ",", 
     "278.42750406315917957757603157288922049789`20.", ",", 
     "280.79016203988462731120144717586511141618`20.", ",", 
     "283.14877113791368945370719518829434294222`20.", ",", 
     "285.5033750518587286603649520912957508766`20.", ",", 
     "287.85401662322928638838288800271072425529`20.", ",", 
     "290.20073786111537998327260880894699957461`20.", ",", 
     "292.54357996882189581233453016253534234133`20.", ",", 
     "294.88258336469673316035252169667606560873`20.", ",", 
     "297.21778770560321791372265262858387312136`20.", ",", 
     "299.54923190709431803768835420243609657215`20.", ",", 
     "301.87695416457387250775122444435441442022`20.", ",", 
     "304.20099197246803504283794950212229223553`20.", ",", 
     "306.52138214357210717135418251975857658093`20.", ",", 
     "308.83816082709760473966381651476007313877`20.", ",", 
     "311.15136352651231397093703197231580938261`20.", ",", 
     "313.46102511645283402396114772745715812332`20.", ",", 
     "315.76717985926292619476877786283907955319`20.", ",", 
     "318.06986142081335975609017458664535312292`20.", ",", 
     "320.36910288588651132121968610813345683425`20.", ",", 
     "322.66493677296721460774277327730946069614`20.", ",", 
     "324.95739504858833391114199979506025839203`20.", ",", 
     "327.24650914116328597871397558019704731579`20.", ",", 
     "329.53230995438673343598178956453887724263`20.", ",", 
     "331.81482788017928245750017409599609783708`20.", ",", 
     "334.09409281122369236759259118230730010755`20.", ",", 
     "336.37013415308888189205124174427717529669`20.", ",", 
     "338.64298083597210675316758990728011382135`20.", ",", 
     "340.91266132606477792533653428183955387638`20.", ",", 
     "343.17920363656334411727797027320719912431`20.", ",", 
     "345.44263533833447925732857130169175739087`20.", ",", 
     "347.7029835702510899348898264823672681281`20.", ",", 
     "349.96027504920960186332288460464735830314`20.", ",", 
     "352.21453607984214436971627503246201289557`20.", ",", 
     "354.46579256393414170721170995428905849036`20.", ",", 
     "356.71407000955905480940508806046701025479`20.", ",", 
     "358.95939353994032641013383832162772210672`20.", ",", 
     "361.20178790205093373104759986227599121376`20.", ",", 
     "363.4412774749599528537362052895365836384`20.", ",", 
     "365.67788627793549785062166508766678676213`20.", ",", 
     "367.91163797831274113201926742789344602841`20.", ",", 
     "370.14255589913551721360843386880159377184`20.", ",", 
     "372.37066302657953360677591365680902833434`20.", ",", 
     "374.59598201716495026575357787351984532896`20.", ",", 
     "376.81853520476570943062377763931686976882`20.", ",", 
     "379.03834460742272451737638669922202908485`20.", ",", 
     "381.25543193396771748848250874315393935278`20.", ",", 
     "383.46981859046423015830368596119495883582`20.", ",", 
     "385.68152568647205670356361520595402540914`20.", ",", 
     "387.89057404114109765804777677645655800363`20.", ",", 
     "390.09698418914038825548281265566732507086`20.", ",", 
     "392.30077638642782622295345022964136162213`20.", ",", 
     "394.50197061586590156028304935321460174536`20.", ",", 
     "396.70058659268852215540630249131874667221`20.", ",", 
     "398.89664376982382757724570006028785234888`20.", ",", 
     "401.09016134307769266341932676712175118017`20.", ",", 
     "403.28115825618243937430000512548789206258`20.", ",", 
     "405.46965320571510118673087712041023229592`20.", ",", 
     "407.65566464588941742649979347212289895688`20.", ",", 
     "409.83921079322557578938469082980140764749`20.", ",", 
     "412.02030963110156897554001568951412777063`20.", ",", 
     "414.19897891418988585668107342176617723542`20.", ",", 
     "416.375236172783118347600810186272404256`20.", ",", 
     "418.54909871701193199988482896696170968215`20.", ",", 
     "420.72058364095872087997079704855742955779`20.", ",", 
     "422.88970782667014532063678467860353021896`20.", ",", 
     "425.05648794807163433654552339029097155083`20.", ",", 
     "427.22094047478682264783134824847271466812`20.", ",", 
     "429.38308167586478510526966424910772416812`20.", ",", 
     "431.54292762341782864374992225652206207868`20.", ",", 
     "433.70049419617250348720589155377128852756`20.", ",", 
     "435.85579708293640099164646849762475695862`20.", ",", 
     "438.00885178598321504949590198488736799464`20.", ",", 
     "440.15967362435845720957427394799100884632`20.", ",", 
     "442.30827773710813242007947016449745736744`20.", ",", 
     "444.45467908643260241539960609699435531361`20.", ",", 
     "446.59889246076778708689793193507257310689`20.", ",", 
     "448.740932477795780557234160432002170651`20.", ",", 
     "450.88081358738688797840388260987338221692`20.", ",", 
     "453.01855007447502116400602474674700328587`20.", ",", 
     "455.15415606186832592117669458932437348032`20.", ",", 
     "457.28764551299685124847619763292438563785`20.", ",", 
     "459.4190322345990102999149496916437053529`20.", ",", 
     "461.54832987934852507504415820615028077203`20.", ",", 
     "463.67555194842349107865079794822684456152`20.", ",", 
     "465.80071179401914460414174685215713844858`20.", ",", 
     "467.92382262180586373994630027554337218142`20.", ",", 
     "470.04489749333388459046093865119999562301`20.", ",", 
     "472.16394932838616645868204613857037608056`20.", ",", 
     "474.28099090728079377721009118073479475801`20.", ",", 
     "476.39603487312425832204333275463617189021`20.", ",", 
     "478.5090937340169226273878145167924975652`20.", ",", 
     "480.62017986521192447087568095391697968456`20.", ",", 
     "482.72930551122874275161734881466791055689`20.", ",", 
     "484.83648278792260697598684400373834091253`20.", ",", 
     "486.94172368451089583842881704280802388866`20.", ",", 
     "489.04504006555763498010898645514665565168`20.", ",", 
     "491.14644367291716987274864320343948707078`20.", ",", 
     "493.24594612763805685680991626643326246539`20.", ",", 
     "495.34355893182818361300783467234073121768`20.", ",", 
     "497.43929347048209971682983532791560102079`20.", ",", 
     "499.53316101327150837237922731061809483058`20.", ",", 
     "501.62517271629984190148025252330341065079`20.", ",", 
     "503.71533962382181603556077098750110148301`20.", ",", 
     "505.80367266992883148215952931702997926833`20.", ",", 
     "507.89018268020106557751747064559271457885`20.", ",", 
     "509.97488037332707205578464057654922926405`20.", ",", 
     "512.05777636269168302965275801589637364602`20.", ",", 
     "514.13888115793298415394812743310807975008`20.", ",", 
     "516.21820516646911160155088484865816031987`20.", ",", 
     "518.29575869499559788995802265434908230708`20.", ",", 
     "520.37155195095397272818092217324380832486`20.", ",", 
     "522.44559504397230487999201744825492298713`20.", ",", 
     "524.51789798727835153450758590964288042221`20.", ",", 
     "526.58847069908596281352646644433873252095`20.", ",", 
     "528.65732300395537080281161986389428063754`20.", ",", 
     "530.72446463412797484848917644642479783397`20.", ",", 
     "532.78990523083621778779972632505427970566`20.", ",", 
     "534.85365434558913126434174473806007755493`20.", ",", 
     "536.91572144143411229134839726990591701513`20.", ",", 
     "538.97611589419547775292608028400479014986`20.", ",", 
     "541.03484699369032855384562113349992355294`20.", ",", 
     "543.09192394492224062546867400520412179218`20.", ",", 
     "545.14735586925328595149548209602042221115`20.", ",", 
     "547.20115180555487317591543886249147826719`20.", ",", 
     "549.25332071133788418097383116327348313323`20.", ",", 
     "551.30387146386257025991766492783698140503`20.", ",", 
     "553.35281286122865914313906490079128579784`20.", ",", 
     "555.40015362344611215306571054825829642767`20.", ",", 
     "557.44590239348695914927870003363947426339`20.", ",", 
     "559.49006773831862766792467654706791013088`20.", ",", 
     "561.53265814991917174609439782753847892944`20.", ",", 
     "563.57368204627479534051337885974771794576`20.", ",", 
     "565.61314777236005498914580961892453786379`20.", ",", 
     "567.65106360110111641310949378384817943561`20.", ",", 
     "569.68743773432243010402169825200369634692`20.", ",", 
     "571.72227830367718157833579554429647124617`20.", ",", 
     "573.75559337156186289556898137472730329592`20.", ",", 
     "575.78739093201530322211852376163134951427`20.", ",", 
     "577.81767891160248766753237994958222421378`20.", ",", 
     "579.84646517028348531689708620688207714929`20.", ",", 
     "581.87375750226779932301779241291226508494`20.", ",", 
     "583.89956363685444409719344332881240542299`20.", ",", 
     "585.92389123925804703983767499176782726555`20.", ",", 
     "587.94674791142126487445582377662912327839`20.", ",", 
     "589.96814119281379748333102266288009074278`20.", ",", 
     "591.98807856121827518373447060652221895513`20.", ",", 
     "594.00656743350328862284884492333058944985`20.", ",", 
     "596.0236151663838239014168080811347983794`20.", ",", 
     "598.03922905716935915417114607034723185855`20.", ",", 
     "600.05341634449987261336748812408427750875`20.", ",", 
     "602.06618420907000615443968641599753223797`20.", ",", 
     "604.07753977434162246435468423102861671635`20.", ",", 
     "606.08749010724498827828071891216984931772`20.", ",", 
     "608.09604221886881059351446799175517757484`20.", ",", 
     "610.10320306513934738623798970628206988643`20.", ",", 
     "612.10897954748880912177078675952999732623`20.", ",", 
     "614.11337851351326225789187631102108937765`20.", ",", 
     "616.11640675762024098904067547850393826381`20.", ",", 
     "618.11807102166626866243021026404182573557`20.", ",", 
     "620.11837799558448561113905160913900384175`20.", ",", 
     "622.11733431800257559005210300557931945949`20.", ",", 
     "624.11494657685117856419716435990097587409`20.", ",", 
     "626.1112213099629732818106166994476296273`20.", ",", 
     "628.10616500566260886272731975855190302249`20.", ",", 
     "630.09978410334766054291686140467916936854`20.", ",", 
     "632.09208499406078073479018020394879197431`20.", ",", 
     "634.08307402105321268700189499465923091667`20.", ",", 
     "636.07275748033983025370975262582171879081`20.", ",", 
     "638.0611416212458636085653796541286251176`20.", ",", 
     "640.04823264694546716014455471468576611844`20.", ",", 
     "642.03403671499228244022388105614039790375`20.", ",", 
     "644.01855993784214534151257084006245345365`20.", ",", 
     "646.00180838336808377448324703491176111067`20.", ",", 
     "647.98378807536774859123270816553401819188`20.", ",", 
     "649.96450499406341748534602954406415249344`20.", ",", 
     "651.94396507659470851812069612216825603477`20.", ",", 
     "653.92217421750413694089616511172019345639`20.", ",", 
     "655.89913826921564607836895559323757953313`20.", ",", 
     "657.87486304250624020646805369604679906574`20.", ",", 
     "659.84935430697084459850484734772310712295`20.", ",", 
     "661.82261779148051522284891900334091790566`20.", ",", 
     "663.79465918463411795233456333827869975237`20.", ",", 
     "665.76548413520359458805503712638082149013`20.", ",", 
     "667.73509825257293050629566348775722735927`20.", ",", 
     "669.70350710717093630529541142646598524484`20.", ",", 
     "671.67071623089795345656882310630378875996`20.", ",", 
     "673.63673111754659165198049863588630409373`20.", ",", 
     "675.60155722321660328101014893845406586649`20.", ",", 
     "677.56519996672399827109606812058717027774`20.", ",", 
     "679.52766473000450037606675766036888984649`20.", ",", 
     "681.48895685851144390198007134739658789845`20.", ",", 
     "683.44908166160820781474843031678031167574`20.", ",", 
     "685.40804441295528217834366118587364858626`20.", ",", 
     "687.36585035089205992479508648211207198071`20.", ",", 
     "689.32250467881344505631039981443318559147`20.", ",", 
     "691.27801256554136652439143875823654294879`20.", ",", 
     "693.23237914569128521955581478651108228372`20.", ",", 
     "695.18560952003377973701749204775549155144`20.", ",", 
     "697.13770875585129485726801892855514751686`20.", ",", 
     "699.08868188729013499481336309702678792695`20.", ",", 
     "701.03853391570778322227113111898259762121`20.", ",", 
     "702.9872698100156248695639863448610329914`20.", ",", 
     "704.93489450701715312803351832301409574466`20.", ",", 
     "706.88141291174173255595141051512479795345`20.", ",", 
     "708.82682989777399488415778389468183599099`20.", ",", 
     "710.77115030757894005747491222306354931438`20.", ",", 
     "712.71437895282281401822059286037145664468`20.", ",", 
     "714.65652061468983334169852881586938431836`20.", ",", 
     "716.59758004419482546911821034472944676242`20.", ",", 
     "718.53756196249185195016408040268474640882`20.", ",", 
     "720.47647106117888080458754856879753330531`20.", ",", 
     "722.41431200259857283895344310364275075305`20.", ",", 
     "724.35108942013524551027520967228193946481`20.", ",", 
     "726.28680791850807671198299119091258237759`20.", ",", 
     "728.22147207406060966876933498833499072146`20.", ",", 
     "730.15508643504661896465294113505255714406`20.", ",", 
     "732.08765552191239659241580056192664217429`20.", ",", 
     "734.01918382757551580174679821687577028695`20.", ",", 
     "735.94967581770012943732760785240583759076`20.", ",", 
     "737.87913593096885839610483781802677191084`20.", ",", 
     "739.80756857935132479450381821497923709493`20.", ",", 
     "741.73497814836938342076908165313696249317`20.", ",", 
     "743.66136899735910405439590613814329227856`20.", ",", 
     "745.58674545972955626319366682043153618872`20.", ",", 
     "747.51111184321844733835808583107780100434`20.", ",", 
     "749.43447243014466309850370136291401934292`20.", ",", 
     "751.35683147765776038441249082559726259423`20.", ",", 
     "753.27819321798445917679619801653814019746`20.", ",", 
     "755.19856185867218139916885353851294445956`20.", ",", 
     "757.11794158282968261651585737425684908888`20.", ",", 
     "759.0363365493648220073733270972109449178`20.", ",", 
     "760.95375089321951517175523611811355999591`20.", ",", 
     "762.8701887256019135396573541745042474543`20.", ",", 
     "764.78565413421585336420913168643820885178`20.", ",", 
     "766.70015118348761651953186724800479170829`20.", ",", 
     "768.61368391479004457559931184640054765221`20.", ",", 
     "770.52625634666404689050164644036625275553`20.", ",", 
     "772.43787247503754274411237019597572232123`20.", ",", 
     "774.34853627344187683588710518256301464297`20.", ",", 
     "776.25825169322574678303062648538063617186`20.", ",", 
     "778.16702266376668058321017375595364498484`20.", ",", 
     "780.07485309268010134803527904227531243165`20.", ",", 
     "781.98174686602601596934206890003899270989`20.", ",", 
     "783.88770784851336374959725951742746440703`20.", ",", 
     "785.79273988370206041016650123095447621505`20.", ",", 
     "787.69684679420277228647440358662264366593`20.", ",", 
     "789.60003238187445492692874898531391788041`20.", ",", 
     "791.50230042801968973260634447907082656081`20.", ",", 
     "793.4036546935778517068277290930895356374`20.", ",", 
     "795.30409891931614082761521899557849335417`20.", ",", 
     "797.20363682601850901137363354658369989224`20.", ",", 
     "799.10227211467251410270285493731362106372`20.", ",", 
     "801.00000846665413180280057555567041341457`20.", ",", 
     "802.89684954391055593720355572306663807001`20.", ",", 
     "804.79279898914101696241460888247009028847`20.", ",", 
     "806.68786042597564812004515277036771313885`20.", ",", 
     "808.5820374591524281662508234074885211982`20.", ",", 
     "810.47533367469222913323803660495675661246`20.", ",", 
     "812.36775264007199711826645641241081358353`20.", ",", 
     "814.25929790439609364366620267247482253198`20.", ",", 
     "816.14997299856582468873546225258167988506`20.", ",", 
     "818.03978143544718406079607687463163987353`20.", ",", 
     "819.92872671003683734797964709164777508147`20.", ",", 
     "821.81681229962637228031848402985339198108`20.", ",", 
     "823.70404166396484091825383604920784255519`20.", ",", 
     "825.59041824541961868858333864148168651305`20.", ",", 
     "827.47594546913560489699128947356268915615`20.", ",", 
     "829.36062674319278896348537556741314474121`20.", ",", 
     "831.24446545876220625215360233647916316244`20.", ",", 
     "833.12746499026030699951256969762324965346`20.", ",", 
     "835.00962869550176148620550181676427804622`20.", ",", 
     "836.89095991585072424479355122716697718697`20.", ",", 
     "838.77146197637057975174022898275951723262`20.", ",", 
     "840.65113818597219171429509086261564390309`20.", ",", 
     "842.52999183756067773272312964516595776803`20.", ",", 
     "844.40802620818073079509014639652634413067`20.", ",", 
     "846.28524455916050874549653811695431397265`20.", ",", 
     "848.16165013625411255715267759909881936018`20.", ",", 
     "850.03724616978267393891402397462143064244`20.", ",", 
     "851.91203587477407250775438614515131219896`20.", ",", 
     "853.78602245110130247006794585642135069225`20.", ",", 
     "855.65920908361950847157683686089181564651`20.", ",", 
     "857.53159894230170999890894777937319987819`20.", ",", 
     "859.40319518237323344553347041859837829442`20.", ",", 
     "861.27400094444487069063853740577266944991`20.", ",", 
     "863.14401935464478278165081478205304661749`20.", ",", 
     "865.01325352474916705938168297600825815684`20.", ",", 
     "866.8817065523117058191950863335724243945`20.", ",", 
     "868.74938152079181436209065255595682567489`20.", ",", 
     "870.61628149968170605615071596817273324441`20.", ",", 
     "872.48240954463229180138598280018124293597`20.", ",", 
     "874.34776869757793106961252010517811344758`20.", ",", 
     "876.21236198686005147558959258711781035496`20.", ",", 
     "878.07619242734965362623705203352556184771`20.", ",", 
     "879.93926302056871779133240528044311834553`20.", ",", 
     "881.80157675481052874166780107363218608878`20.", ",", 
     "883.66313660525893490923906854222249627843`20.", ",", 
     "885.52394553410655783866240719644128213625`20.", ",", 
     "887.3840064906719677196959552822640105282`20.", ",", 
     "889.24332241151584061751669311602750489044`20.", ",", 
     "891.10189622055611285030833561455942622514`20.", ",", 
     "892.9597308291821478028003756453824136435`20.", ",", 
     "894.81682913636793030971662161956106405732`20.", ",", 
     "896.67319402878430359470485003672306425656`20.", ",", 
     "898.52882838091026360829606473502482355234`20.", ",", 
     "900.38373505514332547285790019162931166331`20.", ",", 
     "902.2379169019089766134445776688516999261`20.", ",", 
     "904.09137675976923103099521051422320317031`20.", ",", 
     "905.94411745553029905858983400863070795913`20.", ",", 
     "907.79614180434938683254188851451218119312`20.", ",", 
     "909.64745260984063960809739687386330320999`20.", ",", 
     "911.4980526641802429545417990956743254048`20.", ",", 
     "913.34794474821069577670888841737906290681`20.", ",", 
     "915.19713163154426902937237513984112443788`20.", ",", 
     "917.04561607266566391791517936774826119095`20.", ",", 
     "918.8934008190338833131562732819237228877`20.", ",", 
     "920.74048860718333005041683677893296602049`20.", ",", 
     "922.58688216282414573297877732313649110442`20.", ",", 
     "924.43258420094180361818601641850643999132`20.", ",", 
     "926.27759742589596913072318286450788226992`20.", ",", 
     "928.12192453151864152224183586976174274012`20.", ",", 
     "929.96556820121159017965833336491831592017`20.", ",", 
     "931.80853110804309907628942649816108596041`20.", ",", 
     "933.65081591484403286069248026111493898236`20.", ",", 
     "935.49242527430323808780832078740839017698`20.", ",", 
     "937.33336182906229311593711205508700790272`20.", ",", 
     "939.17362821180962022138092868210576922246`20.", ",", 
     "941.01322704537397352042776564427640257722`20.", ",", 
     "942.85216094281731633589368827772572697011`20.", ",", 
     "944.69043250752710170284051385527782790378`20.", ",", 
     "946.52804433330796977549693533622654727814`20.", ",", 
     "948.36499900447287597497410858699524294453`20.", ",", 
     "950.20129909593366380521509387310012178692`20.", ",", 
     "952.03694717329109636287186074784676016942`20.", ",", 
     "953.87194579292436067557051556709044935213`20.", ",", 
     "955.70629750208005912239548743165248702272`20.", ",", 
     "957.54000483896070232046857834288245350219`20.", ",", 
     "959.3730703328127180022699814707415875133`20.", ",", 
     "961.20549650401399055987282399207043053408`20.", ",", 
     "963.03728586416094609454116134999184176952`20.", ",", 
     "964.8684409161551979831446990743762490268`20.", ",", 
     "966.69896415428976815651007451490070533705`20.", ",", 
     "968.52885806433489947906026072813903174302`20.", ",", 
     "970.35812512362347482375263202640991901566`20.", ",", 
     "972.18676780113605865123079489862992202612`20.", ",", 
     "974.01478855758557712702598877529468422619`20.", ",", 
     "975.84218984550165304529918255577229302644`20.", ",", 
     "977.66897410931461207166685364135942059759`20.", ",", 
     "979.49514378543917707070246128159036989606`20.", ",", 
     "981.32070130235786754528618595519718360595`20.", ",", 
     "983.1456490807041214845505223235423152809`20.", ",", 
     "984.96998953334515719412482413154800141523`20.", ",", 
     "986.79372506546459296602139166418811906113`20.", ",", 
     "988.61685807464484273504418990672301006806`20.", ",", 
     "990.4393909509493061631592017187098045624`20.", ",", 
     "992.261326077004371891862172862115324772`20.", ",", 
     "994.08266582808125300412689773848049612011`20.", ",", 
     "995.90341257217767404081256554524047572838`20.", ",", 
     "997.72356867009942922012783807175674183976`20.", ",", 
     "999.54313647554183181143923527473475576198`20.", ",", 
     "1001.36211833517107491478270606933254450106`20.", ",", 
     "1003.18051658870552419315657298302073302014`20.", ",", 
     "1004.99833356899696339415605812610319190066`20.", ",", 
     "1006.81557160211181377870904711943243575236`20.", ",", 
     "1008.63223300741234884537615970011969740301`20.", ",", 
     "1010.44832009763792599649555981837718357796`20.", ",", 
     "1012.26383517898625703480922998492513514945`20.", ",", 
     "1014.07878055119473960333405392871885059025`20.", ",", 
     "1015.89315850762187188416719148328435013157`20.", ",", 
     "1017.70697133532877305045920927574743487439`20.", ",", 
     "1019.52022131516083211654902234391034678871`20.", ",", 
     "1021.33291072182950795060248693143272648422`20.", ",", 
     "1023.14504182399430329816528004131310605099`20.", ",", 
     "1024.95661688434493570971909475121735261848`20.", ",", 
     "1026.76763815968372826625322413561385106964`20.", ",", 
     "1028.57810790100824294940471751441143794517`20.", ",", 
     "1030.3880283535941794019834118803938922635`20.", ",", 
     "1032.19740175707856166551021331994780855378`20.", ",", 
     "1034.00623034554323525830083537883760709721`20.", ",", 
     "1035.81451634759869666487477060894573890676`20.", ",", 
     "1037.62226198646827693901555019285011234556`20.", ",", 
     "1039.42946948007270067230572258775568577844`20.", ",", 
     "1041.23614104111504104075335574589457606869`20.", ",", 
     "1043.04227887716609100724950931939898723479`20.", ",", 
     "1044.84788519075017001976638580889193613608`20.", ",", 
     "1046.65296217943138469682484784065146495486`20.", ",", 
     "1048.45751203590036102491023189957052517241`20.", ",", 
     "1050.26153694806146449896077026869735918027`20.", ",", 
     "1052.06503909912052340823979053327511918506`20.", ",", 
     "1053.86802066767306909696252713518213836536`20.", ",", 
     "1055.67048382779310550280121763397028199839`20.", ",", 
     "1057.47243074912241858735324864758757891444`20.", ",", 
     "1059.27386359696043441104371580952407834139`20.", ",", 
     "1061.07478453235463256067466365386910670194`20.", ",", 
     "1062.87519571219151940058024186294938651696`20.", ",", 
     "1064.67509928928816317748842979992754002456`20.", ",", 
     "1066.47449741248429035386682740505546327606`20.", ",", 
     "1068.27339222673493966365440464808059902875`20.", ",", 
     "1070.07178587320366726655749899100142584098`20.", ",", 
     "1071.86968048935629301103760124213044473816`20.", ",", 
     "1073.66707820905517419010489913716253601586`20.", ",", 
     "1075.46398116265398927629322553495197252645`20.", ",", 
     "1077.26039147709300994087444213908411664013`20.", ",", 
     "1079.05631127599483518556341150900447631858`20.", ",", 
     "1080.8517426797605566307440829007895375402`20.", ",", 
     "1082.64668780566631890071864308021846513998`20.", ",", 
     "1084.44114876796023361183013377194634237143`20.", ",", 
     "1086.23512767795959969185168393162755435987`20.", ",", 
     "1088.02862664414837662727966332752443922347`20.", ",", 
     "1089.82164777227485073787272152307003009758`20.", ",", 
     "1091.61419316544942770402175888831377307625`20.", ",", 
     "1093.40626492424247731178590278148999934984`20.", ",", 
     "1095.19786514678214872262242892990109790079`20.", ",", 
     "1096.98899592885206651045948916317880479219`20.", ",", 
     "1098.77965936398880922893122293834972992911`20.", ",", 
     "1100.5698575435790633681661853227023190524`20.", ",", 
     "1102.35959255695633622616998438053218474259`20.", ",", 
     "1104.14886649149710144818019345470179862716`20.", ",", 
     "1105.93768143271624077304428567777460059754`20.", ",", 
     "1107.72603946436163486448209735777902694905`20.", ",", 
     "1109.51394266850774499412008804117478303081`20.", ",", 
     "1111.3013931256480157809022336605775423389`20.", ",", 
     "1113.0883929147859171778993143104742619266`20.", ",", 
     "1114.87494411352443143432898644689793255792`20.", ",", 
     "1116.66104879815377785124555800494011838533`20.", ",", 
     "1118.44670904373715479929667062443389844318`20.", ",", 
     "1120.23192692419426468371391539146422843463`20.", ",", 
     "1122.01670451238237333510382800351752017017`20.", ",", 
     "1123.80104388017464068684909448977607700978`20.", ",", 
     "1125.58494709853544458580902331850294133403`20.", ",", 
     "1127.36841623759240419005657913513516223278`20.", ",", 
     "1129.15145336670479365604674545895561078309`20.", ",", 
     "1130.9340605545280207313918960667665817009`20.", ",", 
     "1132.71623986907382847507972716999398535391`20.", ",", 
     "1134.49799337776586165467173800659646112452`20.", ",", 
     "1136.27932314749022245350212651219034207827`20.", ",", 
     "1138.06023124464062299763093086516952288767`20.", ",", 
     "1139.84071973515772492365823242998869736148`20.", ",", 
     "1141.62079068456223879989269767840481135017`20.", ",", 
     "1143.40044615798133873439610519010750466635`20.", ",", 
     "1145.17968822016793000803626628507902816357`20.", ",", 
     "1146.95851893551229011727446102314213698182`20.", ",", 
     "1148.73694036804558626296690669582699478033`20.", ",", 
     "1150.51495458143475514562800762654940024854`20.", ",", 
     "1152.29256363896821399680609925050018315513`20.", ",", 
     "1154.06976960353185516771293757655016583957`20.", ",", 
     "1155.84657453757476039215987140034766380183`20.", ",", 
     "1157.62298050306405512822574136233975619426`20.", ",", 
     "1159.39898956142830825385868754082692624925`20.", ",", 
     "1161.17460377348886794261788693284340560191`20.", ",", 
     "1162.94982519937851087863165414840429326562`20.", ",", 
     "1164.72465589844676919095121817091032010235`20.", ",", 
     "1166.49909792915128770777849776567573866201`20.", ",", 
     "1168.27315334893455346593563253792718276438`20.", ",", 
     "1170.04682421408532998004000400781317294627`20.", ",", 
     "1171.82011257958412070273569423198043141093`20.", ",", 
     "1173.59302049893197951926364219776042556028`20.", ",", 
     "1175.36555002396198114719902101400292392533`20.", ",", 
     "1177.13770320463266108883194222497079939418`20.", ",", 
     "1178.90948208880273344536129728948438956981`20.", ",", 
     "1180.68088872198639558670075000536769102207`20.", ",", 
     "1182.45192514708853151752206075687898082629`20.", ",", 
     "1184.22259340411913092918486972349972553255`20.", ",", 
     "1185.9928955298862485184697525511829930995`20.", ",", 
     "1187.76283355766683832687737188787347875181`20.", ",", 
     "1189.53240951685481074648486707104390602229`20.", ",", 
     "1191.30162543258567558535285211285520543376`20.", ",", 
     "1193.07048332533715331928809094146186877098`20.", ",", 
     "1194.83898521050515850506342591700880078655`20.", ",", 
     "1196.60713309795458441523026016225889228038`20.", ",", 
     "1198.37492899154434639214085744693859604303`20.", ",", 
     "1200.14237488862617331672689884174571844205`20.", ",", 
     "1201.90947277951667204502559393078259345188`20.", ",", 
     "1203.67622464694222877128220104505449472738`20.", ",", 
     "1205.4426324654563541080764058140381213027`20.", ",", 
     "1207.20869820082912529589301966441495252382`20.", ",", 
     "1208.97442380940842941729614837398835196376`20.", ",", 
     "1210.7398112374527658292606502796224638526`20.", ",", 
     "1212.50486242043542425927441324749452900371`20.", ",", 
     "1214.2695792823199171363270103264033682317`20.", ",", 
     "1216.03396373480661072706158025781941852675`20.", ",", 
     "1217.79801767655056947955044870455936746809`20.", ",", 
     "1219.56174299235070157962607239389850153928`20.", ",", 
     "1221.32514155231037101144395185160023941763`20.", ",", 
     "1223.08821521096972227458071025949803943202`20.", ",", 
     "1224.85096580641004820870207430687192937034`20.", ",", 
     "1226.61339515933061895161915408006147698278`20.", ",", 
     "1228.37550507209848071829516815455372197828`20.", ",", 
     "1230.13729732777182662032135601969055687774`20.", ",", 
     "1231.89877368909763790269575230032667572611`20.", ",", 
     "1233.65993589748439248417886530130378610047`20.", ",", 
     "1235.42078567195073824738115474370069853586`20.", ",", 
     "1237.18132470805113080506116026084746075598`20.", ",", 
     "1238.94155467677953911193816220648639061458`20.", ",", 
     "1240.70147722345242691137226406732140618734`20.", ",", 
     "1242.46109396657232319178916911758642898489`20.", ",", 
     "1244.22040649667340014163449328444178207356`20.", ",", 
     "1245.97941637515058207289805411484118633329`20.", ",", 
     "1247.73812513307381294855341070469792384181`20.", ",", 
     "1249.49653426998921299501104523565303104334`20.", ",", 
     "1251.25464525270895588522603695964629876058`20.", ",", 
     "1253.01245951409179660424037248526126756657`20.", ",", 
     "1254.76997845181627580674892666365725004022`20.", ",", 
     "1256.52720342714871868615874703210991472856`20.", ",", 
     "1258.28413576370823453061150812253386698809`20.", ",", 
     "1260.0407767462310066748049758070161282934`20.", ",", 
     "1261.79712761933624089939333981492014372668`20.", ",", 
     "1263.55318958629621291940654002689493903899`20.", ",", 
     "1265.30896380781292188569308791723698263308`20.", ",", 
     "1267.06445140080391625835349243350460939916`20.", ",", 
     "1268.81965343719991047564754582964603825498`20.", ",", 
     "1270.5745709427568550351604440866935671507`20.", ",", 
     "1272.32920489588515845184445673837326073078`20.", ",", 
     "1274.08355622649878661658437680932661868967`20.", ",", 
     "1275.83762581488698294110649423551872964005`20.", ",", 
     "1277.59141449061136097180399957751273300491`20.", ",", 
     "1279.34492303143111956139896024454387423522`20.", ",", 
     "1281.09815216225911892574537954455861707693`20.", ",", 
     "1282.85110255415153375697586611887599605539`20.", ",", 
     "1284.60377482333376684141513673281586727745`20.", ",", 
     "1286.35616953026526322631865154485153622329`20.", ",", 
     "1288.10828717874581083847689395229611456016`20.", ",", 
     "1289.86012821506584858695561367873974788691`20.", ",", 
     "1291.61169302720322745224647252736572013755`20.", ",", 
     "1293.36298194406878401019232002430808342448`20.", ",", 
     "1295.11399523480298946195366957520899315245`20.", ",", 
     "1296.86473310812583080722182551532071282518`20.", ",", 
     "1298.6151957117419646380967998078742558158`20.", ",", 
     "1300.36538313180305854072632985969079847979`20.", ",", 
     "1302.11529539242910072845494277408919000865`20.", ",", 
     "1303.86493245529031581147377264758061759142`20.", ",", 
     "1305.61429421925117410873762664312802640961`20.", ",", 
     "1307.36338052007782425717909501320423932372`20.", ",", 
     "1309.1121911302101147501190668135201918088`20.", ",", 
     "1310.86072575859920016619915022005511951131`20.", ",", 
     "1312.60898405061155299813952835974789881528`20.", ",", 
     "1314.35696558800002295900032131506657145752`20.", ",", 
     "1316.10466988894240326453358173962845862428`20.", ",", 
     "1317.85209640814777852022586740802614957124`20.", ",", 
     "1319.59924453703074235563798724659818792768`20.", ",", 
     "1321.34611360395338573356271257954614243083`20.", ",", 
     "1323.09270287453476980986026610362067330091`20.", ",", 
     "1324.8390115520274112232388841139288835026`20.", ",", 
     "1326.58503877776012363702571880054278414579`20.", ",", 
     "1328.33078363164637810768982862839169164667`20.", ",", 
     "1330.07624513275716726811644945109742273622`20.", ",", 
     "1331.82142223995718521193961850995446802122`20.", ",", 
     "1333.56631385260296714135228068238273217376`20.", ",", 
     "1335.31091881130147105018608339932050508386`20.", ",", 
     "1337.05523589872742866978005554864392456494`20.", ",", 
     "1338.79926384049764527330180137545553244858`20.", ",", 
     "1340.54300130610028832957904389893956406406`20.", ",", 
     "1342.28644690987707398004193184864718252168`20.", ",", 
     "1344.02959921205613838385855788849237322195`20.", ",", 
     "1345.77245671983326857782860083720816608416`20.", ",", 
     "1347.51501788849906500735808696106070227245`20.", ",", 
     "1349.25728112260951561688120888847457688312`20.", ",", 
     "1350.99924477719737959126335828106757144996`20.", ",", 
     "1352.74090715902170769735393472340443125318`20.", ",", 
     "1354.48226652785276580502950155839530498593`20.", ",", 
     "1356.22332109778957862335232386237348128858`20.", ",", 
     "1357.96406903860727196023697699192180655959`20.", ",", 
     "1359.70450847713136383221841980395890043752`20.", ",", 
     "1361.44463749863613738431840453648206161184`20.", ",", 
     "1363.18445414826422164186372391683417322844`20.", ",", 
     "1364.92395643246450936619069540574961114354`20.", ",", 
     "1366.66314232044555443414315022274925276475`20.", ",", 
     "1368.40200974564161387036632141558807120708`20.", ",", 
     "1370.14055660718853155231855098885409795614`20.", ",", 
     "1371.87878077140670126294551826056092891671`20.", ",", 
     "1373.61668007328839573319610438761266937132`20.", ",", 
     "1375.35425231798680511429656618297261213873`20.", ",", 
     "1377.09149528230419244082353223588083531861`20.", ",", 
     "1378.82840671617664456202025429086266725025`20.", ",", 
     "1380.5649843441529741857764506429810103636`20.", ",", 
     "1382.30122586686541154024621959239177780723`20.", ",", 
     "1384.03712896248981214713983416556438958932`20.", ",", 
     "1385.77269128819319974921236953297290232623`20.", ",", 
     "1387.50791048156655997318883206367572193838`20.", ",", 
     "1389.24278416204090027269821817407295018848`20.", ",", 
     "1390.97730993228469452518367227025048540255`20.", ",", 
     "1392.71148537958093580395500386326023398804`20.", ",", 
     "1394.44530807718212777657382699442048565589`20.", ",", 
     "1396.1787755856416533746241422484645546799`20.", ",", 
     "1397.91188545412006833706886277375921251566`20.", ",", 
     "1399.6446352216649764698651480653078032328`20.", ",", 
     "1401.37702241846325253081972534183955970531`20.", ",", 
     "1403.10904456706448710739149096288316302218`20.", ",", 
     "1404.84069918357463529826820763712261337576`20.", ",", 
     "1406.57198377881895705548070467824185211868`20.", ",", 
     "1408.30289585947344133823765320897875608769`20.", ",", 
     "1410.03343292916400844602033547630783285042`20.", ",", 
     "1411.76359248953288473831988268673366063219`20.", ",", 
     "1413.49337204127164114146202924537335841222`20.", ",", 
     "1415.22276908512048114704117771571172328437`20.", ",", 
     "1416.95178112283345520712073654938143255525`20.", ",", 
     "1418.68040565810936634135717541244636548439`20.", ",", 
     "1420.40864019748821622999592457341069523694`20.", ",", 
     "1422.13648225121312193952578335184154776867`20.", ",", 
     "1423.86392933405771060484665437522067300575`20.", ",", 
     "1425.59097896611907278719377491431511794705`20.", ",", 
     "1427.3176286735764247776642205439019862734`20.", ",", 
     "1429.04387598941569578052626838205318370887`20.", ",", 
     "1430.76971845412031766746266623101327747304`20.", ",", 
     "1432.49515361632855284151108261174921182939`20.", ",", 
     "1434.22017903345774970351432912339956743876`20.", ",", 
     "1435.94479227229596530663244881156798765241`20.", ",", 
     "1437.66899090956144106327178984255334846518`20.", ",", 
     "1439.39277253243045989481345643572059895658`20.", ",", 
     "1441.11613473903415206140479501315144176762`20.", ",", 
     "1442.83907513892485216161651875578550380089`20.", ",", 
     "1444.5615913535126415446783078771737402315`20.", ",", 
     "1446.28368101647273873468463334694365959843`20.", ",", 
     "1448.00534177412442553750887376357992981463`20.", ",", 
     "1449.72657128578221840444382483414175549621`20.", ",", 
     "1451.44736722408001348435320216803670896096`20.", ",", 
     "1453.16772727526894973518576353322162448731`20.", ",", 
     "1454.88764913948974761617975021514943672346`20.", ",", 
     "1456.60713053102029137646673092118327060943`20.", ",", 
     "1458.32616917849923092810903926438098096605`20.", ",", 
     "1460.04476282512638487667040494696948390344`20.", ",", 
     "1461.76290922884072961505735149159509941846`20.", ",", 
     "1463.48060616247676060078586085921891308482`20.", ",", 
     "1465.19785141390001116600256027417375634097`20.", ",", 
     "1466.91464278612251158473048934423378544979`20.", ",", 
     "1468.63097809739896677186758262107322725684`20.", ",", 
     "1470.34685518130442503970404172437279009094`20.", ",", 
     "1472.0622718867942029133379471382960898303`20.", ",", 
     "1473.77722607824682222615562405390567289889`20.", ",", 
     "1475.49171563549070569662575569310429103897`20.", ",", 
     "1477.20573845381536604024158532563485396063`20.", ",", 
     "1478.91929244396781150363352339148510504211`20.", ",", 
     "1480.63237553213487762550247774777385597128`20.", ",", 
     "1482.3449856599121811305494074745936667539`20.", ",", 
     "1484.05712078426037724299190382775319509974`20.", ",", 
     "1485.76877887744938645603996719032227307674`20.", ",", 
     "1487.47995792699124099878524623408181465036`20.", ",", 
     "1489.19065593556218498373586826251942969534`20.", ",", 
     "1490.90087092091464557358303756298604279714`20.", ",", 
     "1492.6106009157796755471276056872550849486`20.", ",", 
     "1494.3198439677604504396326270568595251474`20.", ",", 
     "1496.02859813921738604588639180059004649237`20.", ",", 
     "1497.73686150714542456441697033379091971158`20.", ",", 
     "1499.44463216304402008393162074789289152249`20.", ",", 
     "1501.1519082127803365194988667852876525024`20.", ",", 
     "1502.85868777644615354370982703973655538835`20.", ",", 
     "1504.56496898820895857077081591656725796387`20.", ",", 
     "1506.27074999615768547931396689111483602416`20.", ",", 
     "1507.97602896214354353933401322333457690332`20.", ",", 
     "1509.68080406161636297342710273105544648431`20.", ",", 
     "1511.38507348345686676262325185991636028348`20.", ",", 
     "1513.08883542980526172976187800776168260301`20.", ",", 
     "1514.79208811588652562289699932112993278451`20.", ",", 
     "1516.4948297698327508992652914918050029839`20.", ",", 
     "1518.19705863250289019597761662547775322537`20.", ",", 
     "1519.89877295730023308346167387831772723716`20.", ",", 
     "1521.59997100998792864617971056798726208583`20.", ",", 
     "1523.30065106850285373453153647665590376307`20.", ",", 
     "1525.00081142276811239239792056330483874518`20.", ",", 
     "1526.70045037450443799489177479087344565156`20.", ",", 
     "1528.39956623704075603724217631216314634723`20.", ",", 
     "1530.09815733512415230340991527330721829091`20.", ",", 
     "1531.79622200472947831560569182403247511731`20.", ",", 
     "1533.49375859286881352556279461293748035177`20.", ",", 
     "1535.1907654574009916561508484456453480759`20.", ",", 
     "1536.88724096684138693749280839647744347163`20.", ",", 
     "1538.58318350017214470389136400854688646543`20.", ",", 
     "1540.27859144665302992434646211056908589599`20.", ",", 
     "1541.97346320563305672714144601833864506846`20.", ",", 
     "1543.66779718636305184399063859959793197067`20.", ",", 
     "1545.36159180780929513696630283761994016465`20.", ",", 
     "1547.0548454984683709766146435564169126069`20.", ",", 
     "1548.7475566961833552065234541136475172539`20.", ",", 
     "1550.43972384796145375181719639982484744326`20.", ",", 
     "1552.13134540979320059989464101584682953529`20.", ",", 
     "1553.82241984647331489408076183273835493394`20.", ",", 
     "1555.51294563142330922730891844804670855087`20.", ",", 
     "1557.20292124651593389578195498706651200452`20.", ",", 
     "1558.89234518190153486385891812113145057737`20.", ",", 
     "1560.58121593583639649307490334528791916689`20.", ",", 
     "1562.26953201451313369198229519103980491229`20.", ",", 
     "1563.95729193189319204105630854068007859533`20.", ",", 
     "1565.64449420954150862982063505050107475778`20.", ",", 
     "1567.33113737646338080316580720280384836155`20.", ",", 
     "1569.01721996894358474208868934479393461691`20.", ",", 
     "1570.70274053038778079232635873344156960188`20.", ",", 
     "1572.38769761116623769417976747484697760094`20.", ",", 
     "1574.07208976845990334986923157700680526301`20.", ",", 
     "1575.75591556610884548276002210225166693265`20.", ",", 
     "1577.4391735744630814875617362693184117335`20.", ",", 
     "1579.12186237023581293406875601886285677862`20.", ",", 
     "1580.803980536359076561222620757488078442`20.", ",", 
     "1582.48552666184182017542636117329132436067`20.", ",", 
     "1584.16649934163040863945575648149154647306`20.", ",", 
     "1585.84689717647156209847590463877881398225`20.", ",", 
     "1587.52671877277772573022642116078154864478`20.", ",", 
     "1589.20596274249486762019432238743082554243`20.", ",", 
     "1590.8846277029726988425309063835278042024`20.", ",", 
     "1592.56271227683730746674386139507939128766`20.", ",", 
     "1594.24021509186619600214311651662090343473`20.", ",", 
     "1595.91713478086570973015415901701059888477`20.", ",", 
     "1597.59346998155084145263359483767035686853`20.", ",", 
     "1599.26921933642739639610971196263711132233`20.", ",", 
     "1600.94438149267649935149015813707072702806`20.", ",", 
     "1602.61895510204142459047695500374676832105`20.", ",", 
     "1604.29293882071672767813537191977553975101`20.", ",", 
     "1605.96633130923965699038777505956622046627`20.", ",", 
     "1607.6391312323838215404354358493967924374`20.", ",", 
     "1609.31133725905509061421614720431158960378`20.", ",", 
     "1610.98294806218969970712333992403916035988`20.", ",", 
     "1612.65396231865453633765470871204961508463`20.", ",", 
     "1614.32437870914957848390515338609372451609`20.", ",", 
     "1615.99419591811245764151542460077367428928`20.", ",", 
     "1617.66341263362511783264145773344021306267`20.", ",", 
     "1619.33202754732254130068558151369481457232`20.", ",", 
     "1621.00003935430351110104990929639051554859`20.", ",", 
     "1622.66744675304338034030551892496099413536`20.", ",", 
     "1624.33424844530881742133686774623304319502`20.", ",", 
     "1626.00044313607449631678084712709366111306`20.", ",", 
     "1627.66602953344170061413480099461446438055`20.", ",", 
     "1629.33100634855880985009387021252612155944`20.", ",", 
     "1630.99537229554363647596267423304992123852`20.", ",", 
     "1632.6591260914075816674644754868815175076`20.", ",", 
     "1634.32226645598157810816089311590484930273`20.", ",", 
     "1635.98479211184378783333475625256309378571`20.", ",", 
     "1637.64670178424902321803126069119261877036`20.", ",", 
     "1639.30799420105985922656346199762229323143`20.", ",", 
     "1640.96866809267940510884056543658175262107`20.", ",", 
     "1642.62872219198570382914901716902142834052`20.", ",", 
     "1644.28815523426772764338526101386697174398`20.", ",", 
     "1645.94696595716293839918045468525436828163`20.", ",", 
     "1647.60515310059638131794023651412617508961`20.", ",", 
     "1649.26271540672128122670570590734937944693`20.", ",", 
     "1650.91965161986111043917079232610226439995`20.", ",", 
     "1652.57596048645309773749528793976539988125`20.", ",", 
     "1654.2316407549931481781414563742606349353`20.", ",", 
     "1655.88669117598214373432194902158257947381`20.", ",", 
     "1657.54111050187359509333858744852318584313`20.", ",", 
     "1659.19489748702261524774748414018906407343`20.", ",", 
     "1660.84805088763618585360646275230787767882`20.", ",", 
     "1662.50056946172468767581194591093735864759`20.", ",", 
     "1664.15245196905466679854353013875214367553`20.", ",", 
     "1665.80369717110280864699488972999975340682`20.", ",", 
     "1667.45430383101109224382686915263933523607`20.", ",", 
     "1669.10427071354309750913554311958625217388`20.", ",", 
     "1670.75359658504143880524069723907595173897`20.", ",", 
     "1672.40228021338629832637555377239661709702`20.", ",", 
     "1674.05032036795503333755229553396818140698`20.", ",", 
     "1675.69771581958283167569230232240711991426`20.", ",", 
     "1677.34446534052439033879187855747137656095`20.", ",", 
     "1678.99056770441659240473313334668383148996`20.", ",", 
     "1680.63602168624215793967585879486974400313`20.", ",", 
     "1682.280826062294244976148984649864345541`20.", ",", 
     "1683.92497961014197706240593662004361793838`20.", ",", 
     "1685.56848110859687430675901295655248358542`20.", ",", 
     "1687.211329337680165262939684639453845278`20.", ",", 
     "1688.85352307859095742455288383205092663816`20.", ",", 
     "1690.49506111367524451794315369583165456394`20.", ",", 
     "1692.1359422263957292028377606799684301061`20.", ",", 
     "1693.77616520130244020857340981254985526098`20.", ",", 
     "1695.4157288240041233501727537095472217857`20.", ",", 
     "1697.05463188114038628266369331029775244052`20.", ",", 
     "1698.69287316035457726350211663659524544383`20.", ",", 
     "1700.33045145026737860146397269914388196823`20.", ",", 
     "1701.96736554045109587563425803695259656572`20.", ",", 
     "1703.60361422140462440987842952338946555824`20.", ",", 
     "1705.23919628452907488619575263325907407921`20.", ",", 
     "1706.87411052210404037440295114426804670787`20.", ",", 
     "1708.50835572726448744547710412391039875648`20.", ",", 
     "1710.14193069397825442141306241816071118631`20.", ",", 
     "1711.77483421702414019545305407624141147169`20.", ",", 
     "1713.40706509197056743287041759431803770549`20.", ",", 
     "1715.0386221151548043339960331220004007098`20.", ",", 
     "1716.66950408366272950773943760376979008461`20.", ",", 
     "1718.29970979530912486536444357064099318704`20.", ",", 
     "1719.9292380486184818006314854815170282164`20.", ",", 
     "1721.55808764280630627352790235253775506211`20.", ",", 
     "1723.18625737776090876059616604288171957064`20.", ",", 
     "1724.81374605402566537527253585133785044302`20.", ",", 
     "1726.44055247278173679660865787179044797735`20.", ",", 
     "1728.06667543583123197421961533936440215246`20.", ",", 
     "1729.69211374558080390124621607300190506853`20.", ",", 
     "1731.31686620502566506550767014614300415584`20.", ",", 
     "1732.94093161773401050183202985481494386322`20.", ",", 
     "1734.56430878783183667577210757308624788604`20.", ",", 
     "1736.18699651998814473053739457639518423811`20.", ",", 
     "1737.80899361940051692499776002197421997186`20.", ",", 
     "1739.43029889178105538104864138366633109434`20.", ",", 
     "1741.05091114334267254348213147423293863533`20.", ",", 
     "1742.67082918078572303480139983256434691051`20.", ",", 
     "1744.29005181128496686116997581436980158909`20.", ",", 
     "1745.90857784247685419393009199223460866566`20.", ",", 
     "1747.5264060824471222138875518828583398984`20.", ",", 
     "1749.14353533971869476288064131058077835049`20.", ",", 
     "1750.75996442323987579906753663421108293796`20.", ",", 
     "1752.3756921423728278989241805693694161712`20.", ",", 
     "1753.99071730688232729018975473060331550023`20.", ",", 
     "1755.60503872692478713597983544820657634505`20.", ",", 
     "1757.2186552130375410210610952745642580059`20.", ",", 
     "1758.83156557612837881690165928067591290411`20.", ",", 
     "1760.44376862746532732263601083354200311265`20.", ",", 
     "1762.0552631786666682945729429304097556181`20.", ",", 
     "1763.66604804169118668739175720372243927102`20.", ",", 
     "1765.27612202882864213577983698448861222586`20.", ",", 
     "1766.88548395269045690602962359996794741721`20.", ",", 
     "1768.4941326262006137431021441526578980958`20.", ",", 
     "1770.10206686258675722994612889726839879697`20.", ",", 
     "1771.70928547537149246250613563104238827922`20.", ",", 
     "1773.31578727836387502593070512768344630316`20.", ",", 
     "1774.92157108565108643507402531531358906893`20.", ",", 
     "1776.52663571159028937554425395361139523673`20.", ",", 
     "1778.13097997080065725036153951011399112025`20.", ",", 
     "1779.7346026781555727018223986016116020216`20.", ",", 
     "1781.33750264877498993849836735000593781164`20.", ",", 
     "1782.93967869801795585349995113374986212453`20.", ",", 
     "1784.54112964147528507228625780841729719043`20.", ",", 
     "1786.14185429496238421647082310135518878954`20.", ",", 
     "1787.74185147451222081433954949012370375938`20.", ",", 
     "1789.34111999636843242923184091694227238271`20.", ",", 
     "1790.93965867697857171361524021040260426193`20.", ",", 
     "1792.53746633298748322968126140425165393069`20.", ",", 
     "1794.13454178123080800667946604664519828343`20.", ",", 
     "1795.7308838387286119310616207878208635368`20.", ",", 
     "1797.32649132267913418790104120107824241855`20.", ",", 
     "1798.92136305045265209105655406607183787539`20.", ",", 
     "1800.51549783958545875523795654510936166211`20.", ",", 
     "1802.10889450777395017557190514337872965294`20.", ",", 
     "1803.70155187286881838953470366652300643875`20.", ",", 
     "1805.29346875286934750228169299988331414941`20.", ",", 
     "1806.88464396591780945953139437476918641701`20.", ",", 
     "1808.47507633029395655232500601370493975318`20.", ",", 
     "1810.06476466440960773524631759741680984108`20.", ",", 
     "1811.65370778680332593412080690598909193489`20.", ",", 
     "1813.24190451613518361088201131781733704575`20.", ",", 
     "1814.82935367118161394226376512600815472882`20.", ",", 
     "1816.41605407083034505531322865489317769612`20.", ",", 
     "1818.00200453407541484648557810406128698091`20.", ",", 
     "1819.58720388001226399233963272373595369987`20.", ",", 
     "1821.17165092783290483866649410797876217193`20.", ",", 
     "1822.75534449682116393131144111754019550094`20.", ",", 
     "1824.33828340634799602605288468089493409958`20.", ",", 
     "1825.92046647586686748674019132283406149228`20.", ",", 
     "1827.50189252490920705052270561690562421671`20.", ",", 
     "1829.08256037307992200648242601582137103969`20.", ",", 
     "1830.66246884005297789936860891071281486504`20.", ",", 
     "1832.24161674556703993347918782539778649656`20.", ",", 
     "1833.82000290942117431309539277723252040058`20.", ",", 
     "1835.39762615147060781530543023503539575444`20.", ",", 
     "1836.97448529162254394860262390067675060354`20.", ",", 
     "1838.5505791498320341063641040681477079149`20.", ",", 
     "1840.12590654609790217825804950242897711779`20.", ",", 
     "1841.70046630045872113483971157632070734264`20.", ",", 
     "1843.27425723298884015112707016135801228766`20.", ",", 
     "1844.84727816379446088384307656078327103786`20.", ",", 
     "1846.4195279130097615643191355548315902841`20.", ",", 
     "1847.99100530079306761481889021652976872077`20.", ",", 
     "1849.56170914732306754030664895212191583453`20.", ",", 
     "1851.1316382727950728904941166470445901316`20.", ",", 
     "1852.70079149741732112839468439075445298594`20.", ",", 
     "1854.26916764140732028163766836120959713082`20.", ",", 
     "1855.83676552498823429148590050820697375068`20.", ",", 
     "1857.4035839683853080118983630037239734304`20.", ",", 
     "1858.96962179182233084712360551401652831638`20.", ",", 
     "1860.53487781551813805123705957810885752582`20.", ",", 
     "1862.09935085968314874678273917608217076172`20.", ",", 
     "1863.6630397445159397522829749203809600006`20.", ",", 
     "1865.22594329019985433987367960063425242514`20.", ",", 
     "1866.78806031689964507474123003447976094821`20.", ",", 
     "1868.34938964475814991741356832601130286306`20.", ",", 
     "1869.90993009389300079832493042997973753235`20.", ",", 
     "1871.46968048439336390146223171443601754087`20.", ",", 
     "1873.02863963631671092034229609391627379224`20.", ",", 
     "1874.58680636968562057509272636555313620512`20.", ",", 
     "1876.1441795044846097040444121428896590501`20.", ",", 
     "1877.70075786065699326701881972875121813362`20.", ",", 
     "1879.25654025810177262043590847533087089859`20.", ",", 
     "1880.81152551667055144650562902620471328467`20.", ",", 
     "1882.36571245616447874012360777037356272688`20.", ",", 
     "1883.91909989633121827769521918473283655116`20.", ",", 
     "1885.47168665686194401198650051686335228402`20.", ",", 
     "1887.02347155738836085626928900481798221672`20.", ",", 
     "1888.57445341747975033951490241883852788683`20.", ",", 
     "1890.12463105664004063221831913356237107612`20.", ",", 
     "1891.67400329430490045962517604858855022319`20.", ",", 
     "1893.22256894983885643570838886340759770589`20.", ",", 
     "1894.7703268425324333672205860310316141622`20.", ",", 
     "1896.31727579159931709255300440737646243577`20.", ",", 
     "1897.86341461617353943498059656018227533289`20.", ",", 
     "1899.40874213530668486418584175740844686967`20.", ",", 
     "1900.95325716796511847374856238005929284414`20.", ",", 
     "1902.49695853302723489558379826906009707508`20.", ",", 
     "1904.03984504928072778512181548005665843144`20.", ",", 
     "1905.58191553541987952337042687366045667565`20.", ",", 
     "1907.12316881004287079389626802773126039242`20.", ",", 
     "1908.66360369164910970422428811046384686969`20.", ",", 
     "1910.20321899863658013219877584614611586206`20.", ",", 
     "1911.74201354929920898848956127343267383612`20.", ",", 
     "1913.27998616182425209667796391740496282883`20.", ",", 
     "1914.81713565428969840223249198122211187924`20.", ",", 
     "1916.35346084466169223119768706189094435372`20.", ",", 
     "1917.8889605507919733285838752307145413214`20.", ",", 
     "1919.42363359041533441527352863510249107747`20.", ",", 
     "1920.95747878114709601076365379896420382683`20.", ",", 
     "1922.49049494048059827725489740337537824824`20.", ",", 
     "1924.02268088578470964848830433570210481256`20.", ",", 
     "1925.55403543430135201433090655195266630198`20.", ",", 
     "1927.08455740314304223943222907984558558355`20.", ",", 
     "1928.61424560929044980132567970649642376798`20.", ",", 
     "1930.14309886958997034014160409211852402085`20.", ",", 
     "1931.67111600075131491864216472946878683435`20.", ",", 
     "1933.19829581934511479759144039667794768394`20.", ",", 
     "1934.72463714180054153754622558691038352836`20.", ",", 
     "1936.25013878440294224400261211485291761048`20.", ",", 
     "1937.77479956329148977846893421443007947746`20.", ",", 
     "1939.29861829445684776346514055091410636836`20.", ",", 
     "1940.8215937937388502146799269912643241023`20.", ",", 
     "1942.34372487682419563855755519661075848246`20.", ",", 
     "1943.8650103592441554384434620355020550059`20.", ",", 
     "1945.38544905637229647709854487657739457497`20.", ",", 
     "1946.90503978342221764790315079038366720033`20.", ",", 
     "1948.4237813554453003114198254256692184575`20.", ",", 
     "1949.94167258732847245817507825508957463964`20.", ",", 
     "1951.45871229379198646256085733948169482364`20.", ",", 
     "1952.97489928938721029665194211500996516382`20.", ",", 
     "1954.49023238849443207649168835148509354022`20.", ",", 
     "1956.00471040532067781702092155217308104163`20.", ",", 
     "1957.51833215389754227531850127152362641971`20.", ",", 
     "1959.03109644807903276519220458459391440805`20.", ",", 
     "1960.54300210153942582940995185385353754024`20.", ",", 
     "1962.05404792777113665899869185372639372887`20.", ",", 
     "1963.56423274008260115206597226856850034071`20.", ",", 
     "1965.07355535159617050752167358711377579023`20.", ",", 
     "1966.58201457524601825189874508570940627476`20.", ",", 
     "1968.08960922377605960019605960207829492977`20.", ",", 
     "1969.59633810973788305429755621390840200746`20.", ",", 
     "1971.10220004548869414506337736669769746988`20.", ",", 
     "1972.60719384318927122664429862808325797669`20.", ",", 
     "1974.11131831480193323394382771200702655218`20.", ",", 
     "1975.61457227208851931644621552502755124786`20.", ",", 
     "1977.11695452660838026384644932185010632267`20.", ",", 
     "1978.61846388971638164106313743294304335012`20.", ",", 
     "1980.11909917256091855228997881724098538188`20.", ",", 
     "1981.61885918608194195574905702452393889387`20.", ",", 
     "1983.11774274100899645275221497453073292093`20.", ",", 
     "1984.61574864785926947655785598904542613166`20.", ",", 
     "1986.11287571693565180833217705385242838523`20.", ",", 
     "1987.60912275832480934928847293706846222419`20.", ",", 
     "1989.10448858189526607978806002693164209715`20.", ",", 
     "1990.59897199729549813784377040881118909485`20.", ",", 
     "1992.09257181395203895107398533046643508701`20.", ",", 
     "1993.58528684106759535771385333466367918273`20.", ",", 
     "1995.07711588761917465380263062455155718969`20.", ",", 
     "1996.56805776235622250513386950128161726211`20.", ",", 
     "1998.05811127379877166398026893227227080651`20.", ",", 
     "1999.54727523023560143198912040683407704668`20.", ",", 
     "2001.03554843972240781198909288323355417934`20.", ",", 
     "2002.52292971007998429275619589776311022018`20.", ",", 
     "2004.00941784889241321205766783836946285136`20.", ",", 
     "2005.49501166350526764452872249416213416248`20.", ",", 
     "2006.97970996102382376213995665779766944168`20.", ",", 
     "2008.46351154831128361618412235078303237358`20.", ",", 
     "2009.94641523198700829085119116443613080519`20.", ",", 
     "2011.42841981842476137957142385933583012583`20.", ",", 
     "2012.90952411375096273638869302495816557033`20.", ",", 
     "2014.38972692384295245568172824861189186191`20.", ",", 
     "2015.86902705432726503458035250055783490394`20.", ",", 
     "2017.34742331057791367342820044868027978659`20.", ",", 
     "2018.82491449771468467062385563371545623471`20.", ",", 
     "2020.30149942060144186912977339390348397996`20.", ",", 
     "2021.77717688384444111287368940126754249194`20.", ",", 
     "2023.25194569179065467218133030045908383574`20.", ",", 
     "2024.72580464852610559827298678915732836904`20.", ",", 
     "2026.19875255787421196773068853630040143375`20.", ",", 
     "2027.67078822339414097869810846339884917023`20.", ",", 
     "2029.14191044837917286141266224257854855684`20.", ",", 
     "2030.61211803585507456648926712661505961079`20.", ",", 
     "2032.08140978857848319517856205134211569356`20.", ",", 
     "2033.54978450903529913660971910796598838208`20.", ",", 
     "2035.01724099943908887779991807340891296036`20.", ",", 
     "2036.48377806172949745296970729426787537153`20.", ",", 
     "2037.94939449757067049944640701486510979182`20.", ",", 
     "2039.41408910834968588816697204244040914421`20.", ",", 
     "2040.87786069517499489750784294423001684357`20.", ",", 
     "2042.34070805887487289987277991639230924551`20.", ",", 
     "2043.80262999999587953116097079428621050316`20.", ",", 
     "2045.26362531880132831391729363113917414004`20.", ",", 
     "2046.72369281526976570563493447486883483809`20.", ",", 
     "2048.18283128909345954433803324775059381992`20.", ",", 
     "2049.64103953967689686421905782052673415996`20.", ",", 
     "2051.0983163661352910547425740948717201928`20.", ",", 
     "2052.5546605672930983372543573129294570695`20.", ",", 
     "2054.01007094168254353375273028074838775517`20.", ",", 
     "2055.4645462875421551030879560198331371331`20.", ",", 
     "2056.91808540281530942045577941251097566717`20.", ",", 
     "2058.37068708514878427664311474300496497644`20.", ",", 
     "2059.82235013189132157406771051474823707609`20.", ",", 
     "2061.27307334009219919722967377693558832691`20.", ",", 
     "2062.72285550649981203576127557728508499452`20.", ",", 
     "2064.17169542756026213882274768724229769474`20.", ",", 
     "2065.61959189941595798014606799791032398295`20.", ",", 
     "2067.06654371790422281357625698749705467984`20.", ",", 
     "2068.51254967855591209950069935784877683918`20.", ",", 
     "2069.95760857659403998309168263497181467636`20.", ",", 
     "2071.4017192069324148058159183225224091905`20.", ",", 
     "2072.84488036417428363218748238342862679458`20.", ",", 
     "2074.2870908426109857742575732894258104901`20.", ",", 
     "2075.7283494362206152968459224736597330299`20.", ",", 
     "2077.1686549386666924870247809248535193803`20.", ",", 
     "2078.60800614329684427186731671837071245832`20.", ",", 
     "2080.0464018431414935689681543322214705378`20.", ",", 
     "2081.48384083091255755473482379816482233681`20.", ",", 
     "2082.92032189900215483593521585476516930329`20.", ",", 
     "2084.35584383948132151046790196488078676666`20.", ",", 
     "2085.79040544409873610379951317280904883728`20.", ",", 
     "2087.22400550427945336798641158098124304853`20.", ",", 
     "2088.65664281112364693066675968513223360894`20.", ",", 
     "2090.08831615540536078187391781029046634641`20.", ",", 
     "2091.51902432757126958698299548459854505585`20.", ",", 
     "2092.94876611773944781455946119658968912364`20.", ",", 
     "2094.37754031569814766833208461187109864235`20.", ",", 
     "2095.80534571090458581296224976982049301409`20.", ",", 
     "2097.23218109248373888372793680816199483729`20.", ",", 
     "2098.65804524922714777068351929925354436349`20.", ",", 
     "2100.08293696959173066829605658442651222446`20.", ",", 
     "2101.50685504169860488199506431733704245453`20.", ",", 
     "2102.92979825333191738350590718574159144876`20.", ",", 
     "2104.35176539193768410726705769245008808064`20.", ",", 
     "2105.77275524462263798065858311106133648337`20.", ",", 
     "2107.19276659815308568119343555023780391405`20.", ",", 
     "2108.61179823895377311424450094194191327784`20.", ",", 
     "2110.02984895310675960529898254004307466429`20.", ",", 
     "2111.44691752635030080114762146679330790899`20.", ",", 
     "2112.86300274407774027482955684542729729996`20.", ",", 
     "2114.27810339133640982956436466443756942761`20.", ",", 
     "2115.69221825282653849731104908051249641584`20.", ",", 
     "2117.10534611290017022799955161963772168142`20.", ",", 
     "2118.51748575556009026588374989967137521181`20.", ",", 
     "2119.92863596445876020986599336585294392278`20.", ",", 
     "2121.33879552289726175504202255436835548203`20.", ",", 
     "2122.74796321382424911311169226884689700199`20.", ",", 
     "2124.15613781983491010969531777791094169197`20.", ",", 
     "2125.56331812316993595698773511660501481779`20.", ",", 
     "2126.96950290571449970057235865946397639024`20.", ",", 
     "2128.374690948997243339605676714587299299`20.", ",", 
     "2129.77888103418927361996879294418023613464`20.", ",", 
     "2131.18207194210316650036684057741553497645`20.", ",", 
     "2132.58426245319198029173940898570145201533`20.", ",", 
     "2133.98545134754827747072556834273330247181`20.", ",", 
     "2135.38563740490315516830569671326402889731`20.", ",", 
     "2136.7848194046252843351191427933346516308`20.", ",", 
     "2138.18299612571995758533183336289235181866`20.", ",", 
     "2139.58016634682814572130129297067092772627`20.", ",", 
     "2140.97632884622556294165821911444451529094`20.", ",", 
     "2142.37148240182174073579378291379618835304`20.", ",", 
     "2143.76562579115911046811023578569368259158`20.", ",", 
     "2145.15875779141209465575922883253575331045`20.", ",", 
     "2146.55087717938620694395752459895795127814`20.", ",", 
     "2147.94198273151716078333353079597647503758`20.", ",", 
     "2149.33207322386998681412034199660520330061`20.", ",", 
     "2150.72114743213815896237176689295900425766`20.", ",", 
     "2152.10920413164272925373717346634791210691`20.", ",", 
     "2153.4962420973314713506889296598781361274`20.", ",", 
     "2154.88226010377803281945277949016683219358`20.", ",", 
     "2156.26725692518109613324669997992639813212`20.", ",", 
     "2157.65123133536354841878765820533097254989`20.", ",", 
     "2159.0341821077716599533782549025655148284`20.", ",", 
     "2160.41610801547427142023652566177533398656`20.", ",", 
     "2161.79700783116198993008219639271742345075`20.", ",", 
     "2163.17688032714639381734147957690667101601`20.", ",", 
     "2164.55572427535924621968007440962386000735`20.", ",", 
     "2165.9335384473517174499204193644425452435`20.", ",", 
     "2167.31032161429361616974446158110899216433`20.", ",", 
     "2168.68607254697262937492727491414552787322`20.", ",", 
     "2170.06079001579357120218979816021151014251`20.", ",", 
     "2171.43447279077764056810079714337490911122`20.", ",", 
     "2172.80711964156168765079889878947333864134`20.", ",", 
     "2174.1787293373974892256452214611578285507`20.", ",", 
     "2175.54930064715103286625575265080255436853`20.", ",", 
     "2176.91883233930181002270022124699981339298`20.", ",", 
     "2178.28732318194211798899079523170705571918`20.", ",", 
     "2179.65477194277637077231952469180302684872`20.", ",", 
     "2181.02117738912041887683806194609958650469`20.", ",", 
     "2182.38653828790087801510684255429813431698`20.", ",", 
     "2183.75085340565446676067361980693539639737`20.", ",", 
     "2185.11412150852735315557302748407027295226`20.", ",", 
     "2186.47634136227451028686971738268901171375`20.", ",", 
     "2187.83751173225908084669759520210378775225`20.", ",", 
     "2189.19763138345175069057677639020893301359`20.", ",", 
     "2190.55669908043013140911811773934592133757`20.", ",", 
     "2191.91471358737815192855256583428754316554`20.", ",", 
     "2193.27167366808545915584911456608575985813`20.", ",", 
     "2194.62757808594682768451089522401733779528`20.", ",", 
     "2195.98242560396157857746384827942639691665`20.", ",", 
     "2197.33621498473300724377655972734509118151`20.", ",", 
     "2198.68894499046782042627320033875605509897`20.", ",", 
     "2200.04061438297558231742409672463736568392`20.", ",", 
     "2201.39122192366816982122030179573989793762`20.", ",", 
     "2202.74076637355923697905963184407410849778`20.", ",", 
     "2204.08924649326368857799201065385418390683`20.", ",", 
     "2205.43666104299716295999162011171431344064`20.", ",", 
     "2206.78300878257552405124231383294581704049`20.", ",", 
     "2208.12828847141436263074101722470319008275`20.", ",", 
     "2209.47249886852850685784142581244933754711`20.", ",", 
     "2210.8156387325315420786772349811374664254`20.", ",", 
     "2212.1577068216353399317203997247722374524`20.", ",", 
     "2213.49870189364959677304554353545484559515`20.", ",", 
     "2214.83862270598138144218662195859157016698`20.", ",", 
     "2216.17746801563469238978630914470019437428`20.", ",", 
     "2217.51523657921002418855232528026504365606`20.", ",", 
     "2218.85192715290394344934806921308465045955`20.", ",", 
     "2220.18753849250867416455747382937608729766`20.", ",", 
     "2221.52206935341169250117597151591887586342`20.", ",", 
     "2222.8555184905953310663908528759137382193`20.", ",", 
     "2224.18788465863639266872513308915190152007`20.", ",", 
     "2225.51916661170577359812931604675346735096`20.", ",", 
     "2226.84936310356809644871517558539859542236`20.", ",", 
     "2228.17847288758135250813486454084577088753`20.", ",", 
     "2229.50649471669655373791732449056459955811`20.", ",", 
     "2230.83342734345739436938211032694862688551`20.", ",", 
     "2232.15926951999992214005837237539621764642`20.", ",", 
     "2233.48401999805221919584386263984966091158`20.", ",", 
     "2234.80767752893409268444545873268188274669`20.", ",", 
     "2236.1302408635567750659488367542951375281`20.", ",", 
     "2237.45170875242263416667058027766019685596`20.", ",", 
     "2238.77207994562489300275119393183691244069`20.", ",", 
     "2240.09135319284735940025220395543342812048`20.", ",", 
     "2241.40952724336416543882478141792788510151`20.", ",", 
     "2242.72660084603951674632112331966808187517`20.", ",", 
     "2244.04257274932745167202317904107025326413`20.", ",", 
     "2245.35744170127161036646622100499568682325`20.", ",", 
     "2246.67120644950501379613723515746545254308`20.", ",", 
     "2247.98386574124985272163015500272409063489`20.", ",", 
     "2249.29541832331728666814158831999404876853`20.", ",", 
     "2250.60586294210725291749189404160108458339`20.", ",", 
     "2251.91519834360828555115726361654762958726`20.", ",", 
     "2253.2234232733973445740988518824075527825`20.", ",", 
     "2254.53053647663965514947499221597212134545`20.", ",", 
     "2255.83653669808855697462212455646229874063`20.", ",", 
     "2257.14142268208536382898926765476877048769`20.", ",", 
     "2258.44519317255923332500968329250147452234`20.", ",", 
     "2259.74784691302704689319181476460391770771`20.", ",", 
     "2261.04938264659330003300963899301031051838`20.", ",", 
     "2262.34979911595000286147025543602831828771`20.", ",", 
     "2263.64909506337659099153384951467477579369`20.", ",", 
     "2264.947269230739846772858117465517231258`20.", ",", 
     "2266.2443203594938309276358270591344641631`20.", ",", 
     "2267.54024719067982461459041804097140092356`20.", ",", 
     "2268.83504846492628195449042084178215759751`20.", ",", 
     "2270.12872292244879305083899529081659869102`20.", ",", 
     "2271.42126930305005753969006580765203839353`20.", ",", 
     "2272.71268634611986870283735874809261854916`20.", ",", 
     "2274.00297279063510817891713397486407613075`20.", ",", 
     "2275.29212737515975130725954889319636776021`20.", ",", 
     "2276.58014883784488313961740155257491685295`20.", ",", 
     "2277.8670359164287251551944722264056792198`20.", ",", 
     "2279.15278734823667271468882223839854731333`20.", ",", 
     "2280.43740187018134328935921664546857353858`20.", ",", 
     "2281.72087821876263550141531548938209581809`20.", ",", 
     "2283.00321513006779901232442831100196984199`20.", ",", 
     "2284.28441133977151529591944993994244699098`20.", ",", 
     "2285.56446558313598933348409352729544109678`20.", ",", 
     "2286.84337659501105226828271051889106019539`20.", ",", 
     "2288.12114310983427505729283775088498941425`20.", ",", 
     "2289.39776386163109315818913990844164997743`20.", ",", 
     "2290.673237584014942289917621882558892561`20.", ",", 
     "2291.94756301018740530548887059082672535446`20.", ",", 
     "2293.2207388729383702159086499367747058678`20.", ",", 
     "2294.49276390464619940445341595150584267163`20.", ",", 
     "2295.76363683727791007078724181295170374129`20.", ",", 
     "2297.03335640238936594470524423498297521698`20.", ",", 
     "2298.30192133112548030957688336359120767424`20.", ",", 
     "2299.5693303542204303758504673532671376821`20.", ",", 
     "2300.83558220199788304526782960627343238711`20.", ",", 
     "2302.10067560437123210672546046321332240437`20.", ",", 
     "2303.36460929084384690500536499716357856133`20.", ",", 
     "2304.62738199050933252388558338708154285725`20.", ",", 
     "2305.88899243205180152542664886980095595948`20.", ",", 
     "2307.14943934374615728751626907325345313795`20.", ",", 
     "2308.40872145345838898204019803487974350954`20.", ",", 
     "2309.66683748864587823633261666530557681659`20.", ",", 
     "2310.92378617635771752084435692326510166975`20.", ",", 
     "2312.17956624323504030625198745643270302562`20.", ",", 
     "2313.43417641551136303351512370492560600492`20.", ",", 
     "2314.68761541901293894067333106779392048133`20.", ",", 
     "2315.93988197915912379045765314291998327893`20.", ",", 
     "2317.19097482096275354307511554924497703171`20.", ",", 
     "2318.44089266903053401880752654537303998874`20.", ",", 
     "2319.68963424756344259534851552467162800769`20.", ",", 
     "2320.93719828035714198508501628398437216426`20.", ",", 
     "2322.18358349080240613781131035630934863762`20.", ",", 
     "2323.42878860188555831464529312751263703695`20.", ",", 
     "2324.67281233618892137919780821811717933662`20.", ",", 
     "2325.91565341589128035232670983232481703564`20.", ",", 
     "2327.15731056276835727708775442028859737353`20.", ",", 
     "2328.39778249819329844077448786211267485727`20.", ",", 
     "2329.63706794313717400121897809179906626693`20.", ",", 
     "2330.87516561816949006480454109743024146424`20.", ",", 
     "2332.1120742434587132639205158532188465902`20.", ",", 
     "2333.34779253877280788186765608403691357482`20.", ",", 
     "2334.58231922347978557350081878895626344735`20.", ",", 
     "2335.8156530165482677301733359429241333319`20.", ",", 
     "2337.04779263654806053782475137062451657839`20.", ",", 
     "2338.27873680165074277733048388890543580939`20.", ",", 
     "2339.50848422963026641650843471783380751012`20.", ",", 
     "2340.73703363786357004345358596776229378742`20.", ",", 
     "2341.96438374333120519114723165083931504611`20.", ",", 
     "2343.19053326261797560356263689748289232612`20.", ",", 
     "2344.41548091191358949376362846545919225086`20.", ",", 
     "2345.63922540701332484476687362143919318971`20.", ",", 
     "2346.86176546331870780421239828784233711971`20.", ",", 
     "2348.08309979583820422416022204192067905031`20.", ",", 
     "2349.30322711918792439760384001421038138404`20.", ",", 
     "2350.52214614759234104356365266820223537904`20.", ",", 
     "2351.739855594885020592895326383965692089`20.", ",", 
     "2352.95635417450936782721945306956570197784`20.", ",", 
     "2354.17164059951938392364975786132411736814`20.", ",", 
     "2355.38571358258043795826747234436273022858`20.", ",", 
     "2356.59857183597005192155933844601700511481`20.", ",", 
     "2357.81021407157869929930602686409280033963`20.", ",", 
     "2359.02063900091061727267653504622272865381`20.", ",", 
     "2360.2298453350846325915523646109670927868`20.", ",", 
     "2361.43783178483500117537295778885254719514`20.", ",", 
     "2362.64459706051226149606098787247267722519`20.", ",", 
     "2363.8501398720841017978526405257852393667`20.", ",", 
     "2365.05445892913624120912398165630173917596`20.", ",", 
     "2366.25755294087332480156987375751538044647`20.", ",", 
     "2367.45942061611983265235666635454847795133`20.", ",", 
     "2368.66006066332100296513403741915323591573`20.", ",", 
     "2369.85947179054376930605489115931760308024`20.", ",", 
     "2371.05765270547771201121511304444219905965`20.", ",", 
     "2372.25460211543602382218723472144586476384`20.", ",", 
     "2373.4503187273564898065836588430158327572`20.", ",", 
     "2374.64480124780248162084602580929672485019`20.", ",", 
     "2375.83804838296396617271755987057621671002`20.", ",", 
     "2377.03005883865852874111479961139738882986`20.", ",", 
     "2378.22083132033241061137398600412925097324`20.", ",", 
     "2379.41036453306156128410553825741174744413`20.", ",", 
     "2380.59865718155270531614748167327861641683`20.", ",", 
     "2381.78570797014442385236539055276198122109`20.", ",", 
     "2382.97151560280825090730236054462357150779`20.", ",", 
     "2384.15607878314978445593771621060203536625`20.", ",", 
     "2385.33939621440981239306757828132918852201`20.", ",", 
     "2386.52146659946545342107404820023132143572`20.", ",", 
     "2387.70228864083131292610260200015152904679`20.", ",", 
     "2388.88186104066065390291930803164532009467`20.", ",", 
     "2390.06018250074658298897068006534199659598`20.", ",", 
     "2391.23725172252325166841933512494584856297`20.", ",", 
     "2392.41306740706707270717813017218113018029`20.", ",", 
     "2393.5876282550979518802140893575577361175`20.", ",", 
     "2394.76093296698053505264118966522855918852`20.", ",", 
     "2395.93298024272547067636793290628069047624`20.", ",", 
     "2397.10376878199068776431158143747761889921`20.", ",", 
     "2398.27329728408268940443595878093755393801`20.", ",", 
     "2399.44156444795786187611379936713621084129`20.", ",", 
     "2400.6085689722237994315577585842462164472`20.", ",", 
     "2401.77430955514064480530634964828746854436`20.", ",", 
     "2402.93878489462244551499224175900257044902`20.", ",", 
     "2404.10199368823852601686051861413852114094`20.", ",", 
     "2405.26393463321487577974364144765936002184`20.", ",", 
     "2406.42460642643555334143796995167249821034`20.", ",", 
     "2407.58400776444410641166375114164116887568`20.", ",", 
     "2408.74213734344500808602647362086371105578`20.", ",", 
     "2409.89899385930510923563238577047597817128`20.", ",", 
     "2411.05457600755510713724477389797995290192`20.", ",", 
     "2412.20888248339103040910027286767333825927`20.", ",", 
     "2413.36191198167574031773601954125180938334`20.", ",", 
     "2414.51366319694044852140884059012343081274`20.", ",", 
     "2415.66413482338625131591687279860529154402`20.", ",", 
     "2416.81332555488568044886202753650768159395`20.", ",", 
     "2417.96123408498427056861851309854929198725`20.", ",", 
     "2419.10785910690214337449820032425224027324`20.", ",", 
     "2420.25319931353560853482793934208125668204`20.", ",", 
     "2421.39725339745878143987698922045547376762`20.", ",", 
     "2422.54002005092521785679448832812852902187`20.", ",", 
     "2423.68149796586956555393735165619763898091`20.", ",", 
     "2424.82168583390923296218811235842964697354`20.", ",", 
     "2425.96058234634607494108000822554954530903`20.", ",", 
     "2427.0981861941680957177630293968348862872`20.", ",", 
     "2428.23449606805116906705967077659453286389`20.", ",", 
     "2429.36951065836077580107275058451538170324`20.", ",", 
     "2430.50322865515375863701984422016098538095`20.", ",", 
     "2431.63564874818009451217961892718026820997`20.", ",", 
     "2432.76676962688468441504461813673385658498`20.", ",", 
     "2433.89658998040916080198281315686844941009`20.", ",", 
     "2435.02510849759371266891649212884440901624`20.", ",", 
     "2436.15232386697892834773176973499599660693`20.", ",", 
     "2437.27823477680765609733515362559208829886`20.", ",", 
     "2438.40283991502688255947517231145468128886`20.", ",", 
     "2439.52613796928962914964703148825642596708`20.", ",", 
     "2440.64812762695686645359659832663885802648`20.", ",", 
     "2441.76880757509944670013669285379272830913`20.", ",", 
     "2442.88817650050005438118366860552484436672`20.", ",", 
     "2444.0062330896551750901155674454385126114`20.", ",", 
     "2445.12297602877708264974471179510609394552`20.", ",", 
     "2446.23840400379584460138742722390544877882`20.", ",", 
     "2447.35251570036134612670164489926607946619`20.", ",", 
     "2448.46530980384533247414939204840306898754`20.", ",", 
     "2449.57678499934346996212561434282815010076`20.", ",", 
     "2450.68693997167742563097736175869710810944`20.", ",", 
     "2451.79577340539696561631808352054847862495`20.", ",", 
     "2452.90328398478207231622059249330558497375`20.", ",", 
     "2454.00947039384508042504914889602979443934`20.", ",", 
     "2455.11433131633283190686605127715377807479`20.", ",", 
     "2456.21786543572884998152108287844539546285`20.", ",", 
     "2457.32007143525553219670311714423555471401`20.", ",", 
     "2458.42094799787636265940211028030021134655`20.", ",", 
     "2459.5204938062981435003965742658877254065`20.", ",", 
     "2460.61870754297324564554640316079431015726`20.", ",", 
     "2461.71558789010187896783359127012914494847`20.", ",", 
     "2462.81113352963438189425390583001496277856`20.", ",", 
     "2463.90534314327353054182093120958597063329`20.", ",", 
     "2464.99821541247686745710005779363115443944`20.", ",", 
     "2466.08974901845905003384391807477887939923`20.", ",", 
     "2467.17994264219421868345244615589137588427`20.", ",", 
     "2468.26879496441838483313012570662686359537`20.", ",", 
     "2469.35630466563183882676006604952791705407`20.", ",", 
     "2470.44247042610157780365927683910023199949`20.", ",", 
     "2471.52729092586375363052186886246037523538`20.", ",", 
     "2472.61076484472614096199686170400293258631`20.", ",", 
     "2473.69289086227062550548479800211324014827`20.", ",", 
     "2474.77366765785571256587241815714996988724`20.", ",", 
     "2475.85309391061905594605720775142803300648`20.", ",", 
     "2476.93116829948000727924366148901632084567`20.", ",", 
     "2478.00788950314218586912058078151951918404`20.", ",", 
     "2479.08325620009606911415360557161562456246`20.", ",", 
     "2480.15726706862160359234944272511660845301`20.", ",", 
     "2481.22992078679083688296786121093094974488`20.", ",", 
     "2482.30121603247057020177444595276366238861`20.", ",", 
     "2483.37115148332503192654130505288621694738`20.", ",", 
     "2484.43972581681857208961437618298467903`20.", ",", 
     "2485.50693771021837791447464418604009812588`20.", ",", 
     "2486.57278584059721047332642996248472940207`20.", ",", 
     "2487.63726888483616254284890689962711325739`20.", ",", 
     "2488.70038551962743773534711157179166636733`20.", ",", 
     "2489.76213442147715098263590606625752039663`20.", ",", 
     "2490.82251426670815045008458570377068222265`20.", ",", 
     "2491.88152373146286095834107349955627130764`20.", ",", 
     "2492.93916149170614899034286657953417157989`20.", ",", 
     "2493.99542622322820936130706480597645884579`20.", ",", 
     "2495.05031660164747362947388270750504300813`20.", ",", 
     "2496.10383130241354032545698683199830347033`20.", ",", 
     "2497.15596900081012707812977598137946382694`20.", ",", 
     "2498.20672837195804471504929533030792071531`20.", ",", 
     "2499.25610809081819341548881081496882223433`20.", ",", 
     "2500.3041068321945809942161307949215304412`20.", ",", 
     "2501.35072327073736339421751098522293593126`20.", ",", 
     "2502.39595608094590746662637892659962328878`20.", ",", 
     "2503.43980393717187611617212846154704674851`20.", ",", 
     "2504.48226551362233589051682522210839929763`20.", ",", 
     "2505.52333948436288709189679317452233843051`20.", ",", 
     "2506.56302452332081648953168172690803150342`20.", ",", 
     "2507.60131930428827271130570446550692981201`20.", ",", 
     "2508.63822250092546439326425567709579279472`20.", ",", 
     "2509.67373278676388116550401063267436750538`20.", ",", 
     "2510.70784883520953755306586110211211107828`20.", ",", 
     "2511.74056931954623987046758945266919260355`20.", ",", 
     "2512.77189291293887618853700342845450508455`20.", ",", 
     "2513.80181828843672945222629954681383628287`20.", ",", 
     "2514.83034411897681382810465597775059443397`20.", ",", 
     "2515.85746907738723436023843555366734838663`20.", ",", 
     "2516.8831918363905700131768657133918778816`20.", ",", 
     "2517.90751106860728018076561400660102356253`20.", ",", 
     "2518.93042544655913473951125432903440896452`20.", ",", 
     "2519.95193364267266772521617914976658486852`20.", ",", 
     "2520.97203432928265471159601522274919486975`20.", ",", 
     "2521.99072617863561396958000300954581016848`20.", ",", 
     "2523.0080078628933314859790614138719473145`20.", ",", 
     "2524.02387805413640992018633734926667640619`20.", ",", 
     "2525.03833542436784157755089181120770089297`20.", ",", 
     "2526.05137864551660547803675796210955804604`20.", ",", 
     "2527.06300638944128859874687949687121848638`20.", ",", 
     "2528.07321732793373136885435625152410932516`20.", ",", 
     "2529.0820101327226974954419454417985983012`20.", ",", 
     "2530.08938347547756819870484764757963768184`20.", ",", 
     "2531.09533602781206093492140305220731871773`20.", ",", 
     "2532.09986646128797268554139164650076370943`20.", ",", 
     "2533.10297344741894789068212704727572681504`20.", ",", 
     "2534.10465565767427110525841297876461039403`20.", ",", 
     "2535.10491176348268445590364983312869960576`20.", ",", 
     "2536.1037404362362299767658913661180939472`20.", ",", 
     "2537.10114034729411690218441359335406245992`20.", ",", 
     "2538.09711016798661399416932422571369982046`20.", ",", 
     "2539.09164856961896698251886621157591056049`20.", ",", 
     "2540.08475422347534119531630763273322669566`20.", ",", 
     "2541.07642580082278945745061662608837583534`20.", ",", 
     "2542.06666197291524533470244827661400887109`20.", ",", 
     "2543.05546141099754180082927445783054646661`20.", ",", 
     "2544.04282278630945540497072110359939720596`20.", ",", 
     "2545.02874477008977601657729391110323257537`20.", ",", 
     "2546.01322603358040222494262634617692335669`20.", ",", 
     "2546.99626524803046247029112621282887189446`20.", ",", 
     "2547.97786108470046198323938194312507247262`20.", ",", 
     "2548.95801221486645560931086996866171999457`20.", ",", 
     "2549.93671730982424659503933268323281518638`20.", ",", 
     "2550.9139750408936114120466250589685962445`20.", ",", 
     "2551.88978407942255069532580922737361914553`20.", ",", 
     "2552.86414309679156637179976240870105854265`20.", ",", 
     "2553.83705076441796505505950643151854344987`20.", ",", 
     "2554.80850575376018778201481853296715789274`20.", ",", 
     "2555.7785067363221661670123948163083942818`20.", ",", 
     "2556.74705238365770504879386115972593916122`20.", ",", 
     "2557.71414136737489170547721286272370183403`20.", ",", 
     "2558.67977235914053171255076508080102771487`20.", ",", 
     "2559.64394403068461151866836218900966560488`20.", ",", 
     "2560.60665505380478781382837654426825302418`20.", ",", 
     "2561.56790410037090376430687646239565879228`20.", ",", 
     "2562.52768984232953218849721023352537223182`20.", ",", 
     "2563.48601095170854574758408818471720977978`20.", ",", 
     "2564.44286610062171422474999855184134459853`20.", ",", 
     "2565.39825396127332896637541551348740229406`20.", ",", 
     "2566.35217320596285455845169931965010279909`20.", ",", 
     "2567.30462250708960781117679905575105653017`20.", ",", 
     "2568.25560053715746412444879814732378600681`20.", ",", 
     "2569.20510596877959130671094105637827000761`20.", ",", 
     "2570.15313747468321091933399647007564373719`20.", ",", 
     "2571.0996937277143872184475972622322734651`20.", ",", 
     "2572.04477340084284376585150015241494825102`20.", ",", 
     "2572.98837516716680778035047774225736434143`20.", ",", 
     "2573.93049769991788230056274183712920524324`20.", ",", 
     "2574.87113967246594622995134894778642951203`20.", ",", 
     "2575.81029975832408233452090582154778671651`20.", ",", 
     "2576.74797663115353326330802391714442278974`20.", ",", 
     "2577.68416896476868566147331598865232122794`20.", ",", 
     "2578.61887543314208244547523439947443017205`20.", ",", 
     "2579.55209471040946330947166841051268644615`20.", ",", 
     "2580.48382547087483353175389539158580394119`20.", ",", 
     "2581.41406638901556114966916756193566487878`20.", ",", 
     "2582.34281613948750257113286030573956466001`20.", ",", 
     "2583.2700733971301566904686591299800754046`20.", ",", 
     "2584.19583683697184757594566870500296695941`20.", ",", 
     "2585.12010513423493579600453790045415072183`20.", ",", 
     "2586.04287696434105845078065803214854528856`20.", ",", 
     "2586.96415100291639797514115638890508405292`20.", ",", 
     "2587.88392592579697977905372222740335064445`20.", ",", 
     "2588.80220040903399879069921652329468880861`20.", ",", 
     "2589.71897312889917496732647857042774282315`20.", ",", 
     "2590.63424276189013783842670076216811829228`20.", ",", 
     "2591.54800798473584014537614632335792596794`20.", ",", 
     "2592.46026747440200064125978216759031792893`20.", ",", 
     "2593.37101990809657611414453924279015225272`20.", ",", 
     "2594.28026396327526269661934454715950453676`20.", ",", 
     "2595.18799831764702652395974134039893558741`20.", ",", 
     "2596.09422164917966380280777588587278283304`20.", ",", 
     "2596.99893263610539035178282933996954377327`20.", ",", 
     "2597.90212995692646067495616122184174379759`20.", ",", 
     "2598.80381229042081662863105538802286906444`20.", ",", 
     "2599.70397831564776574137156981863840181081`20.", ",", 
     "2600.60262671195368924671593709716497858245`20.", ",", 
     "2601.49975615897777988749559262882469437073`20.", ",", 
     "2602.39536533665780955015757188865394580431`20.", ",", 
     "2603.28945292523592678695656592139936870024`20.", ",", 
     "2604.18201760526448428334320564889584813318`20.", ",", 
     "2605.07305805761189632732711011615411937498`20.", ",", 
     "2605.96257296346852633703683159482301506759`20.", ",", 
     "2606.85056100435260450213401156966146269747`20.", ",", 
     "2607.73702086211617559416577631355352754844`20.", ",", 
     "2608.6219512189510770003575994165029613313`20.", ",", 
     "2609.50535075739494703475849184276007646314`20.", ",", 
     "2610.38721816033726358005139858645152558305`20.", ",", 
     "2611.26755211102541311273403569661689699073`20.", ",", 
     "2612.14635129307079016375904345068968587983`20.", ",", 
     "2613.02361439045492726609721206939231171361`20.", ",", 
     "2613.89934008753565544005360708739826639323`20.", ",", 
     "2614.77352706905329526652363403669683352056`20.", ",", 
     "2615.64617402013687859772438839795838178077`20.", ",", 
     "2616.51727962631040095427598899359357526421`20.", ",", 
     "2617.38684257349910465683794353748864959529`20.", ",", 
     "2618.25486154803579273982689657108562649928`20.", ",", 
     "2619.1213352366671736940543154108442354365`20.", ",", 
     "2619.98626232656023708442573218146718268248`20.", ",", 
     "2620.84964150530866008813703296123396066888`20.", ",", 
     "2621.7114714609392449980879222537902847308`20.", ",", 
     "2622.57175088191838773550804645250940304823`20.", ",", 
     "2623.43047845715857741505728801074650492627`20.", ",", 
     "2624.2876528760249270049183973192855218164`20.", ",", 
     "2625.14327282834173512364736678986296114267`20.", ",", 
     "2625.9973370043990790147847266531036332138`20.", ",", 
     "2626.84984409495943873945921014622477562353`20.", ",", 
     "2627.70079279126435262643395308973692899192`20.", ",", 
     "2628.55018178504110401825451569616521511286`20.", ",", 
     "2629.39800976850943935135749955472014480232`20.", ",", 
     "2630.24427543438831760718833721558127250414`20.", ",", 
     "2631.08897747590269117055691317278404743224`20.", ",", 
     "2631.93211458679031813062999123804253766464`20.", ",", 
     "2632.77368546130860605911993264798715055913`20.", ",", 
     "2633.61368879424148729937985052020787591088`20.", ",", 
     "2634.4521232809063257992561186732031812367`20.", ",", 
     "2635.28898761716085551967999600494568180704`20.", ",", 
     "2636.12428049941015045010100169755240507223`20.", ",", 
     "2636.95800062461362626097554206610234715594`20.", ",", 
     "2637.79014669029207362262510796521835900761`20.", ",", 
     "2638.62071739453472321886909386886878158862`20.", ",", 
     "2639.44971143600634248291789811366219816783`20.", ",", 
     "2640.2771275139543640820824109274527596133`20.", ",", 
     "2641.10296432821604617691624586577345648114`20.", ",", 
     "2641.92722057922566447945708480132657538986`20.", ",", 
     "2642.74989496802173613427325086160080725319`20.", ",", 
     "2643.5709861962542754450510624559535798171`20.", ",", 
     "2644.39049296619208146847762012169259218998`20.", ",", 
     "2645.20841398073005749618240228260782175059`20.", ",", 
     "2646.02474794339656244449936268732690807578`20.", ",", 
     "2646.83949355836079417079909842583751238571`20.", ",", 
     "2647.65264953044020473411806078270824726835`20.", ",", 
     "2648.46421456510794761677868018468267241697`20.", ",", 
     "2649.27418736850035692265064019825613649157`20.", ",", 
     "2650.08256664742445856664933365212234542834`20.", ",", 
     "2650.88935110936551346900273689795266449961`20.", ",", 
     "2651.69453946249459276674251706698615024775`20.", ",", 
     "2652.49813041567618505378911371654056305015`20.", ",", 
     "2653.30012267847583565990378299095498647264`20.", ",", 
     "2654.10051496116781797767313257377797841895`20.", ",", 
     "2654.89930597474283684557348325042797408035`20.", ",", 
     "2655.69649443091576399403344255451597502186`20.", ",", 
     "2656.49207904213340556027334322444632473829`20.", ",", 
     "2657.28605852158230167654966031749128295183`20.", ",", 
     "2658.07843158319655813527115287712036494018`20.", ",", 
     "2658.86919694166571013328125689341632178298`20.", ",", 
     "2659.65835331244261809641816462351297738052`20.", ",", 
     "2660.44589941175139558427004067044368794511`20.", ",", 
     "2661.23183395659536927383792792325095928054`20.", ",", 
     "2662.0161556647650710196030677684090592326`20.", ",", 
     "2662.7988632548462619862685809971318813221`20.", ",", 
     "2663.57995544622798884920771154824096341325`20.", ",", 
     "2664.35943095911067205640210853779395818143`20.", ",", 
     "2665.13728851451422614439389774699074860106`20.", ",", 
     "2665.91352683428621209950455761188556730465`20.", ",", 
     "2666.6881446411100217542918534696349543579`20.", ",", 
     "2667.46114065851309420792328501260290992559`20.", ",", 
     "2668.23251361087516425784065420268974529525`20.", ",", 
     "2669.002262223436542828775453909884827904`20.", ",", 
     "2669.77038522230642938384880186872504058798`20.", ",", 
     "2670.53688133447125630115259181715083599813`20.", ",", 
     "2671.30174928780306519786039654722967542723`20.", ",", 
     "2672.06498781106791518255742975373834242336`20.", ",", 
     "2672.82659563393432301510854977078733551792`20.", ",", 
     "2673.5865714869817351520018643678585574917`20.", ",", 
     "2674.34491410170903165371296865181938773874`20.", ",", 
     "2675.10162221054306192923121580987305109505`20.", ",", 
     "2675.85669454684721229147468206594136744986`20.", ",", 
     "2676.61012984493000529589464307688444749623`20.", ",", 
     "2677.36192684005373083313343047836269514428`20.", ",", 
     "2678.11208426844310894515148697665501365487`20.", ",", 
     "2678.86060086729398433278029002110179195019`20.", ",", 
     "2679.60747537478205252118757262054434622879`20.", ",", 
     "2680.35270653007161764825994142910609049357`20.", ",", 
     "2681.09629307332438183941558418391046157685`20.", ",", 
     "2681.83823374570826613085627952561830422679`20.", ",", 
     "2682.578527289406262901753382016186899898`20.", ",", 
     "2683.31717244762531977433686489430825393398`20.", ",", 
     "2684.05416796460525493931987516266658043728`20.", ",", 
     "2684.78951258562770386254360366001430697745`20.", ",", 
     "2685.52320505702509732716861181977688905144`20.", ",", 
     "2686.25524412618967076416910316191298703494`20.", ",", 
     "2686.98562854158250482230599884895264300863`20.", ",", 
     "2687.71435705274259712716309185443199785027`20.", ",", 
     "2688.44142841029596517722803380191021561942`20.", ",", 
     "2689.16684136596478032338647407519695826209`20.", ",", 
     "2689.89059467257653277657334550993128087731`20.", ",", 
     "2690.61268708407322758669009939714554219936`20.", ",", 
     "2691.33311735552061153425066062864119264835`20.", ",", 
     "2692.05188424311743087456202899788491882187`20.", ",", 
     "2692.76898650420471987257782379737633056262`20.", ",", 
     "2693.48442289727512006488468624977424093477`20.", ",", 
     "2694.19819218198223018359234978261628547413`20.", ",", 
     "2694.91029311914998667519839500800834883972`20.", ",", 
     "2695.62072447078207474578825931186438602804`20.", ",", 
     "2696.32948500007136986221000652886301882513`20.", ",", 
     "2697.03657347140940963713171815412813010915`20.", ",", 
     "2697.74198865039589602414718334780161368432`20.", ",", 
     "2698.44572930384822774734288161738256800559`20.", ",", 
     "2699.14779419981106288797611208823879360766`20.", ",", 
     "2699.84818210756591154914057086220682136235`20.", ",", 
     "2700.5468917976407585175117588924491163074`20.", ",", 
     "2701.24392204181971583947036446575633180125`20.", ",", 
     "2701.93927161315270522709725581211713010412`20.", ",", 
     "2702.63293928596517020771899123476950330978`20.", ",", 
     "2703.32492383586781792885785881290121113782`20.", ",", 
     "2704.01522403976639052860544918942208059548`20.", ",", 
     "2704.70383867587146597959369892162388553847`20.", ",", 
     "2705.39076652370828831288227574806113248216`20.", ",", 
     "2706.07600636412662712621617002970399689683`20.", ",", 
     "2706.75955697931066627923246940331684428682`20.", ",", 
     "2707.4414171527889216763105889256903956554`20.", ",", 
     "2708.12158566944418803586577102656295538951`20.", ",", 
     "2708.80006131552351454298152452817410149431`20.", ",", 
     "2709.47684287864820928036290770967676037704`20.", ",", 
     "2710.15192914782387233066924656342741094712`20.", ",", 
     "2710.82531891345045744135208747688947226385`20.", ",", 
     "2711.49701096733236214118198686086502106204`20.", ",", 
     "2712.16700410268854619569621383899534721512`20.", ",", 
     "2712.83529711416267828683866295810291670612`20.", ",", 
     "2713.50188879783331080009332076470708935845`20.", ",", 
     "2714.16677795122408260043358366942277631653`20.", ",", 
     "2714.8299633733139496764216673072367612069`20.", ",", 
     "2715.49144386454744352979536399779900272962`20.", ",", 
     "2716.15121822684495718587358120714068842813`20.", ",", 
     "2716.80928526361305869809751830371895122593`20.", ",", 
     "2717.4656437797548320180011014925645277322`20.", ",", 
     "2718.12029258168024509987248962892736291471`20.", ",", 
     "2718.77323047731654510732818061659171262713`20.", ",", 
     "2719.4244562761186805869725851871164271967`20.", ",", 
     "2720.07396878907975047225898988698965114156`20.", ",", 
     "2720.72176682874147977860270388284255582423`20.", ",", 
     "2721.36784920920472184872397651266057506195`20.", ",", 
     "2722.01221474613998700511708812380730788115`20.", ",", 
     "2722.65486225679799746445296139385657325939`20.", ",", 
     "2723.29579056002026836662582177001742020895`20.", ",", 
     "2723.93499847624971476904996363278796545914`20.", ",", 
     "2724.57248482754128445470066504579885072149`20.", ",", 
     "2725.20824843757261640027385227153339951443`20.", ",", 
     "2725.84228813165472474871236141247692913648`20.", ",", 
     "2726.47460273674270812821269641282833261673`20.", ",", 
     "2727.1051910814464841576851601003741896818`20.", ",", 
     "2727.73405199604154897649225988072482315453`20.", ",", 
     "2728.36118431247976163413548608835987065285`20.", ",", 
     "2728.98658686440015317339905488052560113309`20.", ",", 
     "2729.61025848713976023829112702446189587873`20.", ",", 
     "2730.23219801774448303594848913832266570395`20.", ",", 
     "2730.85240429497996747948984713822763875239`20.", ",", 
     "2731.47087615934251133661586713371800141198`20.", ",", 
     "2732.08761245306999420656104320028020760712`20.", ",", 
     "2732.70261202015283114580351282664400899727`20.", ",", 
     "2733.31587370634494976073421996338688320896`20.", ",", 
     "2733.92739635917479058327648515957933626952`20.", ",", 
     "2734.53717882795633054323122703491303636403`20.", ",", 
     "2735.14521996380012934890193616537190647494`20.", ",", 
     "2735.75151861962439858532718033310889625458`20.", ",", 
     "2736.35607365016609333721707008256213691792`20.", ",", 
     "2736.95888391199202614145388881816091540401`20.", ",", 
     "2737.55994826351000307177614756512753163849`20.", ",", 
     "2738.15926556497998175601981839343880116029`20.", ",", 
     "2738.75683467852525112404059188478583124103`20.", ",", 
     "2739.35265446814363268218685452163351260153`20.", ",", 
     "2739.94672379971870310793485522377958726921`20.", ",", 
     "2740.53904154103103795603539228740383074362`20.", ",", 
     "2741.12960656176947626525547063848629205625`20.", ",", 
     "2741.71841773354240585252892464705427627799`20.", ",", 
     "2742.30547392988906907905714591601204575133`20.", ",", 
     "2742.89077402629088887062497271579130749616`20.", ",", 
     "2743.47431690018281477211766444108085867106`20.", ",", 
     "2744.05610143096468881394287907266292483265`20.", ",", 
     "2744.63612650001263096577687468355371675068`20.", ",", 
     "2745.21439099069044395076695017145189945417`20.", ",", 
     "2745.79089378836103719103261035147091127376`20.", ",", 
     "2746.36563378039786965301627310736666923688`20.", ",", 
     "2746.93860985619641135894072035446577052792`20.", ",", 
     "2747.50982090718562332833512106152528747241`20.", ",", 
     "2748.07926582683945571129451652379789557716`20.", ",", 
     "2748.64694351068836387283935054480279452982`20.", ",", 
     "2749.21285285633084218544214728907595040304`20.", ",", 
     "2749.77699276344497528448798647459575046194`20.", ",", 
     "2750.33936213380000653913420047857154789397`20.", ",", 
     "2750.89995987126792348873292405717937951968`20.", ",", 
     "2751.45878488183505999267796996950662343364`20.", ",", 
     "2752.01583607361371483923519009747827491061`20.", ",", 
     "2752.57111235685378655661322091426290076196`20.", ",", 
     "2753.12461264395442416722951560896514925072`20.", ",", 
     "2753.67633584947569362382504603782482876241`20.", ",", 
     "2754.22628089015025966378023111999722538605`20.", ",", 
     "2754.77444668489508281568473146160026691031`20.", ",", 
     "2755.3208321548231312899149619490277788361`20.", ",", 
     "2755.86543622325510748267573580426521156309`20.", ",", 
     "2756.4082578157311888206665880592300762897`20.", ",", 
     "2756.94929586002278267123925840263241331926`20.", ",", 
     "2757.48854928614429504062076958825462893722`20.", ",", 
     "2758.02601702636491278048674664679667524439`20.", ",", 
     "2758.56169801522039902088231445013974173605`20.", ",", 
     "2759.09559118952490154520331901337890939981`20.", ",", 
     "2759.62769548838277382066897538677571884966`20.", ",", 
     "2760.15800985320040839543858799451695169561`20.", ",", 
     "2760.68653322769808237124995551698132608011`20.", ",", 
     "2761.21326455792181465818570135662256333909`20.", ",", 
     "2761.73820279225523471590630359576055290893`20.", ",", 
     "2762.26134688143146248342527810215065692501`20.", ",", 
     "2762.78269577854499919724303973343700548687`20.", ",", 
     "2763.30224843906362879540167579605273348965`20.", ",", 
     "2763.8200038208403296027734610617775026507`20.", ",", 
     "2764.33596088412519599065167442092177196879`20.", ",", 
     "2764.85011859157736970147339496884120512336`20.", ",", 
     "2765.36247590827698052727071290242740156761`20.", ",", 
     "2765.87303180173709602821944254884573342996`20.", ",", 
     "2766.3817852419156799754332272231141701167`20.", ",", 
     "2766.88873520122755919993613601243975491331`20.", ",", 
     "2767.39388065455639852753873012231274390919`20.", ",", 
     "2767.897220579266683477141381686031613827`20.", ",", 
     "2768.39875395521571039779462298853418545727`20.", ",", 
     "2768.89847976476558371765975237266300697367`20.", ",", 
     "2769.39639699279521997583408957230595946458`20.", ",", 
     "2769.89250462671235830583442412105760425982`20.", ",", 
     "2770.38680165646557703736960343556272562228`20.", ",", 
     "2770.87928707455631608087913110873461794684`20.", ",", 
     "2771.36995987605090475716936110020113193782`20.", ",", 
     "2771.85881905859259473234265137170240910235`20.", ",", 
     "2772.34586362241359771608795380678171073956`20.", ",", 
     "2772.83109257034712757928403989988438867142`20.", ",", 
     "2773.31450490783944654475916879104424634144`20.", ",", 
     "2773.79609964296191510295377198583411700092`20.", ",", 
     "2774.27587578642304530214593486655735121462`20.", ",", 
     "2774.75383235158055706082337727000673432156`20.", ",", 
     "2775.22996835445343714772055341573253229123`20.", ",", 
     "2775.70428281373400047298568575435192693437`20.", ",", 
     "2776.17677475079995333190029927216929985881`20.", ",", 
     "2776.64744318972645824054341477130091648895`20.", ",", 
     "2777.11628715729820000077427487336965010275`20.", ",", 
     "2777.58330568302145262990159905743450273632`20.", ",", 
     "2778.04849779913614678841417884768862201771`20.", ",", 
     "2778.51186254062793733716741700510118837548`20.", ",", 
     "2778.9733989452402706534534716857062880649`20.", ",", 
     "2779.43310605348645133342927514848628571147`20.", ",", 
     "2779.89098290866170790643714453587297578401`20.", ",", 
     "2780.34702855685525718482727794422582050982`20.", ",", 
     "2780.80124204696236687098042147048307296815`20.", ",", 
     "2781.25362243069641604133269172953754729082`20.", ",", 
     "2781.70416876260095312532323355300459470728`20.", ",", 
     "2782.15288010006175099531937473330827924541`20.", ",", 
     "2782.59975550331885878172349971534237548888`20.", ",", 
     "2783.04479403547865002563129338473456569031`20.", ",", 
     "2783.48799476252586677959259621214757395467`20.", ",", 
     "2783.92935675333565926522415492998916525854`20.", ",", 
     "2784.36887907968562069463834082736444065205`20.", ",", 
     "2784.80656081626781686088373303506428647338`20.", ",", 
     "2785.24240104070081010084261937121082379122`20.", ",", 
     "2785.67639883354167723229724507256091691556`20.", ",", 
     "2786.10855327829802106516133274886012208859`20.", ",", 
     "2786.53886346143997508517629788325552125649`20.", ",", 
     "2786.96732847241220090669298584110841265339`20.", ",", 
     "2787.39394740364587808949995124043430816836`20.", ",", 
     "2787.81871935057068591301858114644059369781`20.", ",", 
     "2788.24164341162677669956402216717719796371`20.", ",", 
     "2788.66271868827674027676920020499591143868`20.", ",", 
     "2789.08194428501755916768751213836816199286`20.", ",", 
     "2789.49931930939255409552831252078247787189`20.", ",", 
     "2789.91484287200331938843840655866806874005`20.", ",", 
     "2790.32851408652164786822268380898548078473`20.", ",", 
     "2790.74033206970144480539807537807530505565`20.", ",", 
     "2791.15029594139063052149748053202371884899`20.", ",", 
     "2791.5584048245430312180844755852565339648`20.", ",", 
     "2791.96465784523025761050577712054408738796`20.", ",", 
     "2792.36905413265357094299687072168750083809`20.", ",", 
     "2792.77159281915573596036722243768143591221`20.", ",", 
     "2793.17227304023286041012534931465946731672`20.", ",", 
     "2793.57109393454622064756102284888849896041`20.", ",", 
     "2793.96805464393407291498229954472580872933`20.", ",", 
     "2794.36315431342344986500919936034973477221`20.", ",", 
     "2794.75639209124194189655396813136424665735`20.", ",", 
     "2795.14776712882946287087024544874079568712`20.", ",", 
     "2795.53727858084999977383039517890527443973`20.", ",", 
     "2795.92492560520334588939202091565362914861`20.", ",", 
     "2796.31070736303681704804156097533993587647`20.", ",", 
     "2796.69462301875695051285511362549932432172`20.", ",", 
     "2797.07667174004118606469455826122156426486`20.", ",", 
     "2797.45685269784952884696088599652158256545`20.", ",", 
     "2797.83516506643619352925670594112021613241`20.", ",", 
     "2798.21160802336122934826642208908471272425`20.", ",", 
     "2798.58618074950212558314584948135956085004`20.", ",", 
     "2798.95888242906539702172332471276086338727`20.", ",", 
     "2799.32971224959814897285193083820752864965`20.", ",", 
     "2799.69866940199962137931756444718624139935`20.", ",", 
     "2800.06575308053271158480048546798864820314`20.", ",", 
     "2800.4309624828354753075089686184772861279`20.", ",", 
     "2800.79429680993260537225297790048492530359`20.", ",", 
     "2801.15575526624688775190366872291413001987`20.", ",", 
     "2801.51533705961063446839124067855082618813`20.", ",", 
     "2801.87304140127709290262947013958537653011`20.", ",", 
     "2802.22886750593183106202039597031041976246`20.", ",", 
     "2802.58281459170409835348736186301576351894`20.", ",", 
     "2802.93488188017816140930918089409938129802`20.", ",", 
     "2803.28506859640461451238282535169398322341`20.", ",", 
     "2803.63337396891166416692699879564034803521`20.", ",", 
     "2803.97979722971638736005445632122161885978`20.", ",", 
     "2804.32433761433596305908723925106780608344`20.", ",", 
     "2804.66699436179887648896631555374899740054`20.", ",", 
     "2805.00776671465609573361569814068970039795`20.", ",", 
     "2805.34665391899222020466117810416170969402`20.", ",", 
     "2805.68365522443660052047558447039564104357`20.", ",", 
     "2806.01876988417442933812618890071533897062`20.", ",", 
     "2806.35199715495780268043573287500944943197`20.", ",", 
     "2806.68333629711675130003678322072426586712`20.", ",", 
     "2807.01278657457024162199993342432177417703`20.", ",", 
     "2807.34034725483714580634997397348618579246`20.", ",", 
     "2807.66601760904718047155076293816481752619`20.", ",", 
     "2807.98979691195181361983934287901455547244`20.", ",", 
     "2808.31168444193513930512307354991568190558`20.", ",", 
     "2808.63167948102471958402038006214193630447`20.", ",", 
     "2808.94978131490239329052634821894356529543`20.", ",", 
     "2809.2659892329150511747190242644224023046`20.", ",", 
     "2809.58030252808537694589108355410475623866`20.", ",", 
     "2809.89272049712255376049470640646817000696`20.", ",", 
     "2810.20324244043293569532522086529701837831`20.", ",", 
     "2810.51186766213068374644151893849609437695`20.", ",", 
     "2810.8185954700483658944285990879223612337`20.", ",", 
     "2811.12342517574752077675000364274529195674`20.", ",", 
     "2811.42635609452918450811557196597577542233`20.", ",", 
     "2811.7273875454443801900029813915137614515`20.", ",", 
     "2812.02651885130456965072015708734612332662`20.", ",", 
     "2812.32374933869206695767995410574699054852`20.", ",", 
     "2812.61907833797041324387870101448581500153`20.", ",", 
     "2812.91250518329471239092639171847234193125`20.", ",", 
     "2813.20402921262192711136866337585997387937`20.", ",", 
     "2813.49364976772113497346934257556781873862`20.", ",", 
     "2813.78136619418374391208741390617272117185`20.", ",", 
     "2814.06717784143366676978389523418861731423`20.", ",", 
     "2814.35108406273745441283241869258020423652`20.", ",", 
     "2814.63308421521438696738243752423007422342`20.", ",", 
     "2814.91317765984652272163602414537973513512`20.", ",", 
     "2815.19136376148870424054830730841642792029`20.", ",", 
     "2815.46764188887852124024782482538780470051`20.", ",", 
     "2815.74201141464622977009654724728699121852`20.", ",", 
     "2816.01447171532462725107015692889070513458`20.", ",", 
     "2816.28502217135888291993744121535107430493`20.", ",", 
     "2816.55366216711632322955346861302686298211`20.", ",", 
     "2816.82039109089617175645464863610366650644`20.", ",", 
     "2817.08520833493924316785491072788505138696`20.", ",", 
     "2817.34811329543759080109115166790184589839`20.", ",", 
     "2817.60910537254410740955286583037667760295`20.", ",", 
     "2817.86818397038207863015555536394061482901`20.", ",", 
     "2818.12534849705468872848017975624071089571`20.", ",", 
     "2818.38059836465447817880160336289949546176`20.", ",", 
     "2818.63393298927275263736778740671037698397`20.", ",", 
     "2818.88535179100894286846839679769269127768`20.", ",", 
     "2819.13485419397991518404659397882026472164`20.", ",", 
     "2819.38243962632923195886110890551667987533`20.", ",", 
     "2819.62810752023636178449723817349065335655`20.", ",", 
     "2819.87185731192583882685526405461293978923`20.", ",", 
     "2820.11368844167637095311291746886576844137`20.", ",", 
     "2820.35360035382989619556495421428320920366`20.", ",", 
     "2820.59159249680058712118768238603789694327`20.", ",", 
     "2820.82766432308380267725937688822902413125`20.", ",", 
     "2821.06181528926498708488894505487323365294`20.", ",", 
     "2821.29404485602851535386496112958083214337`20.", ",", 
     "2821.52435248816648499383525686152674520247`20.", ",", 
     "2821.75273765458745349846362556386483771752`20.", ",", 
     "2821.97919982832512118088484708065320986842`20.", ",", 
     "2822.2037384865469589404921452529050924689`20.", ",", 
     "2822.42635311056278054284231627670686992034`20.", ",", 
     "2822.64704318583325899625307897818628283222`20.", ",", 
     "2822.86580820197838661049465420153496237575`20.", ",", 
     "2823.08264765278587832484313244651229246351`20.", ",", 
     "2823.29756103621951789466678333118026110333`20.", ",", 
     "2823.51054785442744652765803860843604298517`20.", ",", 
     "2823.72160761375039356280337801384614333402`20.", ",", 
     "2823.93073982472984878720069430345761176408`20.", ",", 
     "2824.13794400211617598788883502966433759152`20.", ",", 
     "2824.3432196648766673379468329042543388896`20.", ",", 
     "2824.54656633620353821825075742998110378156`20.", ",", 
     "2824.74798354352186207844405567087590863699`20.", ",", 
     "2824.94747081849744494288260179952663781283`20.", ",", 
     "2825.14502769704463916955834001836898388462`20.", ",", 
     "2825.340653719334096072285274595942175263`20.", ",", 
     "2825.53434842980045701874851945952127375208`20.", ",", 
     "2825.7261113771499826193710477870150108472`20.", ",", 
     "2825.91594211436811962434355345798666030909`20.", ",", 
     "2826.10384019872700514859031953883744448749`20.", ",", 
     "2826.2898051917929078469080470410198906249`20.", ",", 
     "2826.47383665943360566401508722246247577233`20.", ",", 
     "2826.65593417182569978678529429037158701738`20.", ",", 
     "2826.8360973034618644285136184709441380942`20.", ",", 
     "2827.01432563315803207766943237894660886818`20.", ",", 
     "2827.19061874406051384623826117191636740277`20.", ",", 
     "2827.36497622365305455543289822484151170195`20.", ",", 
     "2827.53739766376382219927065652531367838018`20.", ",", 
     "2827.70788266057233142926454958836046255218`20.", ",", 
     "2827.87643081461630070626232676554066547715`20.", ",", 
     "2828.04304173079844276828831314660249590954`20.", ",", 
     "2828.20771501839318806609872504063261440107`20.", ",", 
     "2828.37045029105334082105134395271722256892`20.", ",", 
     "2828.53124716681666736281492519210590229263`20.", ",", 
     "2828.69010526811241640740227640113683010427`20.", ",", 
     "2828.84702422176777093900334553362267615489`20.", ",", 
     "2829.0020036590142313621206808200627155345`20.", ",", 
     "2829.15504321549392959356903526918172010638`20.", ",", 
     "2829.30614253126587376699344807863211978977`20.", ",", 
     "2829.45530125081212322568560236703688111055`20.", ",", 
     "2829.60251902304389348263638492164094262643`20.", ",", 
     "2829.74779550130759082995310585551440412473`20.", ",", 
     "2829.89113034339077628299251553587039300517`20.", ",", 
     "2830.03252321152805854781531893521938813409`20.", ",", 
     "2830.17197377240691570385406445859855583061`20.", ",", 
     "2830.30948169717344529700380086729388894714`20.", ",", 
     "2830.44504666143804254169347250463753671641`20.", ",", 
     "2830.57866834528100633387537481675235314906`20.", ",", 
     "2830.71034643325807278027982920154777332962`20.", ",", 
     "2830.84008061440587595272226346705899947178`20.", ",", 
     "2830.96787058224733557971980153034501589386`20.", ",", 
     "2831.09371603479697139117396831518400506456`20.", ",", 
     "2831.21761667456614383540489300493340051171`20.", ",", 
     "2831.33957220856822089138013083129723248983`20.", ",", 
     "2831.45958234832367070256760048896230062707`20.", ",", 
     "2831.57764680986507976245682626592030759095`20.", ",", 
     "2831.69376531374209638543535146772915663917`20.", ",", 
     "2831.80793758502629920037751832723607818749`20.", ",", 
     "2831.92016335331599040800045025130537487742`20.", ",", 
     "2832.03044235274091354676668121898857591604`20.", ",", 
     "2832.13877432196689551586410605139659350946`20.", ",", 
     "2832.2451590042004126075714211971513587654`20.", ",", 
     "2832.34959614719308030512063118044234310793`20.", ",", 
     "2832.45208550324606660599714904318627642507`20.", ",", 
     "2832.55262682921442863447215367477436321879`20.", ",", 
     "2832.65121988651137231104081220843040220031`20.", ",", 
     "2832.74786444111243485034335672475961135599`20.", ",", 
     "2832.84256026355958986307344215720425169366`20.", ",", 
     "2832.9353071289652748413293231802630634128`20.", ",", 
     "2833.02610481701634081083778450160393421989`20.", ",", 
     "2833.11495311197792393747804983933557122616`20.", ",", 
     "2833.20185180269723887955268441699511329725`20.", ",", 
     "2833.28680068260729368129439459109240226843`20.", ",", 
     "2833.36979954973052600716121291172226315369`20.", ",", 
     "2833.45084820668236052055743037578053279043`20.", ",", 
     "2833.52994646067468721472338899824388381953`20.", ",", 
     "2833.60709412351926050766346256390728509765`20.", ",", 
     "2833.68229101163101891712781339253040279931`20.", ",", 
     "2833.75553694603132513582939648453260136609`20.", ",", 
     "2833.82683175235112633126276437940799931197`20.", ",", 
     "2833.89617526083403449869507793005014549764`20.", ",", 
     "2833.96356730633932670012191812787030015905`20.", ",", 
     "2834.02900772834486502622058701269401021387`20.", ",", 
     "2834.09249637094993612259114330004802903086`20.", ",", 
     "2834.15403308287801012584999928830446639433`20.", ",", 
     "2834.21361771747941885943206547552356951487`20.", ",", 
     "2834.27125013273395314326472077742770232805`20.", ",", 
     "2834.3269301912533790757998590774451433404`20.", ",", 
     "2834.38065776028387315122846404524295291971`20.", ",", 
     "2834.43243271170837607905513800214915403255`20.", ",", 
     "2834.48225492204886517757729872216623380587`20.", ",", 
     "2834.53012427246854521719489950854837844725`20.", ",", 
     "2834.57604064877395759387105927184545986967`20.", ",", 
     "2834.6200039414170077174714448515220572565`20.", ",", 
     "2834.6620140454969105041301593487980407759`20.", ",", 
     "2834.70207086076205386622178741787243441053`20.", ",", 
     "2834.74017429161178009796265878915500120908`20.", ",", 
     "2834.77632424709808505911884019615594313371`20.", ",", 
     "2834.81052064092723506376337678740847396076`20.", ",", 
     "2834.84276339146130138550039856628430339093`20.", ",", 
     "2834.87305242171961229505840513971735515776`20.", ",", 
     "2834.90138765938012255064886106684012440751`20.", ",", 
     "2834.92776903678070026598869073165275752321`20.", ",", 
     "2834.95219649092033108539587071382668877537`20.", ",", 
     "2834.9746699634602395998855924215166945307`20.", ",", 
     "2834.9951894007249279427199202188616594916`20.", ",", 
     "2835.0137547537031315073960110717684004892`20.", ",", 
     "2835.03036597804869173559630028335634873792`20.", ",", 
     "2835.04502303408134592716810250973052475829`20.", ",", 
     "2835.05772588678743402874933522054730442701`20.", ",", 
     "2835.06847450582052236221104943727651572573`20.", ",", 
     "2835.07726886550194425864565543143645713236`20.", ",", 
     "2835.08410894482125756819166381709051796276`20.", ",", 
     "2835.08899472743661902055092917312602028457`20.", ",", 
     "2835.09192620167507541562228744239003660976`20.", ",", 
     "2835.09290336053277162824562284206175341688`20.", ",", 
     "2835.09192620167507541562228744239003660976`20.", ",", 
     "2835.08899472743661902055092917312602028457`20.", ",", 
     "2835.08410894482125756819166381709051796276`20.", ",", 
     "2835.07726886550194425864565543143645713236`20.", ",", 
     "2835.06847450582052236221104943727651572573`20.", ",", 
     "2835.05772588678743402874933522054730442701`20.", ",", 
     "2835.04502303408134592716810250973052475829`20.", ",", 
     "2835.03036597804869173559630028335634873792`20.", ",", 
     "2835.0137547537031315073960110717684004892`20.", ",", 
     "2834.9951894007249279427199202188616594916`20.", ",", 
     "2834.9746699634602395998855924215166945307`20.", ",", 
     "2834.95219649092033108539587071382668877537`20.", ",", 
     "2834.92776903678070026598869073165275752321`20.", ",", 
     "2834.90138765938012255064886106684012440751`20.", ",", 
     "2834.87305242171961229505840513971735515776`20.", ",", 
     "2834.84276339146130138550039856628430339093`20.", ",", 
     "2834.81052064092723506376337678740847396076`20.", ",", 
     "2834.77632424709808505911884019615594313371`20.", ",", 
     "2834.74017429161178009796265878915500120908`20.", ",", 
     "2834.70207086076205386622178741787243441053`20.", ",", 
     "2834.6620140454969105041301593487980407759`20.", ",", 
     "2834.6200039414170077174714448515220572565`20.", ",", 
     "2834.57604064877395759387105927184545986967`20.", ",", 
     "2834.53012427246854521719489950854837844725`20.", ",", 
     "2834.48225492204886517757729872216623380587`20.", ",", 
     "2834.43243271170837607905513800214915403255`20.", ",", 
     "2834.38065776028387315122846404524295291971`20.", ",", 
     "2834.3269301912533790757998590774451433404`20.", ",", 
     "2834.27125013273395314326472077742770232805`20.", ",", 
     "2834.21361771747941885943206547552356951487`20.", ",", 
     "2834.15403308287801012584999928830446639433`20.", ",", 
     "2834.09249637094993612259114330004802903086`20.", ",", 
     "2834.02900772834486502622058701269401021387`20.", ",", 
     "2833.96356730633932670012191812787030015905`20.", ",", 
     "2833.89617526083403449869507793005014549764`20.", ",", 
     "2833.82683175235112633126276437940799931197`20.", ",", 
     "2833.75553694603132513582939648453260136609`20.", ",", 
     "2833.68229101163101891712781339253040279931`20.", ",", 
     "2833.60709412351926050766346256390728509765`20.", ",", 
     "2833.52994646067468721472338899824388381953`20.", ",", 
     "2833.45084820668236052055743037578053279043`20.", ",", 
     "2833.36979954973052600716121291172226315369`20.", ",", 
     "2833.28680068260729368129439459109240226843`20.", ",", 
     "2833.20185180269723887955268441699511329725`20.", ",", 
     "2833.11495311197792393747804983933557122616`20.", ",", 
     "2833.02610481701634081083778450160393421989`20.", ",", 
     "2832.9353071289652748413293231802630634128`20.", ",", 
     "2832.84256026355958986307344215720425169366`20.", ",", 
     "2832.74786444111243485034335672475961135599`20.", ",", 
     "2832.65121988651137231104081220843040220031`20.", ",", 
     "2832.55262682921442863447215367477436321879`20.", ",", 
     "2832.45208550324606660599714904318627642507`20.", ",", 
     "2832.34959614719308030512063118044234310793`20.", ",", 
     "2832.2451590042004126075714211971513587654`20.", ",", 
     "2832.13877432196689551586410605139659350946`20.", ",", 
     "2832.03044235274091354676668121898857591604`20.", ",", 
     "2831.92016335331599040800045025130537487742`20.", ",", 
     "2831.80793758502629920037751832723607818749`20.", ",", 
     "2831.69376531374209638543535146772915663917`20.", ",", 
     "2831.57764680986507976245682626592030759095`20.", ",", 
     "2831.45958234832367070256760048896230062707`20.", ",", 
     "2831.33957220856822089138013083129723248983`20.", ",", 
     "2831.21761667456614383540489300493340051171`20.", ",", 
     "2831.09371603479697139117396831518400506456`20.", ",", 
     "2830.96787058224733557971980153034501589386`20.", ",", 
     "2830.84008061440587595272226346705899947178`20.", ",", 
     "2830.71034643325807278027982920154777332962`20.", ",", 
     "2830.57866834528100633387537481675235314906`20.", ",", 
     "2830.44504666143804254169347250463753671641`20.", ",", 
     "2830.30948169717344529700380086729388894714`20.", ",", 
     "2830.17197377240691570385406445859855583061`20.", ",", 
     "2830.03252321152805854781531893521938813409`20.", ",", 
     "2829.89113034339077628299251553587039300517`20.", ",", 
     "2829.74779550130759082995310585551440412473`20.", ",", 
     "2829.60251902304389348263638492164094262643`20.", ",", 
     "2829.45530125081212322568560236703688111055`20.", ",", 
     "2829.30614253126587376699344807863211978977`20.", ",", 
     "2829.15504321549392959356903526918172010638`20.", ",", 
     "2829.0020036590142313621206808200627155345`20.", ",", 
     "2828.84702422176777093900334553362267615489`20.", ",", 
     "2828.69010526811241640740227640113683010427`20.", ",", 
     "2828.53124716681666736281492519210590229263`20.", ",", 
     "2828.37045029105334082105134395271722256892`20.", ",", 
     "2828.20771501839318806609872504063261440107`20.", ",", 
     "2828.04304173079844276828831314660249590954`20.", ",", 
     "2827.87643081461630070626232676554066547715`20.", ",", 
     "2827.70788266057233142926454958836046255218`20.", ",", 
     "2827.53739766376382219927065652531367838018`20.", ",", 
     "2827.36497622365305455543289822484151170195`20.", ",", 
     "2827.19061874406051384623826117191636740277`20.", ",", 
     "2827.01432563315803207766943237894660886818`20.", ",", 
     "2826.8360973034618644285136184709441380942`20.", ",", 
     "2826.65593417182569978678529429037158701738`20.", ",", 
     "2826.47383665943360566401508722246247577233`20.", ",", 
     "2826.2898051917929078469080470410198906249`20.", ",", 
     "2826.10384019872700514859031953883744448749`20.", ",", 
     "2825.91594211436811962434355345798666030909`20.", ",", 
     "2825.7261113771499826193710477870150108472`20.", ",", 
     "2825.53434842980045701874851945952127375208`20.", ",", 
     "2825.340653719334096072285274595942175263`20.", ",", 
     "2825.14502769704463916955834001836898388462`20.", ",", 
     "2824.94747081849744494288260179952663781283`20.", ",", 
     "2824.74798354352186207844405567087590863699`20.", ",", 
     "2824.54656633620353821825075742998110378156`20.", ",", 
     "2824.3432196648766673379468329042543388896`20.", ",", 
     "2824.13794400211617598788883502966433759152`20.", ",", 
     "2823.93073982472984878720069430345761176408`20.", ",", 
     "2823.72160761375039356280337801384614333402`20.", ",", 
     "2823.51054785442744652765803860843604298517`20.", ",", 
     "2823.29756103621951789466678333118026110333`20.", ",", 
     "2823.08264765278587832484313244651229246351`20.", ",", 
     "2822.86580820197838661049465420153496237575`20.", ",", 
     "2822.64704318583325899625307897818628283222`20.", ",", 
     "2822.42635311056278054284231627670686992034`20.", ",", 
     "2822.2037384865469589404921452529050924689`20.", ",", 
     "2821.97919982832512118088484708065320986842`20.", ",", 
     "2821.75273765458745349846362556386483771752`20.", ",", 
     "2821.52435248816648499383525686152674520247`20.", ",", 
     "2821.29404485602851535386496112958083214337`20.", ",", 
     "2821.06181528926498708488894505487323365294`20.", ",", 
     "2820.82766432308380267725937688822902413125`20.", ",", 
     "2820.59159249680058712118768238603789694327`20.", ",", 
     "2820.35360035382989619556495421428320920366`20.", ",", 
     "2820.11368844167637095311291746886576844137`20.", ",", 
     "2819.87185731192583882685526405461293978923`20.", ",", 
     "2819.62810752023636178449723817349065335655`20.", ",", 
     "2819.38243962632923195886110890551667987533`20.", ",", 
     "2819.13485419397991518404659397882026472164`20.", ",", 
     "2818.88535179100894286846839679769269127768`20.", ",", 
     "2818.63393298927275263736778740671037698397`20.", ",", 
     "2818.38059836465447817880160336289949546176`20.", ",", 
     "2818.12534849705468872848017975624071089571`20.", ",", 
     "2817.86818397038207863015555536394061482901`20.", ",", 
     "2817.60910537254410740955286583037667760295`20.", ",", 
     "2817.34811329543759080109115166790184589839`20.", ",", 
     "2817.08520833493924316785491072788505138696`20.", ",", 
     "2816.82039109089617175645464863610366650644`20.", ",", 
     "2816.55366216711632322955346861302686298211`20.", ",", 
     "2816.28502217135888291993744121535107430493`20.", ",", 
     "2816.01447171532462725107015692889070513458`20.", ",", 
     "2815.74201141464622977009654724728699121852`20.", ",", 
     "2815.46764188887852124024782482538780470051`20.", ",", 
     "2815.19136376148870424054830730841642792029`20.", ",", 
     "2814.91317765984652272163602414537973513512`20.", ",", 
     "2814.63308421521438696738243752423007422342`20.", ",", 
     "2814.35108406273745441283241869258020423652`20.", ",", 
     "2814.06717784143366676978389523418861731423`20.", ",", 
     "2813.78136619418374391208741390617272117185`20.", ",", 
     "2813.49364976772113497346934257556781873862`20.", ",", 
     "2813.20402921262192711136866337585997387937`20.", ",", 
     "2812.91250518329471239092639171847234193125`20.", ",", 
     "2812.61907833797041324387870101448581500153`20.", ",", 
     "2812.32374933869206695767995410574699054852`20.", ",", 
     "2812.02651885130456965072015708734612332662`20.", ",", 
     "2811.7273875454443801900029813915137614515`20.", ",", 
     "2811.42635609452918450811557196597577542233`20.", ",", 
     "2811.12342517574752077675000364274529195674`20.", ",", 
     "2810.8185954700483658944285990879223612337`20.", ",", 
     "2810.51186766213068374644151893849609437695`20.", ",", 
     "2810.20324244043293569532522086529701837831`20.", ",", 
     "2809.89272049712255376049470640646817000696`20.", ",", 
     "2809.58030252808537694589108355410475623866`20.", ",", 
     "2809.2659892329150511747190242644224023046`20.", ",", 
     "2808.94978131490239329052634821894356529543`20.", ",", 
     "2808.63167948102471958402038006214193630447`20.", ",", 
     "2808.31168444193513930512307354991568190558`20.", ",", 
     "2807.98979691195181361983934287901455547244`20.", ",", 
     "2807.66601760904718047155076293816481752619`20.", ",", 
     "2807.34034725483714580634997397348618579246`20.", ",", 
     "2807.01278657457024162199993342432177417703`20.", ",", 
     "2806.68333629711675130003678322072426586712`20.", ",", 
     "2806.35199715495780268043573287500944943197`20.", ",", 
     "2806.01876988417442933812618890071533897062`20.", ",", 
     "2805.68365522443660052047558447039564104357`20.", ",", 
     "2805.34665391899222020466117810416170969402`20.", ",", 
     "2805.00776671465609573361569814068970039795`20.", ",", 
     "2804.66699436179887648896631555374899740054`20.", ",", 
     "2804.32433761433596305908723925106780608344`20.", ",", 
     "2803.97979722971638736005445632122161885978`20.", ",", 
     "2803.63337396891166416692699879564034803521`20.", ",", 
     "2803.28506859640461451238282535169398322341`20.", ",", 
     "2802.93488188017816140930918089409938129802`20.", ",", 
     "2802.58281459170409835348736186301576351894`20.", ",", 
     "2802.22886750593183106202039597031041976246`20.", ",", 
     "2801.87304140127709290262947013958537653011`20.", ",", 
     "2801.51533705961063446839124067855082618813`20.", ",", 
     "2801.15575526624688775190366872291413001987`20.", ",", 
     "2800.79429680993260537225297790048492530359`20.", ",", 
     "2800.4309624828354753075089686184772861279`20.", ",", 
     "2800.06575308053271158480048546798864820314`20.", ",", 
     "2799.69866940199962137931756444718624139935`20.", ",", 
     "2799.32971224959814897285193083820752864965`20.", ",", 
     "2798.95888242906539702172332471276086338727`20.", ",", 
     "2798.58618074950212558314584948135956085004`20.", ",", 
     "2798.21160802336122934826642208908471272425`20.", ",", 
     "2797.83516506643619352925670594112021613241`20.", ",", 
     "2797.45685269784952884696088599652158256545`20.", ",", 
     "2797.07667174004118606469455826122156426486`20.", ",", 
     "2796.69462301875695051285511362549932432172`20.", ",", 
     "2796.31070736303681704804156097533993587647`20.", ",", 
     "2795.92492560520334588939202091565362914861`20.", ",", 
     "2795.53727858084999977383039517890527443973`20.", ",", 
     "2795.14776712882946287087024544874079568712`20.", ",", 
     "2794.75639209124194189655396813136424665735`20.", ",", 
     "2794.36315431342344986500919936034973477221`20.", ",", 
     "2793.96805464393407291498229954472580872933`20.", ",", 
     "2793.57109393454622064756102284888849896041`20.", ",", 
     "2793.17227304023286041012534931465946731672`20.", ",", 
     "2792.77159281915573596036722243768143591221`20.", ",", 
     "2792.36905413265357094299687072168750083809`20.", ",", 
     "2791.96465784523025761050577712054408738796`20.", ",", 
     "2791.5584048245430312180844755852565339648`20.", ",", 
     "2791.15029594139063052149748053202371884899`20.", ",", 
     "2790.74033206970144480539807537807530505565`20.", ",", 
     "2790.32851408652164786822268380898548078473`20.", ",", 
     "2789.91484287200331938843840655866806874005`20.", ",", 
     "2789.49931930939255409552831252078247787189`20.", ",", 
     "2789.08194428501755916768751213836816199286`20.", ",", 
     "2788.66271868827674027676920020499591143868`20.", ",", 
     "2788.24164341162677669956402216717719796371`20.", ",", 
     "2787.81871935057068591301858114644059369781`20.", ",", 
     "2787.39394740364587808949995124043430816836`20.", ",", 
     "2786.96732847241220090669298584110841265339`20.", ",", 
     "2786.53886346143997508517629788325552125649`20.", ",", 
     "2786.10855327829802106516133274886012208859`20.", ",", 
     "2785.67639883354167723229724507256091691556`20.", ",", 
     "2785.24240104070081010084261937121082379122`20.", ",", 
     "2784.80656081626781686088373303506428647338`20.", ",", 
     "2784.36887907968562069463834082736444065205`20.", ",", 
     "2783.92935675333565926522415492998916525854`20.", ",", 
     "2783.48799476252586677959259621214757395467`20.", ",", 
     "2783.04479403547865002563129338473456569031`20.", ",", 
     "2782.59975550331885878172349971534237548888`20.", ",", 
     "2782.15288010006175099531937473330827924541`20.", ",", 
     "2781.70416876260095312532323355300459470728`20.", ",", 
     "2781.25362243069641604133269172953754729082`20.", ",", 
     "2780.80124204696236687098042147048307296815`20.", ",", 
     "2780.34702855685525718482727794422582050982`20.", ",", 
     "2779.89098290866170790643714453587297578401`20.", ",", 
     "2779.43310605348645133342927514848628571147`20.", ",", 
     "2778.9733989452402706534534716857062880649`20.", ",", 
     "2778.51186254062793733716741700510118837548`20.", ",", 
     "2778.04849779913614678841417884768862201771`20.", ",", 
     "2777.58330568302145262990159905743450273632`20.", ",", 
     "2777.11628715729820000077427487336965010275`20.", ",", 
     "2776.64744318972645824054341477130091648895`20.", ",", 
     "2776.17677475079995333190029927216929985881`20.", ",", 
     "2775.70428281373400047298568575435192693437`20.", ",", 
     "2775.22996835445343714772055341573253229123`20.", ",", 
     "2774.75383235158055706082337727000673432156`20.", ",", 
     "2774.27587578642304530214593486655735121462`20.", ",", 
     "2773.79609964296191510295377198583411700092`20.", ",", 
     "2773.31450490783944654475916879104424634144`20.", ",", 
     "2772.83109257034712757928403989988438867142`20.", ",", 
     "2772.34586362241359771608795380678171073956`20.", ",", 
     "2771.85881905859259473234265137170240910235`20.", ",", 
     "2771.36995987605090475716936110020113193782`20.", ",", 
     "2770.87928707455631608087913110873461794684`20.", ",", 
     "2770.38680165646557703736960343556272562228`20.", ",", 
     "2769.89250462671235830583442412105760425982`20.", ",", 
     "2769.39639699279521997583408957230595946458`20.", ",", 
     "2768.89847976476558371765975237266300697367`20.", ",", 
     "2768.39875395521571039779462298853418545727`20.", ",", 
     "2767.897220579266683477141381686031613827`20.", ",", 
     "2767.39388065455639852753873012231274390919`20.", ",", 
     "2766.88873520122755919993613601243975491331`20.", ",", 
     "2766.3817852419156799754332272231141701167`20.", ",", 
     "2765.87303180173709602821944254884573342996`20.", ",", 
     "2765.36247590827698052727071290242740156761`20.", ",", 
     "2764.85011859157736970147339496884120512336`20.", ",", 
     "2764.33596088412519599065167442092177196879`20.", ",", 
     "2763.8200038208403296027734610617775026507`20.", ",", 
     "2763.30224843906362879540167579605273348965`20.", ",", 
     "2762.78269577854499919724303973343700548687`20.", ",", 
     "2762.26134688143146248342527810215065692501`20.", ",", 
     "2761.73820279225523471590630359576055290893`20.", ",", 
     "2761.21326455792181465818570135662256333909`20.", ",", 
     "2760.68653322769808237124995551698132608011`20.", ",", 
     "2760.15800985320040839543858799451695169561`20.", ",", 
     "2759.62769548838277382066897538677571884966`20.", ",", 
     "2759.09559118952490154520331901337890939981`20.", ",", 
     "2758.56169801522039902088231445013974173605`20.", ",", 
     "2758.02601702636491278048674664679667524439`20.", ",", 
     "2757.48854928614429504062076958825462893722`20.", ",", 
     "2756.94929586002278267123925840263241331926`20.", ",", 
     "2756.4082578157311888206665880592300762897`20.", ",", 
     "2755.86543622325510748267573580426521156309`20.", ",", 
     "2755.3208321548231312899149619490277788361`20.", ",", 
     "2754.77444668489508281568473146160026691031`20.", ",", 
     "2754.22628089015025966378023111999722538605`20.", ",", 
     "2753.67633584947569362382504603782482876241`20.", ",", 
     "2753.12461264395442416722951560896514925072`20.", ",", 
     "2752.57111235685378655661322091426290076196`20.", ",", 
     "2752.01583607361371483923519009747827491061`20.", ",", 
     "2751.45878488183505999267796996950662343364`20.", ",", 
     "2750.89995987126792348873292405717937951968`20.", ",", 
     "2750.33936213380000653913420047857154789397`20.", ",", 
     "2749.77699276344497528448798647459575046194`20.", ",", 
     "2749.21285285633084218544214728907595040304`20.", ",", 
     "2748.64694351068836387283935054480279452982`20.", ",", 
     "2748.07926582683945571129451652379789557716`20.", ",", 
     "2747.50982090718562332833512106152528747241`20.", ",", 
     "2746.93860985619641135894072035446577052792`20.", ",", 
     "2746.36563378039786965301627310736666923688`20.", ",", 
     "2745.79089378836103719103261035147091127376`20.", ",", 
     "2745.21439099069044395076695017145189945417`20.", ",", 
     "2744.63612650001263096577687468355371675068`20.", ",", 
     "2744.05610143096468881394287907266292483265`20.", ",", 
     "2743.47431690018281477211766444108085867106`20.", ",", 
     "2742.89077402629088887062497271579130749616`20.", ",", 
     "2742.30547392988906907905714591601204575133`20.", ",", 
     "2741.71841773354240585252892464705427627799`20.", ",", 
     "2741.12960656176947626525547063848629205625`20.", ",", 
     "2740.53904154103103795603539228740383074362`20.", ",", 
     "2739.94672379971870310793485522377958726921`20.", ",", 
     "2739.35265446814363268218685452163351260153`20.", ",", 
     "2738.75683467852525112404059188478583124103`20.", ",", 
     "2738.15926556497998175601981839343880116029`20.", ",", 
     "2737.55994826351000307177614756512753163849`20.", ",", 
     "2736.95888391199202614145388881816091540401`20.", ",", 
     "2736.35607365016609333721707008256213691792`20.", ",", 
     "2735.75151861962439858532718033310889625458`20.", ",", 
     "2735.14521996380012934890193616537190647494`20.", ",", 
     "2734.53717882795633054323122703491303636403`20.", ",", 
     "2733.92739635917479058327648515957933626952`20.", ",", 
     "2733.31587370634494976073421996338688320896`20.", ",", 
     "2732.70261202015283114580351282664400899727`20.", ",", 
     "2732.08761245306999420656104320028020760712`20.", ",", 
     "2731.47087615934251133661586713371800141198`20.", ",", 
     "2730.85240429497996747948984713822763875239`20.", ",", 
     "2730.23219801774448303594848913832266570395`20.", ",", 
     "2729.61025848713976023829112702446189587873`20.", ",", 
     "2728.98658686440015317339905488052560113309`20.", ",", 
     "2728.36118431247976163413548608835987065285`20.", ",", 
     "2727.73405199604154897649225988072482315453`20.", ",", 
     "2727.1051910814464841576851601003741896818`20.", ",", 
     "2726.47460273674270812821269641282833261673`20.", ",", 
     "2725.84228813165472474871236141247692913648`20.", ",", 
     "2725.20824843757261640027385227153339951443`20.", ",", 
     "2724.57248482754128445470066504579885072149`20.", ",", 
     "2723.93499847624971476904996363278796545914`20.", ",", 
     "2723.29579056002026836662582177001742020895`20.", ",", 
     "2722.65486225679799746445296139385657325939`20.", ",", 
     "2722.01221474613998700511708812380730788115`20.", ",", 
     "2721.36784920920472184872397651266057506195`20.", ",", 
     "2720.72176682874147977860270388284255582423`20.", ",", 
     "2720.07396878907975047225898988698965114156`20.", ",", 
     "2719.4244562761186805869725851871164271967`20.", ",", 
     "2718.77323047731654510732818061659171262713`20.", ",", 
     "2718.12029258168024509987248962892736291471`20.", ",", 
     "2717.4656437797548320180011014925645277322`20.", ",", 
     "2716.80928526361305869809751830371895122593`20.", ",", 
     "2716.15121822684495718587358120714068842813`20.", ",", 
     "2715.49144386454744352979536399779900272962`20.", ",", 
     "2714.8299633733139496764216673072367612069`20.", ",", 
     "2714.16677795122408260043358366942277631653`20.", ",", 
     "2713.50188879783331080009332076470708935845`20.", ",", 
     "2712.83529711416267828683866295810291670612`20.", ",", 
     "2712.16700410268854619569621383899534721512`20.", ",", 
     "2711.49701096733236214118198686086502106204`20.", ",", 
     "2710.82531891345045744135208747688947226385`20.", ",", 
     "2710.15192914782387233066924656342741094712`20.", ",", 
     "2709.47684287864820928036290770967676037704`20.", ",", 
     "2708.80006131552351454298152452817410149431`20.", ",", 
     "2708.12158566944418803586577102656295538951`20.", ",", 
     "2707.4414171527889216763105889256903956554`20.", ",", 
     "2706.75955697931066627923246940331684428682`20.", ",", 
     "2706.07600636412662712621617002970399689683`20.", ",", 
     "2705.39076652370828831288227574806113248216`20.", ",", 
     "2704.70383867587146597959369892162388553847`20.", ",", 
     "2704.01522403976639052860544918942208059548`20.", ",", 
     "2703.32492383586781792885785881290121113782`20.", ",", 
     "2702.63293928596517020771899123476950330978`20.", ",", 
     "2701.93927161315270522709725581211713010412`20.", ",", 
     "2701.24392204181971583947036446575633180125`20.", ",", 
     "2700.5468917976407585175117588924491163074`20.", ",", 
     "2699.84818210756591154914057086220682136235`20.", ",", 
     "2699.14779419981106288797611208823879360766`20.", ",", 
     "2698.44572930384822774734288161738256800559`20.", ",", 
     "2697.74198865039589602414718334780161368432`20.", ",", 
     "2697.03657347140940963713171815412813010915`20.", ",", 
     "2696.32948500007136986221000652886301882513`20.", ",", 
     "2695.62072447078207474578825931186438602804`20.", ",", 
     "2694.91029311914998667519839500800834883972`20.", ",", 
     "2694.19819218198223018359234978261628547413`20.", ",", 
     "2693.48442289727512006488468624977424093477`20.", ",", 
     "2692.76898650420471987257782379737633056262`20.", ",", 
     "2692.05188424311743087456202899788491882187`20.", ",", 
     "2691.33311735552061153425066062864119264835`20.", ",", 
     "2690.61268708407322758669009939714554219936`20.", ",", 
     "2689.89059467257653277657334550993128087731`20.", ",", 
     "2689.16684136596478032338647407519695826209`20.", ",", 
     "2688.44142841029596517722803380191021561942`20.", ",", 
     "2687.71435705274259712716309185443199785027`20.", ",", 
     "2686.98562854158250482230599884895264300863`20.", ",", 
     "2686.25524412618967076416910316191298703494`20.", ",", 
     "2685.52320505702509732716861181977688905144`20.", ",", 
     "2684.78951258562770386254360366001430697745`20.", ",", 
     "2684.05416796460525493931987516266658043728`20.", ",", 
     "2683.31717244762531977433686489430825393398`20.", ",", 
     "2682.578527289406262901753382016186899898`20.", ",", 
     "2681.83823374570826613085627952561830422679`20.", ",", 
     "2681.09629307332438183941558418391046157685`20.", ",", 
     "2680.35270653007161764825994142910609049357`20.", ",", 
     "2679.60747537478205252118757262054434622879`20.", ",", 
     "2678.86060086729398433278029002110179195019`20.", ",", 
     "2678.11208426844310894515148697665501365487`20.", ",", 
     "2677.36192684005373083313343047836269514428`20.", ",", 
     "2676.61012984493000529589464307688444749623`20.", ",", 
     "2675.85669454684721229147468206594136744986`20.", ",", 
     "2675.10162221054306192923121580987305109505`20.", ",", 
     "2674.34491410170903165371296865181938773874`20.", ",", 
     "2673.5865714869817351520018643678585574917`20.", ",", 
     "2672.82659563393432301510854977078733551792`20.", ",", 
     "2672.06498781106791518255742975373834242336`20.", ",", 
     "2671.30174928780306519786039654722967542723`20.", ",", 
     "2670.53688133447125630115259181715083599813`20.", ",", 
     "2669.77038522230642938384880186872504058798`20.", ",", 
     "2669.002262223436542828775453909884827904`20.", ",", 
     "2668.23251361087516425784065420268974529525`20.", ",", 
     "2667.46114065851309420792328501260290992559`20.", ",", 
     "2666.6881446411100217542918534696349543579`20.", ",", 
     "2665.91352683428621209950455761188556730465`20.", ",", 
     "2665.13728851451422614439389774699074860106`20.", ",", 
     "2664.35943095911067205640210853779395818143`20.", ",", 
     "2663.57995544622798884920771154824096341325`20.", ",", 
     "2662.7988632548462619862685809971318813221`20.", ",", 
     "2662.0161556647650710196030677684090592326`20.", ",", 
     "2661.23183395659536927383792792325095928054`20.", ",", 
     "2660.44589941175139558427004067044368794511`20.", ",", 
     "2659.65835331244261809641816462351297738052`20.", ",", 
     "2658.86919694166571013328125689341632178298`20.", ",", 
     "2658.07843158319655813527115287712036494018`20.", ",", 
     "2657.28605852158230167654966031749128295183`20.", ",", 
     "2656.49207904213340556027334322444632473829`20.", ",", 
     "2655.69649443091576399403344255451597502186`20.", ",", 
     "2654.89930597474283684557348325042797408035`20.", ",", 
     "2654.10051496116781797767313257377797841895`20.", ",", 
     "2653.30012267847583565990378299095498647264`20.", ",", 
     "2652.49813041567618505378911371654056305015`20.", ",", 
     "2651.69453946249459276674251706698615024775`20.", ",", 
     "2650.88935110936551346900273689795266449961`20.", ",", 
     "2650.08256664742445856664933365212234542834`20.", ",", 
     "2649.27418736850035692265064019825613649157`20.", ",", 
     "2648.46421456510794761677868018468267241697`20.", ",", 
     "2647.65264953044020473411806078270824726835`20.", ",", 
     "2646.83949355836079417079909842583751238571`20.", ",", 
     "2646.02474794339656244449936268732690807578`20.", ",", 
     "2645.20841398073005749618240228260782175059`20.", ",", 
     "2644.39049296619208146847762012169259218998`20.", ",", 
     "2643.5709861962542754450510624559535798171`20.", ",", 
     "2642.74989496802173613427325086160080725319`20.", ",", 
     "2641.92722057922566447945708480132657538986`20.", ",", 
     "2641.10296432821604617691624586577345648114`20.", ",", 
     "2640.2771275139543640820824109274527596133`20.", ",", 
     "2639.44971143600634248291789811366219816783`20.", ",", 
     "2638.62071739453472321886909386886878158862`20.", ",", 
     "2637.79014669029207362262510796521835900761`20.", ",", 
     "2636.95800062461362626097554206610234715594`20.", ",", 
     "2636.12428049941015045010100169755240507223`20.", ",", 
     "2635.28898761716085551967999600494568180704`20.", ",", 
     "2634.4521232809063257992561186732031812367`20.", ",", 
     "2633.61368879424148729937985052020787591088`20.", ",", 
     "2632.77368546130860605911993264798715055913`20.", ",", 
     "2631.93211458679031813062999123804253766464`20.", ",", 
     "2631.08897747590269117055691317278404743224`20.", ",", 
     "2630.24427543438831760718833721558127250414`20.", ",", 
     "2629.39800976850943935135749955472014480232`20.", ",", 
     "2628.55018178504110401825451569616521511286`20.", ",", 
     "2627.70079279126435262643395308973692899192`20.", ",", 
     "2626.84984409495943873945921014622477562353`20.", ",", 
     "2625.9973370043990790147847266531036332138`20.", ",", 
     "2625.14327282834173512364736678986296114267`20.", ",", 
     "2624.2876528760249270049183973192855218164`20.", ",", 
     "2623.43047845715857741505728801074650492627`20.", ",", 
     "2622.57175088191838773550804645250940304823`20.", ",", 
     "2621.7114714609392449980879222537902847308`20.", ",", 
     "2620.84964150530866008813703296123396066888`20.", ",", 
     "2619.98626232656023708442573218146718268248`20.", ",", 
     "2619.1213352366671736940543154108442354365`20.", ",", 
     "2618.25486154803579273982689657108562649928`20.", ",", 
     "2617.38684257349910465683794353748864959529`20.", ",", 
     "2616.51727962631040095427598899359357526421`20.", ",", 
     "2615.64617402013687859772438839795838178077`20.", ",", 
     "2614.77352706905329526652363403669683352056`20.", ",", 
     "2613.89934008753565544005360708739826639323`20.", ",", 
     "2613.02361439045492726609721206939231171361`20.", ",", 
     "2612.14635129307079016375904345068968587983`20.", ",", 
     "2611.26755211102541311273403569661689699073`20.", ",", 
     "2610.38721816033726358005139858645152558305`20.", ",", 
     "2609.50535075739494703475849184276007646314`20.", ",", 
     "2608.6219512189510770003575994165029613313`20.", ",", 
     "2607.73702086211617559416577631355352754844`20.", ",", 
     "2606.85056100435260450213401156966146269747`20.", ",", 
     "2605.96257296346852633703683159482301506759`20.", ",", 
     "2605.07305805761189632732711011615411937498`20.", ",", 
     "2604.18201760526448428334320564889584813318`20.", ",", 
     "2603.28945292523592678695656592139936870024`20.", ",", 
     "2602.39536533665780955015757188865394580431`20.", ",", 
     "2601.49975615897777988749559262882469437073`20.", ",", 
     "2600.60262671195368924671593709716497858245`20.", ",", 
     "2599.70397831564776574137156981863840181081`20.", ",", 
     "2598.80381229042081662863105538802286906444`20.", ",", 
     "2597.90212995692646067495616122184174379759`20.", ",", 
     "2596.99893263610539035178282933996954377327`20.", ",", 
     "2596.09422164917966380280777588587278283304`20.", ",", 
     "2595.18799831764702652395974134039893558741`20.", ",", 
     "2594.28026396327526269661934454715950453676`20.", ",", 
     "2593.37101990809657611414453924279015225272`20.", ",", 
     "2592.46026747440200064125978216759031792893`20.", ",", 
     "2591.54800798473584014537614632335792596794`20.", ",", 
     "2590.63424276189013783842670076216811829228`20.", ",", 
     "2589.71897312889917496732647857042774282315`20.", ",", 
     "2588.80220040903399879069921652329468880861`20.", ",", 
     "2587.88392592579697977905372222740335064445`20.", ",", 
     "2586.96415100291639797514115638890508405292`20.", ",", 
     "2586.04287696434105845078065803214854528856`20.", ",", 
     "2585.12010513423493579600453790045415072183`20.", ",", 
     "2584.19583683697184757594566870500296695941`20.", ",", 
     "2583.2700733971301566904686591299800754046`20.", ",", 
     "2582.34281613948750257113286030573956466001`20.", ",", 
     "2581.41406638901556114966916756193566487878`20.", ",", 
     "2580.48382547087483353175389539158580394119`20.", ",", 
     "2579.55209471040946330947166841051268644615`20.", ",", 
     "2578.61887543314208244547523439947443017205`20.", ",", 
     "2577.68416896476868566147331598865232122794`20.", ",", 
     "2576.74797663115353326330802391714442278974`20.", ",", 
     "2575.81029975832408233452090582154778671651`20.", ",", 
     "2574.87113967246594622995134894778642951203`20.", ",", 
     "2573.93049769991788230056274183712920524324`20.", ",", 
     "2572.98837516716680778035047774225736434143`20.", ",", 
     "2572.04477340084284376585150015241494825102`20.", ",", 
     "2571.0996937277143872184475972622322734651`20.", ",", 
     "2570.15313747468321091933399647007564373719`20.", ",", 
     "2569.20510596877959130671094105637827000761`20.", ",", 
     "2568.25560053715746412444879814732378600681`20.", ",", 
     "2567.30462250708960781117679905575105653017`20.", ",", 
     "2566.35217320596285455845169931965010279909`20.", ",", 
     "2565.39825396127332896637541551348740229406`20.", ",", 
     "2564.44286610062171422474999855184134459853`20.", ",", 
     "2563.48601095170854574758408818471720977978`20.", ",", 
     "2562.52768984232953218849721023352537223182`20.", ",", 
     "2561.56790410037090376430687646239565879228`20.", ",", 
     "2560.60665505380478781382837654426825302418`20.", ",", 
     "2559.64394403068461151866836218900966560488`20.", ",", 
     "2558.67977235914053171255076508080102771487`20.", ",", 
     "2557.71414136737489170547721286272370183403`20.", ",", 
     "2556.74705238365770504879386115972593916122`20.", ",", 
     "2555.7785067363221661670123948163083942818`20.", ",", 
     "2554.80850575376018778201481853296715789274`20.", ",", 
     "2553.83705076441796505505950643151854344987`20.", ",", 
     "2552.86414309679156637179976240870105854265`20.", ",", 
     "2551.88978407942255069532580922737361914553`20.", ",", 
     "2550.9139750408936114120466250589685962445`20.", ",", 
     "2549.93671730982424659503933268323281518638`20.", ",", 
     "2548.95801221486645560931086996866171999457`20.", ",", 
     "2547.97786108470046198323938194312507247262`20.", ",", 
     "2546.99626524803046247029112621282887189446`20.", ",", 
     "2546.01322603358040222494262634617692335669`20.", ",", 
     "2545.02874477008977601657729391110323257537`20.", ",", 
     "2544.04282278630945540497072110359939720596`20.", ",", 
     "2543.05546141099754180082927445783054646661`20.", ",", 
     "2542.06666197291524533470244827661400887109`20.", ",", 
     "2541.07642580082278945745061662608837583534`20.", ",", 
     "2540.08475422347534119531630763273322669566`20.", ",", 
     "2539.09164856961896698251886621157591056049`20.", ",", 
     "2538.09711016798661399416932422571369982046`20.", ",", 
     "2537.10114034729411690218441359335406245992`20.", ",", 
     "2536.1037404362362299767658913661180939472`20.", ",", 
     "2535.10491176348268445590364983312869960576`20.", ",", 
     "2534.10465565767427110525841297876461039403`20.", ",", 
     "2533.10297344741894789068212704727572681504`20.", ",", 
     "2532.09986646128797268554139164650076370943`20.", ",", 
     "2531.09533602781206093492140305220731871773`20.", ",", 
     "2530.08938347547756819870484764757963768184`20.", ",", 
     "2529.0820101327226974954419454417985983012`20.", ",", 
     "2528.07321732793373136885435625152410932516`20.", ",", 
     "2527.06300638944128859874687949687121848638`20.", ",", 
     "2526.05137864551660547803675796210955804604`20.", ",", 
     "2525.03833542436784157755089181120770089297`20.", ",", 
     "2524.02387805413640992018633734926667640619`20.", ",", 
     "2523.0080078628933314859790614138719473145`20.", ",", 
     "2521.99072617863561396958000300954581016848`20.", ",", 
     "2520.97203432928265471159601522274919486975`20.", ",", 
     "2519.95193364267266772521617914976658486852`20.", ",", 
     "2518.93042544655913473951125432903440896452`20.", ",", 
     "2517.90751106860728018076561400660102356253`20.", ",", 
     "2516.8831918363905700131768657133918778816`20.", ",", 
     "2515.85746907738723436023843555366734838663`20.", ",", 
     "2514.83034411897681382810465597775059443397`20.", ",", 
     "2513.80181828843672945222629954681383628287`20.", ",", 
     "2512.77189291293887618853700342845450508455`20.", ",", 
     "2511.74056931954623987046758945266919260355`20.", ",", 
     "2510.70784883520953755306586110211211107828`20.", ",", 
     "2509.67373278676388116550401063267436750538`20.", ",", 
     "2508.63822250092546439326425567709579279472`20.", ",", 
     "2507.60131930428827271130570446550692981201`20.", ",", 
     "2506.56302452332081648953168172690803150342`20.", ",", 
     "2505.52333948436288709189679317452233843051`20.", ",", 
     "2504.48226551362233589051682522210839929763`20.", ",", 
     "2503.43980393717187611617212846154704674851`20.", ",", 
     "2502.39595608094590746662637892659962328878`20.", ",", 
     "2501.35072327073736339421751098522293593126`20.", ",", 
     "2500.3041068321945809942161307949215304412`20.", ",", 
     "2499.25610809081819341548881081496882223433`20.", ",", 
     "2498.20672837195804471504929533030792071531`20.", ",", 
     "2497.15596900081012707812977598137946382694`20.", ",", 
     "2496.10383130241354032545698683199830347033`20.", ",", 
     "2495.05031660164747362947388270750504300813`20.", ",", 
     "2493.99542622322820936130706480597645884579`20.", ",", 
     "2492.93916149170614899034286657953417157989`20.", ",", 
     "2491.88152373146286095834107349955627130764`20.", ",", 
     "2490.82251426670815045008458570377068222265`20.", ",", 
     "2489.76213442147715098263590606625752039663`20.", ",", 
     "2488.70038551962743773534711157179166636733`20.", ",", 
     "2487.63726888483616254284890689962711325739`20.", ",", 
     "2486.57278584059721047332642996248472940207`20.", ",", 
     "2485.50693771021837791447464418604009812588`20.", ",", 
     "2484.43972581681857208961437618298467903`20.", ",", 
     "2483.37115148332503192654130505288621694738`20.", ",", 
     "2482.30121603247057020177444595276366238861`20.", ",", 
     "2481.22992078679083688296786121093094974488`20.", ",", 
     "2480.15726706862160359234944272511660845301`20.", ",", 
     "2479.08325620009606911415360557161562456246`20.", ",", 
     "2478.00788950314218586912058078151951918404`20.", ",", 
     "2476.93116829948000727924366148901632084567`20.", ",", 
     "2475.85309391061905594605720775142803300648`20.", ",", 
     "2474.77366765785571256587241815714996988724`20.", ",", 
     "2473.69289086227062550548479800211324014827`20.", ",", 
     "2472.61076484472614096199686170400293258631`20.", ",", 
     "2471.52729092586375363052186886246037523538`20.", ",", 
     "2470.44247042610157780365927683910023199949`20.", ",", 
     "2469.35630466563183882676006604952791705407`20.", ",", 
     "2468.26879496441838483313012570662686359537`20.", ",", 
     "2467.17994264219421868345244615589137588427`20.", ",", 
     "2466.08974901845905003384391807477887939923`20.", ",", 
     "2464.99821541247686745710005779363115443944`20.", ",", 
     "2463.90534314327353054182093120958597063329`20.", ",", 
     "2462.81113352963438189425390583001496277856`20.", ",", 
     "2461.71558789010187896783359127012914494847`20.", ",", 
     "2460.61870754297324564554640316079431015726`20.", ",", 
     "2459.5204938062981435003965742658877254065`20.", ",", 
     "2458.42094799787636265940211028030021134655`20.", ",", 
     "2457.32007143525553219670311714423555471401`20.", ",", 
     "2456.21786543572884998152108287844539546285`20.", ",", 
     "2455.11433131633283190686605127715377807479`20.", ",", 
     "2454.00947039384508042504914889602979443934`20.", ",", 
     "2452.90328398478207231622059249330558497375`20.", ",", 
     "2451.79577340539696561631808352054847862495`20.", ",", 
     "2450.68693997167742563097736175869710810944`20.", ",", 
     "2449.57678499934346996212561434282815010076`20.", ",", 
     "2448.46530980384533247414939204840306898754`20.", ",", 
     "2447.35251570036134612670164489926607946619`20.", ",", 
     "2446.23840400379584460138742722390544877882`20.", ",", 
     "2445.12297602877708264974471179510609394552`20.", ",", 
     "2444.0062330896551750901155674454385126114`20.", ",", 
     "2442.88817650050005438118366860552484436672`20.", ",", 
     "2441.76880757509944670013669285379272830913`20.", ",", 
     "2440.64812762695686645359659832663885802648`20.", ",", 
     "2439.52613796928962914964703148825642596708`20.", ",", 
     "2438.40283991502688255947517231145468128886`20.", ",", 
     "2437.27823477680765609733515362559208829886`20.", ",", 
     "2436.15232386697892834773176973499599660693`20.", ",", 
     "2435.02510849759371266891649212884440901624`20.", ",", 
     "2433.89658998040916080198281315686844941009`20.", ",", 
     "2432.76676962688468441504461813673385658498`20.", ",", 
     "2431.63564874818009451217961892718026820997`20.", ",", 
     "2430.50322865515375863701984422016098538095`20.", ",", 
     "2429.36951065836077580107275058451538170324`20.", ",", 
     "2428.23449606805116906705967077659453286389`20.", ",", 
     "2427.0981861941680957177630293968348862872`20.", ",", 
     "2425.96058234634607494108000822554954530903`20.", ",", 
     "2424.82168583390923296218811235842964697354`20.", ",", 
     "2423.68149796586956555393735165619763898091`20.", ",", 
     "2422.54002005092521785679448832812852902187`20.", ",", 
     "2421.39725339745878143987698922045547376762`20.", ",", 
     "2420.25319931353560853482793934208125668204`20.", ",", 
     "2419.10785910690214337449820032425224027324`20.", ",", 
     "2417.96123408498427056861851309854929198725`20.", ",", 
     "2416.81332555488568044886202753650768159395`20.", ",", 
     "2415.66413482338625131591687279860529154402`20.", ",", 
     "2414.51366319694044852140884059012343081274`20.", ",", 
     "2413.36191198167574031773601954125180938334`20.", ",", 
     "2412.20888248339103040910027286767333825927`20.", ",", 
     "2411.05457600755510713724477389797995290192`20.", ",", 
     "2409.89899385930510923563238577047597817128`20.", ",", 
     "2408.74213734344500808602647362086371105578`20.", ",", 
     "2407.58400776444410641166375114164116887568`20.", ",", 
     "2406.42460642643555334143796995167249821034`20.", ",", 
     "2405.26393463321487577974364144765936002184`20.", ",", 
     "2404.10199368823852601686051861413852114094`20.", ",", 
     "2402.93878489462244551499224175900257044902`20.", ",", 
     "2401.77430955514064480530634964828746854436`20.", ",", 
     "2400.6085689722237994315577585842462164472`20.", ",", 
     "2399.44156444795786187611379936713621084129`20.", ",", 
     "2398.27329728408268940443595878093755393801`20.", ",", 
     "2397.10376878199068776431158143747761889921`20.", ",", 
     "2395.93298024272547067636793290628069047624`20.", ",", 
     "2394.76093296698053505264118966522855918852`20.", ",", 
     "2393.5876282550979518802140893575577361175`20.", ",", 
     "2392.41306740706707270717813017218113018029`20.", ",", 
     "2391.23725172252325166841933512494584856297`20.", ",", 
     "2390.06018250074658298897068006534199659598`20.", ",", 
     "2388.88186104066065390291930803164532009467`20.", ",", 
     "2387.70228864083131292610260200015152904679`20.", ",", 
     "2386.52146659946545342107404820023132143572`20.", ",", 
     "2385.33939621440981239306757828132918852201`20.", ",", 
     "2384.15607878314978445593771621060203536625`20.", ",", 
     "2382.97151560280825090730236054462357150779`20.", ",", 
     "2381.78570797014442385236539055276198122109`20.", ",", 
     "2380.59865718155270531614748167327861641683`20.", ",", 
     "2379.41036453306156128410553825741174744413`20.", ",", 
     "2378.22083132033241061137398600412925097324`20.", ",", 
     "2377.03005883865852874111479961139738882986`20.", ",", 
     "2375.83804838296396617271755987057621671002`20.", ",", 
     "2374.64480124780248162084602580929672485019`20.", ",", 
     "2373.4503187273564898065836588430158327572`20.", ",", 
     "2372.25460211543602382218723472144586476384`20.", ",", 
     "2371.05765270547771201121511304444219905965`20.", ",", 
     "2369.85947179054376930605489115931760308024`20.", ",", 
     "2368.66006066332100296513403741915323591573`20.", ",", 
     "2367.45942061611983265235666635454847795133`20.", ",", 
     "2366.25755294087332480156987375751538044647`20.", ",", 
     "2365.05445892913624120912398165630173917596`20.", ",", 
     "2363.8501398720841017978526405257852393667`20.", ",", 
     "2362.64459706051226149606098787247267722519`20.", ",", 
     "2361.43783178483500117537295778885254719514`20.", ",", 
     "2360.2298453350846325915523646109670927868`20.", ",", 
     "2359.02063900091061727267653504622272865381`20.", ",", 
     "2357.81021407157869929930602686409280033963`20.", ",", 
     "2356.59857183597005192155933844601700511481`20.", ",", 
     "2355.38571358258043795826747234436273022858`20.", ",", 
     "2354.17164059951938392364975786132411736814`20.", ",", 
     "2352.95635417450936782721945306956570197784`20.", ",", 
     "2351.739855594885020592895326383965692089`20.", ",", 
     "2350.52214614759234104356365266820223537904`20.", ",", 
     "2349.30322711918792439760384001421038138404`20.", ",", 
     "2348.08309979583820422416022204192067905031`20.", ",", 
     "2346.86176546331870780421239828784233711971`20.", ",", 
     "2345.63922540701332484476687362143919318971`20.", ",", 
     "2344.41548091191358949376362846545919225086`20.", ",", 
     "2343.19053326261797560356263689748289232612`20.", ",", 
     "2341.96438374333120519114723165083931504611`20.", ",", 
     "2340.73703363786357004345358596776229378742`20.", ",", 
     "2339.50848422963026641650843471783380751012`20.", ",", 
     "2338.27873680165074277733048388890543580939`20.", ",", 
     "2337.04779263654806053782475137062451657839`20.", ",", 
     "2335.8156530165482677301733359429241333319`20.", ",", 
     "2334.58231922347978557350081878895626344735`20.", ",", 
     "2333.34779253877280788186765608403691357482`20.", ",", 
     "2332.1120742434587132639205158532188465902`20.", ",", 
     "2330.87516561816949006480454109743024146424`20.", ",", 
     "2329.63706794313717400121897809179906626693`20.", ",", 
     "2328.39778249819329844077448786211267485727`20.", ",", 
     "2327.15731056276835727708775442028859737353`20.", ",", 
     "2325.91565341589128035232670983232481703564`20.", ",", 
     "2324.67281233618892137919780821811717933662`20.", ",", 
     "2323.42878860188555831464529312751263703695`20.", ",", 
     "2322.18358349080240613781131035630934863762`20.", ",", 
     "2320.93719828035714198508501628398437216426`20.", ",", 
     "2319.68963424756344259534851552467162800769`20.", ",", 
     "2318.44089266903053401880752654537303998874`20.", ",", 
     "2317.19097482096275354307511554924497703171`20.", ",", 
     "2315.93988197915912379045765314291998327893`20.", ",", 
     "2314.68761541901293894067333106779392048133`20.", ",", 
     "2313.43417641551136303351512370492560600492`20.", ",", 
     "2312.17956624323504030625198745643270302562`20.", ",", 
     "2310.92378617635771752084435692326510166975`20.", ",", 
     "2309.66683748864587823633261666530557681659`20.", ",", 
     "2308.40872145345838898204019803487974350954`20.", ",", 
     "2307.14943934374615728751626907325345313795`20.", ",", 
     "2305.88899243205180152542664886980095595948`20.", ",", 
     "2304.62738199050933252388558338708154285725`20.", ",", 
     "2303.36460929084384690500536499716357856133`20.", ",", 
     "2302.10067560437123210672546046321332240437`20.", ",", 
     "2300.83558220199788304526782960627343238711`20.", ",", 
     "2299.5693303542204303758504673532671376821`20.", ",", 
     "2298.30192133112548030957688336359120767424`20.", ",", 
     "2297.03335640238936594470524423498297521698`20.", ",", 
     "2295.76363683727791007078724181295170374129`20.", ",", 
     "2294.49276390464619940445341595150584267163`20.", ",", 
     "2293.2207388729383702159086499367747058678`20.", ",", 
     "2291.94756301018740530548887059082672535446`20.", ",", 
     "2290.673237584014942289917621882558892561`20.", ",", 
     "2289.39776386163109315818913990844164997743`20.", ",", 
     "2288.12114310983427505729283775088498941425`20.", ",", 
     "2286.84337659501105226828271051889106019539`20.", ",", 
     "2285.56446558313598933348409352729544109678`20.", ",", 
     "2284.28441133977151529591944993994244699098`20.", ",", 
     "2283.00321513006779901232442831100196984199`20.", ",", 
     "2281.72087821876263550141531548938209581809`20.", ",", 
     "2280.43740187018134328935921664546857353858`20.", ",", 
     "2279.15278734823667271468882223839854731333`20.", ",", 
     "2277.8670359164287251551944722264056792198`20.", ",", 
     "2276.58014883784488313961740155257491685295`20.", ",", 
     "2275.29212737515975130725954889319636776021`20.", ",", 
     "2274.00297279063510817891713397486407613075`20.", ",", 
     "2272.71268634611986870283735874809261854916`20.", ",", 
     "2271.42126930305005753969006580765203839353`20.", ",", 
     "2270.12872292244879305083899529081659869102`20.", ",", 
     "2268.83504846492628195449042084178215759751`20.", ",", 
     "2267.54024719067982461459041804097140092356`20.", ",", 
     "2266.2443203594938309276358270591344641631`20.", ",", 
     "2264.947269230739846772858117465517231258`20.", ",", 
     "2263.64909506337659099153384951467477579369`20.", ",", 
     "2262.34979911595000286147025543602831828771`20.", ",", 
     "2261.04938264659330003300963899301031051838`20.", ",", 
     "2259.74784691302704689319181476460391770771`20.", ",", 
     "2258.44519317255923332500968329250147452234`20.", ",", 
     "2257.14142268208536382898926765476877048769`20.", ",", 
     "2255.83653669808855697462212455646229874063`20.", ",", 
     "2254.53053647663965514947499221597212134545`20.", ",", 
     "2253.2234232733973445740988518824075527825`20.", ",", 
     "2251.91519834360828555115726361654762958726`20.", ",", 
     "2250.60586294210725291749189404160108458339`20.", ",", 
     "2249.29541832331728666814158831999404876853`20.", ",", 
     "2247.98386574124985272163015500272409063489`20.", ",", 
     "2246.67120644950501379613723515746545254308`20.", ",", 
     "2245.35744170127161036646622100499568682325`20.", ",", 
     "2244.04257274932745167202317904107025326413`20.", ",", 
     "2242.72660084603951674632112331966808187517`20.", ",", 
     "2241.40952724336416543882478141792788510151`20.", ",", 
     "2240.09135319284735940025220395543342812048`20.", ",", 
     "2238.77207994562489300275119393183691244069`20.", ",", 
     "2237.45170875242263416667058027766019685596`20.", ",", 
     "2236.1302408635567750659488367542951375281`20.", ",", 
     "2234.80767752893409268444545873268188274669`20.", ",", 
     "2233.48401999805221919584386263984966091158`20.", ",", 
     "2232.15926951999992214005837237539621764642`20.", ",", 
     "2230.83342734345739436938211032694862688551`20.", ",", 
     "2229.50649471669655373791732449056459955811`20.", ",", 
     "2228.17847288758135250813486454084577088753`20.", ",", 
     "2226.84936310356809644871517558539859542236`20.", ",", 
     "2225.51916661170577359812931604675346735096`20.", ",", 
     "2224.18788465863639266872513308915190152007`20.", ",", 
     "2222.8555184905953310663908528759137382193`20.", ",", 
     "2221.52206935341169250117597151591887586342`20.", ",", 
     "2220.18753849250867416455747382937608729766`20.", ",", 
     "2218.85192715290394344934806921308465045955`20.", ",", 
     "2217.51523657921002418855232528026504365606`20.", ",", 
     "2216.17746801563469238978630914470019437428`20.", ",", 
     "2214.83862270598138144218662195859157016698`20.", ",", 
     "2213.49870189364959677304554353545484559515`20.", ",", 
     "2212.1577068216353399317203997247722374524`20.", ",", 
     "2210.8156387325315420786772349811374664254`20.", ",", 
     "2209.47249886852850685784142581244933754711`20.", ",", 
     "2208.12828847141436263074101722470319008275`20.", ",", 
     "2206.78300878257552405124231383294581704049`20.", ",", 
     "2205.43666104299716295999162011171431344064`20.", ",", 
     "2204.08924649326368857799201065385418390683`20.", ",", 
     "2202.74076637355923697905963184407410849778`20.", ",", 
     "2201.39122192366816982122030179573989793762`20.", ",", 
     "2200.04061438297558231742409672463736568392`20.", ",", 
     "2198.68894499046782042627320033875605509897`20.", ",", 
     "2197.33621498473300724377655972734509118151`20.", ",", 
     "2195.98242560396157857746384827942639691665`20.", ",", 
     "2194.62757808594682768451089522401733779528`20.", ",", 
     "2193.27167366808545915584911456608575985813`20.", ",", 
     "2191.91471358737815192855256583428754316554`20.", ",", 
     "2190.55669908043013140911811773934592133757`20.", ",", 
     "2189.19763138345175069057677639020893301359`20.", ",", 
     "2187.83751173225908084669759520210378775225`20.", ",", 
     "2186.47634136227451028686971738268901171375`20.", ",", 
     "2185.11412150852735315557302748407027295226`20.", ",", 
     "2183.75085340565446676067361980693539639737`20.", ",", 
     "2182.38653828790087801510684255429813431698`20.", ",", 
     "2181.02117738912041887683806194609958650469`20.", ",", 
     "2179.65477194277637077231952469180302684872`20.", ",", 
     "2178.28732318194211798899079523170705571918`20.", ",", 
     "2176.91883233930181002270022124699981339298`20.", ",", 
     "2175.54930064715103286625575265080255436853`20.", ",", 
     "2174.1787293373974892256452214611578285507`20.", ",", 
     "2172.80711964156168765079889878947333864134`20.", ",", 
     "2171.43447279077764056810079714337490911122`20.", ",", 
     "2170.06079001579357120218979816021151014251`20.", ",", 
     "2168.68607254697262937492727491414552787322`20.", ",", 
     "2167.31032161429361616974446158110899216433`20.", ",", 
     "2165.9335384473517174499204193644425452435`20.", ",", 
     "2164.55572427535924621968007440962386000735`20.", ",", 
     "2163.17688032714639381734147957690667101601`20.", ",", 
     "2161.79700783116198993008219639271742345075`20.", ",", 
     "2160.41610801547427142023652566177533398656`20.", ",", 
     "2159.0341821077716599533782549025655148284`20.", ",", 
     "2157.65123133536354841878765820533097254989`20.", ",", 
     "2156.26725692518109613324669997992639813212`20.", ",", 
     "2154.88226010377803281945277949016683219358`20.", ",", 
     "2153.4962420973314713506889296598781361274`20.", ",", 
     "2152.10920413164272925373717346634791210691`20.", ",", 
     "2150.72114743213815896237176689295900425766`20.", ",", 
     "2149.33207322386998681412034199660520330061`20.", ",", 
     "2147.94198273151716078333353079597647503758`20.", ",", 
     "2146.55087717938620694395752459895795127814`20.", ",", 
     "2145.15875779141209465575922883253575331045`20.", ",", 
     "2143.76562579115911046811023578569368259158`20.", ",", 
     "2142.37148240182174073579378291379618835304`20.", ",", 
     "2140.97632884622556294165821911444451529094`20.", ",", 
     "2139.58016634682814572130129297067092772627`20.", ",", 
     "2138.18299612571995758533183336289235181866`20.", ",", 
     "2136.7848194046252843351191427933346516308`20.", ",", 
     "2135.38563740490315516830569671326402889731`20.", ",", 
     "2133.98545134754827747072556834273330247181`20.", ",", 
     "2132.58426245319198029173940898570145201533`20.", ",", 
     "2131.18207194210316650036684057741553497645`20.", ",", 
     "2129.77888103418927361996879294418023613464`20.", ",", 
     "2128.374690948997243339605676714587299299`20.", ",", 
     "2126.96950290571449970057235865946397639024`20.", ",", 
     "2125.56331812316993595698773511660501481779`20.", ",", 
     "2124.15613781983491010969531777791094169197`20.", ",", 
     "2122.74796321382424911311169226884689700199`20.", ",", 
     "2121.33879552289726175504202255436835548203`20.", ",", 
     "2119.92863596445876020986599336585294392278`20.", ",", 
     "2118.51748575556009026588374989967137521181`20.", ",", 
     "2117.10534611290017022799955161963772168142`20.", ",", 
     "2115.69221825282653849731104908051249641584`20.", ",", 
     "2114.27810339133640982956436466443756942761`20.", ",", 
     "2112.86300274407774027482955684542729729996`20.", ",", 
     "2111.44691752635030080114762146679330790899`20.", ",", 
     "2110.02984895310675960529898254004307466429`20.", ",", 
     "2108.61179823895377311424450094194191327784`20.", ",", 
     "2107.19276659815308568119343555023780391405`20.", ",", 
     "2105.77275524462263798065858311106133648337`20.", ",", 
     "2104.35176539193768410726705769245008808064`20.", ",", 
     "2102.92979825333191738350590718574159144876`20.", ",", 
     "2101.50685504169860488199506431733704245453`20.", ",", 
     "2100.08293696959173066829605658442651222446`20.", ",", 
     "2098.65804524922714777068351929925354436349`20.", ",", 
     "2097.23218109248373888372793680816199483729`20.", ",", 
     "2095.80534571090458581296224976982049301409`20.", ",", 
     "2094.37754031569814766833208461187109864235`20.", ",", 
     "2092.94876611773944781455946119658968912364`20.", ",", 
     "2091.51902432757126958698299548459854505585`20.", ",", 
     "2090.08831615540536078187391781029046634641`20.", ",", 
     "2088.65664281112364693066675968513223360894`20.", ",", 
     "2087.22400550427945336798641158098124304853`20.", ",", 
     "2085.79040544409873610379951317280904883728`20.", ",", 
     "2084.35584383948132151046790196488078676666`20.", ",", 
     "2082.92032189900215483593521585476516930329`20.", ",", 
     "2081.48384083091255755473482379816482233681`20.", ",", 
     "2080.0464018431414935689681543322214705378`20.", ",", 
     "2078.60800614329684427186731671837071245832`20.", ",", 
     "2077.1686549386666924870247809248535193803`20.", ",", 
     "2075.7283494362206152968459224736597330299`20.", ",", 
     "2074.2870908426109857742575732894258104901`20.", ",", 
     "2072.84488036417428363218748238342862679458`20.", ",", 
     "2071.4017192069324148058159183225224091905`20.", ",", 
     "2069.95760857659403998309168263497181467636`20.", ",", 
     "2068.51254967855591209950069935784877683918`20.", ",", 
     "2067.06654371790422281357625698749705467984`20.", ",", 
     "2065.61959189941595798014606799791032398295`20.", ",", 
     "2064.17169542756026213882274768724229769474`20.", ",", 
     "2062.72285550649981203576127557728508499452`20.", ",", 
     "2061.27307334009219919722967377693558832691`20.", ",", 
     "2059.82235013189132157406771051474823707609`20.", ",", 
     "2058.37068708514878427664311474300496497644`20.", ",", 
     "2056.91808540281530942045577941251097566717`20.", ",", 
     "2055.4645462875421551030879560198331371331`20.", ",", 
     "2054.01007094168254353375273028074838775517`20.", ",", 
     "2052.5546605672930983372543573129294570695`20.", ",", 
     "2051.0983163661352910547425740948717201928`20.", ",", 
     "2049.64103953967689686421905782052673415996`20.", ",", 
     "2048.18283128909345954433803324775059381992`20.", ",", 
     "2046.72369281526976570563493447486883483809`20.", ",", 
     "2045.26362531880132831391729363113917414004`20.", ",", 
     "2043.80262999999587953116097079428621050316`20.", ",", 
     "2042.34070805887487289987277991639230924551`20.", ",", 
     "2040.87786069517499489750784294423001684357`20.", ",", 
     "2039.41408910834968588816697204244040914421`20.", ",", 
     "2037.94939449757067049944640701486510979182`20.", ",", 
     "2036.48377806172949745296970729426787537153`20.", ",", 
     "2035.01724099943908887779991807340891296036`20.", ",", 
     "2033.54978450903529913660971910796598838208`20.", ",", 
     "2032.08140978857848319517856205134211569356`20.", ",", 
     "2030.61211803585507456648926712661505961079`20.", ",", 
     "2029.14191044837917286141266224257854855684`20.", ",", 
     "2027.67078822339414097869810846339884917023`20.", ",", 
     "2026.19875255787421196773068853630040143375`20.", ",", 
     "2024.72580464852610559827298678915732836904`20.", ",", 
     "2023.25194569179065467218133030045908383574`20.", ",", 
     "2021.77717688384444111287368940126754249194`20.", ",", 
     "2020.30149942060144186912977339390348397996`20.", ",", 
     "2018.82491449771468467062385563371545623471`20.", ",", 
     "2017.34742331057791367342820044868027978659`20.", ",", 
     "2015.86902705432726503458035250055783490394`20.", ",", 
     "2014.38972692384295245568172824861189186191`20.", ",", 
     "2012.90952411375096273638869302495816557033`20.", ",", 
     "2011.42841981842476137957142385933583012583`20.", ",", 
     "2009.94641523198700829085119116443613080519`20.", ",", 
     "2008.46351154831128361618412235078303237358`20.", ",", 
     "2006.97970996102382376213995665779766944168`20.", ",", 
     "2005.49501166350526764452872249416213416248`20.", ",", 
     "2004.00941784889241321205766783836946285136`20.", ",", 
     "2002.52292971007998429275619589776311022018`20.", ",", 
     "2001.03554843972240781198909288323355417934`20.", ",", 
     "1999.54727523023560143198912040683407704668`20.", ",", 
     "1998.05811127379877166398026893227227080651`20.", ",", 
     "1996.56805776235622250513386950128161726211`20.", ",", 
     "1995.07711588761917465380263062455155718969`20.", ",", 
     "1993.58528684106759535771385333466367918273`20.", ",", 
     "1992.09257181395203895107398533046643508701`20.", ",", 
     "1990.59897199729549813784377040881118909485`20.", ",", 
     "1989.10448858189526607978806002693164209715`20.", ",", 
     "1987.60912275832480934928847293706846222419`20.", ",", 
     "1986.11287571693565180833217705385242838523`20.", ",", 
     "1984.61574864785926947655785598904542613166`20.", ",", 
     "1983.11774274100899645275221497453073292093`20.", ",", 
     "1981.61885918608194195574905702452393889387`20.", ",", 
     "1980.11909917256091855228997881724098538188`20.", ",", 
     "1978.61846388971638164106313743294304335012`20.", ",", 
     "1977.11695452660838026384644932185010632267`20.", ",", 
     "1975.61457227208851931644621552502755124786`20.", ",", 
     "1974.11131831480193323394382771200702655218`20.", ",", 
     "1972.60719384318927122664429862808325797669`20.", ",", 
     "1971.10220004548869414506337736669769746988`20.", ",", 
     "1969.59633810973788305429755621390840200746`20.", ",", 
     "1968.08960922377605960019605960207829492977`20.", ",", 
     "1966.58201457524601825189874508570940627476`20.", ",", 
     "1965.07355535159617050752167358711377579023`20.", ",", 
     "1963.56423274008260115206597226856850034071`20.", ",", 
     "1962.05404792777113665899869185372639372887`20.", ",", 
     "1960.54300210153942582940995185385353754024`20.", ",", 
     "1959.03109644807903276519220458459391440805`20.", ",", 
     "1957.51833215389754227531850127152362641971`20.", ",", 
     "1956.00471040532067781702092155217308104163`20.", ",", 
     "1954.49023238849443207649168835148509354022`20.", ",", 
     "1952.97489928938721029665194211500996516382`20.", ",", 
     "1951.45871229379198646256085733948169482364`20.", ",", 
     "1949.94167258732847245817507825508957463964`20.", ",", 
     "1948.4237813554453003114198254256692184575`20.", ",", 
     "1946.90503978342221764790315079038366720033`20.", ",", 
     "1945.38544905637229647709854487657739457497`20.", ",", 
     "1943.8650103592441554384434620355020550059`20.", ",", 
     "1942.34372487682419563855755519661075848246`20.", ",", 
     "1940.8215937937388502146799269912643241023`20.", ",", 
     "1939.29861829445684776346514055091410636836`20.", ",", 
     "1937.77479956329148977846893421443007947746`20.", ",", 
     "1936.25013878440294224400261211485291761048`20.", ",", 
     "1934.72463714180054153754622558691038352836`20.", ",", 
     "1933.19829581934511479759144039667794768394`20.", ",", 
     "1931.67111600075131491864216472946878683435`20.", ",", 
     "1930.14309886958997034014160409211852402085`20.", ",", 
     "1928.61424560929044980132567970649642376798`20.", ",", 
     "1927.08455740314304223943222907984558558355`20.", ",", 
     "1925.55403543430135201433090655195266630198`20.", ",", 
     "1924.02268088578470964848830433570210481256`20.", ",", 
     "1922.49049494048059827725489740337537824824`20.", ",", 
     "1920.95747878114709601076365379896420382683`20.", ",", 
     "1919.42363359041533441527352863510249107747`20.", ",", 
     "1917.8889605507919733285838752307145413214`20.", ",", 
     "1916.35346084466169223119768706189094435372`20.", ",", 
     "1914.81713565428969840223249198122211187924`20.", ",", 
     "1913.27998616182425209667796391740496282883`20.", ",", 
     "1911.74201354929920898848956127343267383612`20.", ",", 
     "1910.20321899863658013219877584614611586206`20.", ",", 
     "1908.66360369164910970422428811046384686969`20.", ",", 
     "1907.12316881004287079389626802773126039242`20.", ",", 
     "1905.58191553541987952337042687366045667565`20.", ",", 
     "1904.03984504928072778512181548005665843144`20.", ",", 
     "1902.49695853302723489558379826906009707508`20.", ",", 
     "1900.95325716796511847374856238005929284414`20.", ",", 
     "1899.40874213530668486418584175740844686967`20.", ",", 
     "1897.86341461617353943498059656018227533289`20.", ",", 
     "1896.31727579159931709255300440737646243577`20.", ",", 
     "1894.7703268425324333672205860310316141622`20.", ",", 
     "1893.22256894983885643570838886340759770589`20.", ",", 
     "1891.67400329430490045962517604858855022319`20.", ",", 
     "1890.12463105664004063221831913356237107612`20.", ",", 
     "1888.57445341747975033951490241883852788683`20.", ",", 
     "1887.02347155738836085626928900481798221672`20.", ",", 
     "1885.47168665686194401198650051686335228402`20.", ",", 
     "1883.91909989633121827769521918473283655116`20.", ",", 
     "1882.36571245616447874012360777037356272688`20.", ",", 
     "1880.81152551667055144650562902620471328467`20.", ",", 
     "1879.25654025810177262043590847533087089859`20.", ",", 
     "1877.70075786065699326701881972875121813362`20.", ",", 
     "1876.1441795044846097040444121428896590501`20.", ",", 
     "1874.58680636968562057509272636555313620512`20.", ",", 
     "1873.02863963631671092034229609391627379224`20.", ",", 
     "1871.46968048439336390146223171443601754087`20.", ",", 
     "1869.90993009389300079832493042997973753235`20.", ",", 
     "1868.34938964475814991741356832601130286306`20.", ",", 
     "1866.78806031689964507474123003447976094821`20.", ",", 
     "1865.22594329019985433987367960063425242514`20.", ",", 
     "1863.6630397445159397522829749203809600006`20.", ",", 
     "1862.09935085968314874678273917608217076172`20.", ",", 
     "1860.53487781551813805123705957810885752582`20.", ",", 
     "1858.96962179182233084712360551401652831638`20.", ",", 
     "1857.4035839683853080118983630037239734304`20.", ",", 
     "1855.83676552498823429148590050820697375068`20.", ",", 
     "1854.26916764140732028163766836120959713082`20.", ",", 
     "1852.70079149741732112839468439075445298594`20.", ",", 
     "1851.1316382727950728904941166470445901316`20.", ",", 
     "1849.56170914732306754030664895212191583453`20.", ",", 
     "1847.99100530079306761481889021652976872077`20.", ",", 
     "1846.4195279130097615643191355548315902841`20.", ",", 
     "1844.84727816379446088384307656078327103786`20.", ",", 
     "1843.27425723298884015112707016135801228766`20.", ",", 
     "1841.70046630045872113483971157632070734264`20.", ",", 
     "1840.12590654609790217825804950242897711779`20.", ",", 
     "1838.5505791498320341063641040681477079149`20.", ",", 
     "1836.97448529162254394860262390067675060354`20.", ",", 
     "1835.39762615147060781530543023503539575444`20.", ",", 
     "1833.82000290942117431309539277723252040058`20.", ",", 
     "1832.24161674556703993347918782539778649656`20.", ",", 
     "1830.66246884005297789936860891071281486504`20.", ",", 
     "1829.08256037307992200648242601582137103969`20.", ",", 
     "1827.50189252490920705052270561690562421671`20.", ",", 
     "1825.92046647586686748674019132283406149228`20.", ",", 
     "1824.33828340634799602605288468089493409958`20.", ",", 
     "1822.75534449682116393131144111754019550094`20.", ",", 
     "1821.17165092783290483866649410797876217193`20.", ",", 
     "1819.58720388001226399233963272373595369987`20.", ",", 
     "1818.00200453407541484648557810406128698091`20.", ",", 
     "1816.41605407083034505531322865489317769612`20.", ",", 
     "1814.82935367118161394226376512600815472882`20.", ",", 
     "1813.24190451613518361088201131781733704575`20.", ",", 
     "1811.65370778680332593412080690598909193489`20.", ",", 
     "1810.06476466440960773524631759741680984108`20.", ",", 
     "1808.47507633029395655232500601370493975318`20.", ",", 
     "1806.88464396591780945953139437476918641701`20.", ",", 
     "1805.29346875286934750228169299988331414941`20.", ",", 
     "1803.70155187286881838953470366652300643875`20.", ",", 
     "1802.10889450777395017557190514337872965294`20.", ",", 
     "1800.51549783958545875523795654510936166211`20.", ",", 
     "1798.92136305045265209105655406607183787539`20.", ",", 
     "1797.32649132267913418790104120107824241855`20.", ",", 
     "1795.7308838387286119310616207878208635368`20.", ",", 
     "1794.13454178123080800667946604664519828343`20.", ",", 
     "1792.53746633298748322968126140425165393069`20.", ",", 
     "1790.93965867697857171361524021040260426193`20.", ",", 
     "1789.34111999636843242923184091694227238271`20.", ",", 
     "1787.74185147451222081433954949012370375938`20.", ",", 
     "1786.14185429496238421647082310135518878954`20.", ",", 
     "1784.54112964147528507228625780841729719043`20.", ",", 
     "1782.93967869801795585349995113374986212453`20.", ",", 
     "1781.33750264877498993849836735000593781164`20.", ",", 
     "1779.7346026781555727018223986016116020216`20.", ",", 
     "1778.13097997080065725036153951011399112025`20.", ",", 
     "1776.52663571159028937554425395361139523673`20.", ",", 
     "1774.92157108565108643507402531531358906893`20.", ",", 
     "1773.31578727836387502593070512768344630316`20.", ",", 
     "1771.70928547537149246250613563104238827922`20.", ",", 
     "1770.10206686258675722994612889726839879697`20.", ",", 
     "1768.4941326262006137431021441526578980958`20.", ",", 
     "1766.88548395269045690602962359996794741721`20.", ",", 
     "1765.27612202882864213577983698448861222586`20.", ",", 
     "1763.66604804169118668739175720372243927102`20.", ",", 
     "1762.0552631786666682945729429304097556181`20.", ",", 
     "1760.44376862746532732263601083354200311265`20.", ",", 
     "1758.83156557612837881690165928067591290411`20.", ",", 
     "1757.2186552130375410210610952745642580059`20.", ",", 
     "1755.60503872692478713597983544820657634505`20.", ",", 
     "1753.99071730688232729018975473060331550023`20.", ",", 
     "1752.3756921423728278989241805693694161712`20.", ",", 
     "1750.75996442323987579906753663421108293796`20.", ",", 
     "1749.14353533971869476288064131058077835049`20.", ",", 
     "1747.5264060824471222138875518828583398984`20.", ",", 
     "1745.90857784247685419393009199223460866566`20.", ",", 
     "1744.29005181128496686116997581436980158909`20.", ",", 
     "1742.67082918078572303480139983256434691051`20.", ",", 
     "1741.05091114334267254348213147423293863533`20.", ",", 
     "1739.43029889178105538104864138366633109434`20.", ",", 
     "1737.80899361940051692499776002197421997186`20.", ",", 
     "1736.18699651998814473053739457639518423811`20.", ",", 
     "1734.56430878783183667577210757308624788604`20.", ",", 
     "1732.94093161773401050183202985481494386322`20.", ",", 
     "1731.31686620502566506550767014614300415584`20.", ",", 
     "1729.69211374558080390124621607300190506853`20.", ",", 
     "1728.06667543583123197421961533936440215246`20.", ",", 
     "1726.44055247278173679660865787179044797735`20.", ",", 
     "1724.81374605402566537527253585133785044302`20.", ",", 
     "1723.18625737776090876059616604288171957064`20.", ",", 
     "1721.55808764280630627352790235253775506211`20.", ",", 
     "1719.9292380486184818006314854815170282164`20.", ",", 
     "1718.29970979530912486536444357064099318704`20.", ",", 
     "1716.66950408366272950773943760376979008461`20.", ",", 
     "1715.0386221151548043339960331220004007098`20.", ",", 
     "1713.40706509197056743287041759431803770549`20.", ",", 
     "1711.77483421702414019545305407624141147169`20.", ",", 
     "1710.14193069397825442141306241816071118631`20.", ",", 
     "1708.50835572726448744547710412391039875648`20.", ",", 
     "1706.87411052210404037440295114426804670787`20.", ",", 
     "1705.23919628452907488619575263325907407921`20.", ",", 
     "1703.60361422140462440987842952338946555824`20.", ",", 
     "1701.96736554045109587563425803695259656572`20.", ",", 
     "1700.33045145026737860146397269914388196823`20.", ",", 
     "1698.69287316035457726350211663659524544383`20.", ",", 
     "1697.05463188114038628266369331029775244052`20.", ",", 
     "1695.4157288240041233501727537095472217857`20.", ",", 
     "1693.77616520130244020857340981254985526098`20.", ",", 
     "1692.1359422263957292028377606799684301061`20.", ",", 
     "1690.49506111367524451794315369583165456394`20.", ",", 
     "1688.85352307859095742455288383205092663816`20.", ",", 
     "1687.211329337680165262939684639453845278`20.", ",", 
     "1685.56848110859687430675901295655248358542`20.", ",", 
     "1683.92497961014197706240593662004361793838`20.", ",", 
     "1682.280826062294244976148984649864345541`20.", ",", 
     "1680.63602168624215793967585879486974400313`20.", ",", 
     "1678.99056770441659240473313334668383148996`20.", ",", 
     "1677.34446534052439033879187855747137656095`20.", ",", 
     "1675.69771581958283167569230232240711991426`20.", ",", 
     "1674.05032036795503333755229553396818140698`20.", ",", 
     "1672.40228021338629832637555377239661709702`20.", ",", 
     "1670.75359658504143880524069723907595173897`20.", ",", 
     "1669.10427071354309750913554311958625217388`20.", ",", 
     "1667.45430383101109224382686915263933523607`20.", ",", 
     "1665.80369717110280864699488972999975340682`20.", ",", 
     "1664.15245196905466679854353013875214367553`20.", ",", 
     "1662.50056946172468767581194591093735864759`20.", ",", 
     "1660.84805088763618585360646275230787767882`20.", ",", 
     "1659.19489748702261524774748414018906407343`20.", ",", 
     "1657.54111050187359509333858744852318584313`20.", ",", 
     "1655.88669117598214373432194902158257947381`20.", ",", 
     "1654.2316407549931481781414563742606349353`20.", ",", 
     "1652.57596048645309773749528793976539988125`20.", ",", 
     "1650.91965161986111043917079232610226439995`20.", ",", 
     "1649.26271540672128122670570590734937944693`20.", ",", 
     "1647.60515310059638131794023651412617508961`20.", ",", 
     "1645.94696595716293839918045468525436828163`20.", ",", 
     "1644.28815523426772764338526101386697174398`20.", ",", 
     "1642.62872219198570382914901716902142834052`20.", ",", 
     "1640.96866809267940510884056543658175262107`20.", ",", 
     "1639.30799420105985922656346199762229323143`20.", ",", 
     "1637.64670178424902321803126069119261877036`20.", ",", 
     "1635.98479211184378783333475625256309378571`20.", ",", 
     "1634.32226645598157810816089311590484930273`20.", ",", 
     "1632.6591260914075816674644754868815175076`20.", ",", 
     "1630.99537229554363647596267423304992123852`20.", ",", 
     "1629.33100634855880985009387021252612155944`20.", ",", 
     "1627.66602953344170061413480099461446438055`20.", ",", 
     "1626.00044313607449631678084712709366111306`20.", ",", 
     "1624.33424844530881742133686774623304319502`20.", ",", 
     "1622.66744675304338034030551892496099413536`20.", ",", 
     "1621.00003935430351110104990929639051554859`20.", ",", 
     "1619.33202754732254130068558151369481457232`20.", ",", 
     "1617.66341263362511783264145773344021306267`20.", ",", 
     "1615.99419591811245764151542460077367428928`20.", ",", 
     "1614.32437870914957848390515338609372451609`20.", ",", 
     "1612.65396231865453633765470871204961508463`20.", ",", 
     "1610.98294806218969970712333992403916035988`20.", ",", 
     "1609.31133725905509061421614720431158960378`20.", ",", 
     "1607.6391312323838215404354358493967924374`20.", ",", 
     "1605.96633130923965699038777505956622046627`20.", ",", 
     "1604.29293882071672767813537191977553975101`20.", ",", 
     "1602.61895510204142459047695500374676832105`20.", ",", 
     "1600.94438149267649935149015813707072702806`20.", ",", 
     "1599.26921933642739639610971196263711132233`20.", ",", 
     "1597.59346998155084145263359483767035686853`20.", ",", 
     "1595.91713478086570973015415901701059888477`20.", ",", 
     "1594.24021509186619600214311651662090343473`20.", ",", 
     "1592.56271227683730746674386139507939128766`20.", ",", 
     "1590.8846277029726988425309063835278042024`20.", ",", 
     "1589.20596274249486762019432238743082554243`20.", ",", 
     "1587.52671877277772573022642116078154864478`20.", ",", 
     "1585.84689717647156209847590463877881398225`20.", ",", 
     "1584.16649934163040863945575648149154647306`20.", ",", 
     "1582.48552666184182017542636117329132436067`20.", ",", 
     "1580.803980536359076561222620757488078442`20.", ",", 
     "1579.12186237023581293406875601886285677862`20.", ",", 
     "1577.4391735744630814875617362693184117335`20.", ",", 
     "1575.75591556610884548276002210225166693265`20.", ",", 
     "1574.07208976845990334986923157700680526301`20.", ",", 
     "1572.38769761116623769417976747484697760094`20.", ",", 
     "1570.70274053038778079232635873344156960188`20.", ",", 
     "1569.01721996894358474208868934479393461691`20.", ",", 
     "1567.33113737646338080316580720280384836155`20.", ",", 
     "1565.64449420954150862982063505050107475778`20.", ",", 
     "1563.95729193189319204105630854068007859533`20.", ",", 
     "1562.26953201451313369198229519103980491229`20.", ",", 
     "1560.58121593583639649307490334528791916689`20.", ",", 
     "1558.89234518190153486385891812113145057737`20.", ",", 
     "1557.20292124651593389578195498706651200452`20.", ",", 
     "1555.51294563142330922730891844804670855087`20.", ",", 
     "1553.82241984647331489408076183273835493394`20.", ",", 
     "1552.13134540979320059989464101584682953529`20.", ",", 
     "1550.43972384796145375181719639982484744326`20.", ",", 
     "1548.7475566961833552065234541136475172539`20.", ",", 
     "1547.0548454984683709766146435564169126069`20.", ",", 
     "1545.36159180780929513696630283761994016465`20.", ",", 
     "1543.66779718636305184399063859959793197067`20.", ",", 
     "1541.97346320563305672714144601833864506846`20.", ",", 
     "1540.27859144665302992434646211056908589599`20.", ",", 
     "1538.58318350017214470389136400854688646543`20.", ",", 
     "1536.88724096684138693749280839647744347163`20.", ",", 
     "1535.1907654574009916561508484456453480759`20.", ",", 
     "1533.49375859286881352556279461293748035177`20.", ",", 
     "1531.79622200472947831560569182403247511731`20.", ",", 
     "1530.09815733512415230340991527330721829091`20.", ",", 
     "1528.39956623704075603724217631216314634723`20.", ",", 
     "1526.70045037450443799489177479087344565156`20.", ",", 
     "1525.00081142276811239239792056330483874518`20.", ",", 
     "1523.30065106850285373453153647665590376307`20.", ",", 
     "1521.59997100998792864617971056798726208583`20.", ",", 
     "1519.89877295730023308346167387831772723716`20.", ",", 
     "1518.19705863250289019597761662547775322537`20.", ",", 
     "1516.4948297698327508992652914918050029839`20.", ",", 
     "1514.79208811588652562289699932112993278451`20.", ",", 
     "1513.08883542980526172976187800776168260301`20.", ",", 
     "1511.38507348345686676262325185991636028348`20.", ",", 
     "1509.68080406161636297342710273105544648431`20.", ",", 
     "1507.97602896214354353933401322333457690332`20.", ",", 
     "1506.27074999615768547931396689111483602416`20.", ",", 
     "1504.56496898820895857077081591656725796387`20.", ",", 
     "1502.85868777644615354370982703973655538835`20.", ",", 
     "1501.1519082127803365194988667852876525024`20.", ",", 
     "1499.44463216304402008393162074789289152249`20.", ",", 
     "1497.73686150714542456441697033379091971158`20.", ",", 
     "1496.02859813921738604588639180059004649237`20.", ",", 
     "1494.3198439677604504396326270568595251474`20.", ",", 
     "1492.6106009157796755471276056872550849486`20.", ",", 
     "1490.90087092091464557358303756298604279714`20.", ",", 
     "1489.19065593556218498373586826251942969534`20.", ",", 
     "1487.47995792699124099878524623408181465036`20.", ",", 
     "1485.76877887744938645603996719032227307674`20.", ",", 
     "1484.05712078426037724299190382775319509974`20.", ",", 
     "1482.3449856599121811305494074745936667539`20.", ",", 
     "1480.63237553213487762550247774777385597128`20.", ",", 
     "1478.91929244396781150363352339148510504211`20.", ",", 
     "1477.20573845381536604024158532563485396063`20.", ",", 
     "1475.49171563549070569662575569310429103897`20.", ",", 
     "1473.77722607824682222615562405390567289889`20.", ",", 
     "1472.0622718867942029133379471382960898303`20.", ",", 
     "1470.34685518130442503970404172437279009094`20.", ",", 
     "1468.63097809739896677186758262107322725684`20.", ",", 
     "1466.91464278612251158473048934423378544979`20.", ",", 
     "1465.19785141390001116600256027417375634097`20.", ",", 
     "1463.48060616247676060078586085921891308482`20.", ",", 
     "1461.76290922884072961505735149159509941846`20.", ",", 
     "1460.04476282512638487667040494696948390344`20.", ",", 
     "1458.32616917849923092810903926438098096605`20.", ",", 
     "1456.60713053102029137646673092118327060943`20.", ",", 
     "1454.88764913948974761617975021514943672346`20.", ",", 
     "1453.16772727526894973518576353322162448731`20.", ",", 
     "1451.44736722408001348435320216803670896096`20.", ",", 
     "1449.72657128578221840444382483414175549621`20.", ",", 
     "1448.00534177412442553750887376357992981463`20.", ",", 
     "1446.28368101647273873468463334694365959843`20.", ",", 
     "1444.5615913535126415446783078771737402315`20.", ",", 
     "1442.83907513892485216161651875578550380089`20.", ",", 
     "1441.11613473903415206140479501315144176762`20.", ",", 
     "1439.39277253243045989481345643572059895658`20.", ",", 
     "1437.66899090956144106327178984255334846518`20.", ",", 
     "1435.94479227229596530663244881156798765241`20.", ",", 
     "1434.22017903345774970351432912339956743876`20.", ",", 
     "1432.49515361632855284151108261174921182939`20.", ",", 
     "1430.76971845412031766746266623101327747304`20.", ",", 
     "1429.04387598941569578052626838205318370887`20.", ",", 
     "1427.3176286735764247776642205439019862734`20.", ",", 
     "1425.59097896611907278719377491431511794705`20.", ",", 
     "1423.86392933405771060484665437522067300575`20.", ",", 
     "1422.13648225121312193952578335184154776867`20.", ",", 
     "1420.40864019748821622999592457341069523694`20.", ",", 
     "1418.68040565810936634135717541244636548439`20.", ",", 
     "1416.95178112283345520712073654938143255525`20.", ",", 
     "1415.22276908512048114704117771571172328437`20.", ",", 
     "1413.49337204127164114146202924537335841222`20.", ",", 
     "1411.76359248953288473831988268673366063219`20.", ",", 
     "1410.03343292916400844602033547630783285042`20.", ",", 
     "1408.30289585947344133823765320897875608769`20.", ",", 
     "1406.57198377881895705548070467824185211868`20.", ",", 
     "1404.84069918357463529826820763712261337576`20.", ",", 
     "1403.10904456706448710739149096288316302218`20.", ",", 
     "1401.37702241846325253081972534183955970531`20.", ",", 
     "1399.6446352216649764698651480653078032328`20.", ",", 
     "1397.91188545412006833706886277375921251566`20.", ",", 
     "1396.1787755856416533746241422484645546799`20.", ",", 
     "1394.44530807718212777657382699442048565589`20.", ",", 
     "1392.71148537958093580395500386326023398804`20.", ",", 
     "1390.97730993228469452518367227025048540255`20.", ",", 
     "1389.24278416204090027269821817407295018848`20.", ",", 
     "1387.50791048156655997318883206367572193838`20.", ",", 
     "1385.77269128819319974921236953297290232623`20.", ",", 
     "1384.03712896248981214713983416556438958932`20.", ",", 
     "1382.30122586686541154024621959239177780723`20.", ",", 
     "1380.5649843441529741857764506429810103636`20.", ",", 
     "1378.82840671617664456202025429086266725025`20.", ",", 
     "1377.09149528230419244082353223588083531861`20.", ",", 
     "1375.35425231798680511429656618297261213873`20.", ",", 
     "1373.61668007328839573319610438761266937132`20.", ",", 
     "1371.87878077140670126294551826056092891671`20.", ",", 
     "1370.14055660718853155231855098885409795614`20.", ",", 
     "1368.40200974564161387036632141558807120708`20.", ",", 
     "1366.66314232044555443414315022274925276475`20.", ",", 
     "1364.92395643246450936619069540574961114354`20.", ",", 
     "1363.18445414826422164186372391683417322844`20.", ",", 
     "1361.44463749863613738431840453648206161184`20.", ",", 
     "1359.70450847713136383221841980395890043752`20.", ",", 
     "1357.96406903860727196023697699192180655959`20.", ",", 
     "1356.22332109778957862335232386237348128858`20.", ",", 
     "1354.48226652785276580502950155839530498593`20.", ",", 
     "1352.74090715902170769735393472340443125318`20.", ",", 
     "1350.99924477719737959126335828106757144996`20.", ",", 
     "1349.25728112260951561688120888847457688312`20.", ",", 
     "1347.51501788849906500735808696106070227245`20.", ",", 
     "1345.77245671983326857782860083720816608416`20.", ",", 
     "1344.02959921205613838385855788849237322195`20.", ",", 
     "1342.28644690987707398004193184864718252168`20.", ",", 
     "1340.54300130610028832957904389893956406406`20.", ",", 
     "1338.79926384049764527330180137545553244858`20.", ",", 
     "1337.05523589872742866978005554864392456494`20.", ",", 
     "1335.31091881130147105018608339932050508386`20.", ",", 
     "1333.56631385260296714135228068238273217376`20.", ",", 
     "1331.82142223995718521193961850995446802122`20.", ",", 
     "1330.07624513275716726811644945109742273622`20.", ",", 
     "1328.33078363164637810768982862839169164667`20.", ",", 
     "1326.58503877776012363702571880054278414579`20.", ",", 
     "1324.8390115520274112232388841139288835026`20.", ",", 
     "1323.09270287453476980986026610362067330091`20.", ",", 
     "1321.34611360395338573356271257954614243083`20.", ",", 
     "1319.59924453703074235563798724659818792768`20.", ",", 
     "1317.85209640814777852022586740802614957124`20.", ",", 
     "1316.10466988894240326453358173962845862428`20.", ",", 
     "1314.35696558800002295900032131506657145752`20.", ",", 
     "1312.60898405061155299813952835974789881528`20.", ",", 
     "1310.86072575859920016619915022005511951131`20.", ",", 
     "1309.1121911302101147501190668135201918088`20.", ",", 
     "1307.36338052007782425717909501320423932372`20.", ",", 
     "1305.61429421925117410873762664312802640961`20.", ",", 
     "1303.86493245529031581147377264758061759142`20.", ",", 
     "1302.11529539242910072845494277408919000865`20.", ",", 
     "1300.36538313180305854072632985969079847979`20.", ",", 
     "1298.6151957117419646380967998078742558158`20.", ",", 
     "1296.86473310812583080722182551532071282518`20.", ",", 
     "1295.11399523480298946195366957520899315245`20.", ",", 
     "1293.36298194406878401019232002430808342448`20.", ",", 
     "1291.61169302720322745224647252736572013755`20.", ",", 
     "1289.86012821506584858695561367873974788691`20.", ",", 
     "1288.10828717874581083847689395229611456016`20.", ",", 
     "1286.35616953026526322631865154485153622329`20.", ",", 
     "1284.60377482333376684141513673281586727745`20.", ",", 
     "1282.85110255415153375697586611887599605539`20.", ",", 
     "1281.09815216225911892574537954455861707693`20.", ",", 
     "1279.34492303143111956139896024454387423522`20.", ",", 
     "1277.59141449061136097180399957751273300491`20.", ",", 
     "1275.83762581488698294110649423551872964005`20.", ",", 
     "1274.08355622649878661658437680932661868967`20.", ",", 
     "1272.32920489588515845184445673837326073078`20.", ",", 
     "1270.5745709427568550351604440866935671507`20.", ",", 
     "1268.81965343719991047564754582964603825498`20.", ",", 
     "1267.06445140080391625835349243350460939916`20.", ",", 
     "1265.30896380781292188569308791723698263308`20.", ",", 
     "1263.55318958629621291940654002689493903899`20.", ",", 
     "1261.79712761933624089939333981492014372668`20.", ",", 
     "1260.0407767462310066748049758070161282934`20.", ",", 
     "1258.28413576370823453061150812253386698809`20.", ",", 
     "1256.52720342714871868615874703210991472856`20.", ",", 
     "1254.76997845181627580674892666365725004022`20.", ",", 
     "1253.01245951409179660424037248526126756657`20.", ",", 
     "1251.25464525270895588522603695964629876058`20.", ",", 
     "1249.49653426998921299501104523565303104334`20.", ",", 
     "1247.73812513307381294855341070469792384181`20.", ",", 
     "1245.97941637515058207289805411484118633329`20.", ",", 
     "1244.22040649667340014163449328444178207356`20.", ",", 
     "1242.46109396657232319178916911758642898489`20.", ",", 
     "1240.70147722345242691137226406732140618734`20.", ",", 
     "1238.94155467677953911193816220648639061458`20.", ",", 
     "1237.18132470805113080506116026084746075598`20.", ",", 
     "1235.42078567195073824738115474370069853586`20.", ",", 
     "1233.65993589748439248417886530130378610047`20.", ",", 
     "1231.89877368909763790269575230032667572611`20.", ",", 
     "1230.13729732777182662032135601969055687774`20.", ",", 
     "1228.37550507209848071829516815455372197828`20.", ",", 
     "1226.61339515933061895161915408006147698278`20.", ",", 
     "1224.85096580641004820870207430687192937034`20.", ",", 
     "1223.08821521096972227458071025949803943202`20.", ",", 
     "1221.32514155231037101144395185160023941763`20.", ",", 
     "1219.56174299235070157962607239389850153928`20.", ",", 
     "1217.79801767655056947955044870455936746809`20.", ",", 
     "1216.03396373480661072706158025781941852675`20.", ",", 
     "1214.2695792823199171363270103264033682317`20.", ",", 
     "1212.50486242043542425927441324749452900371`20.", ",", 
     "1210.7398112374527658292606502796224638526`20.", ",", 
     "1208.97442380940842941729614837398835196376`20.", ",", 
     "1207.20869820082912529589301966441495252382`20.", ",", 
     "1205.4426324654563541080764058140381213027`20.", ",", 
     "1203.67622464694222877128220104505449472738`20.", ",", 
     "1201.90947277951667204502559393078259345188`20.", ",", 
     "1200.14237488862617331672689884174571844205`20.", ",", 
     "1198.37492899154434639214085744693859604303`20.", ",", 
     "1196.60713309795458441523026016225889228038`20.", ",", 
     "1194.83898521050515850506342591700880078655`20.", ",", 
     "1193.07048332533715331928809094146186877098`20.", ",", 
     "1191.30162543258567558535285211285520543376`20.", ",", 
     "1189.53240951685481074648486707104390602229`20.", ",", 
     "1187.76283355766683832687737188787347875181`20.", ",", 
     "1185.9928955298862485184697525511829930995`20.", ",", 
     "1184.22259340411913092918486972349972553255`20.", ",", 
     "1182.45192514708853151752206075687898082629`20.", ",", 
     "1180.68088872198639558670075000536769102207`20.", ",", 
     "1178.90948208880273344536129728948438956981`20.", ",", 
     "1177.13770320463266108883194222497079939418`20.", ",", 
     "1175.36555002396198114719902101400292392533`20.", ",", 
     "1173.59302049893197951926364219776042556028`20.", ",", 
     "1171.82011257958412070273569423198043141093`20.", ",", 
     "1170.04682421408532998004000400781317294627`20.", ",", 
     "1168.27315334893455346593563253792718276438`20.", ",", 
     "1166.49909792915128770777849776567573866201`20.", ",", 
     "1164.72465589844676919095121817091032010235`20.", ",", 
     "1162.94982519937851087863165414840429326562`20.", ",", 
     "1161.17460377348886794261788693284340560191`20.", ",", 
     "1159.39898956142830825385868754082692624925`20.", ",", 
     "1157.62298050306405512822574136233975619426`20.", ",", 
     "1155.84657453757476039215987140034766380183`20.", ",", 
     "1154.06976960353185516771293757655016583957`20.", ",", 
     "1152.29256363896821399680609925050018315513`20.", ",", 
     "1150.51495458143475514562800762654940024854`20.", ",", 
     "1148.73694036804558626296690669582699478033`20.", ",", 
     "1146.95851893551229011727446102314213698182`20.", ",", 
     "1145.17968822016793000803626628507902816357`20.", ",", 
     "1143.40044615798133873439610519010750466635`20.", ",", 
     "1141.62079068456223879989269767840481135017`20.", ",", 
     "1139.84071973515772492365823242998869736148`20.", ",", 
     "1138.06023124464062299763093086516952288767`20.", ",", 
     "1136.27932314749022245350212651219034207827`20.", ",", 
     "1134.49799337776586165467173800659646112452`20.", ",", 
     "1132.71623986907382847507972716999398535391`20.", ",", 
     "1130.9340605545280207313918960667665817009`20.", ",", 
     "1129.15145336670479365604674545895561078309`20.", ",", 
     "1127.36841623759240419005657913513516223278`20.", ",", 
     "1125.58494709853544458580902331850294133403`20.", ",", 
     "1123.80104388017464068684909448977607700978`20.", ",", 
     "1122.01670451238237333510382800351752017017`20.", ",", 
     "1120.23192692419426468371391539146422843463`20.", ",", 
     "1118.44670904373715479929667062443389844318`20.", ",", 
     "1116.66104879815377785124555800494011838533`20.", ",", 
     "1114.87494411352443143432898644689793255792`20.", ",", 
     "1113.0883929147859171778993143104742619266`20.", ",", 
     "1111.3013931256480157809022336605775423389`20.", ",", 
     "1109.51394266850774499412008804117478303081`20.", ",", 
     "1107.72603946436163486448209735777902694905`20.", ",", 
     "1105.93768143271624077304428567777460059754`20.", ",", 
     "1104.14886649149710144818019345470179862716`20.", ",", 
     "1102.35959255695633622616998438053218474259`20.", ",", 
     "1100.5698575435790633681661853227023190524`20.", ",", 
     "1098.77965936398880922893122293834972992911`20.", ",", 
     "1096.98899592885206651045948916317880479219`20.", ",", 
     "1095.19786514678214872262242892990109790079`20.", ",", 
     "1093.40626492424247731178590278148999934984`20.", ",", 
     "1091.61419316544942770402175888831377307625`20.", ",", 
     "1089.82164777227485073787272152307003009758`20.", ",", 
     "1088.02862664414837662727966332752443922347`20.", ",", 
     "1086.23512767795959969185168393162755435987`20.", ",", 
     "1084.44114876796023361183013377194634237143`20.", ",", 
     "1082.64668780566631890071864308021846513998`20.", ",", 
     "1080.8517426797605566307440829007895375402`20.", ",", 
     "1079.05631127599483518556341150900447631858`20.", ",", 
     "1077.26039147709300994087444213908411664013`20.", ",", 
     "1075.46398116265398927629322553495197252645`20.", ",", 
     "1073.66707820905517419010489913716253601586`20.", ",", 
     "1071.86968048935629301103760124213044473816`20.", ",", 
     "1070.07178587320366726655749899100142584098`20.", ",", 
     "1068.27339222673493966365440464808059902875`20.", ",", 
     "1066.47449741248429035386682740505546327606`20.", ",", 
     "1064.67509928928816317748842979992754002456`20.", ",", 
     "1062.87519571219151940058024186294938651696`20.", ",", 
     "1061.07478453235463256067466365386910670194`20.", ",", 
     "1059.27386359696043441104371580952407834139`20.", ",", 
     "1057.47243074912241858735324864758757891444`20.", ",", 
     "1055.67048382779310550280121763397028199839`20.", ",", 
     "1053.86802066767306909696252713518213836536`20.", ",", 
     "1052.06503909912052340823979053327511918506`20.", ",", 
     "1050.26153694806146449896077026869735918027`20.", ",", 
     "1048.45751203590036102491023189957052517241`20.", ",", 
     "1046.65296217943138469682484784065146495486`20.", ",", 
     "1044.84788519075017001976638580889193613608`20.", ",", 
     "1043.04227887716609100724950931939898723479`20.", ",", 
     "1041.23614104111504104075335574589457606869`20.", ",", 
     "1039.42946948007270067230572258775568577844`20.", ",", 
     "1037.62226198646827693901555019285011234556`20.", ",", 
     "1035.81451634759869666487477060894573890676`20.", ",", 
     "1034.00623034554323525830083537883760709721`20.", ",", 
     "1032.19740175707856166551021331994780855378`20.", ",", 
     "1030.3880283535941794019834118803938922635`20.", ",", 
     "1028.57810790100824294940471751441143794517`20.", ",", 
     "1026.76763815968372826625322413561385106964`20.", ",", 
     "1024.95661688434493570971909475121735261848`20.", ",", 
     "1023.14504182399430329816528004131310605099`20.", ",", 
     "1021.33291072182950795060248693143272648422`20.", ",", 
     "1019.52022131516083211654902234391034678871`20.", ",", 
     "1017.70697133532877305045920927574743487439`20.", ",", 
     "1015.89315850762187188416719148328435013157`20.", ",", 
     "1014.07878055119473960333405392871885059025`20.", ",", 
     "1012.26383517898625703480922998492513514945`20.", ",", 
     "1010.44832009763792599649555981837718357796`20.", ",", 
     "1008.63223300741234884537615970011969740301`20.", ",", 
     "1006.81557160211181377870904711943243575236`20.", ",", 
     "1004.99833356899696339415605812610319190066`20.", ",", 
     "1003.18051658870552419315657298302073302014`20.", ",", 
     "1001.36211833517107491478270606933254450106`20.", ",", 
     "999.54313647554183181143923527473475576198`20.", ",", 
     "997.72356867009942922012783807175674183976`20.", ",", 
     "995.90341257217767404081256554524047572838`20.", ",", 
     "994.08266582808125300412689773848049612011`20.", ",", 
     "992.261326077004371891862172862115324772`20.", ",", 
     "990.4393909509493061631592017187098045624`20.", ",", 
     "988.61685807464484273504418990672301006806`20.", ",", 
     "986.79372506546459296602139166418811906113`20.", ",", 
     "984.96998953334515719412482413154800141523`20.", ",", 
     "983.1456490807041214845505223235423152809`20.", ",", 
     "981.32070130235786754528618595519718360595`20.", ",", 
     "979.49514378543917707070246128159036989606`20.", ",", 
     "977.66897410931461207166685364135942059759`20.", ",", 
     "975.84218984550165304529918255577229302644`20.", ",", 
     "974.01478855758557712702598877529468422619`20.", ",", 
     "972.18676780113605865123079489862992202612`20.", ",", 
     "970.35812512362347482375263202640991901566`20.", ",", 
     "968.52885806433489947906026072813903174302`20.", ",", 
     "966.69896415428976815651007451490070533705`20.", ",", 
     "964.8684409161551979831446990743762490268`20.", ",", 
     "963.03728586416094609454116134999184176952`20.", ",", 
     "961.20549650401399055987282399207043053408`20.", ",", 
     "959.3730703328127180022699814707415875133`20.", ",", 
     "957.54000483896070232046857834288245350219`20.", ",", 
     "955.70629750208005912239548743165248702272`20.", ",", 
     "953.87194579292436067557051556709044935213`20.", ",", 
     "952.03694717329109636287186074784676016942`20.", ",", 
     "950.20129909593366380521509387310012178692`20.", ",", 
     "948.36499900447287597497410858699524294453`20.", ",", 
     "946.52804433330796977549693533622654727814`20.", ",", 
     "944.69043250752710170284051385527782790378`20.", ",", 
     "942.85216094281731633589368827772572697011`20.", ",", 
     "941.01322704537397352042776564427640257722`20.", ",", 
     "939.17362821180962022138092868210576922246`20.", ",", 
     "937.33336182906229311593711205508700790272`20.", ",", 
     "935.49242527430323808780832078740839017698`20.", ",", 
     "933.65081591484403286069248026111493898236`20.", ",", 
     "931.80853110804309907628942649816108596041`20.", ",", 
     "929.96556820121159017965833336491831592017`20.", ",", 
     "928.12192453151864152224183586976174274012`20.", ",", 
     "926.27759742589596913072318286450788226992`20.", ",", 
     "924.43258420094180361818601641850643999132`20.", ",", 
     "922.58688216282414573297877732313649110442`20.", ",", 
     "920.74048860718333005041683677893296602049`20.", ",", 
     "918.8934008190338833131562732819237228877`20.", ",", 
     "917.04561607266566391791517936774826119095`20.", ",", 
     "915.19713163154426902937237513984112443788`20.", ",", 
     "913.34794474821069577670888841737906290681`20.", ",", 
     "911.4980526641802429545417990956743254048`20.", ",", 
     "909.64745260984063960809739687386330320999`20.", ",", 
     "907.79614180434938683254188851451218119312`20.", ",", 
     "905.94411745553029905858983400863070795913`20.", ",", 
     "904.09137675976923103099521051422320317031`20.", ",", 
     "902.2379169019089766134445776688516999261`20.", ",", 
     "900.38373505514332547285790019162931166331`20.", ",", 
     "898.52882838091026360829606473502482355234`20.", ",", 
     "896.67319402878430359470485003672306425656`20.", ",", 
     "894.81682913636793030971662161956106405732`20.", ",", 
     "892.9597308291821478028003756453824136435`20.", ",", 
     "891.10189622055611285030833561455942622514`20.", ",", 
     "889.24332241151584061751669311602750489044`20.", ",", 
     "887.3840064906719677196959552822640105282`20.", ",", 
     "885.52394553410655783866240719644128213625`20.", ",", 
     "883.66313660525893490923906854222249627843`20.", ",", 
     "881.80157675481052874166780107363218608878`20.", ",", 
     "879.93926302056871779133240528044311834553`20.", ",", 
     "878.07619242734965362623705203352556184771`20.", ",", 
     "876.21236198686005147558959258711781035496`20.", ",", 
     "874.34776869757793106961252010517811344758`20.", ",", 
     "872.48240954463229180138598280018124293597`20.", ",", 
     "870.61628149968170605615071596817273324441`20.", ",", 
     "868.74938152079181436209065255595682567489`20.", ",", 
     "866.8817065523117058191950863335724243945`20.", ",", 
     "865.01325352474916705938168297600825815684`20.", ",", 
     "863.14401935464478278165081478205304661749`20.", ",", 
     "861.27400094444487069063853740577266944991`20.", ",", 
     "859.40319518237323344553347041859837829442`20.", ",", 
     "857.53159894230170999890894777937319987819`20.", ",", 
     "855.65920908361950847157683686089181564651`20.", ",", 
     "853.78602245110130247006794585642135069225`20.", ",", 
     "851.91203587477407250775438614515131219896`20.", ",", 
     "850.03724616978267393891402397462143064244`20.", ",", 
     "848.16165013625411255715267759909881936018`20.", ",", 
     "846.28524455916050874549653811695431397265`20.", ",", 
     "844.40802620818073079509014639652634413067`20.", ",", 
     "842.52999183756067773272312964516595776803`20.", ",", 
     "840.65113818597219171429509086261564390309`20.", ",", 
     "838.77146197637057975174022898275951723262`20.", ",", 
     "836.89095991585072424479355122716697718697`20.", ",", 
     "835.00962869550176148620550181676427804622`20.", ",", 
     "833.12746499026030699951256969762324965346`20.", ",", 
     "831.24446545876220625215360233647916316244`20.", ",", 
     "829.36062674319278896348537556741314474121`20.", ",", 
     "827.47594546913560489699128947356268915615`20.", ",", 
     "825.59041824541961868858333864148168651305`20.", ",", 
     "823.70404166396484091825383604920784255519`20.", ",", 
     "821.81681229962637228031848402985339198108`20.", ",", 
     "819.92872671003683734797964709164777508147`20.", ",", 
     "818.03978143544718406079607687463163987353`20.", ",", 
     "816.14997299856582468873546225258167988506`20.", ",", 
     "814.25929790439609364366620267247482253198`20.", ",", 
     "812.36775264007199711826645641241081358353`20.", ",", 
     "810.47533367469222913323803660495675661246`20.", ",", 
     "808.5820374591524281662508234074885211982`20.", ",", 
     "806.68786042597564812004515277036771313885`20.", ",", 
     "804.79279898914101696241460888247009028847`20.", ",", 
     "802.89684954391055593720355572306663807001`20.", ",", 
     "801.00000846665413180280057555567041341457`20.", ",", 
     "799.10227211467251410270285493731362106372`20.", ",", 
     "797.20363682601850901137363354658369989224`20.", ",", 
     "795.30409891931614082761521899557849335417`20.", ",", 
     "793.4036546935778517068277290930895356374`20.", ",", 
     "791.50230042801968973260634447907082656081`20.", ",", 
     "789.60003238187445492692874898531391788041`20.", ",", 
     "787.69684679420277228647440358662264366593`20.", ",", 
     "785.79273988370206041016650123095447621505`20.", ",", 
     "783.88770784851336374959725951742746440703`20.", ",", 
     "781.98174686602601596934206890003899270989`20.", ",", 
     "780.07485309268010134803527904227531243165`20.", ",", 
     "778.16702266376668058321017375595364498484`20.", ",", 
     "776.25825169322574678303062648538063617186`20.", ",", 
     "774.34853627344187683588710518256301464297`20.", ",", 
     "772.43787247503754274411237019597572232123`20.", ",", 
     "770.52625634666404689050164644036625275553`20.", ",", 
     "768.61368391479004457559931184640054765221`20.", ",", 
     "766.70015118348761651953186724800479170829`20.", ",", 
     "764.78565413421585336420913168643820885178`20.", ",", 
     "762.8701887256019135396573541745042474543`20.", ",", 
     "760.95375089321951517175523611811355999591`20.", ",", 
     "759.0363365493648220073733270972109449178`20.", ",", 
     "757.11794158282968261651585737425684908888`20.", ",", 
     "755.19856185867218139916885353851294445956`20.", ",", 
     "753.27819321798445917679619801653814019746`20.", ",", 
     "751.35683147765776038441249082559726259423`20.", ",", 
     "749.43447243014466309850370136291401934292`20.", ",", 
     "747.51111184321844733835808583107780100434`20.", ",", 
     "745.58674545972955626319366682043153618872`20.", ",", 
     "743.66136899735910405439590613814329227856`20.", ",", 
     "741.73497814836938342076908165313696249317`20.", ",", 
     "739.80756857935132479450381821497923709493`20.", ",", 
     "737.87913593096885839610483781802677191084`20.", ",", 
     "735.94967581770012943732760785240583759076`20.", ",", 
     "734.01918382757551580174679821687577028695`20.", ",", 
     "732.08765552191239659241580056192664217429`20.", ",", 
     "730.15508643504661896465294113505255714406`20.", ",", 
     "728.22147207406060966876933498833499072146`20.", ",", 
     "726.28680791850807671198299119091258237759`20.", ",", 
     "724.35108942013524551027520967228193946481`20.", ",", 
     "722.41431200259857283895344310364275075305`20.", ",", 
     "720.47647106117888080458754856879753330531`20.", ",", 
     "718.53756196249185195016408040268474640882`20.", ",", 
     "716.59758004419482546911821034472944676242`20.", ",", 
     "714.65652061468983334169852881586938431836`20.", ",", 
     "712.71437895282281401822059286037145664468`20.", ",", 
     "710.77115030757894005747491222306354931438`20.", ",", 
     "708.82682989777399488415778389468183599099`20.", ",", 
     "706.88141291174173255595141051512479795345`20.", ",", 
     "704.93489450701715312803351832301409574466`20.", ",", 
     "702.9872698100156248695639863448610329914`20.", ",", 
     "701.03853391570778322227113111898259762121`20.", ",", 
     "699.08868188729013499481336309702678792695`20.", ",", 
     "697.13770875585129485726801892855514751686`20.", ",", 
     "695.18560952003377973701749204775549155144`20.", ",", 
     "693.23237914569128521955581478651108228372`20.", ",", 
     "691.27801256554136652439143875823654294879`20.", ",", 
     "689.32250467881344505631039981443318559147`20.", ",", 
     "687.36585035089205992479508648211207198071`20.", ",", 
     "685.40804441295528217834366118587364858626`20.", ",", 
     "683.44908166160820781474843031678031167574`20.", ",", 
     "681.48895685851144390198007134739658789845`20.", ",", 
     "679.52766473000450037606675766036888984649`20.", ",", 
     "677.56519996672399827109606812058717027774`20.", ",", 
     "675.60155722321660328101014893845406586649`20.", ",", 
     "673.63673111754659165198049863588630409373`20.", ",", 
     "671.67071623089795345656882310630378875996`20.", ",", 
     "669.70350710717093630529541142646598524484`20.", ",", 
     "667.73509825257293050629566348775722735927`20.", ",", 
     "665.76548413520359458805503712638082149013`20.", ",", 
     "663.79465918463411795233456333827869975237`20.", ",", 
     "661.82261779148051522284891900334091790566`20.", ",", 
     "659.84935430697084459850484734772310712295`20.", ",", 
     "657.87486304250624020646805369604679906574`20.", ",", 
     "655.89913826921564607836895559323757953313`20.", ",", 
     "653.92217421750413694089616511172019345639`20.", ",", 
     "651.94396507659470851812069612216825603477`20.", ",", 
     "649.96450499406341748534602954406415249344`20.", ",", 
     "647.98378807536774859123270816553401819188`20.", ",", 
     "646.00180838336808377448324703491176111067`20.", ",", 
     "644.01855993784214534151257084006245345365`20.", ",", 
     "642.03403671499228244022388105614039790375`20.", ",", 
     "640.04823264694546716014455471468576611844`20.", ",", 
     "638.0611416212458636085653796541286251176`20.", ",", 
     "636.07275748033983025370975262582171879081`20.", ",", 
     "634.08307402105321268700189499465923091667`20.", ",", 
     "632.09208499406078073479018020394879197431`20.", ",", 
     "630.09978410334766054291686140467916936854`20.", ",", 
     "628.10616500566260886272731975855190302249`20.", ",", 
     "626.1112213099629732818106166994476296273`20.", ",", 
     "624.11494657685117856419716435990097587409`20.", ",", 
     "622.11733431800257559005210300557931945949`20.", ",", 
     "620.11837799558448561113905160913900384175`20.", ",", 
     "618.11807102166626866243021026404182573557`20.", ",", 
     "616.11640675762024098904067547850393826381`20.", ",", 
     "614.11337851351326225789187631102108937765`20.", ",", 
     "612.10897954748880912177078675952999732623`20.", ",", 
     "610.10320306513934738623798970628206988643`20.", ",", 
     "608.09604221886881059351446799175517757484`20.", ",", 
     "606.08749010724498827828071891216984931772`20.", ",", 
     "604.07753977434162246435468423102861671635`20.", ",", 
     "602.06618420907000615443968641599753223797`20.", ",", 
     "600.05341634449987261336748812408427750875`20.", ",", 
     "598.03922905716935915417114607034723185855`20.", ",", 
     "596.0236151663838239014168080811347983794`20.", ",", 
     "594.00656743350328862284884492333058944985`20.", ",", 
     "591.98807856121827518373447060652221895513`20.", ",", 
     "589.96814119281379748333102266288009074278`20.", ",", 
     "587.94674791142126487445582377662912327839`20.", ",", 
     "585.92389123925804703983767499176782726555`20.", ",", 
     "583.89956363685444409719344332881240542299`20.", ",", 
     "581.87375750226779932301779241291226508494`20.", ",", 
     "579.84646517028348531689708620688207714929`20.", ",", 
     "577.81767891160248766753237994958222421378`20.", ",", 
     "575.78739093201530322211852376163134951427`20.", ",", 
     "573.75559337156186289556898137472730329592`20.", ",", 
     "571.72227830367718157833579554429647124617`20.", ",", 
     "569.68743773432243010402169825200369634692`20.", ",", 
     "567.65106360110111641310949378384817943561`20.", ",", 
     "565.61314777236005498914580961892453786379`20.", ",", 
     "563.57368204627479534051337885974771794576`20.", ",", 
     "561.53265814991917174609439782753847892944`20.", ",", 
     "559.49006773831862766792467654706791013088`20.", ",", 
     "557.44590239348695914927870003363947426339`20.", ",", 
     "555.40015362344611215306571054825829642767`20.", ",", 
     "553.35281286122865914313906490079128579784`20.", ",", 
     "551.30387146386257025991766492783698140503`20.", ",", 
     "549.25332071133788418097383116327348313323`20.", ",", 
     "547.20115180555487317591543886249147826719`20.", ",", 
     "545.14735586925328595149548209602042221115`20.", ",", 
     "543.09192394492224062546867400520412179218`20.", ",", 
     "541.03484699369032855384562113349992355294`20.", ",", 
     "538.97611589419547775292608028400479014986`20.", ",", 
     "536.91572144143411229134839726990591701513`20.", ",", 
     "534.85365434558913126434174473806007755493`20.", ",", 
     "532.78990523083621778779972632505427970566`20.", ",", 
     "530.72446463412797484848917644642479783397`20.", ",", 
     "528.65732300395537080281161986389428063754`20.", ",", 
     "526.58847069908596281352646644433873252095`20.", ",", 
     "524.51789798727835153450758590964288042221`20.", ",", 
     "522.44559504397230487999201744825492298713`20.", ",", 
     "520.37155195095397272818092217324380832486`20.", ",", 
     "518.29575869499559788995802265434908230708`20.", ",", 
     "516.21820516646911160155088484865816031987`20.", ",", 
     "514.13888115793298415394812743310807975008`20.", ",", 
     "512.05777636269168302965275801589637364602`20.", ",", 
     "509.97488037332707205578464057654922926405`20.", ",", 
     "507.89018268020106557751747064559271457885`20.", ",", 
     "505.80367266992883148215952931702997926833`20.", ",", 
     "503.71533962382181603556077098750110148301`20.", ",", 
     "501.62517271629984190148025252330341065079`20.", ",", 
     "499.53316101327150837237922731061809483058`20.", ",", 
     "497.43929347048209971682983532791560102079`20.", ",", 
     "495.34355893182818361300783467234073121768`20.", ",", 
     "493.24594612763805685680991626643326246539`20.", ",", 
     "491.14644367291716987274864320343948707078`20.", ",", 
     "489.04504006555763498010898645514665565168`20.", ",", 
     "486.94172368451089583842881704280802388866`20.", ",", 
     "484.83648278792260697598684400373834091253`20.", ",", 
     "482.72930551122874275161734881466791055689`20.", ",", 
     "480.62017986521192447087568095391697968456`20.", ",", 
     "478.5090937340169226273878145167924975652`20.", ",", 
     "476.39603487312425832204333275463617189021`20.", ",", 
     "474.28099090728079377721009118073479475801`20.", ",", 
     "472.16394932838616645868204613857037608056`20.", ",", 
     "470.04489749333388459046093865119999562301`20.", ",", 
     "467.92382262180586373994630027554337218142`20.", ",", 
     "465.80071179401914460414174685215713844858`20.", ",", 
     "463.67555194842349107865079794822684456152`20.", ",", 
     "461.54832987934852507504415820615028077203`20.", ",", 
     "459.4190322345990102999149496916437053529`20.", ",", 
     "457.28764551299685124847619763292438563785`20.", ",", 
     "455.15415606186832592117669458932437348032`20.", ",", 
     "453.01855007447502116400602474674700328587`20.", ",", 
     "450.88081358738688797840388260987338221692`20.", ",", 
     "448.740932477795780557234160432002170651`20.", ",", 
     "446.59889246076778708689793193507257310689`20.", ",", 
     "444.45467908643260241539960609699435531361`20.", ",", 
     "442.30827773710813242007947016449745736744`20.", ",", 
     "440.15967362435845720957427394799100884632`20.", ",", 
     "438.00885178598321504949590198488736799464`20.", ",", 
     "435.85579708293640099164646849762475695862`20.", ",", 
     "433.70049419617250348720589155377128852756`20.", ",", 
     "431.54292762341782864374992225652206207868`20.", ",", 
     "429.38308167586478510526966424910772416812`20.", ",", 
     "427.22094047478682264783134824847271466812`20.", ",", 
     "425.05648794807163433654552339029097155083`20.", ",", 
     "422.88970782667014532063678467860353021896`20.", ",", 
     "420.72058364095872087997079704855742955779`20.", ",", 
     "418.54909871701193199988482896696170968215`20.", ",", 
     "416.375236172783118347600810186272404256`20.", ",", 
     "414.19897891418988585668107342176617723542`20.", ",", 
     "412.02030963110156897554001568951412777063`20.", ",", 
     "409.83921079322557578938469082980140764749`20.", ",", 
     "407.65566464588941742649979347212289895688`20.", ",", 
     "405.46965320571510118673087712041023229592`20.", ",", 
     "403.28115825618243937430000512548789206258`20.", ",", 
     "401.09016134307769266341932676712175118017`20.", ",", 
     "398.89664376982382757724570006028785234888`20.", ",", 
     "396.70058659268852215540630249131874667221`20.", ",", 
     "394.50197061586590156028304935321460174536`20.", ",", 
     "392.30077638642782622295345022964136162213`20.", ",", 
     "390.09698418914038825548281265566732507086`20.", ",", 
     "387.89057404114109765804777677645655800363`20.", ",", 
     "385.68152568647205670356361520595402540914`20.", ",", 
     "383.46981859046423015830368596119495883582`20.", ",", 
     "381.25543193396771748848250874315393935278`20.", ",", 
     "379.03834460742272451737638669922202908485`20.", ",", 
     "376.81853520476570943062377763931686976882`20.", ",", 
     "374.59598201716495026575357787351984532896`20.", ",", 
     "372.37066302657953360677591365680902833434`20.", ",", 
     "370.14255589913551721360843386880159377184`20.", ",", 
     "367.91163797831274113201926742789344602841`20.", ",", 
     "365.67788627793549785062166508766678676213`20.", ",", 
     "363.4412774749599528537362052895365836384`20.", ",", 
     "361.20178790205093373104759986227599121376`20.", ",", 
     "358.95939353994032641013383832162772210672`20.", ",", 
     "356.71407000955905480940508806046701025479`20.", ",", 
     "354.46579256393414170721170995428905849036`20.", ",", 
     "352.21453607984214436971627503246201289557`20.", ",", 
     "349.96027504920960186332288460464735830314`20.", ",", 
     "347.7029835702510899348898264823672681281`20.", ",", 
     "345.44263533833447925732857130169175739087`20.", ",", 
     "343.17920363656334411727797027320719912431`20.", ",", 
     "340.91266132606477792533653428183955387638`20.", ",", 
     "338.64298083597210675316758990728011382135`20.", ",", 
     "336.37013415308888189205124174427717529669`20.", ",", 
     "334.09409281122369236759259118230730010755`20.", ",", 
     "331.81482788017928245750017409599609783708`20.", ",", 
     "329.53230995438673343598178956453887724263`20.", ",", 
     "327.24650914116328597871397558019704731579`20.", ",", 
     "324.95739504858833391114199979506025839203`20.", ",", 
     "322.66493677296721460774277327730946069614`20.", ",", 
     "320.36910288588651132121968610813345683425`20.", ",", 
     "318.06986142081335975609017458664535312292`20.", ",", 
     "315.76717985926292619476877786283907955319`20.", ",", 
     "313.46102511645283402396114772745715812332`20.", ",", 
     "311.15136352651231397093703197231580938261`20.", ",", 
     "308.83816082709760473966381651476007313877`20.", ",", 
     "306.52138214357210717135418251975857658093`20.", ",", 
     "304.20099197246803504283794950212229223553`20.", ",", 
     "301.87695416457387250775122444435441442022`20.", ",", 
     "299.54923190709431803768835420243609657215`20.", ",", 
     "297.21778770560321791372265262858387312136`20.", ",", 
     "294.88258336469673316035252169667606560873`20.", ",", 
     "292.54357996882189581233453016253534234133`20.", ",", 
     "290.20073786111537998327260880894699957461`20.", ",", 
     "287.85401662322928638838288800271072425529`20.", ",", 
     "285.5033750518587286603649520912957508766`20.", ",", 
     "283.14877113791368945370719518829434294222`20.", ",", 
     "280.79016203988462731120144717586511141618`20.", ",", 
     "278.42750406315917957757603157288922049789`20.", ",", 
     "276.06075262870862214837784184231359588752`20.", ",", 
     "273.68986225422218779978192127567918925844`20.", ",", 
     "271.31478651534219385722642680395254222823`20.", ",", 
     "268.93547803196296941145937363435692778523`20.", ",", 
     "266.55188841688531380593456202113607478173`20.", ",", 
     "264.16396827379849659516751201970676627251`20.", ",", 
     "261.77166712381843764798145635499351450464`20.", ",", 
     "259.37493342762096019719147407365520550412`20.", ",", 
     "256.97371447214011787041219644192237209914`20.", ",", 
     "254.56795644038378857182121980512743314105`20.", ",", 
     "252.15760422545477526473330228745006860923`20.", ",", 
     "249.74260159197658070004442944892795282047`20.", ",", 
     "247.32289085690177120750233698415881105049`20.", ",", 
     "244.89841322377131767027607060302768873248`20.", ",", 
     "242.46910821939457844368051979122224640046`20.", ",", 
     "240.03491434980290287425438648070144519316`20.", ",", 
     "237.59576809095915496206102232319463194844`20.", ",", 
     "235.15160513692534986409306761302926294858`20.", ",", 
     "232.70235857995954798308400350138776484967`20.", ",", 
     "230.24796123844028350991135924459406945171`20.", ",", 
     "227.78834237259028661187157414358225280749`20.", ",", 
     "225.32343196361136918455467777092888404315`20.", ",", 
     "222.8531548020822550497886073480276496345`20.", ",", 
     "220.37743826315178228434410992840289801236`20.", ",", 
     "217.89620171545073794751154617951853675659`20.", ",", 
     "215.40937050821539625835138685506398031784`20.", ",", 
     "212.916857109089060862818054659110201151`20.", ",", 
     "210.41858603767986385212825906915272835219`20.", ",", 
     "207.9144604987711191426314458275868118663`20.", ",", 
     "205.40440644567160023345315894488452221639`20.", ",", 
     "202.88831398224609730418990617013935879959`20.", ",", 
     "200.36611457850691162474538254385563318875`20.", ",", 
     "197.83767894300531187764654968850194398136`20.", ",", 
     "195.30295120776148696505025695558727127165`20.", ",", 
     "192.76177233118156319767062425953906886815`20.", ",", 
     "190.21411134440470207317998191188383256649`20.", ",", 
     "187.65976244084424545959200057764509497365`20.", ",", 
     "185.09874015836406295534721499943795406564`20.", ",", 
     "182.53076408078475441466985847791898997674`20.", ",", 
     "179.95592846919329752447977880907439220689`20.", ",", 
     "177.37383300645954795317740367206740684777`20.", ",", 
     "174.78470777751222699328297072659440137817`20.", ",", 
     "172.18795944185023198752735543763212863539`20.", ",", 
     "169.58404481441575298837803528319321370732`20.", ",", 
     "166.97206046894998421464843676939092947903`20.", ",", 
     "164.35283559778969260652721903771780544424`20.", ",", 
     "161.72497099635582466609467911778906352276`20.", ",", 
     "159.08989900051232893052549502240004924368`20.", ",", 
     "156.44543293377904511044203403661550684507`20.", ",", 
     "153.79396985462516526593719249726118473941`20.", ",", 
     "151.13208209296910168366068771009469357945`20.", ",", 
     "148.46369163392333991161450397625873653129`20.", ",", 
     "145.78343220476210622816892885687790510912`20.", ",", 
     "143.09760876670984967019546806442162287969`20.", ",", 
     "140.3978552846181808583204639293528508277`20.", ",", 
     "137.69415861480481300460190739227780585111`20.", ",", 
     "134.97355739377622465915586383386365805622`20.", ",", 
     "132.25166308652965293336001446889964903888`20.", ",", 
     "129.50854862875705689401932933498652411158`20.", ",", 
     "126.76831968468851292253967639986856066385`20.", ",", 
     "124.00060592489511872545499472635904882276`20.", ",", 
     "121.24219145481355600723421239329219187347`20.", ",", 
     "118.44722696919707397055778435006281215177`20.", ",", 
     "115.67119469103361348755334617109647707464`20.", ",", 
     "112.84557315711044748557371527298738057378`20.", ",", 
     "110.0530822381286510073311443218033172838`20.", ",", 
     "107.19239903835284370177075246681655660431`20.", ",", 
     "104.38541863323189583395266055705996691883`20.", ",", 
     "101.483964965925251794856546168673610236`20.", ",", 
     "98.66554100251522495102705805527657297781`20.", ",", 
     "95.7159284879343532506728223864047965033`20.", ",", 
     "92.8904964982917440580201855284772312736`20.", ",", 
     "89.88320805984141096998830194535322447649`20.", ",", 
     "87.05694327944009360555970098281918285205`20.", ",", 
     "83.97980932920735262155754850572007502976`20.", ",", 
     "81.1609981097789586351847651112700453536`20.", ",", 
     "77.99859857700147786848219213943922302444`20.", ",", 
     "75.19801044019067104904056927858320998581`20.", ",", 
     "71.930998149113428787889283790150398007`20.", ",", 
     "69.16224113115691242712663215947960087315`20.", ",", 
     "65.76656157706440482223039025356865262752`20.", ",", 
     "63.04642318348171881828544632350204864657`20.", ",", 
     "59.49235481866828529841804469739326708057`20.", ",", 
     "56.84117774459522201669589154941110021565`20.", ",", 
     "53.09200972912564907672296030903008322075`20.", ",", 
     "50.53424031449418162021265516944723300253`20.", ",", 
     "46.54419057453375856620456678161567865093`20.", ",", 
     "44.10939793077697670403350818623262317125`20.", ",", 
     "39.81992822973490434214829128387814889337`20.", ",", 
     "37.54490675573525890194924261583290920796`20.", ",", 
     "32.87753724949052630659269662118730131152`20.", ",", 
     "30.81085525106772533672560132434387462692`20.", ",", 
     "25.65156724481855300618993681670909524422`20.", ",", 
     "23.86417587765481876896346676120164231107`20.", ",", 
     "18.023290466471560252303674828128326441`20.", ",", 
     "16.63772718860587230922249302056606775384`20.", ",", 
     "9.70406052783923433184124970041447195306`20.", ",", 
     "9.01091334727928902242401757895629538498`20.", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", 
     "0.6931471805599453094172321214581765680747545421319511512698`20."}], 
    "}"}]}],
  SequenceForm[
  "s=", {0.6931471805599453094172321214581765680747545421319511512698`20., 
    DirectedInfinity[-1], 9.01091334727928902242401757895629538498`20., 
    9.70406052783923433184124970041447195306`20., 
    16.63772718860587230922249302056606775384`20., 
    18.023290466471560252303674828128326441`20., 
    23.86417587765481876896346676120164231107`20., 
    25.65156724481855300618993681670909524422`20., 
    30.81085525106772533672560132434387462692`20., 
    32.87753724949052630659269662118730131152`20., 
    37.54490675573525890194924261583290920796`20., 
    39.81992822973490434214829128387814889337`20., 
    44.10939793077697670403350818623262317125`20., 
    46.54419057453375856620456678161567865093`20., 
    50.53424031449418162021265516944723300253`20., 
    53.09200972912564907672296030903008322075`20., 
    56.84117774459522201669589154941110021565`20., 
    59.49235481866828529841804469739326708057`20., 
    63.04642318348171881828544632350204864657`20., 
    65.76656157706440482223039025356865262752`20., 
    69.16224113115691242712663215947960087315`20., 
    71.930998149113428787889283790150398007`20., 
    75.19801044019067104904056927858320998581`20., 
    77.99859857700147786848219213943922302444`20., 
    81.1609981097789586351847651112700453536`20., 
    83.97980932920735262155754850572007502976`20., 
    87.05694327944009360555970098281918285205`20., 
    89.88320805984141096998830194535322447649`20., 
    92.8904964982917440580201855284772312736`20., 
    95.7159284879343532506728223864047965033`20., 
    98.66554100251522495102705805527657297781`20., 
    101.483964965925251794856546168673610236`20., 
    104.38541863323189583395266055705996691883`20., 
    107.19239903835284370177075246681655660431`20., 
    110.0530822381286510073311443218033172838`20., 
    112.84557315711044748557371527298738057378`20., 
    115.67119469103361348755334617109647707464`20., 
    118.44722696919707397055778435006281215177`20., 
    121.24219145481355600723421239329219187347`20., 
    124.00060592489511872545499472635904882276`20., 
    126.76831968468851292253967639986856066385`20., 
    129.50854862875705689401932933498652411158`20., 
    132.25166308652965293336001446889964903888`20., 
    134.97355739377622465915586383386365805622`20., 
    137.69415861480481300460190739227780585111`20., 
    140.3978552846181808583204639293528508277`20., 
    143.09760876670984967019546806442162287969`20., 
    145.78343220476210622816892885687790510912`20., 
    148.46369163392333991161450397625873653129`20., 
    151.13208209296910168366068771009469357945`20., 
    153.79396985462516526593719249726118473941`20., 
    156.44543293377904511044203403661550684507`20., 
    159.08989900051232893052549502240004924368`20., 
    161.72497099635582466609467911778906352276`20., 
    164.35283559778969260652721903771780544424`20., 
    166.97206046894998421464843676939092947903`20., 
    169.58404481441575298837803528319321370732`20., 
    172.18795944185023198752735543763212863539`20., 
    174.78470777751222699328297072659440137817`20., 
    177.37383300645954795317740367206740684777`20., 
    179.95592846919329752447977880907439220689`20., 
    182.53076408078475441466985847791898997674`20., 
    185.09874015836406295534721499943795406564`20., 
    187.65976244084424545959200057764509497365`20., 
    190.21411134440470207317998191188383256649`20., 
    192.76177233118156319767062425953906886815`20., 
    195.30295120776148696505025695558727127165`20., 
    197.83767894300531187764654968850194398136`20., 
    200.36611457850691162474538254385563318875`20., 
    202.88831398224609730418990617013935879959`20., 
    205.40440644567160023345315894488452221639`20., 
    207.9144604987711191426314458275868118663`20., 
    210.41858603767986385212825906915272835219`20., 
    212.916857109089060862818054659110201151`20., 
    215.40937050821539625835138685506398031784`20., 
    217.89620171545073794751154617951853675659`20., 
    220.37743826315178228434410992840289801236`20., 
    222.8531548020822550497886073480276496345`20., 
    225.32343196361136918455467777092888404315`20., 
    227.78834237259028661187157414358225280749`20., 
    230.24796123844028350991135924459406945171`20., 
    232.70235857995954798308400350138776484967`20., 
    235.15160513692534986409306761302926294858`20., 
    237.59576809095915496206102232319463194844`20., 
    240.03491434980290287425438648070144519316`20., 
    242.46910821939457844368051979122224640046`20., 
    244.89841322377131767027607060302768873248`20., 
    247.32289085690177120750233698415881105049`20., 
    249.74260159197658070004442944892795282047`20., 
    252.15760422545477526473330228745006860923`20., 
    254.56795644038378857182121980512743314105`20., 
    256.97371447214011787041219644192237209914`20., 
    259.37493342762096019719147407365520550412`20., 
    261.77166712381843764798145635499351450464`20., 
    264.16396827379849659516751201970676627251`20., 
    266.55188841688531380593456202113607478173`20., 
    268.93547803196296941145937363435692778523`20., 
    271.31478651534219385722642680395254222823`20., 
    273.68986225422218779978192127567918925844`20., 
    276.06075262870862214837784184231359588752`20., 
    278.42750406315917957757603157288922049789`20., 
    280.79016203988462731120144717586511141618`20., 
    283.14877113791368945370719518829434294222`20., 
    285.5033750518587286603649520912957508766`20., 
    287.85401662322928638838288800271072425529`20., 
    290.20073786111537998327260880894699957461`20., 
    292.54357996882189581233453016253534234133`20., 
    294.88258336469673316035252169667606560873`20., 
    297.21778770560321791372265262858387312136`20., 
    299.54923190709431803768835420243609657215`20., 
    301.87695416457387250775122444435441442022`20., 
    304.20099197246803504283794950212229223553`20., 
    306.52138214357210717135418251975857658093`20., 
    308.83816082709760473966381651476007313877`20., 
    311.15136352651231397093703197231580938261`20., 
    313.46102511645283402396114772745715812332`20., 
    315.76717985926292619476877786283907955319`20., 
    318.06986142081335975609017458664535312292`20., 
    320.36910288588651132121968610813345683425`20., 
    322.66493677296721460774277327730946069614`20., 
    324.95739504858833391114199979506025839203`20., 
    327.24650914116328597871397558019704731579`20., 
    329.53230995438673343598178956453887724263`20., 
    331.81482788017928245750017409599609783708`20., 
    334.09409281122369236759259118230730010755`20., 
    336.37013415308888189205124174427717529669`20., 
    338.64298083597210675316758990728011382135`20., 
    340.91266132606477792533653428183955387638`20., 
    343.17920363656334411727797027320719912431`20., 
    345.44263533833447925732857130169175739087`20., 
    347.7029835702510899348898264823672681281`20., 
    349.96027504920960186332288460464735830314`20., 
    352.21453607984214436971627503246201289557`20., 
    354.46579256393414170721170995428905849036`20., 
    356.71407000955905480940508806046701025479`20., 
    358.95939353994032641013383832162772210672`20., 
    361.20178790205093373104759986227599121376`20., 
    363.4412774749599528537362052895365836384`20., 
    365.67788627793549785062166508766678676213`20., 
    367.91163797831274113201926742789344602841`20., 
    370.14255589913551721360843386880159377184`20., 
    372.37066302657953360677591365680902833434`20., 
    374.59598201716495026575357787351984532896`20., 
    376.81853520476570943062377763931686976882`20., 
    379.03834460742272451737638669922202908485`20., 
    381.25543193396771748848250874315393935278`20., 
    383.46981859046423015830368596119495883582`20., 
    385.68152568647205670356361520595402540914`20., 
    387.89057404114109765804777677645655800363`20., 
    390.09698418914038825548281265566732507086`20., 
    392.30077638642782622295345022964136162213`20., 
    394.50197061586590156028304935321460174536`20., 
    396.70058659268852215540630249131874667221`20., 
    398.89664376982382757724570006028785234888`20., 
    401.09016134307769266341932676712175118017`20., 
    403.28115825618243937430000512548789206258`20., 
    405.46965320571510118673087712041023229592`20., 
    407.65566464588941742649979347212289895688`20., 
    409.83921079322557578938469082980140764749`20., 
    412.02030963110156897554001568951412777063`20., 
    414.19897891418988585668107342176617723542`20., 
    416.375236172783118347600810186272404256`20., 
    418.54909871701193199988482896696170968215`20., 
    420.72058364095872087997079704855742955779`20., 
    422.88970782667014532063678467860353021896`20., 
    425.05648794807163433654552339029097155083`20., 
    427.22094047478682264783134824847271466812`20., 
    429.38308167586478510526966424910772416812`20., 
    431.54292762341782864374992225652206207868`20., 
    433.70049419617250348720589155377128852756`20., 
    435.85579708293640099164646849762475695862`20., 
    438.00885178598321504949590198488736799464`20., 
    440.15967362435845720957427394799100884632`20., 
    442.30827773710813242007947016449745736744`20., 
    444.45467908643260241539960609699435531361`20., 
    446.59889246076778708689793193507257310689`20., 
    448.740932477795780557234160432002170651`20., 
    450.88081358738688797840388260987338221692`20., 
    453.01855007447502116400602474674700328587`20., 
    455.15415606186832592117669458932437348032`20., 
    457.28764551299685124847619763292438563785`20., 
    459.4190322345990102999149496916437053529`20., 
    461.54832987934852507504415820615028077203`20., 
    463.67555194842349107865079794822684456152`20., 
    465.80071179401914460414174685215713844858`20., 
    467.92382262180586373994630027554337218142`20., 
    470.04489749333388459046093865119999562301`20., 
    472.16394932838616645868204613857037608056`20., 
    474.28099090728079377721009118073479475801`20., 
    476.39603487312425832204333275463617189021`20., 
    478.5090937340169226273878145167924975652`20., 
    480.62017986521192447087568095391697968456`20., 
    482.72930551122874275161734881466791055689`20., 
    484.83648278792260697598684400373834091253`20., 
    486.94172368451089583842881704280802388866`20., 
    489.04504006555763498010898645514665565168`20., 
    491.14644367291716987274864320343948707078`20., 
    493.24594612763805685680991626643326246539`20., 
    495.34355893182818361300783467234073121768`20., 
    497.43929347048209971682983532791560102079`20., 
    499.53316101327150837237922731061809483058`20., 
    501.62517271629984190148025252330341065079`20., 
    503.71533962382181603556077098750110148301`20., 
    505.80367266992883148215952931702997926833`20., 
    507.89018268020106557751747064559271457885`20., 
    509.97488037332707205578464057654922926405`20., 
    512.05777636269168302965275801589637364602`20., 
    514.13888115793298415394812743310807975008`20., 
    516.21820516646911160155088484865816031987`20., 
    518.29575869499559788995802265434908230708`20., 
    520.37155195095397272818092217324380832486`20., 
    522.44559504397230487999201744825492298713`20., 
    524.51789798727835153450758590964288042221`20., 
    526.58847069908596281352646644433873252095`20., 
    528.65732300395537080281161986389428063754`20., 
    530.72446463412797484848917644642479783397`20., 
    532.78990523083621778779972632505427970566`20., 
    534.85365434558913126434174473806007755493`20., 
    536.91572144143411229134839726990591701513`20., 
    538.97611589419547775292608028400479014986`20., 
    541.03484699369032855384562113349992355294`20., 
    543.09192394492224062546867400520412179218`20., 
    545.14735586925328595149548209602042221115`20., 
    547.20115180555487317591543886249147826719`20., 
    549.25332071133788418097383116327348313323`20., 
    551.30387146386257025991766492783698140503`20., 
    553.35281286122865914313906490079128579784`20., 
    555.40015362344611215306571054825829642767`20., 
    557.44590239348695914927870003363947426339`20., 
    559.49006773831862766792467654706791013088`20., 
    561.53265814991917174609439782753847892944`20., 
    563.57368204627479534051337885974771794576`20., 
    565.61314777236005498914580961892453786379`20., 
    567.65106360110111641310949378384817943561`20., 
    569.68743773432243010402169825200369634692`20., 
    571.72227830367718157833579554429647124617`20., 
    573.75559337156186289556898137472730329592`20., 
    575.78739093201530322211852376163134951427`20., 
    577.81767891160248766753237994958222421378`20., 
    579.84646517028348531689708620688207714929`20., 
    581.87375750226779932301779241291226508494`20., 
    583.89956363685444409719344332881240542299`20., 
    585.92389123925804703983767499176782726555`20., 
    587.94674791142126487445582377662912327839`20., 
    589.96814119281379748333102266288009074278`20., 
    591.98807856121827518373447060652221895513`20., 
    594.00656743350328862284884492333058944985`20., 
    596.0236151663838239014168080811347983794`20., 
    598.03922905716935915417114607034723185855`20., 
    600.05341634449987261336748812408427750875`20., 
    602.06618420907000615443968641599753223797`20., 
    604.07753977434162246435468423102861671635`20., 
    606.08749010724498827828071891216984931772`20., 
    608.09604221886881059351446799175517757484`20., 
    610.10320306513934738623798970628206988643`20., 
    612.10897954748880912177078675952999732623`20., 
    614.11337851351326225789187631102108937765`20., 
    616.11640675762024098904067547850393826381`20., 
    618.11807102166626866243021026404182573557`20., 
    620.11837799558448561113905160913900384175`20., 
    622.11733431800257559005210300557931945949`20., 
    624.11494657685117856419716435990097587409`20., 
    626.1112213099629732818106166994476296273`20., 
    628.10616500566260886272731975855190302249`20., 
    630.09978410334766054291686140467916936854`20., 
    632.09208499406078073479018020394879197431`20., 
    634.08307402105321268700189499465923091667`20., 
    636.07275748033983025370975262582171879081`20., 
    638.0611416212458636085653796541286251176`20., 
    640.04823264694546716014455471468576611844`20., 
    642.03403671499228244022388105614039790375`20., 
    644.01855993784214534151257084006245345365`20., 
    646.00180838336808377448324703491176111067`20., 
    647.98378807536774859123270816553401819188`20., 
    649.96450499406341748534602954406415249344`20., 
    651.94396507659470851812069612216825603477`20., 
    653.92217421750413694089616511172019345639`20., 
    655.89913826921564607836895559323757953313`20., 
    657.87486304250624020646805369604679906574`20., 
    659.84935430697084459850484734772310712295`20., 
    661.82261779148051522284891900334091790566`20., 
    663.79465918463411795233456333827869975237`20., 
    665.76548413520359458805503712638082149013`20., 
    667.73509825257293050629566348775722735927`20., 
    669.70350710717093630529541142646598524484`20., 
    671.67071623089795345656882310630378875996`20., 
    673.63673111754659165198049863588630409373`20., 
    675.60155722321660328101014893845406586649`20., 
    677.56519996672399827109606812058717027774`20., 
    679.52766473000450037606675766036888984649`20., 
    681.48895685851144390198007134739658789845`20., 
    683.44908166160820781474843031678031167574`20., 
    685.40804441295528217834366118587364858626`20., 
    687.36585035089205992479508648211207198071`20., 
    689.32250467881344505631039981443318559147`20., 
    691.27801256554136652439143875823654294879`20., 
    693.23237914569128521955581478651108228372`20., 
    695.18560952003377973701749204775549155144`20., 
    697.13770875585129485726801892855514751686`20., 
    699.08868188729013499481336309702678792695`20., 
    701.03853391570778322227113111898259762121`20., 
    702.9872698100156248695639863448610329914`20., 
    704.93489450701715312803351832301409574466`20., 
    706.88141291174173255595141051512479795345`20., 
    708.82682989777399488415778389468183599099`20., 
    710.77115030757894005747491222306354931438`20., 
    712.71437895282281401822059286037145664468`20., 
    714.65652061468983334169852881586938431836`20., 
    716.59758004419482546911821034472944676242`20., 
    718.53756196249185195016408040268474640882`20., 
    720.47647106117888080458754856879753330531`20., 
    722.41431200259857283895344310364275075305`20., 
    724.35108942013524551027520967228193946481`20., 
    726.28680791850807671198299119091258237759`20., 
    728.22147207406060966876933498833499072146`20., 
    730.15508643504661896465294113505255714406`20., 
    732.08765552191239659241580056192664217429`20., 
    734.01918382757551580174679821687577028695`20., 
    735.94967581770012943732760785240583759076`20., 
    737.87913593096885839610483781802677191084`20., 
    739.80756857935132479450381821497923709493`20., 
    741.73497814836938342076908165313696249317`20., 
    743.66136899735910405439590613814329227856`20., 
    745.58674545972955626319366682043153618872`20., 
    747.51111184321844733835808583107780100434`20., 
    749.43447243014466309850370136291401934292`20., 
    751.35683147765776038441249082559726259423`20., 
    753.27819321798445917679619801653814019746`20., 
    755.19856185867218139916885353851294445956`20., 
    757.11794158282968261651585737425684908888`20., 
    759.0363365493648220073733270972109449178`20., 
    760.95375089321951517175523611811355999591`20., 
    762.8701887256019135396573541745042474543`20., 
    764.78565413421585336420913168643820885178`20., 
    766.70015118348761651953186724800479170829`20., 
    768.61368391479004457559931184640054765221`20., 
    770.52625634666404689050164644036625275553`20., 
    772.43787247503754274411237019597572232123`20., 
    774.34853627344187683588710518256301464297`20., 
    776.25825169322574678303062648538063617186`20., 
    778.16702266376668058321017375595364498484`20., 
    780.07485309268010134803527904227531243165`20., 
    781.98174686602601596934206890003899270989`20., 
    783.88770784851336374959725951742746440703`20., 
    785.79273988370206041016650123095447621505`20., 
    787.69684679420277228647440358662264366593`20., 
    789.60003238187445492692874898531391788041`20., 
    791.50230042801968973260634447907082656081`20., 
    793.4036546935778517068277290930895356374`20., 
    795.30409891931614082761521899557849335417`20., 
    797.20363682601850901137363354658369989224`20., 
    799.10227211467251410270285493731362106372`20., 
    801.00000846665413180280057555567041341457`20., 
    802.89684954391055593720355572306663807001`20., 
    804.79279898914101696241460888247009028847`20., 
    806.68786042597564812004515277036771313885`20., 
    808.5820374591524281662508234074885211982`20., 
    810.47533367469222913323803660495675661246`20., 
    812.36775264007199711826645641241081358353`20., 
    814.25929790439609364366620267247482253198`20., 
    816.14997299856582468873546225258167988506`20., 
    818.03978143544718406079607687463163987353`20., 
    819.92872671003683734797964709164777508147`20., 
    821.81681229962637228031848402985339198108`20., 
    823.70404166396484091825383604920784255519`20., 
    825.59041824541961868858333864148168651305`20., 
    827.47594546913560489699128947356268915615`20., 
    829.36062674319278896348537556741314474121`20., 
    831.24446545876220625215360233647916316244`20., 
    833.12746499026030699951256969762324965346`20., 
    835.00962869550176148620550181676427804622`20., 
    836.89095991585072424479355122716697718697`20., 
    838.77146197637057975174022898275951723262`20., 
    840.65113818597219171429509086261564390309`20., 
    842.52999183756067773272312964516595776803`20., 
    844.40802620818073079509014639652634413067`20., 
    846.28524455916050874549653811695431397265`20., 
    848.16165013625411255715267759909881936018`20., 
    850.03724616978267393891402397462143064244`20., 
    851.91203587477407250775438614515131219896`20., 
    853.78602245110130247006794585642135069225`20., 
    855.65920908361950847157683686089181564651`20., 
    857.53159894230170999890894777937319987819`20., 
    859.40319518237323344553347041859837829442`20., 
    861.27400094444487069063853740577266944991`20., 
    863.14401935464478278165081478205304661749`20., 
    865.01325352474916705938168297600825815684`20., 
    866.8817065523117058191950863335724243945`20., 
    868.74938152079181436209065255595682567489`20., 
    870.61628149968170605615071596817273324441`20., 
    872.48240954463229180138598280018124293597`20., 
    874.34776869757793106961252010517811344758`20., 
    876.21236198686005147558959258711781035496`20., 
    878.07619242734965362623705203352556184771`20., 
    879.93926302056871779133240528044311834553`20., 
    881.80157675481052874166780107363218608878`20., 
    883.66313660525893490923906854222249627843`20., 
    885.52394553410655783866240719644128213625`20., 
    887.3840064906719677196959552822640105282`20., 
    889.24332241151584061751669311602750489044`20., 
    891.10189622055611285030833561455942622514`20., 
    892.9597308291821478028003756453824136435`20., 
    894.81682913636793030971662161956106405732`20., 
    896.67319402878430359470485003672306425656`20., 
    898.52882838091026360829606473502482355234`20., 
    900.38373505514332547285790019162931166331`20., 
    902.2379169019089766134445776688516999261`20., 
    904.09137675976923103099521051422320317031`20., 
    905.94411745553029905858983400863070795913`20., 
    907.79614180434938683254188851451218119312`20., 
    909.64745260984063960809739687386330320999`20., 
    911.4980526641802429545417990956743254048`20., 
    913.34794474821069577670888841737906290681`20., 
    915.19713163154426902937237513984112443788`20., 
    917.04561607266566391791517936774826119095`20., 
    918.8934008190338833131562732819237228877`20., 
    920.74048860718333005041683677893296602049`20., 
    922.58688216282414573297877732313649110442`20., 
    924.43258420094180361818601641850643999132`20., 
    926.27759742589596913072318286450788226992`20., 
    928.12192453151864152224183586976174274012`20., 
    929.96556820121159017965833336491831592017`20., 
    931.80853110804309907628942649816108596041`20., 
    933.65081591484403286069248026111493898236`20., 
    935.49242527430323808780832078740839017698`20., 
    937.33336182906229311593711205508700790272`20., 
    939.17362821180962022138092868210576922246`20., 
    941.01322704537397352042776564427640257722`20., 
    942.85216094281731633589368827772572697011`20., 
    944.69043250752710170284051385527782790378`20., 
    946.52804433330796977549693533622654727814`20., 
    948.36499900447287597497410858699524294453`20., 
    950.20129909593366380521509387310012178692`20., 
    952.03694717329109636287186074784676016942`20., 
    953.87194579292436067557051556709044935213`20., 
    955.70629750208005912239548743165248702272`20., 
    957.54000483896070232046857834288245350219`20., 
    959.3730703328127180022699814707415875133`20., 
    961.20549650401399055987282399207043053408`20., 
    963.03728586416094609454116134999184176952`20., 
    964.8684409161551979831446990743762490268`20., 
    966.69896415428976815651007451490070533705`20., 
    968.52885806433489947906026072813903174302`20., 
    970.35812512362347482375263202640991901566`20., 
    972.18676780113605865123079489862992202612`20., 
    974.01478855758557712702598877529468422619`20., 
    975.84218984550165304529918255577229302644`20., 
    977.66897410931461207166685364135942059759`20., 
    979.49514378543917707070246128159036989606`20., 
    981.32070130235786754528618595519718360595`20., 
    983.1456490807041214845505223235423152809`20., 
    984.96998953334515719412482413154800141523`20., 
    986.79372506546459296602139166418811906113`20., 
    988.61685807464484273504418990672301006806`20., 
    990.4393909509493061631592017187098045624`20., 
    992.261326077004371891862172862115324772`20., 
    994.08266582808125300412689773848049612011`20., 
    995.90341257217767404081256554524047572838`20., 
    997.72356867009942922012783807175674183976`20., 
    999.54313647554183181143923527473475576198`20., 
    1001.36211833517107491478270606933254450106`20., 
    1003.18051658870552419315657298302073302014`20., 
    1004.99833356899696339415605812610319190066`20., 
    1006.81557160211181377870904711943243575236`20., 
    1008.63223300741234884537615970011969740301`20., 
    1010.44832009763792599649555981837718357796`20., 
    1012.26383517898625703480922998492513514945`20., 
    1014.07878055119473960333405392871885059025`20., 
    1015.89315850762187188416719148328435013157`20., 
    1017.70697133532877305045920927574743487439`20., 
    1019.52022131516083211654902234391034678871`20., 
    1021.33291072182950795060248693143272648422`20., 
    1023.14504182399430329816528004131310605099`20., 
    1024.95661688434493570971909475121735261848`20., 
    1026.76763815968372826625322413561385106964`20., 
    1028.57810790100824294940471751441143794517`20., 
    1030.3880283535941794019834118803938922635`20., 
    1032.19740175707856166551021331994780855378`20., 
    1034.00623034554323525830083537883760709721`20., 
    1035.81451634759869666487477060894573890676`20., 
    1037.62226198646827693901555019285011234556`20., 
    1039.42946948007270067230572258775568577844`20., 
    1041.23614104111504104075335574589457606869`20., 
    1043.04227887716609100724950931939898723479`20., 
    1044.84788519075017001976638580889193613608`20., 
    1046.65296217943138469682484784065146495486`20., 
    1048.45751203590036102491023189957052517241`20., 
    1050.26153694806146449896077026869735918027`20., 
    1052.06503909912052340823979053327511918506`20., 
    1053.86802066767306909696252713518213836536`20., 
    1055.67048382779310550280121763397028199839`20., 
    1057.47243074912241858735324864758757891444`20., 
    1059.27386359696043441104371580952407834139`20., 
    1061.07478453235463256067466365386910670194`20., 
    1062.87519571219151940058024186294938651696`20., 
    1064.67509928928816317748842979992754002456`20., 
    1066.47449741248429035386682740505546327606`20., 
    1068.27339222673493966365440464808059902875`20., 
    1070.07178587320366726655749899100142584098`20., 
    1071.86968048935629301103760124213044473816`20., 
    1073.66707820905517419010489913716253601586`20., 
    1075.46398116265398927629322553495197252645`20., 
    1077.26039147709300994087444213908411664013`20., 
    1079.05631127599483518556341150900447631858`20., 
    1080.8517426797605566307440829007895375402`20., 
    1082.64668780566631890071864308021846513998`20., 
    1084.44114876796023361183013377194634237143`20., 
    1086.23512767795959969185168393162755435987`20., 
    1088.02862664414837662727966332752443922347`20., 
    1089.82164777227485073787272152307003009758`20., 
    1091.61419316544942770402175888831377307625`20., 
    1093.40626492424247731178590278148999934984`20., 
    1095.19786514678214872262242892990109790079`20., 
    1096.98899592885206651045948916317880479219`20., 
    1098.77965936398880922893122293834972992911`20., 
    1100.5698575435790633681661853227023190524`20., 
    1102.35959255695633622616998438053218474259`20., 
    1104.14886649149710144818019345470179862716`20., 
    1105.93768143271624077304428567777460059754`20., 
    1107.72603946436163486448209735777902694905`20., 
    1109.51394266850774499412008804117478303081`20., 
    1111.3013931256480157809022336605775423389`20., 
    1113.0883929147859171778993143104742619266`20., 
    1114.87494411352443143432898644689793255792`20., 
    1116.66104879815377785124555800494011838533`20., 
    1118.44670904373715479929667062443389844318`20., 
    1120.23192692419426468371391539146422843463`20., 
    1122.01670451238237333510382800351752017017`20., 
    1123.80104388017464068684909448977607700978`20., 
    1125.58494709853544458580902331850294133403`20., 
    1127.36841623759240419005657913513516223278`20., 
    1129.15145336670479365604674545895561078309`20., 
    1130.9340605545280207313918960667665817009`20., 
    1132.71623986907382847507972716999398535391`20., 
    1134.49799337776586165467173800659646112452`20., 
    1136.27932314749022245350212651219034207827`20., 
    1138.06023124464062299763093086516952288767`20., 
    1139.84071973515772492365823242998869736148`20., 
    1141.62079068456223879989269767840481135017`20., 
    1143.40044615798133873439610519010750466635`20., 
    1145.17968822016793000803626628507902816357`20., 
    1146.95851893551229011727446102314213698182`20., 
    1148.73694036804558626296690669582699478033`20., 
    1150.51495458143475514562800762654940024854`20., 
    1152.29256363896821399680609925050018315513`20., 
    1154.06976960353185516771293757655016583957`20., 
    1155.84657453757476039215987140034766380183`20., 
    1157.62298050306405512822574136233975619426`20., 
    1159.39898956142830825385868754082692624925`20., 
    1161.17460377348886794261788693284340560191`20., 
    1162.94982519937851087863165414840429326562`20., 
    1164.72465589844676919095121817091032010235`20., 
    1166.49909792915128770777849776567573866201`20., 
    1168.27315334893455346593563253792718276438`20., 
    1170.04682421408532998004000400781317294627`20., 
    1171.82011257958412070273569423198043141093`20., 
    1173.59302049893197951926364219776042556028`20., 
    1175.36555002396198114719902101400292392533`20., 
    1177.13770320463266108883194222497079939418`20., 
    1178.90948208880273344536129728948438956981`20., 
    1180.68088872198639558670075000536769102207`20., 
    1182.45192514708853151752206075687898082629`20., 
    1184.22259340411913092918486972349972553255`20., 
    1185.9928955298862485184697525511829930995`20., 
    1187.76283355766683832687737188787347875181`20., 
    1189.53240951685481074648486707104390602229`20., 
    1191.30162543258567558535285211285520543376`20., 
    1193.07048332533715331928809094146186877098`20., 
    1194.83898521050515850506342591700880078655`20., 
    1196.60713309795458441523026016225889228038`20., 
    1198.37492899154434639214085744693859604303`20., 
    1200.14237488862617331672689884174571844205`20., 
    1201.90947277951667204502559393078259345188`20., 
    1203.67622464694222877128220104505449472738`20., 
    1205.4426324654563541080764058140381213027`20., 
    1207.20869820082912529589301966441495252382`20., 
    1208.97442380940842941729614837398835196376`20., 
    1210.7398112374527658292606502796224638526`20., 
    1212.50486242043542425927441324749452900371`20., 
    1214.2695792823199171363270103264033682317`20., 
    1216.03396373480661072706158025781941852675`20., 
    1217.79801767655056947955044870455936746809`20., 
    1219.56174299235070157962607239389850153928`20., 
    1221.32514155231037101144395185160023941763`20., 
    1223.08821521096972227458071025949803943202`20., 
    1224.85096580641004820870207430687192937034`20., 
    1226.61339515933061895161915408006147698278`20., 
    1228.37550507209848071829516815455372197828`20., 
    1230.13729732777182662032135601969055687774`20., 
    1231.89877368909763790269575230032667572611`20., 
    1233.65993589748439248417886530130378610047`20., 
    1235.42078567195073824738115474370069853586`20., 
    1237.18132470805113080506116026084746075598`20., 
    1238.94155467677953911193816220648639061458`20., 
    1240.70147722345242691137226406732140618734`20., 
    1242.46109396657232319178916911758642898489`20., 
    1244.22040649667340014163449328444178207356`20., 
    1245.97941637515058207289805411484118633329`20., 
    1247.73812513307381294855341070469792384181`20., 
    1249.49653426998921299501104523565303104334`20., 
    1251.25464525270895588522603695964629876058`20., 
    1253.01245951409179660424037248526126756657`20., 
    1254.76997845181627580674892666365725004022`20., 
    1256.52720342714871868615874703210991472856`20., 
    1258.28413576370823453061150812253386698809`20., 
    1260.0407767462310066748049758070161282934`20., 
    1261.79712761933624089939333981492014372668`20., 
    1263.55318958629621291940654002689493903899`20., 
    1265.30896380781292188569308791723698263308`20., 
    1267.06445140080391625835349243350460939916`20., 
    1268.81965343719991047564754582964603825498`20., 
    1270.5745709427568550351604440866935671507`20., 
    1272.32920489588515845184445673837326073078`20., 
    1274.08355622649878661658437680932661868967`20., 
    1275.83762581488698294110649423551872964005`20., 
    1277.59141449061136097180399957751273300491`20., 
    1279.34492303143111956139896024454387423522`20., 
    1281.09815216225911892574537954455861707693`20., 
    1282.85110255415153375697586611887599605539`20., 
    1284.60377482333376684141513673281586727745`20., 
    1286.35616953026526322631865154485153622329`20., 
    1288.10828717874581083847689395229611456016`20., 
    1289.86012821506584858695561367873974788691`20., 
    1291.61169302720322745224647252736572013755`20., 
    1293.36298194406878401019232002430808342448`20., 
    1295.11399523480298946195366957520899315245`20., 
    1296.86473310812583080722182551532071282518`20., 
    1298.6151957117419646380967998078742558158`20., 
    1300.36538313180305854072632985969079847979`20., 
    1302.11529539242910072845494277408919000865`20., 
    1303.86493245529031581147377264758061759142`20., 
    1305.61429421925117410873762664312802640961`20., 
    1307.36338052007782425717909501320423932372`20., 
    1309.1121911302101147501190668135201918088`20., 
    1310.86072575859920016619915022005511951131`20., 
    1312.60898405061155299813952835974789881528`20., 
    1314.35696558800002295900032131506657145752`20., 
    1316.10466988894240326453358173962845862428`20., 
    1317.85209640814777852022586740802614957124`20., 
    1319.59924453703074235563798724659818792768`20., 
    1321.34611360395338573356271257954614243083`20., 
    1323.09270287453476980986026610362067330091`20., 
    1324.8390115520274112232388841139288835026`20., 
    1326.58503877776012363702571880054278414579`20., 
    1328.33078363164637810768982862839169164667`20., 
    1330.07624513275716726811644945109742273622`20., 
    1331.82142223995718521193961850995446802122`20., 
    1333.56631385260296714135228068238273217376`20., 
    1335.31091881130147105018608339932050508386`20., 
    1337.05523589872742866978005554864392456494`20., 
    1338.79926384049764527330180137545553244858`20., 
    1340.54300130610028832957904389893956406406`20., 
    1342.28644690987707398004193184864718252168`20., 
    1344.02959921205613838385855788849237322195`20., 
    1345.77245671983326857782860083720816608416`20., 
    1347.51501788849906500735808696106070227245`20., 
    1349.25728112260951561688120888847457688312`20., 
    1350.99924477719737959126335828106757144996`20., 
    1352.74090715902170769735393472340443125318`20., 
    1354.48226652785276580502950155839530498593`20., 
    1356.22332109778957862335232386237348128858`20., 
    1357.96406903860727196023697699192180655959`20., 
    1359.70450847713136383221841980395890043752`20., 
    1361.44463749863613738431840453648206161184`20., 
    1363.18445414826422164186372391683417322844`20., 
    1364.92395643246450936619069540574961114354`20., 
    1366.66314232044555443414315022274925276475`20., 
    1368.40200974564161387036632141558807120708`20., 
    1370.14055660718853155231855098885409795614`20., 
    1371.87878077140670126294551826056092891671`20., 
    1373.61668007328839573319610438761266937132`20., 
    1375.35425231798680511429656618297261213873`20., 
    1377.09149528230419244082353223588083531861`20., 
    1378.82840671617664456202025429086266725025`20., 
    1380.5649843441529741857764506429810103636`20., 
    1382.30122586686541154024621959239177780723`20., 
    1384.03712896248981214713983416556438958932`20., 
    1385.77269128819319974921236953297290232623`20., 
    1387.50791048156655997318883206367572193838`20., 
    1389.24278416204090027269821817407295018848`20., 
    1390.97730993228469452518367227025048540255`20., 
    1392.71148537958093580395500386326023398804`20., 
    1394.44530807718212777657382699442048565589`20., 
    1396.1787755856416533746241422484645546799`20., 
    1397.91188545412006833706886277375921251566`20., 
    1399.6446352216649764698651480653078032328`20., 
    1401.37702241846325253081972534183955970531`20., 
    1403.10904456706448710739149096288316302218`20., 
    1404.84069918357463529826820763712261337576`20., 
    1406.57198377881895705548070467824185211868`20., 
    1408.30289585947344133823765320897875608769`20., 
    1410.03343292916400844602033547630783285042`20., 
    1411.76359248953288473831988268673366063219`20., 
    1413.49337204127164114146202924537335841222`20., 
    1415.22276908512048114704117771571172328437`20., 
    1416.95178112283345520712073654938143255525`20., 
    1418.68040565810936634135717541244636548439`20., 
    1420.40864019748821622999592457341069523694`20., 
    1422.13648225121312193952578335184154776867`20., 
    1423.86392933405771060484665437522067300575`20., 
    1425.59097896611907278719377491431511794705`20., 
    1427.3176286735764247776642205439019862734`20., 
    1429.04387598941569578052626838205318370887`20., 
    1430.76971845412031766746266623101327747304`20., 
    1432.49515361632855284151108261174921182939`20., 
    1434.22017903345774970351432912339956743876`20., 
    1435.94479227229596530663244881156798765241`20., 
    1437.66899090956144106327178984255334846518`20., 
    1439.39277253243045989481345643572059895658`20., 
    1441.11613473903415206140479501315144176762`20., 
    1442.83907513892485216161651875578550380089`20., 
    1444.5615913535126415446783078771737402315`20., 
    1446.28368101647273873468463334694365959843`20., 
    1448.00534177412442553750887376357992981463`20., 
    1449.72657128578221840444382483414175549621`20., 
    1451.44736722408001348435320216803670896096`20., 
    1453.16772727526894973518576353322162448731`20., 
    1454.88764913948974761617975021514943672346`20., 
    1456.60713053102029137646673092118327060943`20., 
    1458.32616917849923092810903926438098096605`20., 
    1460.04476282512638487667040494696948390344`20., 
    1461.76290922884072961505735149159509941846`20., 
    1463.48060616247676060078586085921891308482`20., 
    1465.19785141390001116600256027417375634097`20., 
    1466.91464278612251158473048934423378544979`20., 
    1468.63097809739896677186758262107322725684`20., 
    1470.34685518130442503970404172437279009094`20., 
    1472.0622718867942029133379471382960898303`20., 
    1473.77722607824682222615562405390567289889`20., 
    1475.49171563549070569662575569310429103897`20., 
    1477.20573845381536604024158532563485396063`20., 
    1478.91929244396781150363352339148510504211`20., 
    1480.63237553213487762550247774777385597128`20., 
    1482.3449856599121811305494074745936667539`20., 
    1484.05712078426037724299190382775319509974`20., 
    1485.76877887744938645603996719032227307674`20., 
    1487.47995792699124099878524623408181465036`20., 
    1489.19065593556218498373586826251942969534`20., 
    1490.90087092091464557358303756298604279714`20., 
    1492.6106009157796755471276056872550849486`20., 
    1494.3198439677604504396326270568595251474`20., 
    1496.02859813921738604588639180059004649237`20., 
    1497.73686150714542456441697033379091971158`20., 
    1499.44463216304402008393162074789289152249`20., 
    1501.1519082127803365194988667852876525024`20., 
    1502.85868777644615354370982703973655538835`20., 
    1504.56496898820895857077081591656725796387`20., 
    1506.27074999615768547931396689111483602416`20., 
    1507.97602896214354353933401322333457690332`20., 
    1509.68080406161636297342710273105544648431`20., 
    1511.38507348345686676262325185991636028348`20., 
    1513.08883542980526172976187800776168260301`20., 
    1514.79208811588652562289699932112993278451`20., 
    1516.4948297698327508992652914918050029839`20., 
    1518.19705863250289019597761662547775322537`20., 
    1519.89877295730023308346167387831772723716`20., 
    1521.59997100998792864617971056798726208583`20., 
    1523.30065106850285373453153647665590376307`20., 
    1525.00081142276811239239792056330483874518`20., 
    1526.70045037450443799489177479087344565156`20., 
    1528.39956623704075603724217631216314634723`20., 
    1530.09815733512415230340991527330721829091`20., 
    1531.79622200472947831560569182403247511731`20., 
    1533.49375859286881352556279461293748035177`20., 
    1535.1907654574009916561508484456453480759`20., 
    1536.88724096684138693749280839647744347163`20., 
    1538.58318350017214470389136400854688646543`20., 
    1540.27859144665302992434646211056908589599`20., 
    1541.97346320563305672714144601833864506846`20., 
    1543.66779718636305184399063859959793197067`20., 
    1545.36159180780929513696630283761994016465`20., 
    1547.0548454984683709766146435564169126069`20., 
    1548.7475566961833552065234541136475172539`20., 
    1550.43972384796145375181719639982484744326`20., 
    1552.13134540979320059989464101584682953529`20., 
    1553.82241984647331489408076183273835493394`20., 
    1555.51294563142330922730891844804670855087`20., 
    1557.20292124651593389578195498706651200452`20., 
    1558.89234518190153486385891812113145057737`20., 
    1560.58121593583639649307490334528791916689`20., 
    1562.26953201451313369198229519103980491229`20., 
    1563.95729193189319204105630854068007859533`20., 
    1565.64449420954150862982063505050107475778`20., 
    1567.33113737646338080316580720280384836155`20., 
    1569.01721996894358474208868934479393461691`20., 
    1570.70274053038778079232635873344156960188`20., 
    1572.38769761116623769417976747484697760094`20., 
    1574.07208976845990334986923157700680526301`20., 
    1575.75591556610884548276002210225166693265`20., 
    1577.4391735744630814875617362693184117335`20., 
    1579.12186237023581293406875601886285677862`20., 
    1580.803980536359076561222620757488078442`20., 
    1582.48552666184182017542636117329132436067`20., 
    1584.16649934163040863945575648149154647306`20., 
    1585.84689717647156209847590463877881398225`20., 
    1587.52671877277772573022642116078154864478`20., 
    1589.20596274249486762019432238743082554243`20., 
    1590.8846277029726988425309063835278042024`20., 
    1592.56271227683730746674386139507939128766`20., 
    1594.24021509186619600214311651662090343473`20., 
    1595.91713478086570973015415901701059888477`20., 
    1597.59346998155084145263359483767035686853`20., 
    1599.26921933642739639610971196263711132233`20., 
    1600.94438149267649935149015813707072702806`20., 
    1602.61895510204142459047695500374676832105`20., 
    1604.29293882071672767813537191977553975101`20., 
    1605.96633130923965699038777505956622046627`20., 
    1607.6391312323838215404354358493967924374`20., 
    1609.31133725905509061421614720431158960378`20., 
    1610.98294806218969970712333992403916035988`20., 
    1612.65396231865453633765470871204961508463`20., 
    1614.32437870914957848390515338609372451609`20., 
    1615.99419591811245764151542460077367428928`20., 
    1617.66341263362511783264145773344021306267`20., 
    1619.33202754732254130068558151369481457232`20., 
    1621.00003935430351110104990929639051554859`20., 
    1622.66744675304338034030551892496099413536`20., 
    1624.33424844530881742133686774623304319502`20., 
    1626.00044313607449631678084712709366111306`20., 
    1627.66602953344170061413480099461446438055`20., 
    1629.33100634855880985009387021252612155944`20., 
    1630.99537229554363647596267423304992123852`20., 
    1632.6591260914075816674644754868815175076`20., 
    1634.32226645598157810816089311590484930273`20., 
    1635.98479211184378783333475625256309378571`20., 
    1637.64670178424902321803126069119261877036`20., 
    1639.30799420105985922656346199762229323143`20., 
    1640.96866809267940510884056543658175262107`20., 
    1642.62872219198570382914901716902142834052`20., 
    1644.28815523426772764338526101386697174398`20., 
    1645.94696595716293839918045468525436828163`20., 
    1647.60515310059638131794023651412617508961`20., 
    1649.26271540672128122670570590734937944693`20., 
    1650.91965161986111043917079232610226439995`20., 
    1652.57596048645309773749528793976539988125`20., 
    1654.2316407549931481781414563742606349353`20., 
    1655.88669117598214373432194902158257947381`20., 
    1657.54111050187359509333858744852318584313`20., 
    1659.19489748702261524774748414018906407343`20., 
    1660.84805088763618585360646275230787767882`20., 
    1662.50056946172468767581194591093735864759`20., 
    1664.15245196905466679854353013875214367553`20., 
    1665.80369717110280864699488972999975340682`20., 
    1667.45430383101109224382686915263933523607`20., 
    1669.10427071354309750913554311958625217388`20., 
    1670.75359658504143880524069723907595173897`20., 
    1672.40228021338629832637555377239661709702`20., 
    1674.05032036795503333755229553396818140698`20., 
    1675.69771581958283167569230232240711991426`20., 
    1677.34446534052439033879187855747137656095`20., 
    1678.99056770441659240473313334668383148996`20., 
    1680.63602168624215793967585879486974400313`20., 
    1682.280826062294244976148984649864345541`20., 
    1683.92497961014197706240593662004361793838`20., 
    1685.56848110859687430675901295655248358542`20., 
    1687.211329337680165262939684639453845278`20., 
    1688.85352307859095742455288383205092663816`20., 
    1690.49506111367524451794315369583165456394`20., 
    1692.1359422263957292028377606799684301061`20., 
    1693.77616520130244020857340981254985526098`20., 
    1695.4157288240041233501727537095472217857`20., 
    1697.05463188114038628266369331029775244052`20., 
    1698.69287316035457726350211663659524544383`20., 
    1700.33045145026737860146397269914388196823`20., 
    1701.96736554045109587563425803695259656572`20., 
    1703.60361422140462440987842952338946555824`20., 
    1705.23919628452907488619575263325907407921`20., 
    1706.87411052210404037440295114426804670787`20., 
    1708.50835572726448744547710412391039875648`20., 
    1710.14193069397825442141306241816071118631`20., 
    1711.77483421702414019545305407624141147169`20., 
    1713.40706509197056743287041759431803770549`20., 
    1715.0386221151548043339960331220004007098`20., 
    1716.66950408366272950773943760376979008461`20., 
    1718.29970979530912486536444357064099318704`20., 
    1719.9292380486184818006314854815170282164`20., 
    1721.55808764280630627352790235253775506211`20., 
    1723.18625737776090876059616604288171957064`20., 
    1724.81374605402566537527253585133785044302`20., 
    1726.44055247278173679660865787179044797735`20., 
    1728.06667543583123197421961533936440215246`20., 
    1729.69211374558080390124621607300190506853`20., 
    1731.31686620502566506550767014614300415584`20., 
    1732.94093161773401050183202985481494386322`20., 
    1734.56430878783183667577210757308624788604`20., 
    1736.18699651998814473053739457639518423811`20., 
    1737.80899361940051692499776002197421997186`20., 
    1739.43029889178105538104864138366633109434`20., 
    1741.05091114334267254348213147423293863533`20., 
    1742.67082918078572303480139983256434691051`20., 
    1744.29005181128496686116997581436980158909`20., 
    1745.90857784247685419393009199223460866566`20., 
    1747.5264060824471222138875518828583398984`20., 
    1749.14353533971869476288064131058077835049`20., 
    1750.75996442323987579906753663421108293796`20., 
    1752.3756921423728278989241805693694161712`20., 
    1753.99071730688232729018975473060331550023`20., 
    1755.60503872692478713597983544820657634505`20., 
    1757.2186552130375410210610952745642580059`20., 
    1758.83156557612837881690165928067591290411`20., 
    1760.44376862746532732263601083354200311265`20., 
    1762.0552631786666682945729429304097556181`20., 
    1763.66604804169118668739175720372243927102`20., 
    1765.27612202882864213577983698448861222586`20., 
    1766.88548395269045690602962359996794741721`20., 
    1768.4941326262006137431021441526578980958`20., 
    1770.10206686258675722994612889726839879697`20., 
    1771.70928547537149246250613563104238827922`20., 
    1773.31578727836387502593070512768344630316`20., 
    1774.92157108565108643507402531531358906893`20., 
    1776.52663571159028937554425395361139523673`20., 
    1778.13097997080065725036153951011399112025`20., 
    1779.7346026781555727018223986016116020216`20., 
    1781.33750264877498993849836735000593781164`20., 
    1782.93967869801795585349995113374986212453`20., 
    1784.54112964147528507228625780841729719043`20., 
    1786.14185429496238421647082310135518878954`20., 
    1787.74185147451222081433954949012370375938`20., 
    1789.34111999636843242923184091694227238271`20., 
    1790.93965867697857171361524021040260426193`20., 
    1792.53746633298748322968126140425165393069`20., 
    1794.13454178123080800667946604664519828343`20., 
    1795.7308838387286119310616207878208635368`20., 
    1797.32649132267913418790104120107824241855`20., 
    1798.92136305045265209105655406607183787539`20., 
    1800.51549783958545875523795654510936166211`20., 
    1802.10889450777395017557190514337872965294`20., 
    1803.70155187286881838953470366652300643875`20., 
    1805.29346875286934750228169299988331414941`20., 
    1806.88464396591780945953139437476918641701`20., 
    1808.47507633029395655232500601370493975318`20., 
    1810.06476466440960773524631759741680984108`20., 
    1811.65370778680332593412080690598909193489`20., 
    1813.24190451613518361088201131781733704575`20., 
    1814.82935367118161394226376512600815472882`20., 
    1816.41605407083034505531322865489317769612`20., 
    1818.00200453407541484648557810406128698091`20., 
    1819.58720388001226399233963272373595369987`20., 
    1821.17165092783290483866649410797876217193`20., 
    1822.75534449682116393131144111754019550094`20., 
    1824.33828340634799602605288468089493409958`20., 
    1825.92046647586686748674019132283406149228`20., 
    1827.50189252490920705052270561690562421671`20., 
    1829.08256037307992200648242601582137103969`20., 
    1830.66246884005297789936860891071281486504`20., 
    1832.24161674556703993347918782539778649656`20., 
    1833.82000290942117431309539277723252040058`20., 
    1835.39762615147060781530543023503539575444`20., 
    1836.97448529162254394860262390067675060354`20., 
    1838.5505791498320341063641040681477079149`20., 
    1840.12590654609790217825804950242897711779`20., 
    1841.70046630045872113483971157632070734264`20., 
    1843.27425723298884015112707016135801228766`20., 
    1844.84727816379446088384307656078327103786`20., 
    1846.4195279130097615643191355548315902841`20., 
    1847.99100530079306761481889021652976872077`20., 
    1849.56170914732306754030664895212191583453`20., 
    1851.1316382727950728904941166470445901316`20., 
    1852.70079149741732112839468439075445298594`20., 
    1854.26916764140732028163766836120959713082`20., 
    1855.83676552498823429148590050820697375068`20., 
    1857.4035839683853080118983630037239734304`20., 
    1858.96962179182233084712360551401652831638`20., 
    1860.53487781551813805123705957810885752582`20., 
    1862.09935085968314874678273917608217076172`20., 
    1863.6630397445159397522829749203809600006`20., 
    1865.22594329019985433987367960063425242514`20., 
    1866.78806031689964507474123003447976094821`20., 
    1868.34938964475814991741356832601130286306`20., 
    1869.90993009389300079832493042997973753235`20., 
    1871.46968048439336390146223171443601754087`20., 
    1873.02863963631671092034229609391627379224`20., 
    1874.58680636968562057509272636555313620512`20., 
    1876.1441795044846097040444121428896590501`20., 
    1877.70075786065699326701881972875121813362`20., 
    1879.25654025810177262043590847533087089859`20., 
    1880.81152551667055144650562902620471328467`20., 
    1882.36571245616447874012360777037356272688`20., 
    1883.91909989633121827769521918473283655116`20., 
    1885.47168665686194401198650051686335228402`20., 
    1887.02347155738836085626928900481798221672`20., 
    1888.57445341747975033951490241883852788683`20., 
    1890.12463105664004063221831913356237107612`20., 
    1891.67400329430490045962517604858855022319`20., 
    1893.22256894983885643570838886340759770589`20., 
    1894.7703268425324333672205860310316141622`20., 
    1896.31727579159931709255300440737646243577`20., 
    1897.86341461617353943498059656018227533289`20., 
    1899.40874213530668486418584175740844686967`20., 
    1900.95325716796511847374856238005929284414`20., 
    1902.49695853302723489558379826906009707508`20., 
    1904.03984504928072778512181548005665843144`20., 
    1905.58191553541987952337042687366045667565`20., 
    1907.12316881004287079389626802773126039242`20., 
    1908.66360369164910970422428811046384686969`20., 
    1910.20321899863658013219877584614611586206`20., 
    1911.74201354929920898848956127343267383612`20., 
    1913.27998616182425209667796391740496282883`20., 
    1914.81713565428969840223249198122211187924`20., 
    1916.35346084466169223119768706189094435372`20., 
    1917.8889605507919733285838752307145413214`20., 
    1919.42363359041533441527352863510249107747`20., 
    1920.95747878114709601076365379896420382683`20., 
    1922.49049494048059827725489740337537824824`20., 
    1924.02268088578470964848830433570210481256`20., 
    1925.55403543430135201433090655195266630198`20., 
    1927.08455740314304223943222907984558558355`20., 
    1928.61424560929044980132567970649642376798`20., 
    1930.14309886958997034014160409211852402085`20., 
    1931.67111600075131491864216472946878683435`20., 
    1933.19829581934511479759144039667794768394`20., 
    1934.72463714180054153754622558691038352836`20., 
    1936.25013878440294224400261211485291761048`20., 
    1937.77479956329148977846893421443007947746`20., 
    1939.29861829445684776346514055091410636836`20., 
    1940.8215937937388502146799269912643241023`20., 
    1942.34372487682419563855755519661075848246`20., 
    1943.8650103592441554384434620355020550059`20., 
    1945.38544905637229647709854487657739457497`20., 
    1946.90503978342221764790315079038366720033`20., 
    1948.4237813554453003114198254256692184575`20., 
    1949.94167258732847245817507825508957463964`20., 
    1951.45871229379198646256085733948169482364`20., 
    1952.97489928938721029665194211500996516382`20., 
    1954.49023238849443207649168835148509354022`20., 
    1956.00471040532067781702092155217308104163`20., 
    1957.51833215389754227531850127152362641971`20., 
    1959.03109644807903276519220458459391440805`20., 
    1960.54300210153942582940995185385353754024`20., 
    1962.05404792777113665899869185372639372887`20., 
    1963.56423274008260115206597226856850034071`20., 
    1965.07355535159617050752167358711377579023`20., 
    1966.58201457524601825189874508570940627476`20., 
    1968.08960922377605960019605960207829492977`20., 
    1969.59633810973788305429755621390840200746`20., 
    1971.10220004548869414506337736669769746988`20., 
    1972.60719384318927122664429862808325797669`20., 
    1974.11131831480193323394382771200702655218`20., 
    1975.61457227208851931644621552502755124786`20., 
    1977.11695452660838026384644932185010632267`20., 
    1978.61846388971638164106313743294304335012`20., 
    1980.11909917256091855228997881724098538188`20., 
    1981.61885918608194195574905702452393889387`20., 
    1983.11774274100899645275221497453073292093`20., 
    1984.61574864785926947655785598904542613166`20., 
    1986.11287571693565180833217705385242838523`20., 
    1987.60912275832480934928847293706846222419`20., 
    1989.10448858189526607978806002693164209715`20., 
    1990.59897199729549813784377040881118909485`20., 
    1992.09257181395203895107398533046643508701`20., 
    1993.58528684106759535771385333466367918273`20., 
    1995.07711588761917465380263062455155718969`20., 
    1996.56805776235622250513386950128161726211`20., 
    1998.05811127379877166398026893227227080651`20., 
    1999.54727523023560143198912040683407704668`20., 
    2001.03554843972240781198909288323355417934`20., 
    2002.52292971007998429275619589776311022018`20., 
    2004.00941784889241321205766783836946285136`20., 
    2005.49501166350526764452872249416213416248`20., 
    2006.97970996102382376213995665779766944168`20., 
    2008.46351154831128361618412235078303237358`20., 
    2009.94641523198700829085119116443613080519`20., 
    2011.42841981842476137957142385933583012583`20., 
    2012.90952411375096273638869302495816557033`20., 
    2014.38972692384295245568172824861189186191`20., 
    2015.86902705432726503458035250055783490394`20., 
    2017.34742331057791367342820044868027978659`20., 
    2018.82491449771468467062385563371545623471`20., 
    2020.30149942060144186912977339390348397996`20., 
    2021.77717688384444111287368940126754249194`20., 
    2023.25194569179065467218133030045908383574`20., 
    2024.72580464852610559827298678915732836904`20., 
    2026.19875255787421196773068853630040143375`20., 
    2027.67078822339414097869810846339884917023`20., 
    2029.14191044837917286141266224257854855684`20., 
    2030.61211803585507456648926712661505961079`20., 
    2032.08140978857848319517856205134211569356`20., 
    2033.54978450903529913660971910796598838208`20., 
    2035.01724099943908887779991807340891296036`20., 
    2036.48377806172949745296970729426787537153`20., 
    2037.94939449757067049944640701486510979182`20., 
    2039.41408910834968588816697204244040914421`20., 
    2040.87786069517499489750784294423001684357`20., 
    2042.34070805887487289987277991639230924551`20., 
    2043.80262999999587953116097079428621050316`20., 
    2045.26362531880132831391729363113917414004`20., 
    2046.72369281526976570563493447486883483809`20., 
    2048.18283128909345954433803324775059381992`20., 
    2049.64103953967689686421905782052673415996`20., 
    2051.0983163661352910547425740948717201928`20., 
    2052.5546605672930983372543573129294570695`20., 
    2054.01007094168254353375273028074838775517`20., 
    2055.4645462875421551030879560198331371331`20., 
    2056.91808540281530942045577941251097566717`20., 
    2058.37068708514878427664311474300496497644`20., 
    2059.82235013189132157406771051474823707609`20., 
    2061.27307334009219919722967377693558832691`20., 
    2062.72285550649981203576127557728508499452`20., 
    2064.17169542756026213882274768724229769474`20., 
    2065.61959189941595798014606799791032398295`20., 
    2067.06654371790422281357625698749705467984`20., 
    2068.51254967855591209950069935784877683918`20., 
    2069.95760857659403998309168263497181467636`20., 
    2071.4017192069324148058159183225224091905`20., 
    2072.84488036417428363218748238342862679458`20., 
    2074.2870908426109857742575732894258104901`20., 
    2075.7283494362206152968459224736597330299`20., 
    2077.1686549386666924870247809248535193803`20., 
    2078.60800614329684427186731671837071245832`20., 
    2080.0464018431414935689681543322214705378`20., 
    2081.48384083091255755473482379816482233681`20., 
    2082.92032189900215483593521585476516930329`20., 
    2084.35584383948132151046790196488078676666`20., 
    2085.79040544409873610379951317280904883728`20., 
    2087.22400550427945336798641158098124304853`20., 
    2088.65664281112364693066675968513223360894`20., 
    2090.08831615540536078187391781029046634641`20., 
    2091.51902432757126958698299548459854505585`20., 
    2092.94876611773944781455946119658968912364`20., 
    2094.37754031569814766833208461187109864235`20., 
    2095.80534571090458581296224976982049301409`20., 
    2097.23218109248373888372793680816199483729`20., 
    2098.65804524922714777068351929925354436349`20., 
    2100.08293696959173066829605658442651222446`20., 
    2101.50685504169860488199506431733704245453`20., 
    2102.92979825333191738350590718574159144876`20., 
    2104.35176539193768410726705769245008808064`20., 
    2105.77275524462263798065858311106133648337`20., 
    2107.19276659815308568119343555023780391405`20., 
    2108.61179823895377311424450094194191327784`20., 
    2110.02984895310675960529898254004307466429`20., 
    2111.44691752635030080114762146679330790899`20., 
    2112.86300274407774027482955684542729729996`20., 
    2114.27810339133640982956436466443756942761`20., 
    2115.69221825282653849731104908051249641584`20., 
    2117.10534611290017022799955161963772168142`20., 
    2118.51748575556009026588374989967137521181`20., 
    2119.92863596445876020986599336585294392278`20., 
    2121.33879552289726175504202255436835548203`20., 
    2122.74796321382424911311169226884689700199`20., 
    2124.15613781983491010969531777791094169197`20., 
    2125.56331812316993595698773511660501481779`20., 
    2126.96950290571449970057235865946397639024`20., 
    2128.374690948997243339605676714587299299`20., 
    2129.77888103418927361996879294418023613464`20., 
    2131.18207194210316650036684057741553497645`20., 
    2132.58426245319198029173940898570145201533`20., 
    2133.98545134754827747072556834273330247181`20., 
    2135.38563740490315516830569671326402889731`20., 
    2136.7848194046252843351191427933346516308`20., 
    2138.18299612571995758533183336289235181866`20., 
    2139.58016634682814572130129297067092772627`20., 
    2140.97632884622556294165821911444451529094`20., 
    2142.37148240182174073579378291379618835304`20., 
    2143.76562579115911046811023578569368259158`20., 
    2145.15875779141209465575922883253575331045`20., 
    2146.55087717938620694395752459895795127814`20., 
    2147.94198273151716078333353079597647503758`20., 
    2149.33207322386998681412034199660520330061`20., 
    2150.72114743213815896237176689295900425766`20., 
    2152.10920413164272925373717346634791210691`20., 
    2153.4962420973314713506889296598781361274`20., 
    2154.88226010377803281945277949016683219358`20., 
    2156.26725692518109613324669997992639813212`20., 
    2157.65123133536354841878765820533097254989`20., 
    2159.0341821077716599533782549025655148284`20., 
    2160.41610801547427142023652566177533398656`20., 
    2161.79700783116198993008219639271742345075`20., 
    2163.17688032714639381734147957690667101601`20., 
    2164.55572427535924621968007440962386000735`20., 
    2165.9335384473517174499204193644425452435`20., 
    2167.31032161429361616974446158110899216433`20., 
    2168.68607254697262937492727491414552787322`20., 
    2170.06079001579357120218979816021151014251`20., 
    2171.43447279077764056810079714337490911122`20., 
    2172.80711964156168765079889878947333864134`20., 
    2174.1787293373974892256452214611578285507`20., 
    2175.54930064715103286625575265080255436853`20., 
    2176.91883233930181002270022124699981339298`20., 
    2178.28732318194211798899079523170705571918`20., 
    2179.65477194277637077231952469180302684872`20., 
    2181.02117738912041887683806194609958650469`20., 
    2182.38653828790087801510684255429813431698`20., 
    2183.75085340565446676067361980693539639737`20., 
    2185.11412150852735315557302748407027295226`20., 
    2186.47634136227451028686971738268901171375`20., 
    2187.83751173225908084669759520210378775225`20., 
    2189.19763138345175069057677639020893301359`20., 
    2190.55669908043013140911811773934592133757`20., 
    2191.91471358737815192855256583428754316554`20., 
    2193.27167366808545915584911456608575985813`20., 
    2194.62757808594682768451089522401733779528`20., 
    2195.98242560396157857746384827942639691665`20., 
    2197.33621498473300724377655972734509118151`20., 
    2198.68894499046782042627320033875605509897`20., 
    2200.04061438297558231742409672463736568392`20., 
    2201.39122192366816982122030179573989793762`20., 
    2202.74076637355923697905963184407410849778`20., 
    2204.08924649326368857799201065385418390683`20., 
    2205.43666104299716295999162011171431344064`20., 
    2206.78300878257552405124231383294581704049`20., 
    2208.12828847141436263074101722470319008275`20., 
    2209.47249886852850685784142581244933754711`20., 
    2210.8156387325315420786772349811374664254`20., 
    2212.1577068216353399317203997247722374524`20., 
    2213.49870189364959677304554353545484559515`20., 
    2214.83862270598138144218662195859157016698`20., 
    2216.17746801563469238978630914470019437428`20., 
    2217.51523657921002418855232528026504365606`20., 
    2218.85192715290394344934806921308465045955`20., 
    2220.18753849250867416455747382937608729766`20., 
    2221.52206935341169250117597151591887586342`20., 
    2222.8555184905953310663908528759137382193`20., 
    2224.18788465863639266872513308915190152007`20., 
    2225.51916661170577359812931604675346735096`20., 
    2226.84936310356809644871517558539859542236`20., 
    2228.17847288758135250813486454084577088753`20., 
    2229.50649471669655373791732449056459955811`20., 
    2230.83342734345739436938211032694862688551`20., 
    2232.15926951999992214005837237539621764642`20., 
    2233.48401999805221919584386263984966091158`20., 
    2234.80767752893409268444545873268188274669`20., 
    2236.1302408635567750659488367542951375281`20., 
    2237.45170875242263416667058027766019685596`20., 
    2238.77207994562489300275119393183691244069`20., 
    2240.09135319284735940025220395543342812048`20., 
    2241.40952724336416543882478141792788510151`20., 
    2242.72660084603951674632112331966808187517`20., 
    2244.04257274932745167202317904107025326413`20., 
    2245.35744170127161036646622100499568682325`20., 
    2246.67120644950501379613723515746545254308`20., 
    2247.98386574124985272163015500272409063489`20., 
    2249.29541832331728666814158831999404876853`20., 
    2250.60586294210725291749189404160108458339`20., 
    2251.91519834360828555115726361654762958726`20., 
    2253.2234232733973445740988518824075527825`20., 
    2254.53053647663965514947499221597212134545`20., 
    2255.83653669808855697462212455646229874063`20., 
    2257.14142268208536382898926765476877048769`20., 
    2258.44519317255923332500968329250147452234`20., 
    2259.74784691302704689319181476460391770771`20., 
    2261.04938264659330003300963899301031051838`20., 
    2262.34979911595000286147025543602831828771`20., 
    2263.64909506337659099153384951467477579369`20., 
    2264.947269230739846772858117465517231258`20., 
    2266.2443203594938309276358270591344641631`20., 
    2267.54024719067982461459041804097140092356`20., 
    2268.83504846492628195449042084178215759751`20., 
    2270.12872292244879305083899529081659869102`20., 
    2271.42126930305005753969006580765203839353`20., 
    2272.71268634611986870283735874809261854916`20., 
    2274.00297279063510817891713397486407613075`20., 
    2275.29212737515975130725954889319636776021`20., 
    2276.58014883784488313961740155257491685295`20., 
    2277.8670359164287251551944722264056792198`20., 
    2279.15278734823667271468882223839854731333`20., 
    2280.43740187018134328935921664546857353858`20., 
    2281.72087821876263550141531548938209581809`20., 
    2283.00321513006779901232442831100196984199`20., 
    2284.28441133977151529591944993994244699098`20., 
    2285.56446558313598933348409352729544109678`20., 
    2286.84337659501105226828271051889106019539`20., 
    2288.12114310983427505729283775088498941425`20., 
    2289.39776386163109315818913990844164997743`20., 
    2290.673237584014942289917621882558892561`20., 
    2291.94756301018740530548887059082672535446`20., 
    2293.2207388729383702159086499367747058678`20., 
    2294.49276390464619940445341595150584267163`20., 
    2295.76363683727791007078724181295170374129`20., 
    2297.03335640238936594470524423498297521698`20., 
    2298.30192133112548030957688336359120767424`20., 
    2299.5693303542204303758504673532671376821`20., 
    2300.83558220199788304526782960627343238711`20., 
    2302.10067560437123210672546046321332240437`20., 
    2303.36460929084384690500536499716357856133`20., 
    2304.62738199050933252388558338708154285725`20., 
    2305.88899243205180152542664886980095595948`20., 
    2307.14943934374615728751626907325345313795`20., 
    2308.40872145345838898204019803487974350954`20., 
    2309.66683748864587823633261666530557681659`20., 
    2310.92378617635771752084435692326510166975`20., 
    2312.17956624323504030625198745643270302562`20., 
    2313.43417641551136303351512370492560600492`20., 
    2314.68761541901293894067333106779392048133`20., 
    2315.93988197915912379045765314291998327893`20., 
    2317.19097482096275354307511554924497703171`20., 
    2318.44089266903053401880752654537303998874`20., 
    2319.68963424756344259534851552467162800769`20., 
    2320.93719828035714198508501628398437216426`20., 
    2322.18358349080240613781131035630934863762`20., 
    2323.42878860188555831464529312751263703695`20., 
    2324.67281233618892137919780821811717933662`20., 
    2325.91565341589128035232670983232481703564`20., 
    2327.15731056276835727708775442028859737353`20., 
    2328.39778249819329844077448786211267485727`20., 
    2329.63706794313717400121897809179906626693`20., 
    2330.87516561816949006480454109743024146424`20., 
    2332.1120742434587132639205158532188465902`20., 
    2333.34779253877280788186765608403691357482`20., 
    2334.58231922347978557350081878895626344735`20., 
    2335.8156530165482677301733359429241333319`20., 
    2337.04779263654806053782475137062451657839`20., 
    2338.27873680165074277733048388890543580939`20., 
    2339.50848422963026641650843471783380751012`20., 
    2340.73703363786357004345358596776229378742`20., 
    2341.96438374333120519114723165083931504611`20., 
    2343.19053326261797560356263689748289232612`20., 
    2344.41548091191358949376362846545919225086`20., 
    2345.63922540701332484476687362143919318971`20., 
    2346.86176546331870780421239828784233711971`20., 
    2348.08309979583820422416022204192067905031`20., 
    2349.30322711918792439760384001421038138404`20., 
    2350.52214614759234104356365266820223537904`20., 
    2351.739855594885020592895326383965692089`20., 
    2352.95635417450936782721945306956570197784`20., 
    2354.17164059951938392364975786132411736814`20., 
    2355.38571358258043795826747234436273022858`20., 
    2356.59857183597005192155933844601700511481`20., 
    2357.81021407157869929930602686409280033963`20., 
    2359.02063900091061727267653504622272865381`20., 
    2360.2298453350846325915523646109670927868`20., 
    2361.43783178483500117537295778885254719514`20., 
    2362.64459706051226149606098787247267722519`20., 
    2363.8501398720841017978526405257852393667`20., 
    2365.05445892913624120912398165630173917596`20., 
    2366.25755294087332480156987375751538044647`20., 
    2367.45942061611983265235666635454847795133`20., 
    2368.66006066332100296513403741915323591573`20., 
    2369.85947179054376930605489115931760308024`20., 
    2371.05765270547771201121511304444219905965`20., 
    2372.25460211543602382218723472144586476384`20., 
    2373.4503187273564898065836588430158327572`20., 
    2374.64480124780248162084602580929672485019`20., 
    2375.83804838296396617271755987057621671002`20., 
    2377.03005883865852874111479961139738882986`20., 
    2378.22083132033241061137398600412925097324`20., 
    2379.41036453306156128410553825741174744413`20., 
    2380.59865718155270531614748167327861641683`20., 
    2381.78570797014442385236539055276198122109`20., 
    2382.97151560280825090730236054462357150779`20., 
    2384.15607878314978445593771621060203536625`20., 
    2385.33939621440981239306757828132918852201`20., 
    2386.52146659946545342107404820023132143572`20., 
    2387.70228864083131292610260200015152904679`20., 
    2388.88186104066065390291930803164532009467`20., 
    2390.06018250074658298897068006534199659598`20., 
    2391.23725172252325166841933512494584856297`20., 
    2392.41306740706707270717813017218113018029`20., 
    2393.5876282550979518802140893575577361175`20., 
    2394.76093296698053505264118966522855918852`20., 
    2395.93298024272547067636793290628069047624`20., 
    2397.10376878199068776431158143747761889921`20., 
    2398.27329728408268940443595878093755393801`20., 
    2399.44156444795786187611379936713621084129`20., 
    2400.6085689722237994315577585842462164472`20., 
    2401.77430955514064480530634964828746854436`20., 
    2402.93878489462244551499224175900257044902`20., 
    2404.10199368823852601686051861413852114094`20., 
    2405.26393463321487577974364144765936002184`20., 
    2406.42460642643555334143796995167249821034`20., 
    2407.58400776444410641166375114164116887568`20., 
    2408.74213734344500808602647362086371105578`20., 
    2409.89899385930510923563238577047597817128`20., 
    2411.05457600755510713724477389797995290192`20., 
    2412.20888248339103040910027286767333825927`20., 
    2413.36191198167574031773601954125180938334`20., 
    2414.51366319694044852140884059012343081274`20., 
    2415.66413482338625131591687279860529154402`20., 
    2416.81332555488568044886202753650768159395`20., 
    2417.96123408498427056861851309854929198725`20., 
    2419.10785910690214337449820032425224027324`20., 
    2420.25319931353560853482793934208125668204`20., 
    2421.39725339745878143987698922045547376762`20., 
    2422.54002005092521785679448832812852902187`20., 
    2423.68149796586956555393735165619763898091`20., 
    2424.82168583390923296218811235842964697354`20., 
    2425.96058234634607494108000822554954530903`20., 
    2427.0981861941680957177630293968348862872`20., 
    2428.23449606805116906705967077659453286389`20., 
    2429.36951065836077580107275058451538170324`20., 
    2430.50322865515375863701984422016098538095`20., 
    2431.63564874818009451217961892718026820997`20., 
    2432.76676962688468441504461813673385658498`20., 
    2433.89658998040916080198281315686844941009`20., 
    2435.02510849759371266891649212884440901624`20., 
    2436.15232386697892834773176973499599660693`20., 
    2437.27823477680765609733515362559208829886`20., 
    2438.40283991502688255947517231145468128886`20., 
    2439.52613796928962914964703148825642596708`20., 
    2440.64812762695686645359659832663885802648`20., 
    2441.76880757509944670013669285379272830913`20., 
    2442.88817650050005438118366860552484436672`20., 
    2444.0062330896551750901155674454385126114`20., 
    2445.12297602877708264974471179510609394552`20., 
    2446.23840400379584460138742722390544877882`20., 
    2447.35251570036134612670164489926607946619`20., 
    2448.46530980384533247414939204840306898754`20., 
    2449.57678499934346996212561434282815010076`20., 
    2450.68693997167742563097736175869710810944`20., 
    2451.79577340539696561631808352054847862495`20., 
    2452.90328398478207231622059249330558497375`20., 
    2454.00947039384508042504914889602979443934`20., 
    2455.11433131633283190686605127715377807479`20., 
    2456.21786543572884998152108287844539546285`20., 
    2457.32007143525553219670311714423555471401`20., 
    2458.42094799787636265940211028030021134655`20., 
    2459.5204938062981435003965742658877254065`20., 
    2460.61870754297324564554640316079431015726`20., 
    2461.71558789010187896783359127012914494847`20., 
    2462.81113352963438189425390583001496277856`20., 
    2463.90534314327353054182093120958597063329`20., 
    2464.99821541247686745710005779363115443944`20., 
    2466.08974901845905003384391807477887939923`20., 
    2467.17994264219421868345244615589137588427`20., 
    2468.26879496441838483313012570662686359537`20., 
    2469.35630466563183882676006604952791705407`20., 
    2470.44247042610157780365927683910023199949`20., 
    2471.52729092586375363052186886246037523538`20., 
    2472.61076484472614096199686170400293258631`20., 
    2473.69289086227062550548479800211324014827`20., 
    2474.77366765785571256587241815714996988724`20., 
    2475.85309391061905594605720775142803300648`20., 
    2476.93116829948000727924366148901632084567`20., 
    2478.00788950314218586912058078151951918404`20., 
    2479.08325620009606911415360557161562456246`20., 
    2480.15726706862160359234944272511660845301`20., 
    2481.22992078679083688296786121093094974488`20., 
    2482.30121603247057020177444595276366238861`20., 
    2483.37115148332503192654130505288621694738`20., 
    2484.43972581681857208961437618298467903`20., 
    2485.50693771021837791447464418604009812588`20., 
    2486.57278584059721047332642996248472940207`20., 
    2487.63726888483616254284890689962711325739`20., 
    2488.70038551962743773534711157179166636733`20., 
    2489.76213442147715098263590606625752039663`20., 
    2490.82251426670815045008458570377068222265`20., 
    2491.88152373146286095834107349955627130764`20., 
    2492.93916149170614899034286657953417157989`20., 
    2493.99542622322820936130706480597645884579`20., 
    2495.05031660164747362947388270750504300813`20., 
    2496.10383130241354032545698683199830347033`20., 
    2497.15596900081012707812977598137946382694`20., 
    2498.20672837195804471504929533030792071531`20., 
    2499.25610809081819341548881081496882223433`20., 
    2500.3041068321945809942161307949215304412`20., 
    2501.35072327073736339421751098522293593126`20., 
    2502.39595608094590746662637892659962328878`20., 
    2503.43980393717187611617212846154704674851`20., 
    2504.48226551362233589051682522210839929763`20., 
    2505.52333948436288709189679317452233843051`20., 
    2506.56302452332081648953168172690803150342`20., 
    2507.60131930428827271130570446550692981201`20., 
    2508.63822250092546439326425567709579279472`20., 
    2509.67373278676388116550401063267436750538`20., 
    2510.70784883520953755306586110211211107828`20., 
    2511.74056931954623987046758945266919260355`20., 
    2512.77189291293887618853700342845450508455`20., 
    2513.80181828843672945222629954681383628287`20., 
    2514.83034411897681382810465597775059443397`20., 
    2515.85746907738723436023843555366734838663`20., 
    2516.8831918363905700131768657133918778816`20., 
    2517.90751106860728018076561400660102356253`20., 
    2518.93042544655913473951125432903440896452`20., 
    2519.95193364267266772521617914976658486852`20., 
    2520.97203432928265471159601522274919486975`20., 
    2521.99072617863561396958000300954581016848`20., 
    2523.0080078628933314859790614138719473145`20., 
    2524.02387805413640992018633734926667640619`20., 
    2525.03833542436784157755089181120770089297`20., 
    2526.05137864551660547803675796210955804604`20., 
    2527.06300638944128859874687949687121848638`20., 
    2528.07321732793373136885435625152410932516`20., 
    2529.0820101327226974954419454417985983012`20., 
    2530.08938347547756819870484764757963768184`20., 
    2531.09533602781206093492140305220731871773`20., 
    2532.09986646128797268554139164650076370943`20., 
    2533.10297344741894789068212704727572681504`20., 
    2534.10465565767427110525841297876461039403`20., 
    2535.10491176348268445590364983312869960576`20., 
    2536.1037404362362299767658913661180939472`20., 
    2537.10114034729411690218441359335406245992`20., 
    2538.09711016798661399416932422571369982046`20., 
    2539.09164856961896698251886621157591056049`20., 
    2540.08475422347534119531630763273322669566`20., 
    2541.07642580082278945745061662608837583534`20., 
    2542.06666197291524533470244827661400887109`20., 
    2543.05546141099754180082927445783054646661`20., 
    2544.04282278630945540497072110359939720596`20., 
    2545.02874477008977601657729391110323257537`20., 
    2546.01322603358040222494262634617692335669`20., 
    2546.99626524803046247029112621282887189446`20., 
    2547.97786108470046198323938194312507247262`20., 
    2548.95801221486645560931086996866171999457`20., 
    2549.93671730982424659503933268323281518638`20., 
    2550.9139750408936114120466250589685962445`20., 
    2551.88978407942255069532580922737361914553`20., 
    2552.86414309679156637179976240870105854265`20., 
    2553.83705076441796505505950643151854344987`20., 
    2554.80850575376018778201481853296715789274`20., 
    2555.7785067363221661670123948163083942818`20., 
    2556.74705238365770504879386115972593916122`20., 
    2557.71414136737489170547721286272370183403`20., 
    2558.67977235914053171255076508080102771487`20., 
    2559.64394403068461151866836218900966560488`20., 
    2560.60665505380478781382837654426825302418`20., 
    2561.56790410037090376430687646239565879228`20., 
    2562.52768984232953218849721023352537223182`20., 
    2563.48601095170854574758408818471720977978`20., 
    2564.44286610062171422474999855184134459853`20., 
    2565.39825396127332896637541551348740229406`20., 
    2566.35217320596285455845169931965010279909`20., 
    2567.30462250708960781117679905575105653017`20., 
    2568.25560053715746412444879814732378600681`20., 
    2569.20510596877959130671094105637827000761`20., 
    2570.15313747468321091933399647007564373719`20., 
    2571.0996937277143872184475972622322734651`20., 
    2572.04477340084284376585150015241494825102`20., 
    2572.98837516716680778035047774225736434143`20., 
    2573.93049769991788230056274183712920524324`20., 
    2574.87113967246594622995134894778642951203`20., 
    2575.81029975832408233452090582154778671651`20., 
    2576.74797663115353326330802391714442278974`20., 
    2577.68416896476868566147331598865232122794`20., 
    2578.61887543314208244547523439947443017205`20., 
    2579.55209471040946330947166841051268644615`20., 
    2580.48382547087483353175389539158580394119`20., 
    2581.41406638901556114966916756193566487878`20., 
    2582.34281613948750257113286030573956466001`20., 
    2583.2700733971301566904686591299800754046`20., 
    2584.19583683697184757594566870500296695941`20., 
    2585.12010513423493579600453790045415072183`20., 
    2586.04287696434105845078065803214854528856`20., 
    2586.96415100291639797514115638890508405292`20., 
    2587.88392592579697977905372222740335064445`20., 
    2588.80220040903399879069921652329468880861`20., 
    2589.71897312889917496732647857042774282315`20., 
    2590.63424276189013783842670076216811829228`20., 
    2591.54800798473584014537614632335792596794`20., 
    2592.46026747440200064125978216759031792893`20., 
    2593.37101990809657611414453924279015225272`20., 
    2594.28026396327526269661934454715950453676`20., 
    2595.18799831764702652395974134039893558741`20., 
    2596.09422164917966380280777588587278283304`20., 
    2596.99893263610539035178282933996954377327`20., 
    2597.90212995692646067495616122184174379759`20., 
    2598.80381229042081662863105538802286906444`20., 
    2599.70397831564776574137156981863840181081`20., 
    2600.60262671195368924671593709716497858245`20., 
    2601.49975615897777988749559262882469437073`20., 
    2602.39536533665780955015757188865394580431`20., 
    2603.28945292523592678695656592139936870024`20., 
    2604.18201760526448428334320564889584813318`20., 
    2605.07305805761189632732711011615411937498`20., 
    2605.96257296346852633703683159482301506759`20., 
    2606.85056100435260450213401156966146269747`20., 
    2607.73702086211617559416577631355352754844`20., 
    2608.6219512189510770003575994165029613313`20., 
    2609.50535075739494703475849184276007646314`20., 
    2610.38721816033726358005139858645152558305`20., 
    2611.26755211102541311273403569661689699073`20., 
    2612.14635129307079016375904345068968587983`20., 
    2613.02361439045492726609721206939231171361`20., 
    2613.89934008753565544005360708739826639323`20., 
    2614.77352706905329526652363403669683352056`20., 
    2615.64617402013687859772438839795838178077`20., 
    2616.51727962631040095427598899359357526421`20., 
    2617.38684257349910465683794353748864959529`20., 
    2618.25486154803579273982689657108562649928`20., 
    2619.1213352366671736940543154108442354365`20., 
    2619.98626232656023708442573218146718268248`20., 
    2620.84964150530866008813703296123396066888`20., 
    2621.7114714609392449980879222537902847308`20., 
    2622.57175088191838773550804645250940304823`20., 
    2623.43047845715857741505728801074650492627`20., 
    2624.2876528760249270049183973192855218164`20., 
    2625.14327282834173512364736678986296114267`20., 
    2625.9973370043990790147847266531036332138`20., 
    2626.84984409495943873945921014622477562353`20., 
    2627.70079279126435262643395308973692899192`20., 
    2628.55018178504110401825451569616521511286`20., 
    2629.39800976850943935135749955472014480232`20., 
    2630.24427543438831760718833721558127250414`20., 
    2631.08897747590269117055691317278404743224`20., 
    2631.93211458679031813062999123804253766464`20., 
    2632.77368546130860605911993264798715055913`20., 
    2633.61368879424148729937985052020787591088`20., 
    2634.4521232809063257992561186732031812367`20., 
    2635.28898761716085551967999600494568180704`20., 
    2636.12428049941015045010100169755240507223`20., 
    2636.95800062461362626097554206610234715594`20., 
    2637.79014669029207362262510796521835900761`20., 
    2638.62071739453472321886909386886878158862`20., 
    2639.44971143600634248291789811366219816783`20., 
    2640.2771275139543640820824109274527596133`20., 
    2641.10296432821604617691624586577345648114`20., 
    2641.92722057922566447945708480132657538986`20., 
    2642.74989496802173613427325086160080725319`20., 
    2643.5709861962542754450510624559535798171`20., 
    2644.39049296619208146847762012169259218998`20., 
    2645.20841398073005749618240228260782175059`20., 
    2646.02474794339656244449936268732690807578`20., 
    2646.83949355836079417079909842583751238571`20., 
    2647.65264953044020473411806078270824726835`20., 
    2648.46421456510794761677868018468267241697`20., 
    2649.27418736850035692265064019825613649157`20., 
    2650.08256664742445856664933365212234542834`20., 
    2650.88935110936551346900273689795266449961`20., 
    2651.69453946249459276674251706698615024775`20., 
    2652.49813041567618505378911371654056305015`20., 
    2653.30012267847583565990378299095498647264`20., 
    2654.10051496116781797767313257377797841895`20., 
    2654.89930597474283684557348325042797408035`20., 
    2655.69649443091576399403344255451597502186`20., 
    2656.49207904213340556027334322444632473829`20., 
    2657.28605852158230167654966031749128295183`20., 
    2658.07843158319655813527115287712036494018`20., 
    2658.86919694166571013328125689341632178298`20., 
    2659.65835331244261809641816462351297738052`20., 
    2660.44589941175139558427004067044368794511`20., 
    2661.23183395659536927383792792325095928054`20., 
    2662.0161556647650710196030677684090592326`20., 
    2662.7988632548462619862685809971318813221`20., 
    2663.57995544622798884920771154824096341325`20., 
    2664.35943095911067205640210853779395818143`20., 
    2665.13728851451422614439389774699074860106`20., 
    2665.91352683428621209950455761188556730465`20., 
    2666.6881446411100217542918534696349543579`20., 
    2667.46114065851309420792328501260290992559`20., 
    2668.23251361087516425784065420268974529525`20., 
    2669.002262223436542828775453909884827904`20., 
    2669.77038522230642938384880186872504058798`20., 
    2670.53688133447125630115259181715083599813`20., 
    2671.30174928780306519786039654722967542723`20., 
    2672.06498781106791518255742975373834242336`20., 
    2672.82659563393432301510854977078733551792`20., 
    2673.5865714869817351520018643678585574917`20., 
    2674.34491410170903165371296865181938773874`20., 
    2675.10162221054306192923121580987305109505`20., 
    2675.85669454684721229147468206594136744986`20., 
    2676.61012984493000529589464307688444749623`20., 
    2677.36192684005373083313343047836269514428`20., 
    2678.11208426844310894515148697665501365487`20., 
    2678.86060086729398433278029002110179195019`20., 
    2679.60747537478205252118757262054434622879`20., 
    2680.35270653007161764825994142910609049357`20., 
    2681.09629307332438183941558418391046157685`20., 
    2681.83823374570826613085627952561830422679`20., 
    2682.578527289406262901753382016186899898`20., 
    2683.31717244762531977433686489430825393398`20., 
    2684.05416796460525493931987516266658043728`20., 
    2684.78951258562770386254360366001430697745`20., 
    2685.52320505702509732716861181977688905144`20., 
    2686.25524412618967076416910316191298703494`20., 
    2686.98562854158250482230599884895264300863`20., 
    2687.71435705274259712716309185443199785027`20., 
    2688.44142841029596517722803380191021561942`20., 
    2689.16684136596478032338647407519695826209`20., 
    2689.89059467257653277657334550993128087731`20., 
    2690.61268708407322758669009939714554219936`20., 
    2691.33311735552061153425066062864119264835`20., 
    2692.05188424311743087456202899788491882187`20., 
    2692.76898650420471987257782379737633056262`20., 
    2693.48442289727512006488468624977424093477`20., 
    2694.19819218198223018359234978261628547413`20., 
    2694.91029311914998667519839500800834883972`20., 
    2695.62072447078207474578825931186438602804`20., 
    2696.32948500007136986221000652886301882513`20., 
    2697.03657347140940963713171815412813010915`20., 
    2697.74198865039589602414718334780161368432`20., 
    2698.44572930384822774734288161738256800559`20., 
    2699.14779419981106288797611208823879360766`20., 
    2699.84818210756591154914057086220682136235`20., 
    2700.5468917976407585175117588924491163074`20., 
    2701.24392204181971583947036446575633180125`20., 
    2701.93927161315270522709725581211713010412`20., 
    2702.63293928596517020771899123476950330978`20., 
    2703.32492383586781792885785881290121113782`20., 
    2704.01522403976639052860544918942208059548`20., 
    2704.70383867587146597959369892162388553847`20., 
    2705.39076652370828831288227574806113248216`20., 
    2706.07600636412662712621617002970399689683`20., 
    2706.75955697931066627923246940331684428682`20., 
    2707.4414171527889216763105889256903956554`20., 
    2708.12158566944418803586577102656295538951`20., 
    2708.80006131552351454298152452817410149431`20., 
    2709.47684287864820928036290770967676037704`20., 
    2710.15192914782387233066924656342741094712`20., 
    2710.82531891345045744135208747688947226385`20., 
    2711.49701096733236214118198686086502106204`20., 
    2712.16700410268854619569621383899534721512`20., 
    2712.83529711416267828683866295810291670612`20., 
    2713.50188879783331080009332076470708935845`20., 
    2714.16677795122408260043358366942277631653`20., 
    2714.8299633733139496764216673072367612069`20., 
    2715.49144386454744352979536399779900272962`20., 
    2716.15121822684495718587358120714068842813`20., 
    2716.80928526361305869809751830371895122593`20., 
    2717.4656437797548320180011014925645277322`20., 
    2718.12029258168024509987248962892736291471`20., 
    2718.77323047731654510732818061659171262713`20., 
    2719.4244562761186805869725851871164271967`20., 
    2720.07396878907975047225898988698965114156`20., 
    2720.72176682874147977860270388284255582423`20., 
    2721.36784920920472184872397651266057506195`20., 
    2722.01221474613998700511708812380730788115`20., 
    2722.65486225679799746445296139385657325939`20., 
    2723.29579056002026836662582177001742020895`20., 
    2723.93499847624971476904996363278796545914`20., 
    2724.57248482754128445470066504579885072149`20., 
    2725.20824843757261640027385227153339951443`20., 
    2725.84228813165472474871236141247692913648`20., 
    2726.47460273674270812821269641282833261673`20., 
    2727.1051910814464841576851601003741896818`20., 
    2727.73405199604154897649225988072482315453`20., 
    2728.36118431247976163413548608835987065285`20., 
    2728.98658686440015317339905488052560113309`20., 
    2729.61025848713976023829112702446189587873`20., 
    2730.23219801774448303594848913832266570395`20., 
    2730.85240429497996747948984713822763875239`20., 
    2731.47087615934251133661586713371800141198`20., 
    2732.08761245306999420656104320028020760712`20., 
    2732.70261202015283114580351282664400899727`20., 
    2733.31587370634494976073421996338688320896`20., 
    2733.92739635917479058327648515957933626952`20., 
    2734.53717882795633054323122703491303636403`20., 
    2735.14521996380012934890193616537190647494`20., 
    2735.75151861962439858532718033310889625458`20., 
    2736.35607365016609333721707008256213691792`20., 
    2736.95888391199202614145388881816091540401`20., 
    2737.55994826351000307177614756512753163849`20., 
    2738.15926556497998175601981839343880116029`20., 
    2738.75683467852525112404059188478583124103`20., 
    2739.35265446814363268218685452163351260153`20., 
    2739.94672379971870310793485522377958726921`20., 
    2740.53904154103103795603539228740383074362`20., 
    2741.12960656176947626525547063848629205625`20., 
    2741.71841773354240585252892464705427627799`20., 
    2742.30547392988906907905714591601204575133`20., 
    2742.89077402629088887062497271579130749616`20., 
    2743.47431690018281477211766444108085867106`20., 
    2744.05610143096468881394287907266292483265`20., 
    2744.63612650001263096577687468355371675068`20., 
    2745.21439099069044395076695017145189945417`20., 
    2745.79089378836103719103261035147091127376`20., 
    2746.36563378039786965301627310736666923688`20., 
    2746.93860985619641135894072035446577052792`20., 
    2747.50982090718562332833512106152528747241`20., 
    2748.07926582683945571129451652379789557716`20., 
    2748.64694351068836387283935054480279452982`20., 
    2749.21285285633084218544214728907595040304`20., 
    2749.77699276344497528448798647459575046194`20., 
    2750.33936213380000653913420047857154789397`20., 
    2750.89995987126792348873292405717937951968`20., 
    2751.45878488183505999267796996950662343364`20., 
    2752.01583607361371483923519009747827491061`20., 
    2752.57111235685378655661322091426290076196`20., 
    2753.12461264395442416722951560896514925072`20., 
    2753.67633584947569362382504603782482876241`20., 
    2754.22628089015025966378023111999722538605`20., 
    2754.77444668489508281568473146160026691031`20., 
    2755.3208321548231312899149619490277788361`20., 
    2755.86543622325510748267573580426521156309`20., 
    2756.4082578157311888206665880592300762897`20., 
    2756.94929586002278267123925840263241331926`20., 
    2757.48854928614429504062076958825462893722`20., 
    2758.02601702636491278048674664679667524439`20., 
    2758.56169801522039902088231445013974173605`20., 
    2759.09559118952490154520331901337890939981`20., 
    2759.62769548838277382066897538677571884966`20., 
    2760.15800985320040839543858799451695169561`20., 
    2760.68653322769808237124995551698132608011`20., 
    2761.21326455792181465818570135662256333909`20., 
    2761.73820279225523471590630359576055290893`20., 
    2762.26134688143146248342527810215065692501`20., 
    2762.78269577854499919724303973343700548687`20., 
    2763.30224843906362879540167579605273348965`20., 
    2763.8200038208403296027734610617775026507`20., 
    2764.33596088412519599065167442092177196879`20., 
    2764.85011859157736970147339496884120512336`20., 
    2765.36247590827698052727071290242740156761`20., 
    2765.87303180173709602821944254884573342996`20., 
    2766.3817852419156799754332272231141701167`20., 
    2766.88873520122755919993613601243975491331`20., 
    2767.39388065455639852753873012231274390919`20., 
    2767.897220579266683477141381686031613827`20., 
    2768.39875395521571039779462298853418545727`20., 
    2768.89847976476558371765975237266300697367`20., 
    2769.39639699279521997583408957230595946458`20., 
    2769.89250462671235830583442412105760425982`20., 
    2770.38680165646557703736960343556272562228`20., 
    2770.87928707455631608087913110873461794684`20., 
    2771.36995987605090475716936110020113193782`20., 
    2771.85881905859259473234265137170240910235`20., 
    2772.34586362241359771608795380678171073956`20., 
    2772.83109257034712757928403989988438867142`20., 
    2773.31450490783944654475916879104424634144`20., 
    2773.79609964296191510295377198583411700092`20., 
    2774.27587578642304530214593486655735121462`20., 
    2774.75383235158055706082337727000673432156`20., 
    2775.22996835445343714772055341573253229123`20., 
    2775.70428281373400047298568575435192693437`20., 
    2776.17677475079995333190029927216929985881`20., 
    2776.64744318972645824054341477130091648895`20., 
    2777.11628715729820000077427487336965010275`20., 
    2777.58330568302145262990159905743450273632`20., 
    2778.04849779913614678841417884768862201771`20., 
    2778.51186254062793733716741700510118837548`20., 
    2778.9733989452402706534534716857062880649`20., 
    2779.43310605348645133342927514848628571147`20., 
    2779.89098290866170790643714453587297578401`20., 
    2780.34702855685525718482727794422582050982`20., 
    2780.80124204696236687098042147048307296815`20., 
    2781.25362243069641604133269172953754729082`20., 
    2781.70416876260095312532323355300459470728`20., 
    2782.15288010006175099531937473330827924541`20., 
    2782.59975550331885878172349971534237548888`20., 
    2783.04479403547865002563129338473456569031`20., 
    2783.48799476252586677959259621214757395467`20., 
    2783.92935675333565926522415492998916525854`20., 
    2784.36887907968562069463834082736444065205`20., 
    2784.80656081626781686088373303506428647338`20., 
    2785.24240104070081010084261937121082379122`20., 
    2785.67639883354167723229724507256091691556`20., 
    2786.10855327829802106516133274886012208859`20., 
    2786.53886346143997508517629788325552125649`20., 
    2786.96732847241220090669298584110841265339`20., 
    2787.39394740364587808949995124043430816836`20., 
    2787.81871935057068591301858114644059369781`20., 
    2788.24164341162677669956402216717719796371`20., 
    2788.66271868827674027676920020499591143868`20., 
    2789.08194428501755916768751213836816199286`20., 
    2789.49931930939255409552831252078247787189`20., 
    2789.91484287200331938843840655866806874005`20., 
    2790.32851408652164786822268380898548078473`20., 
    2790.74033206970144480539807537807530505565`20., 
    2791.15029594139063052149748053202371884899`20., 
    2791.5584048245430312180844755852565339648`20., 
    2791.96465784523025761050577712054408738796`20., 
    2792.36905413265357094299687072168750083809`20., 
    2792.77159281915573596036722243768143591221`20., 
    2793.17227304023286041012534931465946731672`20., 
    2793.57109393454622064756102284888849896041`20., 
    2793.96805464393407291498229954472580872933`20., 
    2794.36315431342344986500919936034973477221`20., 
    2794.75639209124194189655396813136424665735`20., 
    2795.14776712882946287087024544874079568712`20., 
    2795.53727858084999977383039517890527443973`20., 
    2795.92492560520334588939202091565362914861`20., 
    2796.31070736303681704804156097533993587647`20., 
    2796.69462301875695051285511362549932432172`20., 
    2797.07667174004118606469455826122156426486`20., 
    2797.45685269784952884696088599652158256545`20., 
    2797.83516506643619352925670594112021613241`20., 
    2798.21160802336122934826642208908471272425`20., 
    2798.58618074950212558314584948135956085004`20., 
    2798.95888242906539702172332471276086338727`20., 
    2799.32971224959814897285193083820752864965`20., 
    2799.69866940199962137931756444718624139935`20., 
    2800.06575308053271158480048546798864820314`20., 
    2800.4309624828354753075089686184772861279`20., 
    2800.79429680993260537225297790048492530359`20., 
    2801.15575526624688775190366872291413001987`20., 
    2801.51533705961063446839124067855082618813`20., 
    2801.87304140127709290262947013958537653011`20., 
    2802.22886750593183106202039597031041976246`20., 
    2802.58281459170409835348736186301576351894`20., 
    2802.93488188017816140930918089409938129802`20., 
    2803.28506859640461451238282535169398322341`20., 
    2803.63337396891166416692699879564034803521`20., 
    2803.97979722971638736005445632122161885978`20., 
    2804.32433761433596305908723925106780608344`20., 
    2804.66699436179887648896631555374899740054`20., 
    2805.00776671465609573361569814068970039795`20., 
    2805.34665391899222020466117810416170969402`20., 
    2805.68365522443660052047558447039564104357`20., 
    2806.01876988417442933812618890071533897062`20., 
    2806.35199715495780268043573287500944943197`20., 
    2806.68333629711675130003678322072426586712`20., 
    2807.01278657457024162199993342432177417703`20., 
    2807.34034725483714580634997397348618579246`20., 
    2807.66601760904718047155076293816481752619`20., 
    2807.98979691195181361983934287901455547244`20., 
    2808.31168444193513930512307354991568190558`20., 
    2808.63167948102471958402038006214193630447`20., 
    2808.94978131490239329052634821894356529543`20., 
    2809.2659892329150511747190242644224023046`20., 
    2809.58030252808537694589108355410475623866`20., 
    2809.89272049712255376049470640646817000696`20., 
    2810.20324244043293569532522086529701837831`20., 
    2810.51186766213068374644151893849609437695`20., 
    2810.8185954700483658944285990879223612337`20., 
    2811.12342517574752077675000364274529195674`20., 
    2811.42635609452918450811557196597577542233`20., 
    2811.7273875454443801900029813915137614515`20., 
    2812.02651885130456965072015708734612332662`20., 
    2812.32374933869206695767995410574699054852`20., 
    2812.61907833797041324387870101448581500153`20., 
    2812.91250518329471239092639171847234193125`20., 
    2813.20402921262192711136866337585997387937`20., 
    2813.49364976772113497346934257556781873862`20., 
    2813.78136619418374391208741390617272117185`20., 
    2814.06717784143366676978389523418861731423`20., 
    2814.35108406273745441283241869258020423652`20., 
    2814.63308421521438696738243752423007422342`20., 
    2814.91317765984652272163602414537973513512`20., 
    2815.19136376148870424054830730841642792029`20., 
    2815.46764188887852124024782482538780470051`20., 
    2815.74201141464622977009654724728699121852`20., 
    2816.01447171532462725107015692889070513458`20., 
    2816.28502217135888291993744121535107430493`20., 
    2816.55366216711632322955346861302686298211`20., 
    2816.82039109089617175645464863610366650644`20., 
    2817.08520833493924316785491072788505138696`20., 
    2817.34811329543759080109115166790184589839`20., 
    2817.60910537254410740955286583037667760295`20., 
    2817.86818397038207863015555536394061482901`20., 
    2818.12534849705468872848017975624071089571`20., 
    2818.38059836465447817880160336289949546176`20., 
    2818.63393298927275263736778740671037698397`20., 
    2818.88535179100894286846839679769269127768`20., 
    2819.13485419397991518404659397882026472164`20., 
    2819.38243962632923195886110890551667987533`20., 
    2819.62810752023636178449723817349065335655`20., 
    2819.87185731192583882685526405461293978923`20., 
    2820.11368844167637095311291746886576844137`20., 
    2820.35360035382989619556495421428320920366`20., 
    2820.59159249680058712118768238603789694327`20., 
    2820.82766432308380267725937688822902413125`20., 
    2821.06181528926498708488894505487323365294`20., 
    2821.29404485602851535386496112958083214337`20., 
    2821.52435248816648499383525686152674520247`20., 
    2821.75273765458745349846362556386483771752`20., 
    2821.97919982832512118088484708065320986842`20., 
    2822.2037384865469589404921452529050924689`20., 
    2822.42635311056278054284231627670686992034`20., 
    2822.64704318583325899625307897818628283222`20., 
    2822.86580820197838661049465420153496237575`20., 
    2823.08264765278587832484313244651229246351`20., 
    2823.29756103621951789466678333118026110333`20., 
    2823.51054785442744652765803860843604298517`20., 
    2823.72160761375039356280337801384614333402`20., 
    2823.93073982472984878720069430345761176408`20., 
    2824.13794400211617598788883502966433759152`20., 
    2824.3432196648766673379468329042543388896`20., 
    2824.54656633620353821825075742998110378156`20., 
    2824.74798354352186207844405567087590863699`20., 
    2824.94747081849744494288260179952663781283`20., 
    2825.14502769704463916955834001836898388462`20., 
    2825.340653719334096072285274595942175263`20., 
    2825.53434842980045701874851945952127375208`20., 
    2825.7261113771499826193710477870150108472`20., 
    2825.91594211436811962434355345798666030909`20., 
    2826.10384019872700514859031953883744448749`20., 
    2826.2898051917929078469080470410198906249`20., 
    2826.47383665943360566401508722246247577233`20., 
    2826.65593417182569978678529429037158701738`20., 
    2826.8360973034618644285136184709441380942`20., 
    2827.01432563315803207766943237894660886818`20., 
    2827.19061874406051384623826117191636740277`20., 
    2827.36497622365305455543289822484151170195`20., 
    2827.53739766376382219927065652531367838018`20., 
    2827.70788266057233142926454958836046255218`20., 
    2827.87643081461630070626232676554066547715`20., 
    2828.04304173079844276828831314660249590954`20., 
    2828.20771501839318806609872504063261440107`20., 
    2828.37045029105334082105134395271722256892`20., 
    2828.53124716681666736281492519210590229263`20., 
    2828.69010526811241640740227640113683010427`20., 
    2828.84702422176777093900334553362267615489`20., 
    2829.0020036590142313621206808200627155345`20., 
    2829.15504321549392959356903526918172010638`20., 
    2829.30614253126587376699344807863211978977`20., 
    2829.45530125081212322568560236703688111055`20., 
    2829.60251902304389348263638492164094262643`20., 
    2829.74779550130759082995310585551440412473`20., 
    2829.89113034339077628299251553587039300517`20., 
    2830.03252321152805854781531893521938813409`20., 
    2830.17197377240691570385406445859855583061`20., 
    2830.30948169717344529700380086729388894714`20., 
    2830.44504666143804254169347250463753671641`20., 
    2830.57866834528100633387537481675235314906`20., 
    2830.71034643325807278027982920154777332962`20., 
    2830.84008061440587595272226346705899947178`20., 
    2830.96787058224733557971980153034501589386`20., 
    2831.09371603479697139117396831518400506456`20., 
    2831.21761667456614383540489300493340051171`20., 
    2831.33957220856822089138013083129723248983`20., 
    2831.45958234832367070256760048896230062707`20., 
    2831.57764680986507976245682626592030759095`20., 
    2831.69376531374209638543535146772915663917`20., 
    2831.80793758502629920037751832723607818749`20., 
    2831.92016335331599040800045025130537487742`20., 
    2832.03044235274091354676668121898857591604`20., 
    2832.13877432196689551586410605139659350946`20., 
    2832.2451590042004126075714211971513587654`20., 
    2832.34959614719308030512063118044234310793`20., 
    2832.45208550324606660599714904318627642507`20., 
    2832.55262682921442863447215367477436321879`20., 
    2832.65121988651137231104081220843040220031`20., 
    2832.74786444111243485034335672475961135599`20., 
    2832.84256026355958986307344215720425169366`20., 
    2832.9353071289652748413293231802630634128`20., 
    2833.02610481701634081083778450160393421989`20., 
    2833.11495311197792393747804983933557122616`20., 
    2833.20185180269723887955268441699511329725`20., 
    2833.28680068260729368129439459109240226843`20., 
    2833.36979954973052600716121291172226315369`20., 
    2833.45084820668236052055743037578053279043`20., 
    2833.52994646067468721472338899824388381953`20., 
    2833.60709412351926050766346256390728509765`20., 
    2833.68229101163101891712781339253040279931`20., 
    2833.75553694603132513582939648453260136609`20., 
    2833.82683175235112633126276437940799931197`20., 
    2833.89617526083403449869507793005014549764`20., 
    2833.96356730633932670012191812787030015905`20., 
    2834.02900772834486502622058701269401021387`20., 
    2834.09249637094993612259114330004802903086`20., 
    2834.15403308287801012584999928830446639433`20., 
    2834.21361771747941885943206547552356951487`20., 
    2834.27125013273395314326472077742770232805`20., 
    2834.3269301912533790757998590774451433404`20., 
    2834.38065776028387315122846404524295291971`20., 
    2834.43243271170837607905513800214915403255`20., 
    2834.48225492204886517757729872216623380587`20., 
    2834.53012427246854521719489950854837844725`20., 
    2834.57604064877395759387105927184545986967`20., 
    2834.6200039414170077174714448515220572565`20., 
    2834.6620140454969105041301593487980407759`20., 
    2834.70207086076205386622178741787243441053`20., 
    2834.74017429161178009796265878915500120908`20., 
    2834.77632424709808505911884019615594313371`20., 
    2834.81052064092723506376337678740847396076`20., 
    2834.84276339146130138550039856628430339093`20., 
    2834.87305242171961229505840513971735515776`20., 
    2834.90138765938012255064886106684012440751`20., 
    2834.92776903678070026598869073165275752321`20., 
    2834.95219649092033108539587071382668877537`20., 
    2834.9746699634602395998855924215166945307`20., 
    2834.9951894007249279427199202188616594916`20., 
    2835.0137547537031315073960110717684004892`20., 
    2835.03036597804869173559630028335634873792`20., 
    2835.04502303408134592716810250973052475829`20., 
    2835.05772588678743402874933522054730442701`20., 
    2835.06847450582052236221104943727651572573`20., 
    2835.07726886550194425864565543143645713236`20., 
    2835.08410894482125756819166381709051796276`20., 
    2835.08899472743661902055092917312602028457`20., 
    2835.09192620167507541562228744239003660976`20., 
    2835.09290336053277162824562284206175341688`20., 
    2835.09192620167507541562228744239003660976`20., 
    2835.08899472743661902055092917312602028457`20., 
    2835.08410894482125756819166381709051796276`20., 
    2835.07726886550194425864565543143645713236`20., 
    2835.06847450582052236221104943727651572573`20., 
    2835.05772588678743402874933522054730442701`20., 
    2835.04502303408134592716810250973052475829`20., 
    2835.03036597804869173559630028335634873792`20., 
    2835.0137547537031315073960110717684004892`20., 
    2834.9951894007249279427199202188616594916`20., 
    2834.9746699634602395998855924215166945307`20., 
    2834.95219649092033108539587071382668877537`20., 
    2834.92776903678070026598869073165275752321`20., 
    2834.90138765938012255064886106684012440751`20., 
    2834.87305242171961229505840513971735515776`20., 
    2834.84276339146130138550039856628430339093`20., 
    2834.81052064092723506376337678740847396076`20., 
    2834.77632424709808505911884019615594313371`20., 
    2834.74017429161178009796265878915500120908`20., 
    2834.70207086076205386622178741787243441053`20., 
    2834.6620140454969105041301593487980407759`20., 
    2834.6200039414170077174714448515220572565`20., 
    2834.57604064877395759387105927184545986967`20., 
    2834.53012427246854521719489950854837844725`20., 
    2834.48225492204886517757729872216623380587`20., 
    2834.43243271170837607905513800214915403255`20., 
    2834.38065776028387315122846404524295291971`20., 
    2834.3269301912533790757998590774451433404`20., 
    2834.27125013273395314326472077742770232805`20., 
    2834.21361771747941885943206547552356951487`20., 
    2834.15403308287801012584999928830446639433`20., 
    2834.09249637094993612259114330004802903086`20., 
    2834.02900772834486502622058701269401021387`20., 
    2833.96356730633932670012191812787030015905`20., 
    2833.89617526083403449869507793005014549764`20., 
    2833.82683175235112633126276437940799931197`20., 
    2833.75553694603132513582939648453260136609`20., 
    2833.68229101163101891712781339253040279931`20., 
    2833.60709412351926050766346256390728509765`20., 
    2833.52994646067468721472338899824388381953`20., 
    2833.45084820668236052055743037578053279043`20., 
    2833.36979954973052600716121291172226315369`20., 
    2833.28680068260729368129439459109240226843`20., 
    2833.20185180269723887955268441699511329725`20., 
    2833.11495311197792393747804983933557122616`20., 
    2833.02610481701634081083778450160393421989`20., 
    2832.9353071289652748413293231802630634128`20., 
    2832.84256026355958986307344215720425169366`20., 
    2832.74786444111243485034335672475961135599`20., 
    2832.65121988651137231104081220843040220031`20., 
    2832.55262682921442863447215367477436321879`20., 
    2832.45208550324606660599714904318627642507`20., 
    2832.34959614719308030512063118044234310793`20., 
    2832.2451590042004126075714211971513587654`20., 
    2832.13877432196689551586410605139659350946`20., 
    2832.03044235274091354676668121898857591604`20., 
    2831.92016335331599040800045025130537487742`20., 
    2831.80793758502629920037751832723607818749`20., 
    2831.69376531374209638543535146772915663917`20., 
    2831.57764680986507976245682626592030759095`20., 
    2831.45958234832367070256760048896230062707`20., 
    2831.33957220856822089138013083129723248983`20., 
    2831.21761667456614383540489300493340051171`20., 
    2831.09371603479697139117396831518400506456`20., 
    2830.96787058224733557971980153034501589386`20., 
    2830.84008061440587595272226346705899947178`20., 
    2830.71034643325807278027982920154777332962`20., 
    2830.57866834528100633387537481675235314906`20., 
    2830.44504666143804254169347250463753671641`20., 
    2830.30948169717344529700380086729388894714`20., 
    2830.17197377240691570385406445859855583061`20., 
    2830.03252321152805854781531893521938813409`20., 
    2829.89113034339077628299251553587039300517`20., 
    2829.74779550130759082995310585551440412473`20., 
    2829.60251902304389348263638492164094262643`20., 
    2829.45530125081212322568560236703688111055`20., 
    2829.30614253126587376699344807863211978977`20., 
    2829.15504321549392959356903526918172010638`20., 
    2829.0020036590142313621206808200627155345`20., 
    2828.84702422176777093900334553362267615489`20., 
    2828.69010526811241640740227640113683010427`20., 
    2828.53124716681666736281492519210590229263`20., 
    2828.37045029105334082105134395271722256892`20., 
    2828.20771501839318806609872504063261440107`20., 
    2828.04304173079844276828831314660249590954`20., 
    2827.87643081461630070626232676554066547715`20., 
    2827.70788266057233142926454958836046255218`20., 
    2827.53739766376382219927065652531367838018`20., 
    2827.36497622365305455543289822484151170195`20., 
    2827.19061874406051384623826117191636740277`20., 
    2827.01432563315803207766943237894660886818`20., 
    2826.8360973034618644285136184709441380942`20., 
    2826.65593417182569978678529429037158701738`20., 
    2826.47383665943360566401508722246247577233`20., 
    2826.2898051917929078469080470410198906249`20., 
    2826.10384019872700514859031953883744448749`20., 
    2825.91594211436811962434355345798666030909`20., 
    2825.7261113771499826193710477870150108472`20., 
    2825.53434842980045701874851945952127375208`20., 
    2825.340653719334096072285274595942175263`20., 
    2825.14502769704463916955834001836898388462`20., 
    2824.94747081849744494288260179952663781283`20., 
    2824.74798354352186207844405567087590863699`20., 
    2824.54656633620353821825075742998110378156`20., 
    2824.3432196648766673379468329042543388896`20., 
    2824.13794400211617598788883502966433759152`20., 
    2823.93073982472984878720069430345761176408`20., 
    2823.72160761375039356280337801384614333402`20., 
    2823.51054785442744652765803860843604298517`20., 
    2823.29756103621951789466678333118026110333`20., 
    2823.08264765278587832484313244651229246351`20., 
    2822.86580820197838661049465420153496237575`20., 
    2822.64704318583325899625307897818628283222`20., 
    2822.42635311056278054284231627670686992034`20., 
    2822.2037384865469589404921452529050924689`20., 
    2821.97919982832512118088484708065320986842`20., 
    2821.75273765458745349846362556386483771752`20., 
    2821.52435248816648499383525686152674520247`20., 
    2821.29404485602851535386496112958083214337`20., 
    2821.06181528926498708488894505487323365294`20., 
    2820.82766432308380267725937688822902413125`20., 
    2820.59159249680058712118768238603789694327`20., 
    2820.35360035382989619556495421428320920366`20., 
    2820.11368844167637095311291746886576844137`20., 
    2819.87185731192583882685526405461293978923`20., 
    2819.62810752023636178449723817349065335655`20., 
    2819.38243962632923195886110890551667987533`20., 
    2819.13485419397991518404659397882026472164`20., 
    2818.88535179100894286846839679769269127768`20., 
    2818.63393298927275263736778740671037698397`20., 
    2818.38059836465447817880160336289949546176`20., 
    2818.12534849705468872848017975624071089571`20., 
    2817.86818397038207863015555536394061482901`20., 
    2817.60910537254410740955286583037667760295`20., 
    2817.34811329543759080109115166790184589839`20., 
    2817.08520833493924316785491072788505138696`20., 
    2816.82039109089617175645464863610366650644`20., 
    2816.55366216711632322955346861302686298211`20., 
    2816.28502217135888291993744121535107430493`20., 
    2816.01447171532462725107015692889070513458`20., 
    2815.74201141464622977009654724728699121852`20., 
    2815.46764188887852124024782482538780470051`20., 
    2815.19136376148870424054830730841642792029`20., 
    2814.91317765984652272163602414537973513512`20., 
    2814.63308421521438696738243752423007422342`20., 
    2814.35108406273745441283241869258020423652`20., 
    2814.06717784143366676978389523418861731423`20., 
    2813.78136619418374391208741390617272117185`20., 
    2813.49364976772113497346934257556781873862`20., 
    2813.20402921262192711136866337585997387937`20., 
    2812.91250518329471239092639171847234193125`20., 
    2812.61907833797041324387870101448581500153`20., 
    2812.32374933869206695767995410574699054852`20., 
    2812.02651885130456965072015708734612332662`20., 
    2811.7273875454443801900029813915137614515`20., 
    2811.42635609452918450811557196597577542233`20., 
    2811.12342517574752077675000364274529195674`20., 
    2810.8185954700483658944285990879223612337`20., 
    2810.51186766213068374644151893849609437695`20., 
    2810.20324244043293569532522086529701837831`20., 
    2809.89272049712255376049470640646817000696`20., 
    2809.58030252808537694589108355410475623866`20., 
    2809.2659892329150511747190242644224023046`20., 
    2808.94978131490239329052634821894356529543`20., 
    2808.63167948102471958402038006214193630447`20., 
    2808.31168444193513930512307354991568190558`20., 
    2807.98979691195181361983934287901455547244`20., 
    2807.66601760904718047155076293816481752619`20., 
    2807.34034725483714580634997397348618579246`20., 
    2807.01278657457024162199993342432177417703`20., 
    2806.68333629711675130003678322072426586712`20., 
    2806.35199715495780268043573287500944943197`20., 
    2806.01876988417442933812618890071533897062`20., 
    2805.68365522443660052047558447039564104357`20., 
    2805.34665391899222020466117810416170969402`20., 
    2805.00776671465609573361569814068970039795`20., 
    2804.66699436179887648896631555374899740054`20., 
    2804.32433761433596305908723925106780608344`20., 
    2803.97979722971638736005445632122161885978`20., 
    2803.63337396891166416692699879564034803521`20., 
    2803.28506859640461451238282535169398322341`20., 
    2802.93488188017816140930918089409938129802`20., 
    2802.58281459170409835348736186301576351894`20., 
    2802.22886750593183106202039597031041976246`20., 
    2801.87304140127709290262947013958537653011`20., 
    2801.51533705961063446839124067855082618813`20., 
    2801.15575526624688775190366872291413001987`20., 
    2800.79429680993260537225297790048492530359`20., 
    2800.4309624828354753075089686184772861279`20., 
    2800.06575308053271158480048546798864820314`20., 
    2799.69866940199962137931756444718624139935`20., 
    2799.32971224959814897285193083820752864965`20., 
    2798.95888242906539702172332471276086338727`20., 
    2798.58618074950212558314584948135956085004`20., 
    2798.21160802336122934826642208908471272425`20., 
    2797.83516506643619352925670594112021613241`20., 
    2797.45685269784952884696088599652158256545`20., 
    2797.07667174004118606469455826122156426486`20., 
    2796.69462301875695051285511362549932432172`20., 
    2796.31070736303681704804156097533993587647`20., 
    2795.92492560520334588939202091565362914861`20., 
    2795.53727858084999977383039517890527443973`20., 
    2795.14776712882946287087024544874079568712`20., 
    2794.75639209124194189655396813136424665735`20., 
    2794.36315431342344986500919936034973477221`20., 
    2793.96805464393407291498229954472580872933`20., 
    2793.57109393454622064756102284888849896041`20., 
    2793.17227304023286041012534931465946731672`20., 
    2792.77159281915573596036722243768143591221`20., 
    2792.36905413265357094299687072168750083809`20., 
    2791.96465784523025761050577712054408738796`20., 
    2791.5584048245430312180844755852565339648`20., 
    2791.15029594139063052149748053202371884899`20., 
    2790.74033206970144480539807537807530505565`20., 
    2790.32851408652164786822268380898548078473`20., 
    2789.91484287200331938843840655866806874005`20., 
    2789.49931930939255409552831252078247787189`20., 
    2789.08194428501755916768751213836816199286`20., 
    2788.66271868827674027676920020499591143868`20., 
    2788.24164341162677669956402216717719796371`20., 
    2787.81871935057068591301858114644059369781`20., 
    2787.39394740364587808949995124043430816836`20., 
    2786.96732847241220090669298584110841265339`20., 
    2786.53886346143997508517629788325552125649`20., 
    2786.10855327829802106516133274886012208859`20., 
    2785.67639883354167723229724507256091691556`20., 
    2785.24240104070081010084261937121082379122`20., 
    2784.80656081626781686088373303506428647338`20., 
    2784.36887907968562069463834082736444065205`20., 
    2783.92935675333565926522415492998916525854`20., 
    2783.48799476252586677959259621214757395467`20., 
    2783.04479403547865002563129338473456569031`20., 
    2782.59975550331885878172349971534237548888`20., 
    2782.15288010006175099531937473330827924541`20., 
    2781.70416876260095312532323355300459470728`20., 
    2781.25362243069641604133269172953754729082`20., 
    2780.80124204696236687098042147048307296815`20., 
    2780.34702855685525718482727794422582050982`20., 
    2779.89098290866170790643714453587297578401`20., 
    2779.43310605348645133342927514848628571147`20., 
    2778.9733989452402706534534716857062880649`20., 
    2778.51186254062793733716741700510118837548`20., 
    2778.04849779913614678841417884768862201771`20., 
    2777.58330568302145262990159905743450273632`20., 
    2777.11628715729820000077427487336965010275`20., 
    2776.64744318972645824054341477130091648895`20., 
    2776.17677475079995333190029927216929985881`20., 
    2775.70428281373400047298568575435192693437`20., 
    2775.22996835445343714772055341573253229123`20., 
    2774.75383235158055706082337727000673432156`20., 
    2774.27587578642304530214593486655735121462`20., 
    2773.79609964296191510295377198583411700092`20., 
    2773.31450490783944654475916879104424634144`20., 
    2772.83109257034712757928403989988438867142`20., 
    2772.34586362241359771608795380678171073956`20., 
    2771.85881905859259473234265137170240910235`20., 
    2771.36995987605090475716936110020113193782`20., 
    2770.87928707455631608087913110873461794684`20., 
    2770.38680165646557703736960343556272562228`20., 
    2769.89250462671235830583442412105760425982`20., 
    2769.39639699279521997583408957230595946458`20., 
    2768.89847976476558371765975237266300697367`20., 
    2768.39875395521571039779462298853418545727`20., 
    2767.897220579266683477141381686031613827`20., 
    2767.39388065455639852753873012231274390919`20., 
    2766.88873520122755919993613601243975491331`20., 
    2766.3817852419156799754332272231141701167`20., 
    2765.87303180173709602821944254884573342996`20., 
    2765.36247590827698052727071290242740156761`20., 
    2764.85011859157736970147339496884120512336`20., 
    2764.33596088412519599065167442092177196879`20., 
    2763.8200038208403296027734610617775026507`20., 
    2763.30224843906362879540167579605273348965`20., 
    2762.78269577854499919724303973343700548687`20., 
    2762.26134688143146248342527810215065692501`20., 
    2761.73820279225523471590630359576055290893`20., 
    2761.21326455792181465818570135662256333909`20., 
    2760.68653322769808237124995551698132608011`20., 
    2760.15800985320040839543858799451695169561`20., 
    2759.62769548838277382066897538677571884966`20., 
    2759.09559118952490154520331901337890939981`20., 
    2758.56169801522039902088231445013974173605`20., 
    2758.02601702636491278048674664679667524439`20., 
    2757.48854928614429504062076958825462893722`20., 
    2756.94929586002278267123925840263241331926`20., 
    2756.4082578157311888206665880592300762897`20., 
    2755.86543622325510748267573580426521156309`20., 
    2755.3208321548231312899149619490277788361`20., 
    2754.77444668489508281568473146160026691031`20., 
    2754.22628089015025966378023111999722538605`20., 
    2753.67633584947569362382504603782482876241`20., 
    2753.12461264395442416722951560896514925072`20., 
    2752.57111235685378655661322091426290076196`20., 
    2752.01583607361371483923519009747827491061`20., 
    2751.45878488183505999267796996950662343364`20., 
    2750.89995987126792348873292405717937951968`20., 
    2750.33936213380000653913420047857154789397`20., 
    2749.77699276344497528448798647459575046194`20., 
    2749.21285285633084218544214728907595040304`20., 
    2748.64694351068836387283935054480279452982`20., 
    2748.07926582683945571129451652379789557716`20., 
    2747.50982090718562332833512106152528747241`20., 
    2746.93860985619641135894072035446577052792`20., 
    2746.36563378039786965301627310736666923688`20., 
    2745.79089378836103719103261035147091127376`20., 
    2745.21439099069044395076695017145189945417`20., 
    2744.63612650001263096577687468355371675068`20., 
    2744.05610143096468881394287907266292483265`20., 
    2743.47431690018281477211766444108085867106`20., 
    2742.89077402629088887062497271579130749616`20., 
    2742.30547392988906907905714591601204575133`20., 
    2741.71841773354240585252892464705427627799`20., 
    2741.12960656176947626525547063848629205625`20., 
    2740.53904154103103795603539228740383074362`20., 
    2739.94672379971870310793485522377958726921`20., 
    2739.35265446814363268218685452163351260153`20., 
    2738.75683467852525112404059188478583124103`20., 
    2738.15926556497998175601981839343880116029`20., 
    2737.55994826351000307177614756512753163849`20., 
    2736.95888391199202614145388881816091540401`20., 
    2736.35607365016609333721707008256213691792`20., 
    2735.75151861962439858532718033310889625458`20., 
    2735.14521996380012934890193616537190647494`20., 
    2734.53717882795633054323122703491303636403`20., 
    2733.92739635917479058327648515957933626952`20., 
    2733.31587370634494976073421996338688320896`20., 
    2732.70261202015283114580351282664400899727`20., 
    2732.08761245306999420656104320028020760712`20., 
    2731.47087615934251133661586713371800141198`20., 
    2730.85240429497996747948984713822763875239`20., 
    2730.23219801774448303594848913832266570395`20., 
    2729.61025848713976023829112702446189587873`20., 
    2728.98658686440015317339905488052560113309`20., 
    2728.36118431247976163413548608835987065285`20., 
    2727.73405199604154897649225988072482315453`20., 
    2727.1051910814464841576851601003741896818`20., 
    2726.47460273674270812821269641282833261673`20., 
    2725.84228813165472474871236141247692913648`20., 
    2725.20824843757261640027385227153339951443`20., 
    2724.57248482754128445470066504579885072149`20., 
    2723.93499847624971476904996363278796545914`20., 
    2723.29579056002026836662582177001742020895`20., 
    2722.65486225679799746445296139385657325939`20., 
    2722.01221474613998700511708812380730788115`20., 
    2721.36784920920472184872397651266057506195`20., 
    2720.72176682874147977860270388284255582423`20., 
    2720.07396878907975047225898988698965114156`20., 
    2719.4244562761186805869725851871164271967`20., 
    2718.77323047731654510732818061659171262713`20., 
    2718.12029258168024509987248962892736291471`20., 
    2717.4656437797548320180011014925645277322`20., 
    2716.80928526361305869809751830371895122593`20., 
    2716.15121822684495718587358120714068842813`20., 
    2715.49144386454744352979536399779900272962`20., 
    2714.8299633733139496764216673072367612069`20., 
    2714.16677795122408260043358366942277631653`20., 
    2713.50188879783331080009332076470708935845`20., 
    2712.83529711416267828683866295810291670612`20., 
    2712.16700410268854619569621383899534721512`20., 
    2711.49701096733236214118198686086502106204`20., 
    2710.82531891345045744135208747688947226385`20., 
    2710.15192914782387233066924656342741094712`20., 
    2709.47684287864820928036290770967676037704`20., 
    2708.80006131552351454298152452817410149431`20., 
    2708.12158566944418803586577102656295538951`20., 
    2707.4414171527889216763105889256903956554`20., 
    2706.75955697931066627923246940331684428682`20., 
    2706.07600636412662712621617002970399689683`20., 
    2705.39076652370828831288227574806113248216`20., 
    2704.70383867587146597959369892162388553847`20., 
    2704.01522403976639052860544918942208059548`20., 
    2703.32492383586781792885785881290121113782`20., 
    2702.63293928596517020771899123476950330978`20., 
    2701.93927161315270522709725581211713010412`20., 
    2701.24392204181971583947036446575633180125`20., 
    2700.5468917976407585175117588924491163074`20., 
    2699.84818210756591154914057086220682136235`20., 
    2699.14779419981106288797611208823879360766`20., 
    2698.44572930384822774734288161738256800559`20., 
    2697.74198865039589602414718334780161368432`20., 
    2697.03657347140940963713171815412813010915`20., 
    2696.32948500007136986221000652886301882513`20., 
    2695.62072447078207474578825931186438602804`20., 
    2694.91029311914998667519839500800834883972`20., 
    2694.19819218198223018359234978261628547413`20., 
    2693.48442289727512006488468624977424093477`20., 
    2692.76898650420471987257782379737633056262`20., 
    2692.05188424311743087456202899788491882187`20., 
    2691.33311735552061153425066062864119264835`20., 
    2690.61268708407322758669009939714554219936`20., 
    2689.89059467257653277657334550993128087731`20., 
    2689.16684136596478032338647407519695826209`20., 
    2688.44142841029596517722803380191021561942`20., 
    2687.71435705274259712716309185443199785027`20., 
    2686.98562854158250482230599884895264300863`20., 
    2686.25524412618967076416910316191298703494`20., 
    2685.52320505702509732716861181977688905144`20., 
    2684.78951258562770386254360366001430697745`20., 
    2684.05416796460525493931987516266658043728`20., 
    2683.31717244762531977433686489430825393398`20., 
    2682.578527289406262901753382016186899898`20., 
    2681.83823374570826613085627952561830422679`20., 
    2681.09629307332438183941558418391046157685`20., 
    2680.35270653007161764825994142910609049357`20., 
    2679.60747537478205252118757262054434622879`20., 
    2678.86060086729398433278029002110179195019`20., 
    2678.11208426844310894515148697665501365487`20., 
    2677.36192684005373083313343047836269514428`20., 
    2676.61012984493000529589464307688444749623`20., 
    2675.85669454684721229147468206594136744986`20., 
    2675.10162221054306192923121580987305109505`20., 
    2674.34491410170903165371296865181938773874`20., 
    2673.5865714869817351520018643678585574917`20., 
    2672.82659563393432301510854977078733551792`20., 
    2672.06498781106791518255742975373834242336`20., 
    2671.30174928780306519786039654722967542723`20., 
    2670.53688133447125630115259181715083599813`20., 
    2669.77038522230642938384880186872504058798`20., 
    2669.002262223436542828775453909884827904`20., 
    2668.23251361087516425784065420268974529525`20., 
    2667.46114065851309420792328501260290992559`20., 
    2666.6881446411100217542918534696349543579`20., 
    2665.91352683428621209950455761188556730465`20., 
    2665.13728851451422614439389774699074860106`20., 
    2664.35943095911067205640210853779395818143`20., 
    2663.57995544622798884920771154824096341325`20., 
    2662.7988632548462619862685809971318813221`20., 
    2662.0161556647650710196030677684090592326`20., 
    2661.23183395659536927383792792325095928054`20., 
    2660.44589941175139558427004067044368794511`20., 
    2659.65835331244261809641816462351297738052`20., 
    2658.86919694166571013328125689341632178298`20., 
    2658.07843158319655813527115287712036494018`20., 
    2657.28605852158230167654966031749128295183`20., 
    2656.49207904213340556027334322444632473829`20., 
    2655.69649443091576399403344255451597502186`20., 
    2654.89930597474283684557348325042797408035`20., 
    2654.10051496116781797767313257377797841895`20., 
    2653.30012267847583565990378299095498647264`20., 
    2652.49813041567618505378911371654056305015`20., 
    2651.69453946249459276674251706698615024775`20., 
    2650.88935110936551346900273689795266449961`20., 
    2650.08256664742445856664933365212234542834`20., 
    2649.27418736850035692265064019825613649157`20., 
    2648.46421456510794761677868018468267241697`20., 
    2647.65264953044020473411806078270824726835`20., 
    2646.83949355836079417079909842583751238571`20., 
    2646.02474794339656244449936268732690807578`20., 
    2645.20841398073005749618240228260782175059`20., 
    2644.39049296619208146847762012169259218998`20., 
    2643.5709861962542754450510624559535798171`20., 
    2642.74989496802173613427325086160080725319`20., 
    2641.92722057922566447945708480132657538986`20., 
    2641.10296432821604617691624586577345648114`20., 
    2640.2771275139543640820824109274527596133`20., 
    2639.44971143600634248291789811366219816783`20., 
    2638.62071739453472321886909386886878158862`20., 
    2637.79014669029207362262510796521835900761`20., 
    2636.95800062461362626097554206610234715594`20., 
    2636.12428049941015045010100169755240507223`20., 
    2635.28898761716085551967999600494568180704`20., 
    2634.4521232809063257992561186732031812367`20., 
    2633.61368879424148729937985052020787591088`20., 
    2632.77368546130860605911993264798715055913`20., 
    2631.93211458679031813062999123804253766464`20., 
    2631.08897747590269117055691317278404743224`20., 
    2630.24427543438831760718833721558127250414`20., 
    2629.39800976850943935135749955472014480232`20., 
    2628.55018178504110401825451569616521511286`20., 
    2627.70079279126435262643395308973692899192`20., 
    2626.84984409495943873945921014622477562353`20., 
    2625.9973370043990790147847266531036332138`20., 
    2625.14327282834173512364736678986296114267`20., 
    2624.2876528760249270049183973192855218164`20., 
    2623.43047845715857741505728801074650492627`20., 
    2622.57175088191838773550804645250940304823`20., 
    2621.7114714609392449980879222537902847308`20., 
    2620.84964150530866008813703296123396066888`20., 
    2619.98626232656023708442573218146718268248`20., 
    2619.1213352366671736940543154108442354365`20., 
    2618.25486154803579273982689657108562649928`20., 
    2617.38684257349910465683794353748864959529`20., 
    2616.51727962631040095427598899359357526421`20., 
    2615.64617402013687859772438839795838178077`20., 
    2614.77352706905329526652363403669683352056`20., 
    2613.89934008753565544005360708739826639323`20., 
    2613.02361439045492726609721206939231171361`20., 
    2612.14635129307079016375904345068968587983`20., 
    2611.26755211102541311273403569661689699073`20., 
    2610.38721816033726358005139858645152558305`20., 
    2609.50535075739494703475849184276007646314`20., 
    2608.6219512189510770003575994165029613313`20., 
    2607.73702086211617559416577631355352754844`20., 
    2606.85056100435260450213401156966146269747`20., 
    2605.96257296346852633703683159482301506759`20., 
    2605.07305805761189632732711011615411937498`20., 
    2604.18201760526448428334320564889584813318`20., 
    2603.28945292523592678695656592139936870024`20., 
    2602.39536533665780955015757188865394580431`20., 
    2601.49975615897777988749559262882469437073`20., 
    2600.60262671195368924671593709716497858245`20., 
    2599.70397831564776574137156981863840181081`20., 
    2598.80381229042081662863105538802286906444`20., 
    2597.90212995692646067495616122184174379759`20., 
    2596.99893263610539035178282933996954377327`20., 
    2596.09422164917966380280777588587278283304`20., 
    2595.18799831764702652395974134039893558741`20., 
    2594.28026396327526269661934454715950453676`20., 
    2593.37101990809657611414453924279015225272`20., 
    2592.46026747440200064125978216759031792893`20., 
    2591.54800798473584014537614632335792596794`20., 
    2590.63424276189013783842670076216811829228`20., 
    2589.71897312889917496732647857042774282315`20., 
    2588.80220040903399879069921652329468880861`20., 
    2587.88392592579697977905372222740335064445`20., 
    2586.96415100291639797514115638890508405292`20., 
    2586.04287696434105845078065803214854528856`20., 
    2585.12010513423493579600453790045415072183`20., 
    2584.19583683697184757594566870500296695941`20., 
    2583.2700733971301566904686591299800754046`20., 
    2582.34281613948750257113286030573956466001`20., 
    2581.41406638901556114966916756193566487878`20., 
    2580.48382547087483353175389539158580394119`20., 
    2579.55209471040946330947166841051268644615`20., 
    2578.61887543314208244547523439947443017205`20., 
    2577.68416896476868566147331598865232122794`20., 
    2576.74797663115353326330802391714442278974`20., 
    2575.81029975832408233452090582154778671651`20., 
    2574.87113967246594622995134894778642951203`20., 
    2573.93049769991788230056274183712920524324`20., 
    2572.98837516716680778035047774225736434143`20., 
    2572.04477340084284376585150015241494825102`20., 
    2571.0996937277143872184475972622322734651`20., 
    2570.15313747468321091933399647007564373719`20., 
    2569.20510596877959130671094105637827000761`20., 
    2568.25560053715746412444879814732378600681`20., 
    2567.30462250708960781117679905575105653017`20., 
    2566.35217320596285455845169931965010279909`20., 
    2565.39825396127332896637541551348740229406`20., 
    2564.44286610062171422474999855184134459853`20., 
    2563.48601095170854574758408818471720977978`20., 
    2562.52768984232953218849721023352537223182`20., 
    2561.56790410037090376430687646239565879228`20., 
    2560.60665505380478781382837654426825302418`20., 
    2559.64394403068461151866836218900966560488`20., 
    2558.67977235914053171255076508080102771487`20., 
    2557.71414136737489170547721286272370183403`20., 
    2556.74705238365770504879386115972593916122`20., 
    2555.7785067363221661670123948163083942818`20., 
    2554.80850575376018778201481853296715789274`20., 
    2553.83705076441796505505950643151854344987`20., 
    2552.86414309679156637179976240870105854265`20., 
    2551.88978407942255069532580922737361914553`20., 
    2550.9139750408936114120466250589685962445`20., 
    2549.93671730982424659503933268323281518638`20., 
    2548.95801221486645560931086996866171999457`20., 
    2547.97786108470046198323938194312507247262`20., 
    2546.99626524803046247029112621282887189446`20., 
    2546.01322603358040222494262634617692335669`20., 
    2545.02874477008977601657729391110323257537`20., 
    2544.04282278630945540497072110359939720596`20., 
    2543.05546141099754180082927445783054646661`20., 
    2542.06666197291524533470244827661400887109`20., 
    2541.07642580082278945745061662608837583534`20., 
    2540.08475422347534119531630763273322669566`20., 
    2539.09164856961896698251886621157591056049`20., 
    2538.09711016798661399416932422571369982046`20., 
    2537.10114034729411690218441359335406245992`20., 
    2536.1037404362362299767658913661180939472`20., 
    2535.10491176348268445590364983312869960576`20., 
    2534.10465565767427110525841297876461039403`20., 
    2533.10297344741894789068212704727572681504`20., 
    2532.09986646128797268554139164650076370943`20., 
    2531.09533602781206093492140305220731871773`20., 
    2530.08938347547756819870484764757963768184`20., 
    2529.0820101327226974954419454417985983012`20., 
    2528.07321732793373136885435625152410932516`20., 
    2527.06300638944128859874687949687121848638`20., 
    2526.05137864551660547803675796210955804604`20., 
    2525.03833542436784157755089181120770089297`20., 
    2524.02387805413640992018633734926667640619`20., 
    2523.0080078628933314859790614138719473145`20., 
    2521.99072617863561396958000300954581016848`20., 
    2520.97203432928265471159601522274919486975`20., 
    2519.95193364267266772521617914976658486852`20., 
    2518.93042544655913473951125432903440896452`20., 
    2517.90751106860728018076561400660102356253`20., 
    2516.8831918363905700131768657133918778816`20., 
    2515.85746907738723436023843555366734838663`20., 
    2514.83034411897681382810465597775059443397`20., 
    2513.80181828843672945222629954681383628287`20., 
    2512.77189291293887618853700342845450508455`20., 
    2511.74056931954623987046758945266919260355`20., 
    2510.70784883520953755306586110211211107828`20., 
    2509.67373278676388116550401063267436750538`20., 
    2508.63822250092546439326425567709579279472`20., 
    2507.60131930428827271130570446550692981201`20., 
    2506.56302452332081648953168172690803150342`20., 
    2505.52333948436288709189679317452233843051`20., 
    2504.48226551362233589051682522210839929763`20., 
    2503.43980393717187611617212846154704674851`20., 
    2502.39595608094590746662637892659962328878`20., 
    2501.35072327073736339421751098522293593126`20., 
    2500.3041068321945809942161307949215304412`20., 
    2499.25610809081819341548881081496882223433`20., 
    2498.20672837195804471504929533030792071531`20., 
    2497.15596900081012707812977598137946382694`20., 
    2496.10383130241354032545698683199830347033`20., 
    2495.05031660164747362947388270750504300813`20., 
    2493.99542622322820936130706480597645884579`20., 
    2492.93916149170614899034286657953417157989`20., 
    2491.88152373146286095834107349955627130764`20., 
    2490.82251426670815045008458570377068222265`20., 
    2489.76213442147715098263590606625752039663`20., 
    2488.70038551962743773534711157179166636733`20., 
    2487.63726888483616254284890689962711325739`20., 
    2486.57278584059721047332642996248472940207`20., 
    2485.50693771021837791447464418604009812588`20., 
    2484.43972581681857208961437618298467903`20., 
    2483.37115148332503192654130505288621694738`20., 
    2482.30121603247057020177444595276366238861`20., 
    2481.22992078679083688296786121093094974488`20., 
    2480.15726706862160359234944272511660845301`20., 
    2479.08325620009606911415360557161562456246`20., 
    2478.00788950314218586912058078151951918404`20., 
    2476.93116829948000727924366148901632084567`20., 
    2475.85309391061905594605720775142803300648`20., 
    2474.77366765785571256587241815714996988724`20., 
    2473.69289086227062550548479800211324014827`20., 
    2472.61076484472614096199686170400293258631`20., 
    2471.52729092586375363052186886246037523538`20., 
    2470.44247042610157780365927683910023199949`20., 
    2469.35630466563183882676006604952791705407`20., 
    2468.26879496441838483313012570662686359537`20., 
    2467.17994264219421868345244615589137588427`20., 
    2466.08974901845905003384391807477887939923`20., 
    2464.99821541247686745710005779363115443944`20., 
    2463.90534314327353054182093120958597063329`20., 
    2462.81113352963438189425390583001496277856`20., 
    2461.71558789010187896783359127012914494847`20., 
    2460.61870754297324564554640316079431015726`20., 
    2459.5204938062981435003965742658877254065`20., 
    2458.42094799787636265940211028030021134655`20., 
    2457.32007143525553219670311714423555471401`20., 
    2456.21786543572884998152108287844539546285`20., 
    2455.11433131633283190686605127715377807479`20., 
    2454.00947039384508042504914889602979443934`20., 
    2452.90328398478207231622059249330558497375`20., 
    2451.79577340539696561631808352054847862495`20., 
    2450.68693997167742563097736175869710810944`20., 
    2449.57678499934346996212561434282815010076`20., 
    2448.46530980384533247414939204840306898754`20., 
    2447.35251570036134612670164489926607946619`20., 
    2446.23840400379584460138742722390544877882`20., 
    2445.12297602877708264974471179510609394552`20., 
    2444.0062330896551750901155674454385126114`20., 
    2442.88817650050005438118366860552484436672`20., 
    2441.76880757509944670013669285379272830913`20., 
    2440.64812762695686645359659832663885802648`20., 
    2439.52613796928962914964703148825642596708`20., 
    2438.40283991502688255947517231145468128886`20., 
    2437.27823477680765609733515362559208829886`20., 
    2436.15232386697892834773176973499599660693`20., 
    2435.02510849759371266891649212884440901624`20., 
    2433.89658998040916080198281315686844941009`20., 
    2432.76676962688468441504461813673385658498`20., 
    2431.63564874818009451217961892718026820997`20., 
    2430.50322865515375863701984422016098538095`20., 
    2429.36951065836077580107275058451538170324`20., 
    2428.23449606805116906705967077659453286389`20., 
    2427.0981861941680957177630293968348862872`20., 
    2425.96058234634607494108000822554954530903`20., 
    2424.82168583390923296218811235842964697354`20., 
    2423.68149796586956555393735165619763898091`20., 
    2422.54002005092521785679448832812852902187`20., 
    2421.39725339745878143987698922045547376762`20., 
    2420.25319931353560853482793934208125668204`20., 
    2419.10785910690214337449820032425224027324`20., 
    2417.96123408498427056861851309854929198725`20., 
    2416.81332555488568044886202753650768159395`20., 
    2415.66413482338625131591687279860529154402`20., 
    2414.51366319694044852140884059012343081274`20., 
    2413.36191198167574031773601954125180938334`20., 
    2412.20888248339103040910027286767333825927`20., 
    2411.05457600755510713724477389797995290192`20., 
    2409.89899385930510923563238577047597817128`20., 
    2408.74213734344500808602647362086371105578`20., 
    2407.58400776444410641166375114164116887568`20., 
    2406.42460642643555334143796995167249821034`20., 
    2405.26393463321487577974364144765936002184`20., 
    2404.10199368823852601686051861413852114094`20., 
    2402.93878489462244551499224175900257044902`20., 
    2401.77430955514064480530634964828746854436`20., 
    2400.6085689722237994315577585842462164472`20., 
    2399.44156444795786187611379936713621084129`20., 
    2398.27329728408268940443595878093755393801`20., 
    2397.10376878199068776431158143747761889921`20., 
    2395.93298024272547067636793290628069047624`20., 
    2394.76093296698053505264118966522855918852`20., 
    2393.5876282550979518802140893575577361175`20., 
    2392.41306740706707270717813017218113018029`20., 
    2391.23725172252325166841933512494584856297`20., 
    2390.06018250074658298897068006534199659598`20., 
    2388.88186104066065390291930803164532009467`20., 
    2387.70228864083131292610260200015152904679`20., 
    2386.52146659946545342107404820023132143572`20., 
    2385.33939621440981239306757828132918852201`20., 
    2384.15607878314978445593771621060203536625`20., 
    2382.97151560280825090730236054462357150779`20., 
    2381.78570797014442385236539055276198122109`20., 
    2380.59865718155270531614748167327861641683`20., 
    2379.41036453306156128410553825741174744413`20., 
    2378.22083132033241061137398600412925097324`20., 
    2377.03005883865852874111479961139738882986`20., 
    2375.83804838296396617271755987057621671002`20., 
    2374.64480124780248162084602580929672485019`20., 
    2373.4503187273564898065836588430158327572`20., 
    2372.25460211543602382218723472144586476384`20., 
    2371.05765270547771201121511304444219905965`20., 
    2369.85947179054376930605489115931760308024`20., 
    2368.66006066332100296513403741915323591573`20., 
    2367.45942061611983265235666635454847795133`20., 
    2366.25755294087332480156987375751538044647`20., 
    2365.05445892913624120912398165630173917596`20., 
    2363.8501398720841017978526405257852393667`20., 
    2362.64459706051226149606098787247267722519`20., 
    2361.43783178483500117537295778885254719514`20., 
    2360.2298453350846325915523646109670927868`20., 
    2359.02063900091061727267653504622272865381`20., 
    2357.81021407157869929930602686409280033963`20., 
    2356.59857183597005192155933844601700511481`20., 
    2355.38571358258043795826747234436273022858`20., 
    2354.17164059951938392364975786132411736814`20., 
    2352.95635417450936782721945306956570197784`20., 
    2351.739855594885020592895326383965692089`20., 
    2350.52214614759234104356365266820223537904`20., 
    2349.30322711918792439760384001421038138404`20., 
    2348.08309979583820422416022204192067905031`20., 
    2346.86176546331870780421239828784233711971`20., 
    2345.63922540701332484476687362143919318971`20., 
    2344.41548091191358949376362846545919225086`20., 
    2343.19053326261797560356263689748289232612`20., 
    2341.96438374333120519114723165083931504611`20., 
    2340.73703363786357004345358596776229378742`20., 
    2339.50848422963026641650843471783380751012`20., 
    2338.27873680165074277733048388890543580939`20., 
    2337.04779263654806053782475137062451657839`20., 
    2335.8156530165482677301733359429241333319`20., 
    2334.58231922347978557350081878895626344735`20., 
    2333.34779253877280788186765608403691357482`20., 
    2332.1120742434587132639205158532188465902`20., 
    2330.87516561816949006480454109743024146424`20., 
    2329.63706794313717400121897809179906626693`20., 
    2328.39778249819329844077448786211267485727`20., 
    2327.15731056276835727708775442028859737353`20., 
    2325.91565341589128035232670983232481703564`20., 
    2324.67281233618892137919780821811717933662`20., 
    2323.42878860188555831464529312751263703695`20., 
    2322.18358349080240613781131035630934863762`20., 
    2320.93719828035714198508501628398437216426`20., 
    2319.68963424756344259534851552467162800769`20., 
    2318.44089266903053401880752654537303998874`20., 
    2317.19097482096275354307511554924497703171`20., 
    2315.93988197915912379045765314291998327893`20., 
    2314.68761541901293894067333106779392048133`20., 
    2313.43417641551136303351512370492560600492`20., 
    2312.17956624323504030625198745643270302562`20., 
    2310.92378617635771752084435692326510166975`20., 
    2309.66683748864587823633261666530557681659`20., 
    2308.40872145345838898204019803487974350954`20., 
    2307.14943934374615728751626907325345313795`20., 
    2305.88899243205180152542664886980095595948`20., 
    2304.62738199050933252388558338708154285725`20., 
    2303.36460929084384690500536499716357856133`20., 
    2302.10067560437123210672546046321332240437`20., 
    2300.83558220199788304526782960627343238711`20., 
    2299.5693303542204303758504673532671376821`20., 
    2298.30192133112548030957688336359120767424`20., 
    2297.03335640238936594470524423498297521698`20., 
    2295.76363683727791007078724181295170374129`20., 
    2294.49276390464619940445341595150584267163`20., 
    2293.2207388729383702159086499367747058678`20., 
    2291.94756301018740530548887059082672535446`20., 
    2290.673237584014942289917621882558892561`20., 
    2289.39776386163109315818913990844164997743`20., 
    2288.12114310983427505729283775088498941425`20., 
    2286.84337659501105226828271051889106019539`20., 
    2285.56446558313598933348409352729544109678`20., 
    2284.28441133977151529591944993994244699098`20., 
    2283.00321513006779901232442831100196984199`20., 
    2281.72087821876263550141531548938209581809`20., 
    2280.43740187018134328935921664546857353858`20., 
    2279.15278734823667271468882223839854731333`20., 
    2277.8670359164287251551944722264056792198`20., 
    2276.58014883784488313961740155257491685295`20., 
    2275.29212737515975130725954889319636776021`20., 
    2274.00297279063510817891713397486407613075`20., 
    2272.71268634611986870283735874809261854916`20., 
    2271.42126930305005753969006580765203839353`20., 
    2270.12872292244879305083899529081659869102`20., 
    2268.83504846492628195449042084178215759751`20., 
    2267.54024719067982461459041804097140092356`20., 
    2266.2443203594938309276358270591344641631`20., 
    2264.947269230739846772858117465517231258`20., 
    2263.64909506337659099153384951467477579369`20., 
    2262.34979911595000286147025543602831828771`20., 
    2261.04938264659330003300963899301031051838`20., 
    2259.74784691302704689319181476460391770771`20., 
    2258.44519317255923332500968329250147452234`20., 
    2257.14142268208536382898926765476877048769`20., 
    2255.83653669808855697462212455646229874063`20., 
    2254.53053647663965514947499221597212134545`20., 
    2253.2234232733973445740988518824075527825`20., 
    2251.91519834360828555115726361654762958726`20., 
    2250.60586294210725291749189404160108458339`20., 
    2249.29541832331728666814158831999404876853`20., 
    2247.98386574124985272163015500272409063489`20., 
    2246.67120644950501379613723515746545254308`20., 
    2245.35744170127161036646622100499568682325`20., 
    2244.04257274932745167202317904107025326413`20., 
    2242.72660084603951674632112331966808187517`20., 
    2241.40952724336416543882478141792788510151`20., 
    2240.09135319284735940025220395543342812048`20., 
    2238.77207994562489300275119393183691244069`20., 
    2237.45170875242263416667058027766019685596`20., 
    2236.1302408635567750659488367542951375281`20., 
    2234.80767752893409268444545873268188274669`20., 
    2233.48401999805221919584386263984966091158`20., 
    2232.15926951999992214005837237539621764642`20., 
    2230.83342734345739436938211032694862688551`20., 
    2229.50649471669655373791732449056459955811`20., 
    2228.17847288758135250813486454084577088753`20., 
    2226.84936310356809644871517558539859542236`20., 
    2225.51916661170577359812931604675346735096`20., 
    2224.18788465863639266872513308915190152007`20., 
    2222.8555184905953310663908528759137382193`20., 
    2221.52206935341169250117597151591887586342`20., 
    2220.18753849250867416455747382937608729766`20., 
    2218.85192715290394344934806921308465045955`20., 
    2217.51523657921002418855232528026504365606`20., 
    2216.17746801563469238978630914470019437428`20., 
    2214.83862270598138144218662195859157016698`20., 
    2213.49870189364959677304554353545484559515`20., 
    2212.1577068216353399317203997247722374524`20., 
    2210.8156387325315420786772349811374664254`20., 
    2209.47249886852850685784142581244933754711`20., 
    2208.12828847141436263074101722470319008275`20., 
    2206.78300878257552405124231383294581704049`20., 
    2205.43666104299716295999162011171431344064`20., 
    2204.08924649326368857799201065385418390683`20., 
    2202.74076637355923697905963184407410849778`20., 
    2201.39122192366816982122030179573989793762`20., 
    2200.04061438297558231742409672463736568392`20., 
    2198.68894499046782042627320033875605509897`20., 
    2197.33621498473300724377655972734509118151`20., 
    2195.98242560396157857746384827942639691665`20., 
    2194.62757808594682768451089522401733779528`20., 
    2193.27167366808545915584911456608575985813`20., 
    2191.91471358737815192855256583428754316554`20., 
    2190.55669908043013140911811773934592133757`20., 
    2189.19763138345175069057677639020893301359`20., 
    2187.83751173225908084669759520210378775225`20., 
    2186.47634136227451028686971738268901171375`20., 
    2185.11412150852735315557302748407027295226`20., 
    2183.75085340565446676067361980693539639737`20., 
    2182.38653828790087801510684255429813431698`20., 
    2181.02117738912041887683806194609958650469`20., 
    2179.65477194277637077231952469180302684872`20., 
    2178.28732318194211798899079523170705571918`20., 
    2176.91883233930181002270022124699981339298`20., 
    2175.54930064715103286625575265080255436853`20., 
    2174.1787293373974892256452214611578285507`20., 
    2172.80711964156168765079889878947333864134`20., 
    2171.43447279077764056810079714337490911122`20., 
    2170.06079001579357120218979816021151014251`20., 
    2168.68607254697262937492727491414552787322`20., 
    2167.31032161429361616974446158110899216433`20., 
    2165.9335384473517174499204193644425452435`20., 
    2164.55572427535924621968007440962386000735`20., 
    2163.17688032714639381734147957690667101601`20., 
    2161.79700783116198993008219639271742345075`20., 
    2160.41610801547427142023652566177533398656`20., 
    2159.0341821077716599533782549025655148284`20., 
    2157.65123133536354841878765820533097254989`20., 
    2156.26725692518109613324669997992639813212`20., 
    2154.88226010377803281945277949016683219358`20., 
    2153.4962420973314713506889296598781361274`20., 
    2152.10920413164272925373717346634791210691`20., 
    2150.72114743213815896237176689295900425766`20., 
    2149.33207322386998681412034199660520330061`20., 
    2147.94198273151716078333353079597647503758`20., 
    2146.55087717938620694395752459895795127814`20., 
    2145.15875779141209465575922883253575331045`20., 
    2143.76562579115911046811023578569368259158`20., 
    2142.37148240182174073579378291379618835304`20., 
    2140.97632884622556294165821911444451529094`20., 
    2139.58016634682814572130129297067092772627`20., 
    2138.18299612571995758533183336289235181866`20., 
    2136.7848194046252843351191427933346516308`20., 
    2135.38563740490315516830569671326402889731`20., 
    2133.98545134754827747072556834273330247181`20., 
    2132.58426245319198029173940898570145201533`20., 
    2131.18207194210316650036684057741553497645`20., 
    2129.77888103418927361996879294418023613464`20., 
    2128.374690948997243339605676714587299299`20., 
    2126.96950290571449970057235865946397639024`20., 
    2125.56331812316993595698773511660501481779`20., 
    2124.15613781983491010969531777791094169197`20., 
    2122.74796321382424911311169226884689700199`20., 
    2121.33879552289726175504202255436835548203`20., 
    2119.92863596445876020986599336585294392278`20., 
    2118.51748575556009026588374989967137521181`20., 
    2117.10534611290017022799955161963772168142`20., 
    2115.69221825282653849731104908051249641584`20., 
    2114.27810339133640982956436466443756942761`20., 
    2112.86300274407774027482955684542729729996`20., 
    2111.44691752635030080114762146679330790899`20., 
    2110.02984895310675960529898254004307466429`20., 
    2108.61179823895377311424450094194191327784`20., 
    2107.19276659815308568119343555023780391405`20., 
    2105.77275524462263798065858311106133648337`20., 
    2104.35176539193768410726705769245008808064`20., 
    2102.92979825333191738350590718574159144876`20., 
    2101.50685504169860488199506431733704245453`20., 
    2100.08293696959173066829605658442651222446`20., 
    2098.65804524922714777068351929925354436349`20., 
    2097.23218109248373888372793680816199483729`20., 
    2095.80534571090458581296224976982049301409`20., 
    2094.37754031569814766833208461187109864235`20., 
    2092.94876611773944781455946119658968912364`20., 
    2091.51902432757126958698299548459854505585`20., 
    2090.08831615540536078187391781029046634641`20., 
    2088.65664281112364693066675968513223360894`20., 
    2087.22400550427945336798641158098124304853`20., 
    2085.79040544409873610379951317280904883728`20., 
    2084.35584383948132151046790196488078676666`20., 
    2082.92032189900215483593521585476516930329`20., 
    2081.48384083091255755473482379816482233681`20., 
    2080.0464018431414935689681543322214705378`20., 
    2078.60800614329684427186731671837071245832`20., 
    2077.1686549386666924870247809248535193803`20., 
    2075.7283494362206152968459224736597330299`20., 
    2074.2870908426109857742575732894258104901`20., 
    2072.84488036417428363218748238342862679458`20., 
    2071.4017192069324148058159183225224091905`20., 
    2069.95760857659403998309168263497181467636`20., 
    2068.51254967855591209950069935784877683918`20., 
    2067.06654371790422281357625698749705467984`20., 
    2065.61959189941595798014606799791032398295`20., 
    2064.17169542756026213882274768724229769474`20., 
    2062.72285550649981203576127557728508499452`20., 
    2061.27307334009219919722967377693558832691`20., 
    2059.82235013189132157406771051474823707609`20., 
    2058.37068708514878427664311474300496497644`20., 
    2056.91808540281530942045577941251097566717`20., 
    2055.4645462875421551030879560198331371331`20., 
    2054.01007094168254353375273028074838775517`20., 
    2052.5546605672930983372543573129294570695`20., 
    2051.0983163661352910547425740948717201928`20., 
    2049.64103953967689686421905782052673415996`20., 
    2048.18283128909345954433803324775059381992`20., 
    2046.72369281526976570563493447486883483809`20., 
    2045.26362531880132831391729363113917414004`20., 
    2043.80262999999587953116097079428621050316`20., 
    2042.34070805887487289987277991639230924551`20., 
    2040.87786069517499489750784294423001684357`20., 
    2039.41408910834968588816697204244040914421`20., 
    2037.94939449757067049944640701486510979182`20., 
    2036.48377806172949745296970729426787537153`20., 
    2035.01724099943908887779991807340891296036`20., 
    2033.54978450903529913660971910796598838208`20., 
    2032.08140978857848319517856205134211569356`20., 
    2030.61211803585507456648926712661505961079`20., 
    2029.14191044837917286141266224257854855684`20., 
    2027.67078822339414097869810846339884917023`20., 
    2026.19875255787421196773068853630040143375`20., 
    2024.72580464852610559827298678915732836904`20., 
    2023.25194569179065467218133030045908383574`20., 
    2021.77717688384444111287368940126754249194`20., 
    2020.30149942060144186912977339390348397996`20., 
    2018.82491449771468467062385563371545623471`20., 
    2017.34742331057791367342820044868027978659`20., 
    2015.86902705432726503458035250055783490394`20., 
    2014.38972692384295245568172824861189186191`20., 
    2012.90952411375096273638869302495816557033`20., 
    2011.42841981842476137957142385933583012583`20., 
    2009.94641523198700829085119116443613080519`20., 
    2008.46351154831128361618412235078303237358`20., 
    2006.97970996102382376213995665779766944168`20., 
    2005.49501166350526764452872249416213416248`20., 
    2004.00941784889241321205766783836946285136`20., 
    2002.52292971007998429275619589776311022018`20., 
    2001.03554843972240781198909288323355417934`20., 
    1999.54727523023560143198912040683407704668`20., 
    1998.05811127379877166398026893227227080651`20., 
    1996.56805776235622250513386950128161726211`20., 
    1995.07711588761917465380263062455155718969`20., 
    1993.58528684106759535771385333466367918273`20., 
    1992.09257181395203895107398533046643508701`20., 
    1990.59897199729549813784377040881118909485`20., 
    1989.10448858189526607978806002693164209715`20., 
    1987.60912275832480934928847293706846222419`20., 
    1986.11287571693565180833217705385242838523`20., 
    1984.61574864785926947655785598904542613166`20., 
    1983.11774274100899645275221497453073292093`20., 
    1981.61885918608194195574905702452393889387`20., 
    1980.11909917256091855228997881724098538188`20., 
    1978.61846388971638164106313743294304335012`20., 
    1977.11695452660838026384644932185010632267`20., 
    1975.61457227208851931644621552502755124786`20., 
    1974.11131831480193323394382771200702655218`20., 
    1972.60719384318927122664429862808325797669`20., 
    1971.10220004548869414506337736669769746988`20., 
    1969.59633810973788305429755621390840200746`20., 
    1968.08960922377605960019605960207829492977`20., 
    1966.58201457524601825189874508570940627476`20., 
    1965.07355535159617050752167358711377579023`20., 
    1963.56423274008260115206597226856850034071`20., 
    1962.05404792777113665899869185372639372887`20., 
    1960.54300210153942582940995185385353754024`20., 
    1959.03109644807903276519220458459391440805`20., 
    1957.51833215389754227531850127152362641971`20., 
    1956.00471040532067781702092155217308104163`20., 
    1954.49023238849443207649168835148509354022`20., 
    1952.97489928938721029665194211500996516382`20., 
    1951.45871229379198646256085733948169482364`20., 
    1949.94167258732847245817507825508957463964`20., 
    1948.4237813554453003114198254256692184575`20., 
    1946.90503978342221764790315079038366720033`20., 
    1945.38544905637229647709854487657739457497`20., 
    1943.8650103592441554384434620355020550059`20., 
    1942.34372487682419563855755519661075848246`20., 
    1940.8215937937388502146799269912643241023`20., 
    1939.29861829445684776346514055091410636836`20., 
    1937.77479956329148977846893421443007947746`20., 
    1936.25013878440294224400261211485291761048`20., 
    1934.72463714180054153754622558691038352836`20., 
    1933.19829581934511479759144039667794768394`20., 
    1931.67111600075131491864216472946878683435`20., 
    1930.14309886958997034014160409211852402085`20., 
    1928.61424560929044980132567970649642376798`20., 
    1927.08455740314304223943222907984558558355`20., 
    1925.55403543430135201433090655195266630198`20., 
    1924.02268088578470964848830433570210481256`20., 
    1922.49049494048059827725489740337537824824`20., 
    1920.95747878114709601076365379896420382683`20., 
    1919.42363359041533441527352863510249107747`20., 
    1917.8889605507919733285838752307145413214`20., 
    1916.35346084466169223119768706189094435372`20., 
    1914.81713565428969840223249198122211187924`20., 
    1913.27998616182425209667796391740496282883`20., 
    1911.74201354929920898848956127343267383612`20., 
    1910.20321899863658013219877584614611586206`20., 
    1908.66360369164910970422428811046384686969`20., 
    1907.12316881004287079389626802773126039242`20., 
    1905.58191553541987952337042687366045667565`20., 
    1904.03984504928072778512181548005665843144`20., 
    1902.49695853302723489558379826906009707508`20., 
    1900.95325716796511847374856238005929284414`20., 
    1899.40874213530668486418584175740844686967`20., 
    1897.86341461617353943498059656018227533289`20., 
    1896.31727579159931709255300440737646243577`20., 
    1894.7703268425324333672205860310316141622`20., 
    1893.22256894983885643570838886340759770589`20., 
    1891.67400329430490045962517604858855022319`20., 
    1890.12463105664004063221831913356237107612`20., 
    1888.57445341747975033951490241883852788683`20., 
    1887.02347155738836085626928900481798221672`20., 
    1885.47168665686194401198650051686335228402`20., 
    1883.91909989633121827769521918473283655116`20., 
    1882.36571245616447874012360777037356272688`20., 
    1880.81152551667055144650562902620471328467`20., 
    1879.25654025810177262043590847533087089859`20., 
    1877.70075786065699326701881972875121813362`20., 
    1876.1441795044846097040444121428896590501`20., 
    1874.58680636968562057509272636555313620512`20., 
    1873.02863963631671092034229609391627379224`20., 
    1871.46968048439336390146223171443601754087`20., 
    1869.90993009389300079832493042997973753235`20., 
    1868.34938964475814991741356832601130286306`20., 
    1866.78806031689964507474123003447976094821`20., 
    1865.22594329019985433987367960063425242514`20., 
    1863.6630397445159397522829749203809600006`20., 
    1862.09935085968314874678273917608217076172`20., 
    1860.53487781551813805123705957810885752582`20., 
    1858.96962179182233084712360551401652831638`20., 
    1857.4035839683853080118983630037239734304`20., 
    1855.83676552498823429148590050820697375068`20., 
    1854.26916764140732028163766836120959713082`20., 
    1852.70079149741732112839468439075445298594`20., 
    1851.1316382727950728904941166470445901316`20., 
    1849.56170914732306754030664895212191583453`20., 
    1847.99100530079306761481889021652976872077`20., 
    1846.4195279130097615643191355548315902841`20., 
    1844.84727816379446088384307656078327103786`20., 
    1843.27425723298884015112707016135801228766`20., 
    1841.70046630045872113483971157632070734264`20., 
    1840.12590654609790217825804950242897711779`20., 
    1838.5505791498320341063641040681477079149`20., 
    1836.97448529162254394860262390067675060354`20., 
    1835.39762615147060781530543023503539575444`20., 
    1833.82000290942117431309539277723252040058`20., 
    1832.24161674556703993347918782539778649656`20., 
    1830.66246884005297789936860891071281486504`20., 
    1829.08256037307992200648242601582137103969`20., 
    1827.50189252490920705052270561690562421671`20., 
    1825.92046647586686748674019132283406149228`20., 
    1824.33828340634799602605288468089493409958`20., 
    1822.75534449682116393131144111754019550094`20., 
    1821.17165092783290483866649410797876217193`20., 
    1819.58720388001226399233963272373595369987`20., 
    1818.00200453407541484648557810406128698091`20., 
    1816.41605407083034505531322865489317769612`20., 
    1814.82935367118161394226376512600815472882`20., 
    1813.24190451613518361088201131781733704575`20., 
    1811.65370778680332593412080690598909193489`20., 
    1810.06476466440960773524631759741680984108`20., 
    1808.47507633029395655232500601370493975318`20., 
    1806.88464396591780945953139437476918641701`20., 
    1805.29346875286934750228169299988331414941`20., 
    1803.70155187286881838953470366652300643875`20., 
    1802.10889450777395017557190514337872965294`20., 
    1800.51549783958545875523795654510936166211`20., 
    1798.92136305045265209105655406607183787539`20., 
    1797.32649132267913418790104120107824241855`20., 
    1795.7308838387286119310616207878208635368`20., 
    1794.13454178123080800667946604664519828343`20., 
    1792.53746633298748322968126140425165393069`20., 
    1790.93965867697857171361524021040260426193`20., 
    1789.34111999636843242923184091694227238271`20., 
    1787.74185147451222081433954949012370375938`20., 
    1786.14185429496238421647082310135518878954`20., 
    1784.54112964147528507228625780841729719043`20., 
    1782.93967869801795585349995113374986212453`20., 
    1781.33750264877498993849836735000593781164`20., 
    1779.7346026781555727018223986016116020216`20., 
    1778.13097997080065725036153951011399112025`20., 
    1776.52663571159028937554425395361139523673`20., 
    1774.92157108565108643507402531531358906893`20., 
    1773.31578727836387502593070512768344630316`20., 
    1771.70928547537149246250613563104238827922`20., 
    1770.10206686258675722994612889726839879697`20., 
    1768.4941326262006137431021441526578980958`20., 
    1766.88548395269045690602962359996794741721`20., 
    1765.27612202882864213577983698448861222586`20., 
    1763.66604804169118668739175720372243927102`20., 
    1762.0552631786666682945729429304097556181`20., 
    1760.44376862746532732263601083354200311265`20., 
    1758.83156557612837881690165928067591290411`20., 
    1757.2186552130375410210610952745642580059`20., 
    1755.60503872692478713597983544820657634505`20., 
    1753.99071730688232729018975473060331550023`20., 
    1752.3756921423728278989241805693694161712`20., 
    1750.75996442323987579906753663421108293796`20., 
    1749.14353533971869476288064131058077835049`20., 
    1747.5264060824471222138875518828583398984`20., 
    1745.90857784247685419393009199223460866566`20., 
    1744.29005181128496686116997581436980158909`20., 
    1742.67082918078572303480139983256434691051`20., 
    1741.05091114334267254348213147423293863533`20., 
    1739.43029889178105538104864138366633109434`20., 
    1737.80899361940051692499776002197421997186`20., 
    1736.18699651998814473053739457639518423811`20., 
    1734.56430878783183667577210757308624788604`20., 
    1732.94093161773401050183202985481494386322`20., 
    1731.31686620502566506550767014614300415584`20., 
    1729.69211374558080390124621607300190506853`20., 
    1728.06667543583123197421961533936440215246`20., 
    1726.44055247278173679660865787179044797735`20., 
    1724.81374605402566537527253585133785044302`20., 
    1723.18625737776090876059616604288171957064`20., 
    1721.55808764280630627352790235253775506211`20., 
    1719.9292380486184818006314854815170282164`20., 
    1718.29970979530912486536444357064099318704`20., 
    1716.66950408366272950773943760376979008461`20., 
    1715.0386221151548043339960331220004007098`20., 
    1713.40706509197056743287041759431803770549`20., 
    1711.77483421702414019545305407624141147169`20., 
    1710.14193069397825442141306241816071118631`20., 
    1708.50835572726448744547710412391039875648`20., 
    1706.87411052210404037440295114426804670787`20., 
    1705.23919628452907488619575263325907407921`20., 
    1703.60361422140462440987842952338946555824`20., 
    1701.96736554045109587563425803695259656572`20., 
    1700.33045145026737860146397269914388196823`20., 
    1698.69287316035457726350211663659524544383`20., 
    1697.05463188114038628266369331029775244052`20., 
    1695.4157288240041233501727537095472217857`20., 
    1693.77616520130244020857340981254985526098`20., 
    1692.1359422263957292028377606799684301061`20., 
    1690.49506111367524451794315369583165456394`20., 
    1688.85352307859095742455288383205092663816`20., 
    1687.211329337680165262939684639453845278`20., 
    1685.56848110859687430675901295655248358542`20., 
    1683.92497961014197706240593662004361793838`20., 
    1682.280826062294244976148984649864345541`20., 
    1680.63602168624215793967585879486974400313`20., 
    1678.99056770441659240473313334668383148996`20., 
    1677.34446534052439033879187855747137656095`20., 
    1675.69771581958283167569230232240711991426`20., 
    1674.05032036795503333755229553396818140698`20., 
    1672.40228021338629832637555377239661709702`20., 
    1670.75359658504143880524069723907595173897`20., 
    1669.10427071354309750913554311958625217388`20., 
    1667.45430383101109224382686915263933523607`20., 
    1665.80369717110280864699488972999975340682`20., 
    1664.15245196905466679854353013875214367553`20., 
    1662.50056946172468767581194591093735864759`20., 
    1660.84805088763618585360646275230787767882`20., 
    1659.19489748702261524774748414018906407343`20., 
    1657.54111050187359509333858744852318584313`20., 
    1655.88669117598214373432194902158257947381`20., 
    1654.2316407549931481781414563742606349353`20., 
    1652.57596048645309773749528793976539988125`20., 
    1650.91965161986111043917079232610226439995`20., 
    1649.26271540672128122670570590734937944693`20., 
    1647.60515310059638131794023651412617508961`20., 
    1645.94696595716293839918045468525436828163`20., 
    1644.28815523426772764338526101386697174398`20., 
    1642.62872219198570382914901716902142834052`20., 
    1640.96866809267940510884056543658175262107`20., 
    1639.30799420105985922656346199762229323143`20., 
    1637.64670178424902321803126069119261877036`20., 
    1635.98479211184378783333475625256309378571`20., 
    1634.32226645598157810816089311590484930273`20., 
    1632.6591260914075816674644754868815175076`20., 
    1630.99537229554363647596267423304992123852`20., 
    1629.33100634855880985009387021252612155944`20., 
    1627.66602953344170061413480099461446438055`20., 
    1626.00044313607449631678084712709366111306`20., 
    1624.33424844530881742133686774623304319502`20., 
    1622.66744675304338034030551892496099413536`20., 
    1621.00003935430351110104990929639051554859`20., 
    1619.33202754732254130068558151369481457232`20., 
    1617.66341263362511783264145773344021306267`20., 
    1615.99419591811245764151542460077367428928`20., 
    1614.32437870914957848390515338609372451609`20., 
    1612.65396231865453633765470871204961508463`20., 
    1610.98294806218969970712333992403916035988`20., 
    1609.31133725905509061421614720431158960378`20., 
    1607.6391312323838215404354358493967924374`20., 
    1605.96633130923965699038777505956622046627`20., 
    1604.29293882071672767813537191977553975101`20., 
    1602.61895510204142459047695500374676832105`20., 
    1600.94438149267649935149015813707072702806`20., 
    1599.26921933642739639610971196263711132233`20., 
    1597.59346998155084145263359483767035686853`20., 
    1595.91713478086570973015415901701059888477`20., 
    1594.24021509186619600214311651662090343473`20., 
    1592.56271227683730746674386139507939128766`20., 
    1590.8846277029726988425309063835278042024`20., 
    1589.20596274249486762019432238743082554243`20., 
    1587.52671877277772573022642116078154864478`20., 
    1585.84689717647156209847590463877881398225`20., 
    1584.16649934163040863945575648149154647306`20., 
    1582.48552666184182017542636117329132436067`20., 
    1580.803980536359076561222620757488078442`20., 
    1579.12186237023581293406875601886285677862`20., 
    1577.4391735744630814875617362693184117335`20., 
    1575.75591556610884548276002210225166693265`20., 
    1574.07208976845990334986923157700680526301`20., 
    1572.38769761116623769417976747484697760094`20., 
    1570.70274053038778079232635873344156960188`20., 
    1569.01721996894358474208868934479393461691`20., 
    1567.33113737646338080316580720280384836155`20., 
    1565.64449420954150862982063505050107475778`20., 
    1563.95729193189319204105630854068007859533`20., 
    1562.26953201451313369198229519103980491229`20., 
    1560.58121593583639649307490334528791916689`20., 
    1558.89234518190153486385891812113145057737`20., 
    1557.20292124651593389578195498706651200452`20., 
    1555.51294563142330922730891844804670855087`20., 
    1553.82241984647331489408076183273835493394`20., 
    1552.13134540979320059989464101584682953529`20., 
    1550.43972384796145375181719639982484744326`20., 
    1548.7475566961833552065234541136475172539`20., 
    1547.0548454984683709766146435564169126069`20., 
    1545.36159180780929513696630283761994016465`20., 
    1543.66779718636305184399063859959793197067`20., 
    1541.97346320563305672714144601833864506846`20., 
    1540.27859144665302992434646211056908589599`20., 
    1538.58318350017214470389136400854688646543`20., 
    1536.88724096684138693749280839647744347163`20., 
    1535.1907654574009916561508484456453480759`20., 
    1533.49375859286881352556279461293748035177`20., 
    1531.79622200472947831560569182403247511731`20., 
    1530.09815733512415230340991527330721829091`20., 
    1528.39956623704075603724217631216314634723`20., 
    1526.70045037450443799489177479087344565156`20., 
    1525.00081142276811239239792056330483874518`20., 
    1523.30065106850285373453153647665590376307`20., 
    1521.59997100998792864617971056798726208583`20., 
    1519.89877295730023308346167387831772723716`20., 
    1518.19705863250289019597761662547775322537`20., 
    1516.4948297698327508992652914918050029839`20., 
    1514.79208811588652562289699932112993278451`20., 
    1513.08883542980526172976187800776168260301`20., 
    1511.38507348345686676262325185991636028348`20., 
    1509.68080406161636297342710273105544648431`20., 
    1507.97602896214354353933401322333457690332`20., 
    1506.27074999615768547931396689111483602416`20., 
    1504.56496898820895857077081591656725796387`20., 
    1502.85868777644615354370982703973655538835`20., 
    1501.1519082127803365194988667852876525024`20., 
    1499.44463216304402008393162074789289152249`20., 
    1497.73686150714542456441697033379091971158`20., 
    1496.02859813921738604588639180059004649237`20., 
    1494.3198439677604504396326270568595251474`20., 
    1492.6106009157796755471276056872550849486`20., 
    1490.90087092091464557358303756298604279714`20., 
    1489.19065593556218498373586826251942969534`20., 
    1487.47995792699124099878524623408181465036`20., 
    1485.76877887744938645603996719032227307674`20., 
    1484.05712078426037724299190382775319509974`20., 
    1482.3449856599121811305494074745936667539`20., 
    1480.63237553213487762550247774777385597128`20., 
    1478.91929244396781150363352339148510504211`20., 
    1477.20573845381536604024158532563485396063`20., 
    1475.49171563549070569662575569310429103897`20., 
    1473.77722607824682222615562405390567289889`20., 
    1472.0622718867942029133379471382960898303`20., 
    1470.34685518130442503970404172437279009094`20., 
    1468.63097809739896677186758262107322725684`20., 
    1466.91464278612251158473048934423378544979`20., 
    1465.19785141390001116600256027417375634097`20., 
    1463.48060616247676060078586085921891308482`20., 
    1461.76290922884072961505735149159509941846`20., 
    1460.04476282512638487667040494696948390344`20., 
    1458.32616917849923092810903926438098096605`20., 
    1456.60713053102029137646673092118327060943`20., 
    1454.88764913948974761617975021514943672346`20., 
    1453.16772727526894973518576353322162448731`20., 
    1451.44736722408001348435320216803670896096`20., 
    1449.72657128578221840444382483414175549621`20., 
    1448.00534177412442553750887376357992981463`20., 
    1446.28368101647273873468463334694365959843`20., 
    1444.5615913535126415446783078771737402315`20., 
    1442.83907513892485216161651875578550380089`20., 
    1441.11613473903415206140479501315144176762`20., 
    1439.39277253243045989481345643572059895658`20., 
    1437.66899090956144106327178984255334846518`20., 
    1435.94479227229596530663244881156798765241`20., 
    1434.22017903345774970351432912339956743876`20., 
    1432.49515361632855284151108261174921182939`20., 
    1430.76971845412031766746266623101327747304`20., 
    1429.04387598941569578052626838205318370887`20., 
    1427.3176286735764247776642205439019862734`20., 
    1425.59097896611907278719377491431511794705`20., 
    1423.86392933405771060484665437522067300575`20., 
    1422.13648225121312193952578335184154776867`20., 
    1420.40864019748821622999592457341069523694`20., 
    1418.68040565810936634135717541244636548439`20., 
    1416.95178112283345520712073654938143255525`20., 
    1415.22276908512048114704117771571172328437`20., 
    1413.49337204127164114146202924537335841222`20., 
    1411.76359248953288473831988268673366063219`20., 
    1410.03343292916400844602033547630783285042`20., 
    1408.30289585947344133823765320897875608769`20., 
    1406.57198377881895705548070467824185211868`20., 
    1404.84069918357463529826820763712261337576`20., 
    1403.10904456706448710739149096288316302218`20., 
    1401.37702241846325253081972534183955970531`20., 
    1399.6446352216649764698651480653078032328`20., 
    1397.91188545412006833706886277375921251566`20., 
    1396.1787755856416533746241422484645546799`20., 
    1394.44530807718212777657382699442048565589`20., 
    1392.71148537958093580395500386326023398804`20., 
    1390.97730993228469452518367227025048540255`20., 
    1389.24278416204090027269821817407295018848`20., 
    1387.50791048156655997318883206367572193838`20., 
    1385.77269128819319974921236953297290232623`20., 
    1384.03712896248981214713983416556438958932`20., 
    1382.30122586686541154024621959239177780723`20., 
    1380.5649843441529741857764506429810103636`20., 
    1378.82840671617664456202025429086266725025`20., 
    1377.09149528230419244082353223588083531861`20., 
    1375.35425231798680511429656618297261213873`20., 
    1373.61668007328839573319610438761266937132`20., 
    1371.87878077140670126294551826056092891671`20., 
    1370.14055660718853155231855098885409795614`20., 
    1368.40200974564161387036632141558807120708`20., 
    1366.66314232044555443414315022274925276475`20., 
    1364.92395643246450936619069540574961114354`20., 
    1363.18445414826422164186372391683417322844`20., 
    1361.44463749863613738431840453648206161184`20., 
    1359.70450847713136383221841980395890043752`20., 
    1357.96406903860727196023697699192180655959`20., 
    1356.22332109778957862335232386237348128858`20., 
    1354.48226652785276580502950155839530498593`20., 
    1352.74090715902170769735393472340443125318`20., 
    1350.99924477719737959126335828106757144996`20., 
    1349.25728112260951561688120888847457688312`20., 
    1347.51501788849906500735808696106070227245`20., 
    1345.77245671983326857782860083720816608416`20., 
    1344.02959921205613838385855788849237322195`20., 
    1342.28644690987707398004193184864718252168`20., 
    1340.54300130610028832957904389893956406406`20., 
    1338.79926384049764527330180137545553244858`20., 
    1337.05523589872742866978005554864392456494`20., 
    1335.31091881130147105018608339932050508386`20., 
    1333.56631385260296714135228068238273217376`20., 
    1331.82142223995718521193961850995446802122`20., 
    1330.07624513275716726811644945109742273622`20., 
    1328.33078363164637810768982862839169164667`20., 
    1326.58503877776012363702571880054278414579`20., 
    1324.8390115520274112232388841139288835026`20., 
    1323.09270287453476980986026610362067330091`20., 
    1321.34611360395338573356271257954614243083`20., 
    1319.59924453703074235563798724659818792768`20., 
    1317.85209640814777852022586740802614957124`20., 
    1316.10466988894240326453358173962845862428`20., 
    1314.35696558800002295900032131506657145752`20., 
    1312.60898405061155299813952835974789881528`20., 
    1310.86072575859920016619915022005511951131`20., 
    1309.1121911302101147501190668135201918088`20., 
    1307.36338052007782425717909501320423932372`20., 
    1305.61429421925117410873762664312802640961`20., 
    1303.86493245529031581147377264758061759142`20., 
    1302.11529539242910072845494277408919000865`20., 
    1300.36538313180305854072632985969079847979`20., 
    1298.6151957117419646380967998078742558158`20., 
    1296.86473310812583080722182551532071282518`20., 
    1295.11399523480298946195366957520899315245`20., 
    1293.36298194406878401019232002430808342448`20., 
    1291.61169302720322745224647252736572013755`20., 
    1289.86012821506584858695561367873974788691`20., 
    1288.10828717874581083847689395229611456016`20., 
    1286.35616953026526322631865154485153622329`20., 
    1284.60377482333376684141513673281586727745`20., 
    1282.85110255415153375697586611887599605539`20., 
    1281.09815216225911892574537954455861707693`20., 
    1279.34492303143111956139896024454387423522`20., 
    1277.59141449061136097180399957751273300491`20., 
    1275.83762581488698294110649423551872964005`20., 
    1274.08355622649878661658437680932661868967`20., 
    1272.32920489588515845184445673837326073078`20., 
    1270.5745709427568550351604440866935671507`20., 
    1268.81965343719991047564754582964603825498`20., 
    1267.06445140080391625835349243350460939916`20., 
    1265.30896380781292188569308791723698263308`20., 
    1263.55318958629621291940654002689493903899`20., 
    1261.79712761933624089939333981492014372668`20., 
    1260.0407767462310066748049758070161282934`20., 
    1258.28413576370823453061150812253386698809`20., 
    1256.52720342714871868615874703210991472856`20., 
    1254.76997845181627580674892666365725004022`20., 
    1253.01245951409179660424037248526126756657`20., 
    1251.25464525270895588522603695964629876058`20., 
    1249.49653426998921299501104523565303104334`20., 
    1247.73812513307381294855341070469792384181`20., 
    1245.97941637515058207289805411484118633329`20., 
    1244.22040649667340014163449328444178207356`20., 
    1242.46109396657232319178916911758642898489`20., 
    1240.70147722345242691137226406732140618734`20., 
    1238.94155467677953911193816220648639061458`20., 
    1237.18132470805113080506116026084746075598`20., 
    1235.42078567195073824738115474370069853586`20., 
    1233.65993589748439248417886530130378610047`20., 
    1231.89877368909763790269575230032667572611`20., 
    1230.13729732777182662032135601969055687774`20., 
    1228.37550507209848071829516815455372197828`20., 
    1226.61339515933061895161915408006147698278`20., 
    1224.85096580641004820870207430687192937034`20., 
    1223.08821521096972227458071025949803943202`20., 
    1221.32514155231037101144395185160023941763`20., 
    1219.56174299235070157962607239389850153928`20., 
    1217.79801767655056947955044870455936746809`20., 
    1216.03396373480661072706158025781941852675`20., 
    1214.2695792823199171363270103264033682317`20., 
    1212.50486242043542425927441324749452900371`20., 
    1210.7398112374527658292606502796224638526`20., 
    1208.97442380940842941729614837398835196376`20., 
    1207.20869820082912529589301966441495252382`20., 
    1205.4426324654563541080764058140381213027`20., 
    1203.67622464694222877128220104505449472738`20., 
    1201.90947277951667204502559393078259345188`20., 
    1200.14237488862617331672689884174571844205`20., 
    1198.37492899154434639214085744693859604303`20., 
    1196.60713309795458441523026016225889228038`20., 
    1194.83898521050515850506342591700880078655`20., 
    1193.07048332533715331928809094146186877098`20., 
    1191.30162543258567558535285211285520543376`20., 
    1189.53240951685481074648486707104390602229`20., 
    1187.76283355766683832687737188787347875181`20., 
    1185.9928955298862485184697525511829930995`20., 
    1184.22259340411913092918486972349972553255`20., 
    1182.45192514708853151752206075687898082629`20., 
    1180.68088872198639558670075000536769102207`20., 
    1178.90948208880273344536129728948438956981`20., 
    1177.13770320463266108883194222497079939418`20., 
    1175.36555002396198114719902101400292392533`20., 
    1173.59302049893197951926364219776042556028`20., 
    1171.82011257958412070273569423198043141093`20., 
    1170.04682421408532998004000400781317294627`20., 
    1168.27315334893455346593563253792718276438`20., 
    1166.49909792915128770777849776567573866201`20., 
    1164.72465589844676919095121817091032010235`20., 
    1162.94982519937851087863165414840429326562`20., 
    1161.17460377348886794261788693284340560191`20., 
    1159.39898956142830825385868754082692624925`20., 
    1157.62298050306405512822574136233975619426`20., 
    1155.84657453757476039215987140034766380183`20., 
    1154.06976960353185516771293757655016583957`20., 
    1152.29256363896821399680609925050018315513`20., 
    1150.51495458143475514562800762654940024854`20., 
    1148.73694036804558626296690669582699478033`20., 
    1146.95851893551229011727446102314213698182`20., 
    1145.17968822016793000803626628507902816357`20., 
    1143.40044615798133873439610519010750466635`20., 
    1141.62079068456223879989269767840481135017`20., 
    1139.84071973515772492365823242998869736148`20., 
    1138.06023124464062299763093086516952288767`20., 
    1136.27932314749022245350212651219034207827`20., 
    1134.49799337776586165467173800659646112452`20., 
    1132.71623986907382847507972716999398535391`20., 
    1130.9340605545280207313918960667665817009`20., 
    1129.15145336670479365604674545895561078309`20., 
    1127.36841623759240419005657913513516223278`20., 
    1125.58494709853544458580902331850294133403`20., 
    1123.80104388017464068684909448977607700978`20., 
    1122.01670451238237333510382800351752017017`20., 
    1120.23192692419426468371391539146422843463`20., 
    1118.44670904373715479929667062443389844318`20., 
    1116.66104879815377785124555800494011838533`20., 
    1114.87494411352443143432898644689793255792`20., 
    1113.0883929147859171778993143104742619266`20., 
    1111.3013931256480157809022336605775423389`20., 
    1109.51394266850774499412008804117478303081`20., 
    1107.72603946436163486448209735777902694905`20., 
    1105.93768143271624077304428567777460059754`20., 
    1104.14886649149710144818019345470179862716`20., 
    1102.35959255695633622616998438053218474259`20., 
    1100.5698575435790633681661853227023190524`20., 
    1098.77965936398880922893122293834972992911`20., 
    1096.98899592885206651045948916317880479219`20., 
    1095.19786514678214872262242892990109790079`20., 
    1093.40626492424247731178590278148999934984`20., 
    1091.61419316544942770402175888831377307625`20., 
    1089.82164777227485073787272152307003009758`20., 
    1088.02862664414837662727966332752443922347`20., 
    1086.23512767795959969185168393162755435987`20., 
    1084.44114876796023361183013377194634237143`20., 
    1082.64668780566631890071864308021846513998`20., 
    1080.8517426797605566307440829007895375402`20., 
    1079.05631127599483518556341150900447631858`20., 
    1077.26039147709300994087444213908411664013`20., 
    1075.46398116265398927629322553495197252645`20., 
    1073.66707820905517419010489913716253601586`20., 
    1071.86968048935629301103760124213044473816`20., 
    1070.07178587320366726655749899100142584098`20., 
    1068.27339222673493966365440464808059902875`20., 
    1066.47449741248429035386682740505546327606`20., 
    1064.67509928928816317748842979992754002456`20., 
    1062.87519571219151940058024186294938651696`20., 
    1061.07478453235463256067466365386910670194`20., 
    1059.27386359696043441104371580952407834139`20., 
    1057.47243074912241858735324864758757891444`20., 
    1055.67048382779310550280121763397028199839`20., 
    1053.86802066767306909696252713518213836536`20., 
    1052.06503909912052340823979053327511918506`20., 
    1050.26153694806146449896077026869735918027`20., 
    1048.45751203590036102491023189957052517241`20., 
    1046.65296217943138469682484784065146495486`20., 
    1044.84788519075017001976638580889193613608`20., 
    1043.04227887716609100724950931939898723479`20., 
    1041.23614104111504104075335574589457606869`20., 
    1039.42946948007270067230572258775568577844`20., 
    1037.62226198646827693901555019285011234556`20., 
    1035.81451634759869666487477060894573890676`20., 
    1034.00623034554323525830083537883760709721`20., 
    1032.19740175707856166551021331994780855378`20., 
    1030.3880283535941794019834118803938922635`20., 
    1028.57810790100824294940471751441143794517`20., 
    1026.76763815968372826625322413561385106964`20., 
    1024.95661688434493570971909475121735261848`20., 
    1023.14504182399430329816528004131310605099`20., 
    1021.33291072182950795060248693143272648422`20., 
    1019.52022131516083211654902234391034678871`20., 
    1017.70697133532877305045920927574743487439`20., 
    1015.89315850762187188416719148328435013157`20., 
    1014.07878055119473960333405392871885059025`20., 
    1012.26383517898625703480922998492513514945`20., 
    1010.44832009763792599649555981837718357796`20., 
    1008.63223300741234884537615970011969740301`20., 
    1006.81557160211181377870904711943243575236`20., 
    1004.99833356899696339415605812610319190066`20., 
    1003.18051658870552419315657298302073302014`20., 
    1001.36211833517107491478270606933254450106`20., 
    999.54313647554183181143923527473475576198`20., 
    997.72356867009942922012783807175674183976`20., 
    995.90341257217767404081256554524047572838`20., 
    994.08266582808125300412689773848049612011`20., 
    992.261326077004371891862172862115324772`20., 
    990.4393909509493061631592017187098045624`20., 
    988.61685807464484273504418990672301006806`20., 
    986.79372506546459296602139166418811906113`20., 
    984.96998953334515719412482413154800141523`20., 
    983.1456490807041214845505223235423152809`20., 
    981.32070130235786754528618595519718360595`20., 
    979.49514378543917707070246128159036989606`20., 
    977.66897410931461207166685364135942059759`20., 
    975.84218984550165304529918255577229302644`20., 
    974.01478855758557712702598877529468422619`20., 
    972.18676780113605865123079489862992202612`20., 
    970.35812512362347482375263202640991901566`20., 
    968.52885806433489947906026072813903174302`20., 
    966.69896415428976815651007451490070533705`20., 
    964.8684409161551979831446990743762490268`20., 
    963.03728586416094609454116134999184176952`20., 
    961.20549650401399055987282399207043053408`20., 
    959.3730703328127180022699814707415875133`20., 
    957.54000483896070232046857834288245350219`20., 
    955.70629750208005912239548743165248702272`20., 
    953.87194579292436067557051556709044935213`20., 
    952.03694717329109636287186074784676016942`20., 
    950.20129909593366380521509387310012178692`20., 
    948.36499900447287597497410858699524294453`20., 
    946.52804433330796977549693533622654727814`20., 
    944.69043250752710170284051385527782790378`20., 
    942.85216094281731633589368827772572697011`20., 
    941.01322704537397352042776564427640257722`20., 
    939.17362821180962022138092868210576922246`20., 
    937.33336182906229311593711205508700790272`20., 
    935.49242527430323808780832078740839017698`20., 
    933.65081591484403286069248026111493898236`20., 
    931.80853110804309907628942649816108596041`20., 
    929.96556820121159017965833336491831592017`20., 
    928.12192453151864152224183586976174274012`20., 
    926.27759742589596913072318286450788226992`20., 
    924.43258420094180361818601641850643999132`20., 
    922.58688216282414573297877732313649110442`20., 
    920.74048860718333005041683677893296602049`20., 
    918.8934008190338833131562732819237228877`20., 
    917.04561607266566391791517936774826119095`20., 
    915.19713163154426902937237513984112443788`20., 
    913.34794474821069577670888841737906290681`20., 
    911.4980526641802429545417990956743254048`20., 
    909.64745260984063960809739687386330320999`20., 
    907.79614180434938683254188851451218119312`20., 
    905.94411745553029905858983400863070795913`20., 
    904.09137675976923103099521051422320317031`20., 
    902.2379169019089766134445776688516999261`20., 
    900.38373505514332547285790019162931166331`20., 
    898.52882838091026360829606473502482355234`20., 
    896.67319402878430359470485003672306425656`20., 
    894.81682913636793030971662161956106405732`20., 
    892.9597308291821478028003756453824136435`20., 
    891.10189622055611285030833561455942622514`20., 
    889.24332241151584061751669311602750489044`20., 
    887.3840064906719677196959552822640105282`20., 
    885.52394553410655783866240719644128213625`20., 
    883.66313660525893490923906854222249627843`20., 
    881.80157675481052874166780107363218608878`20., 
    879.93926302056871779133240528044311834553`20., 
    878.07619242734965362623705203352556184771`20., 
    876.21236198686005147558959258711781035496`20., 
    874.34776869757793106961252010517811344758`20., 
    872.48240954463229180138598280018124293597`20., 
    870.61628149968170605615071596817273324441`20., 
    868.74938152079181436209065255595682567489`20., 
    866.8817065523117058191950863335724243945`20., 
    865.01325352474916705938168297600825815684`20., 
    863.14401935464478278165081478205304661749`20., 
    861.27400094444487069063853740577266944991`20., 
    859.40319518237323344553347041859837829442`20., 
    857.53159894230170999890894777937319987819`20., 
    855.65920908361950847157683686089181564651`20., 
    853.78602245110130247006794585642135069225`20., 
    851.91203587477407250775438614515131219896`20., 
    850.03724616978267393891402397462143064244`20., 
    848.16165013625411255715267759909881936018`20., 
    846.28524455916050874549653811695431397265`20., 
    844.40802620818073079509014639652634413067`20., 
    842.52999183756067773272312964516595776803`20., 
    840.65113818597219171429509086261564390309`20., 
    838.77146197637057975174022898275951723262`20., 
    836.89095991585072424479355122716697718697`20., 
    835.00962869550176148620550181676427804622`20., 
    833.12746499026030699951256969762324965346`20., 
    831.24446545876220625215360233647916316244`20., 
    829.36062674319278896348537556741314474121`20., 
    827.47594546913560489699128947356268915615`20., 
    825.59041824541961868858333864148168651305`20., 
    823.70404166396484091825383604920784255519`20., 
    821.81681229962637228031848402985339198108`20., 
    819.92872671003683734797964709164777508147`20., 
    818.03978143544718406079607687463163987353`20., 
    816.14997299856582468873546225258167988506`20., 
    814.25929790439609364366620267247482253198`20., 
    812.36775264007199711826645641241081358353`20., 
    810.47533367469222913323803660495675661246`20., 
    808.5820374591524281662508234074885211982`20., 
    806.68786042597564812004515277036771313885`20., 
    804.79279898914101696241460888247009028847`20., 
    802.89684954391055593720355572306663807001`20., 
    801.00000846665413180280057555567041341457`20., 
    799.10227211467251410270285493731362106372`20., 
    797.20363682601850901137363354658369989224`20., 
    795.30409891931614082761521899557849335417`20., 
    793.4036546935778517068277290930895356374`20., 
    791.50230042801968973260634447907082656081`20., 
    789.60003238187445492692874898531391788041`20., 
    787.69684679420277228647440358662264366593`20., 
    785.79273988370206041016650123095447621505`20., 
    783.88770784851336374959725951742746440703`20., 
    781.98174686602601596934206890003899270989`20., 
    780.07485309268010134803527904227531243165`20., 
    778.16702266376668058321017375595364498484`20., 
    776.25825169322574678303062648538063617186`20., 
    774.34853627344187683588710518256301464297`20., 
    772.43787247503754274411237019597572232123`20., 
    770.52625634666404689050164644036625275553`20., 
    768.61368391479004457559931184640054765221`20., 
    766.70015118348761651953186724800479170829`20., 
    764.78565413421585336420913168643820885178`20., 
    762.8701887256019135396573541745042474543`20., 
    760.95375089321951517175523611811355999591`20., 
    759.0363365493648220073733270972109449178`20., 
    757.11794158282968261651585737425684908888`20., 
    755.19856185867218139916885353851294445956`20., 
    753.27819321798445917679619801653814019746`20., 
    751.35683147765776038441249082559726259423`20., 
    749.43447243014466309850370136291401934292`20., 
    747.51111184321844733835808583107780100434`20., 
    745.58674545972955626319366682043153618872`20., 
    743.66136899735910405439590613814329227856`20., 
    741.73497814836938342076908165313696249317`20., 
    739.80756857935132479450381821497923709493`20., 
    737.87913593096885839610483781802677191084`20., 
    735.94967581770012943732760785240583759076`20., 
    734.01918382757551580174679821687577028695`20., 
    732.08765552191239659241580056192664217429`20., 
    730.15508643504661896465294113505255714406`20., 
    728.22147207406060966876933498833499072146`20., 
    726.28680791850807671198299119091258237759`20., 
    724.35108942013524551027520967228193946481`20., 
    722.41431200259857283895344310364275075305`20., 
    720.47647106117888080458754856879753330531`20., 
    718.53756196249185195016408040268474640882`20., 
    716.59758004419482546911821034472944676242`20., 
    714.65652061468983334169852881586938431836`20., 
    712.71437895282281401822059286037145664468`20., 
    710.77115030757894005747491222306354931438`20., 
    708.82682989777399488415778389468183599099`20., 
    706.88141291174173255595141051512479795345`20., 
    704.93489450701715312803351832301409574466`20., 
    702.9872698100156248695639863448610329914`20., 
    701.03853391570778322227113111898259762121`20., 
    699.08868188729013499481336309702678792695`20., 
    697.13770875585129485726801892855514751686`20., 
    695.18560952003377973701749204775549155144`20., 
    693.23237914569128521955581478651108228372`20., 
    691.27801256554136652439143875823654294879`20., 
    689.32250467881344505631039981443318559147`20., 
    687.36585035089205992479508648211207198071`20., 
    685.40804441295528217834366118587364858626`20., 
    683.44908166160820781474843031678031167574`20., 
    681.48895685851144390198007134739658789845`20., 
    679.52766473000450037606675766036888984649`20., 
    677.56519996672399827109606812058717027774`20., 
    675.60155722321660328101014893845406586649`20., 
    673.63673111754659165198049863588630409373`20., 
    671.67071623089795345656882310630378875996`20., 
    669.70350710717093630529541142646598524484`20., 
    667.73509825257293050629566348775722735927`20., 
    665.76548413520359458805503712638082149013`20., 
    663.79465918463411795233456333827869975237`20., 
    661.82261779148051522284891900334091790566`20., 
    659.84935430697084459850484734772310712295`20., 
    657.87486304250624020646805369604679906574`20., 
    655.89913826921564607836895559323757953313`20., 
    653.92217421750413694089616511172019345639`20., 
    651.94396507659470851812069612216825603477`20., 
    649.96450499406341748534602954406415249344`20., 
    647.98378807536774859123270816553401819188`20., 
    646.00180838336808377448324703491176111067`20., 
    644.01855993784214534151257084006245345365`20., 
    642.03403671499228244022388105614039790375`20., 
    640.04823264694546716014455471468576611844`20., 
    638.0611416212458636085653796541286251176`20., 
    636.07275748033983025370975262582171879081`20., 
    634.08307402105321268700189499465923091667`20., 
    632.09208499406078073479018020394879197431`20., 
    630.09978410334766054291686140467916936854`20., 
    628.10616500566260886272731975855190302249`20., 
    626.1112213099629732818106166994476296273`20., 
    624.11494657685117856419716435990097587409`20., 
    622.11733431800257559005210300557931945949`20., 
    620.11837799558448561113905160913900384175`20., 
    618.11807102166626866243021026404182573557`20., 
    616.11640675762024098904067547850393826381`20., 
    614.11337851351326225789187631102108937765`20., 
    612.10897954748880912177078675952999732623`20., 
    610.10320306513934738623798970628206988643`20., 
    608.09604221886881059351446799175517757484`20., 
    606.08749010724498827828071891216984931772`20., 
    604.07753977434162246435468423102861671635`20., 
    602.06618420907000615443968641599753223797`20., 
    600.05341634449987261336748812408427750875`20., 
    598.03922905716935915417114607034723185855`20., 
    596.0236151663838239014168080811347983794`20., 
    594.00656743350328862284884492333058944985`20., 
    591.98807856121827518373447060652221895513`20., 
    589.96814119281379748333102266288009074278`20., 
    587.94674791142126487445582377662912327839`20., 
    585.92389123925804703983767499176782726555`20., 
    583.89956363685444409719344332881240542299`20., 
    581.87375750226779932301779241291226508494`20., 
    579.84646517028348531689708620688207714929`20., 
    577.81767891160248766753237994958222421378`20., 
    575.78739093201530322211852376163134951427`20., 
    573.75559337156186289556898137472730329592`20., 
    571.72227830367718157833579554429647124617`20., 
    569.68743773432243010402169825200369634692`20., 
    567.65106360110111641310949378384817943561`20., 
    565.61314777236005498914580961892453786379`20., 
    563.57368204627479534051337885974771794576`20., 
    561.53265814991917174609439782753847892944`20., 
    559.49006773831862766792467654706791013088`20., 
    557.44590239348695914927870003363947426339`20., 
    555.40015362344611215306571054825829642767`20., 
    553.35281286122865914313906490079128579784`20., 
    551.30387146386257025991766492783698140503`20., 
    549.25332071133788418097383116327348313323`20., 
    547.20115180555487317591543886249147826719`20., 
    545.14735586925328595149548209602042221115`20., 
    543.09192394492224062546867400520412179218`20., 
    541.03484699369032855384562113349992355294`20., 
    538.97611589419547775292608028400479014986`20., 
    536.91572144143411229134839726990591701513`20., 
    534.85365434558913126434174473806007755493`20., 
    532.78990523083621778779972632505427970566`20., 
    530.72446463412797484848917644642479783397`20., 
    528.65732300395537080281161986389428063754`20., 
    526.58847069908596281352646644433873252095`20., 
    524.51789798727835153450758590964288042221`20., 
    522.44559504397230487999201744825492298713`20., 
    520.37155195095397272818092217324380832486`20., 
    518.29575869499559788995802265434908230708`20., 
    516.21820516646911160155088484865816031987`20., 
    514.13888115793298415394812743310807975008`20., 
    512.05777636269168302965275801589637364602`20., 
    509.97488037332707205578464057654922926405`20., 
    507.89018268020106557751747064559271457885`20., 
    505.80367266992883148215952931702997926833`20., 
    503.71533962382181603556077098750110148301`20., 
    501.62517271629984190148025252330341065079`20., 
    499.53316101327150837237922731061809483058`20., 
    497.43929347048209971682983532791560102079`20., 
    495.34355893182818361300783467234073121768`20., 
    493.24594612763805685680991626643326246539`20., 
    491.14644367291716987274864320343948707078`20., 
    489.04504006555763498010898645514665565168`20., 
    486.94172368451089583842881704280802388866`20., 
    484.83648278792260697598684400373834091253`20., 
    482.72930551122874275161734881466791055689`20., 
    480.62017986521192447087568095391697968456`20., 
    478.5090937340169226273878145167924975652`20., 
    476.39603487312425832204333275463617189021`20., 
    474.28099090728079377721009118073479475801`20., 
    472.16394932838616645868204613857037608056`20., 
    470.04489749333388459046093865119999562301`20., 
    467.92382262180586373994630027554337218142`20., 
    465.80071179401914460414174685215713844858`20., 
    463.67555194842349107865079794822684456152`20., 
    461.54832987934852507504415820615028077203`20., 
    459.4190322345990102999149496916437053529`20., 
    457.28764551299685124847619763292438563785`20., 
    455.15415606186832592117669458932437348032`20., 
    453.01855007447502116400602474674700328587`20., 
    450.88081358738688797840388260987338221692`20., 
    448.740932477795780557234160432002170651`20., 
    446.59889246076778708689793193507257310689`20., 
    444.45467908643260241539960609699435531361`20., 
    442.30827773710813242007947016449745736744`20., 
    440.15967362435845720957427394799100884632`20., 
    438.00885178598321504949590198488736799464`20., 
    435.85579708293640099164646849762475695862`20., 
    433.70049419617250348720589155377128852756`20., 
    431.54292762341782864374992225652206207868`20., 
    429.38308167586478510526966424910772416812`20., 
    427.22094047478682264783134824847271466812`20., 
    425.05648794807163433654552339029097155083`20., 
    422.88970782667014532063678467860353021896`20., 
    420.72058364095872087997079704855742955779`20., 
    418.54909871701193199988482896696170968215`20., 
    416.375236172783118347600810186272404256`20., 
    414.19897891418988585668107342176617723542`20., 
    412.02030963110156897554001568951412777063`20., 
    409.83921079322557578938469082980140764749`20., 
    407.65566464588941742649979347212289895688`20., 
    405.46965320571510118673087712041023229592`20., 
    403.28115825618243937430000512548789206258`20., 
    401.09016134307769266341932676712175118017`20., 
    398.89664376982382757724570006028785234888`20., 
    396.70058659268852215540630249131874667221`20., 
    394.50197061586590156028304935321460174536`20., 
    392.30077638642782622295345022964136162213`20., 
    390.09698418914038825548281265566732507086`20., 
    387.89057404114109765804777677645655800363`20., 
    385.68152568647205670356361520595402540914`20., 
    383.46981859046423015830368596119495883582`20., 
    381.25543193396771748848250874315393935278`20., 
    379.03834460742272451737638669922202908485`20., 
    376.81853520476570943062377763931686976882`20., 
    374.59598201716495026575357787351984532896`20., 
    372.37066302657953360677591365680902833434`20., 
    370.14255589913551721360843386880159377184`20., 
    367.91163797831274113201926742789344602841`20., 
    365.67788627793549785062166508766678676213`20., 
    363.4412774749599528537362052895365836384`20., 
    361.20178790205093373104759986227599121376`20., 
    358.95939353994032641013383832162772210672`20., 
    356.71407000955905480940508806046701025479`20., 
    354.46579256393414170721170995428905849036`20., 
    352.21453607984214436971627503246201289557`20., 
    349.96027504920960186332288460464735830314`20., 
    347.7029835702510899348898264823672681281`20., 
    345.44263533833447925732857130169175739087`20., 
    343.17920363656334411727797027320719912431`20., 
    340.91266132606477792533653428183955387638`20., 
    338.64298083597210675316758990728011382135`20., 
    336.37013415308888189205124174427717529669`20., 
    334.09409281122369236759259118230730010755`20., 
    331.81482788017928245750017409599609783708`20., 
    329.53230995438673343598178956453887724263`20., 
    327.24650914116328597871397558019704731579`20., 
    324.95739504858833391114199979506025839203`20., 
    322.66493677296721460774277327730946069614`20., 
    320.36910288588651132121968610813345683425`20., 
    318.06986142081335975609017458664535312292`20., 
    315.76717985926292619476877786283907955319`20., 
    313.46102511645283402396114772745715812332`20., 
    311.15136352651231397093703197231580938261`20., 
    308.83816082709760473966381651476007313877`20., 
    306.52138214357210717135418251975857658093`20., 
    304.20099197246803504283794950212229223553`20., 
    301.87695416457387250775122444435441442022`20., 
    299.54923190709431803768835420243609657215`20., 
    297.21778770560321791372265262858387312136`20., 
    294.88258336469673316035252169667606560873`20., 
    292.54357996882189581233453016253534234133`20., 
    290.20073786111537998327260880894699957461`20., 
    287.85401662322928638838288800271072425529`20., 
    285.5033750518587286603649520912957508766`20., 
    283.14877113791368945370719518829434294222`20., 
    280.79016203988462731120144717586511141618`20., 
    278.42750406315917957757603157288922049789`20., 
    276.06075262870862214837784184231359588752`20., 
    273.68986225422218779978192127567918925844`20., 
    271.31478651534219385722642680395254222823`20., 
    268.93547803196296941145937363435692778523`20., 
    266.55188841688531380593456202113607478173`20., 
    264.16396827379849659516751201970676627251`20., 
    261.77166712381843764798145635499351450464`20., 
    259.37493342762096019719147407365520550412`20., 
    256.97371447214011787041219644192237209914`20., 
    254.56795644038378857182121980512743314105`20., 
    252.15760422545477526473330228745006860923`20., 
    249.74260159197658070004442944892795282047`20., 
    247.32289085690177120750233698415881105049`20., 
    244.89841322377131767027607060302768873248`20., 
    242.46910821939457844368051979122224640046`20., 
    240.03491434980290287425438648070144519316`20., 
    237.59576809095915496206102232319463194844`20., 
    235.15160513692534986409306761302926294858`20., 
    232.70235857995954798308400350138776484967`20., 
    230.24796123844028350991135924459406945171`20., 
    227.78834237259028661187157414358225280749`20., 
    225.32343196361136918455467777092888404315`20., 
    222.8531548020822550497886073480276496345`20., 
    220.37743826315178228434410992840289801236`20., 
    217.89620171545073794751154617951853675659`20., 
    215.40937050821539625835138685506398031784`20., 
    212.916857109089060862818054659110201151`20., 
    210.41858603767986385212825906915272835219`20., 
    207.9144604987711191426314458275868118663`20., 
    205.40440644567160023345315894488452221639`20., 
    202.88831398224609730418990617013935879959`20., 
    200.36611457850691162474538254385563318875`20., 
    197.83767894300531187764654968850194398136`20., 
    195.30295120776148696505025695558727127165`20., 
    192.76177233118156319767062425953906886815`20., 
    190.21411134440470207317998191188383256649`20., 
    187.65976244084424545959200057764509497365`20., 
    185.09874015836406295534721499943795406564`20., 
    182.53076408078475441466985847791898997674`20., 
    179.95592846919329752447977880907439220689`20., 
    177.37383300645954795317740367206740684777`20., 
    174.78470777751222699328297072659440137817`20., 
    172.18795944185023198752735543763212863539`20., 
    169.58404481441575298837803528319321370732`20., 
    166.97206046894998421464843676939092947903`20., 
    164.35283559778969260652721903771780544424`20., 
    161.72497099635582466609467911778906352276`20., 
    159.08989900051232893052549502240004924368`20., 
    156.44543293377904511044203403661550684507`20., 
    153.79396985462516526593719249726118473941`20., 
    151.13208209296910168366068771009469357945`20., 
    148.46369163392333991161450397625873653129`20., 
    145.78343220476210622816892885687790510912`20., 
    143.09760876670984967019546806442162287969`20., 
    140.3978552846181808583204639293528508277`20., 
    137.69415861480481300460190739227780585111`20., 
    134.97355739377622465915586383386365805622`20., 
    132.25166308652965293336001446889964903888`20., 
    129.50854862875705689401932933498652411158`20., 
    126.76831968468851292253967639986856066385`20., 
    124.00060592489511872545499472635904882276`20., 
    121.24219145481355600723421239329219187347`20., 
    118.44722696919707397055778435006281215177`20., 
    115.67119469103361348755334617109647707464`20., 
    112.84557315711044748557371527298738057378`20., 
    110.0530822381286510073311443218033172838`20., 
    107.19239903835284370177075246681655660431`20., 
    104.38541863323189583395266055705996691883`20., 
    101.483964965925251794856546168673610236`20., 
    98.66554100251522495102705805527657297781`20., 
    95.7159284879343532506728223864047965033`20., 
    92.8904964982917440580201855284772312736`20., 
    89.88320805984141096998830194535322447649`20., 
    87.05694327944009360555970098281918285205`20., 
    83.97980932920735262155754850572007502976`20., 
    81.1609981097789586351847651112700453536`20., 
    77.99859857700147786848219213943922302444`20., 
    75.19801044019067104904056927858320998581`20., 
    71.930998149113428787889283790150398007`20., 
    69.16224113115691242712663215947960087315`20., 
    65.76656157706440482223039025356865262752`20., 
    63.04642318348171881828544632350204864657`20., 
    59.49235481866828529841804469739326708057`20., 
    56.84117774459522201669589154941110021565`20., 
    53.09200972912564907672296030903008322075`20., 
    50.53424031449418162021265516944723300253`20., 
    46.54419057453375856620456678161567865093`20., 
    44.10939793077697670403350818623262317125`20., 
    39.81992822973490434214829128387814889337`20., 
    37.54490675573525890194924261583290920796`20., 
    32.87753724949052630659269662118730131152`20., 
    30.81085525106772533672560132434387462692`20., 
    25.65156724481855300618993681670909524422`20., 
    23.86417587765481876896346676120164231107`20., 
    18.023290466471560252303674828128326441`20., 
    16.63772718860587230922249302056606775384`20., 
    9.70406052783923433184124970041447195306`20., 
    9.01091334727928902242401757895629538498`20., 
    DirectedInfinity[-1], 
    0.6931471805599453094172321214581765680747545421319511512698`20.}],
  Editable->False]], "Print",
 CellChangeTimes->{3.499820515928492*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 656},
WindowMargins->{{Automatic, 157}, {-2, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 555, 17, 134, "Title"],
Cell[1125, 41, 2863, 68, 536, "Text"],
Cell[CellGroupData[{
Cell[4013, 113, 22952, 663, 1288, "Input"],
Cell[26968, 778, 54262, 898, 249, 47285, 782, "CachedBoxData", "BoxData", \
"Output"],
Cell[81233, 1678, 5803, 102, 252, "Output"],
Cell[87039, 1782, 6347, 111, 265, "Output"],
Cell[93389, 1895, 472643, 8201, 20496, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
